@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -68,9 +66,10 @@ static AtomicInt errorCount(0);
 /**
   Thread Parameters Class
 */
-class T_Parms{
-   public:
-    AutoPtr<CIMClient> client; //PEP101
+class T_Parms
+{
+public:
+    CIMClient* client;
     int verboseTest;
     int activeTest;
     int testCount;
@@ -137,7 +136,7 @@ static void TestNameSpaceOperations(CIMClient* client, Boolean activeTest,
         {
             // Get the next increment in naming for all a name element in the
             // array
-            Array<CIMInstance> instances = 
+            Array<CIMInstance> instances =
                 client->enumerateInstances(namespaceNames[range], className);
             for (Uint32 i = 0 ; i < instances.size(); i++)
             {
@@ -163,7 +162,7 @@ static void TestNameSpaceOperations(CIMClient* client, Boolean activeTest,
         }
     }
     while (start != end);
-    // Validate that all of the returned entities are really namespaces. 
+    // Validate that all of the returned entities are really namespaces.
     // It is legal for us to have an name component that is really not a
     // namespace (ex. root/fred/john is a namespace
     // but root/fred is not.
@@ -191,7 +190,7 @@ static void TestNameSpaceOperations(CIMClient* client, Boolean activeTest,
     cout << returnNamespaces.size() << " namespaces " << " returned." << endl;
     for( Uint32 cnt = 0 ; cnt < returnNamespaces.size(); cnt++ )
     {
-        cout << returnNamespaces[cnt] << endl;;
+        cout << returnNamespaces[cnt].getString() << endl;;
     }
 
     // ATTN: The following code is probably no good. KS April 2003
@@ -228,7 +227,7 @@ static void TestNameSpaceOperations(CIMClient* client, Boolean activeTest,
         CIMInstance newInstance(name);
             newInstance.addProperty(
                 CIMProperty(CIMName ("name"), testNamespaceName.getString()));
-            newInstanceName = 
+            newInstanceName =
                 client->createInstance(__NAMESPACE_NAMESPACE, newInstance);
         }
         catch(CIMException& e)
@@ -248,7 +247,7 @@ static void TestNameSpaceOperations(CIMClient* client, Boolean activeTest,
         }
         catch(Exception& e)
         {
-            PEGASUS_STD(cerr) << "Exception NameSpace Creation: " 
+            PEGASUS_STD(cerr) << "Exception NameSpace Creation: "
                 << e.getMessage() << PEGASUS_STD(endl);
             errorCount++;
             return;
@@ -301,7 +300,7 @@ static void TestEnumerateClassNames (CIMClient* client, Boolean activeTest,
          if (verboseTest)
          {
              for (Uint32 i = 0, n = classNames.size(); i < n; i++)
-                 cout << classNames[i] << endl;
+                 cout << classNames[i].getString() << endl;
          }
 
          cout << classNames.size() << " ClassNames" << endl;
@@ -334,8 +333,8 @@ static void TestClassOperations(CIMClient* client, Boolean ActiveTest,
     {
         if (verboseTest)
         {
-            cout << "Test to create, modify and delete test class " 
-                << testClass << endl;
+            cout << "Test to create, modify and delete test class "
+                << testClass.getString() << endl;
         }
         for (Uint32 i = 0; i < classNames.size(); i++)
         {
@@ -346,7 +345,8 @@ static void TestClassOperations(CIMClient* client, Boolean ActiveTest,
                  }
                 catch (CIMException& e)
                 {
-                        cout << "TestClass " << testClass << " delete failed " 
+                        cout << "TestClass " << testClass.getString()
+                            << " delete failed "
                             << e.getMessage() << endl;
                         errorCount++;
                         return;
@@ -367,11 +367,12 @@ static void TestClassOperations(CIMClient* client, Boolean ActiveTest,
         {
             CIMStatusCode code = e.getCode();
             if (code == CIM_ERR_ALREADY_EXISTS)
-                cout << "TestClass " << testClass 
+                cout << "TestClass " << testClass.getString()
                     << " already exists during create " << endl;
             else
             {
-                cout << "TestClass " << testClass << " create failed " 
+                cout << "TestClass " << testClass.getString()
+                    << " create failed "
                     <<  e.getMessage() << endl;
                 errorCount++;
                 return;
@@ -426,7 +427,8 @@ static void TestClassOperations(CIMClient* client, Boolean ActiveTest,
         }
         if (!found)
         {
-            cout << "Test Class " << testClass << " Not found in enumeration " 
+            cout << "Test Class " << testClass.getString()
+                << " Not found in enumeration "
                 << endl;
             errorCount++;
             return;
@@ -472,14 +474,14 @@ static void TestClassOperations(CIMClient* client, Boolean ActiveTest,
 static void TestQualifierOperations(CIMClient* client, Boolean activeTest,
                          Boolean verboseTest, String uniqueID) {
 
-    Array<CIMQualifierDecl> qualifierDecls = 
+    Array<CIMQualifierDecl> qualifierDecls =
         client->enumerateQualifiers(globalNamespace);
 
     if (verboseTest)
     {
          for (Uint32 i = 0; i < qualifierDecls.size(); i++)
          {
-           cout << qualifierDecls[i].getName() << endl;
+             cout << qualifierDecls[i].getName().getString() << endl;
          }
 
     }
@@ -505,18 +507,17 @@ static void TestQualifierOperations(CIMClient* client, Boolean activeTest,
 
          // Get them and compare:
 
-         CIMQualifierDecl tmp1 = 
+         CIMQualifierDecl tmp1 =
              client->getQualifier(globalNamespace, qd1_name);
          PEGASUS_TEST_ASSERT(tmp1.identical(qd1));
 
-         CIMQualifierDecl tmp2 = 
+         CIMQualifierDecl tmp2 =
              client->getQualifier(globalNamespace, qd2_name);
          PEGASUS_TEST_ASSERT(tmp2.identical(qd2));
 
          // Enumerate the qualifiers:
 
-         Array<CIMQualifierDecl> qualifierDecls = 
-             client->enumerateQualifiers(globalNamespace);
+         qualifierDecls = client->enumerateQualifiers(globalNamespace);
 
          for (Uint32 i = 0; i < qualifierDecls.size(); i++)
          {
@@ -550,7 +551,7 @@ static Boolean lookupError(const String& ignoreErrors, CIMStatusCode lookupCode)
         Uint32 pos = ignoreErrors.find(startPos, ERROR_DELIMETER);
         if (pos == PEG_NOT_FOUND)
         {
-            pos = strSize; 
+            pos = strSize;
         }
 
         String errorStr = ignoreErrors.subString(startPos, pos - startPos);
@@ -594,13 +595,11 @@ static void TestInstanceGetOperations(CIMClient* client, Boolean activeTest,
        //{
            try
            {
-               instanceNames = 
+               instanceNames =
                   client->enumerateInstanceNames(globalNamespace,classNames[i]);
                if (instanceNames.size() > 0)
-               {
-                   cout << "Class " << classNames[i] << " "
+                   cout << "Class " << classNames[i].getString() << " "
                         << instanceNames.size() << " Instances" << endl;
-               }
            }
            catch(CIMException& e)
            {
@@ -616,7 +615,8 @@ static void TestInstanceGetOperations(CIMClient* client, Boolean activeTest,
                  }
                  else
                  {
-                    cerr << "CIMException : " << classNames[i] << endl;
+                    cerr << "CIMException : " << classNames[i].getString()
+                         << endl;
                     cerr << e.getMessage() << endl;
                     errorCount++;
                     return;
@@ -624,13 +624,13 @@ static void TestInstanceGetOperations(CIMClient* client, Boolean activeTest,
            }
        catch(ConnectionTimeoutException& e)
        {
-           PEGASUS_STD(cerr) << "Warning: " << e.getMessage() 
+           PEGASUS_STD(cerr) << "Warning: " << e.getMessage()
                << PEGASUS_STD(endl);
            exit(2);
        }
        catch(Exception& e)
        {
-           PEGASUS_STD(cerr) << "Error: " << e.getMessage() 
+           PEGASUS_STD(cerr) << "Error: " << e.getMessage()
                << PEGASUS_STD(endl);
            exit(1);
        }
@@ -695,7 +695,7 @@ static void TestInstanceModifyOperations(CIMClient* client, Boolean
     client->createClass(globalNamespace, cimClass);
 
     // Create an instance of that class:
-    cout << "Create one Instance of class " << className << endl;
+    cout << "Create one Instance of class " << className.getString() << endl;
 
     CIMInstance cimInstance(className);
     cimInstance.addProperty(CIMProperty(CIMName ("last"), String("Smith")));
@@ -807,8 +807,8 @@ static void testRefandAssoc(CIMClient* client, CIMNamespaceName& nameSpace,
 
     if (verboseTest)
     {
-        cout << "Test references results for class: " 
-            << objectName.getClassName()
+        cout << "Test references results for class: "
+            << objectName.getClassName().getString()
             << " returned " << result.size() << "reference names" << endl;
     }
     if (result.size() != resultObjects.size())
@@ -871,8 +871,8 @@ static void testRefandAssoc(CIMClient* client, CIMNamespaceName& nameSpace,
 
     if (verboseTest)
     {
-        cout << "Test associations results for class: " 
-            << objectName.getClassName()
+        cout << "Test associations results for class: "
+            << objectName.getClassName().getString()
             << " returned " << result.size() << "associator names" << endl;
     }
     if (assocResult.size() != assocResultObjects.size())
@@ -890,13 +890,13 @@ static void testRefandAssoc(CIMClient* client, CIMNamespaceName& nameSpace,
 
         for (Uint32 i = 0 ; i < maxCount ; i ++)
         {
-            cout << i << " " 
-                << ((i < assocResult.size())? assocResult[i].toString() : "") 
+            cout << i << " "
+                << ((i < assocResult.size())? assocResult[i].toString() : "")
                 << endl;
 
-            cout << i << " " 
-                << ((i < assocResultObjects.size())? 
-                        assocResultObjects[i].getPath().toString() : "") 
+            cout << i << " "
+                << ((i < assocResultObjects.size())?
+                        assocResultObjects[i].getPath().toString() : "")
                 << endl;
         }
         errorCount++;
@@ -909,7 +909,7 @@ static void testRefandAssoc(CIMClient* client, CIMNamespaceName& nameSpace,
       Uint32 matched=0;
       for (Uint32 j = 0; j < assocResult.size(); j++)
       {
-        if (assocResultObjects[i].getPath().toString() == 
+        if (assocResultObjects[i].getPath().toString() ==
                 assocResult[j].toString())
         {
            matched=1;
@@ -952,17 +952,17 @@ static void TestAssociationOperations(CIMClient* client, Boolean
         CIMObjectPath o1("CIM_ManagedElement");
         CIMObjectPath o2("CIM_ManagedElement.name=\"karl\"");
 
-        testRefandAssoc(client, globalNamespace, verboseTest, o1, 
+        testRefandAssoc(client, globalNamespace, verboseTest, o1,
             CIMName(), CIMName());
         try
         {
-            testRefandAssoc(client, globalNamespace, verboseTest, 
+            testRefandAssoc(client, globalNamespace, verboseTest,
                 o2, CIMName(), CIMName());
         }
         catch(CIMException& e)
         {
             // This test will get a not supported exception in the case where
-            // the repository is not the default instance provider. 
+            // the repository is not the default instance provider.
             // We should not flag this as a test error.
             if (e.getCode() == CIM_ERR_NOT_SUPPORTED)
             {
@@ -981,14 +981,14 @@ static void TestAssociationOperations(CIMClient* client, Boolean
         }
         catch(CIMException& e)
         {
-              if (e.getCode() == CIM_ERR_INVALID_NAMESPACE 
+              if (e.getCode() == CIM_ERR_INVALID_NAMESPACE
                       || e.getCode() == CIM_ERR_INVALID_CLASS)
               {
                  runTest = false;
               }
               else
               {
-                 cerr << "CIMException : " << className << endl;
+                 cerr << "CIMException : " << className.getString() << endl;
                  cerr << e.getMessage() << endl;
                  errorCount++;
                  return;
@@ -999,20 +999,20 @@ static void TestAssociationOperations(CIMClient* client, Boolean
     {
 
         CIMObjectPath TST_PersonClass= CIMObjectPath("TST_Person");
-        CIMObjectPath TST_PersonInstance = 
+        CIMObjectPath TST_PersonInstance =
             CIMObjectPath( "TST_Person.name=\"Mike\"");
-        CIMObjectPath TST_PersonDynamicClass = 
+        CIMObjectPath TST_PersonDynamicClass =
             CIMObjectPath("TST_PersonDynamic");
-        CIMObjectPath TST_PersonDynamicInstance = 
+        CIMObjectPath TST_PersonDynamicInstance =
             CIMObjectPath( "TST_PersonDynamic.name=\"Father\"");
 
-        testRefandAssoc(client, nameSpace, verboseTest, TST_PersonClass , 
+        testRefandAssoc(client, nameSpace, verboseTest, TST_PersonClass ,
                 CIMName(), CIMName());
-        testRefandAssoc(client, nameSpace, verboseTest, TST_PersonInstance , 
+        testRefandAssoc(client, nameSpace, verboseTest, TST_PersonInstance ,
                 CIMName(), CIMName());
-        testRefandAssoc(client, nameSpace, verboseTest, 
+        testRefandAssoc(client, nameSpace, verboseTest,
                 TST_PersonDynamicClass , CIMName(), CIMName());
-        testRefandAssoc(client, nameSpace, verboseTest, 
+        testRefandAssoc(client, nameSpace, verboseTest,
                 TST_PersonDynamicInstance , CIMName(), CIMName());
     }
 
@@ -1083,10 +1083,10 @@ static void TestInvokeMethod(
                 if (verboseTest)
                 {
                     cout << "Output: " << retValue.toString() << endl;
-                    for (Uint32 i = 0; i < outParams.size(); i++)
+                    for (Uint32 j = 0; j < outParams.size(); j++)
                     {
-                        cout << outParams[i].getParameterName() << ": " <<
-                            outParams[i].getValue().toString() << endl;
+                        cout << outParams[j].getParameterName() << ": " <<
+                            outParams[j].getValue().toString() << endl;
                     }
                 }
 
@@ -1144,26 +1144,26 @@ static void TestEnumerateInstances( CIMClient * client,
                       localOnly,  includeQualifiers,
                       includeClassOrigin );
 
-      cout << "Found " << cimNInstances.size() << " Instances of " 
-          << className << endl;
+      cout << "Found " << cimNInstances.size() << " Instances of "
+          << className.getString() << endl;
       //ASSERTTEMP(cimNInstances.size() == 3);
       numberInstances =  cimNInstances.size();
 
-      for (Uint32 i = 0; i < cimNInstances.size(); i++)
+      for (Uint32 j = 0; j < cimNInstances.size(); j++)
       {
-          CIMObjectPath instanceRef = cimNInstances[i].getPath();
+          CIMObjectPath instanceRef = cimNInstances[j].getPath();
 
           if((instanceRef != INSTANCE0) &&
              (instanceRef != INSTANCE1) &&
              (instanceRef != INSTANCE2))
           {
-              PEGASUS_STD(cerr) 
+              PEGASUS_STD(cerr)
                   << "Error: EnumInstances failed. Instance Name Error"
                   << " Expected instance name = "
                   << INSTANCE0.toString() << " or "
                   << INSTANCE1.toString() << " or "
                   << INSTANCE2.toString()
-                  << "received = " << instanceRef.toString() 
+                  << "received = " << instanceRef.toString()
                   << PEGASUS_STD(endl);
 
               errorCount++;
@@ -1171,7 +1171,7 @@ static void TestEnumerateInstances( CIMClient * client,
           }
         }
     }
-      cout << "Enumerate " << numberInstances << " instances " << testRepeat 
+      cout << "Enumerate " << numberInstances << " instances " << testRepeat
           << " times" << endl;
     }
   catch(Exception& e)
@@ -1275,11 +1275,11 @@ void GetOptions(
 }
 
 
-ThreadReturnType PEGASUS_THREAD_CDECL executeTests(void *parm){
-
+ThreadReturnType PEGASUS_THREAD_CDECL executeTests(void *parm)
+{
     Thread *my_thread = (Thread *)parm;
-    T_Parms *parms = (T_Parms *)my_thread->get_parm();
-    CIMClient *client = parms->client.get();
+    AutoPtr<T_Parms> parms((T_Parms *)my_thread->get_parm());
+    CIMClient* client = parms->client;
     Uint32 testCount = parms->testCount;
     Boolean verboseTest = parms->verboseTest == 0 ? false : true;
     Boolean activeTest = parms->activeTest == 0 ? false : true;
@@ -1326,7 +1326,7 @@ ThreadReturnType PEGASUS_THREAD_CDECL executeTests(void *parm){
         testStart("Test Instance Get Operations");
         elapsedTime.reset();
         elapsedTime.start();
-        TestInstanceGetOperations(client,activeTest,verboseTest, uniqueID, 
+        TestInstanceGetOperations(client,activeTest,verboseTest, uniqueID,
             ignoreErrors);
         elapsedTime.stop();
         testEnd(elapsedTime.getElapsed());
@@ -1363,25 +1363,29 @@ ThreadReturnType PEGASUS_THREAD_CDECL executeTests(void *parm){
       errorCount++;
     }
     }
-    my_thread->exit_self((ThreadReturnType)5);
-    return(0);
+    return ThreadReturnType(0);
 }
 
-Thread * runTests(CIMClient *client, Uint32 testCount, Boolean activeTest, 
-        Boolean verboseTest, int uniqueID, String ignoreErrors){
-        // package parameters, create thread and run...
-        AutoPtr<T_Parms> parms(new T_Parms());
-        parms->client.reset(client);
-        parms->testCount = testCount;
-        parms->activeTest = (activeTest) ? 1 : 0;
-        parms->verboseTest = (verboseTest) ? 1 : 0;
-        parms->uniqueID = uniqueID;
-        parms->ignoreErrors = ignoreErrors;
-        AutoPtr<Thread> t(new Thread(executeTests, (void*)parms.release(), 
-                    false));
+Thread* runTests(
+    CIMClient* client,
+    Uint32 testCount,
+    Boolean activeTest,
+    Boolean verboseTest,
+    int uniqueID,
+    String ignoreErrors)
+{
+    // package parameters, create thread and run...
+    AutoPtr<T_Parms> parms(new T_Parms());
+    parms->client = client;
+    parms->testCount = testCount;
+    parms->activeTest = (activeTest) ? 1 : 0;
+    parms->verboseTest = (verboseTest) ? 1 : 0;
+    parms->uniqueID = uniqueID;
+    parms->ignoreErrors = ignoreErrors;
+    AutoPtr<Thread> t(new Thread(executeTests, (void*)parms.release(), false));
 
     // zzzzz... (1 second) zzzzz...
-        Threads::sleep(1000);
+    Threads::sleep(1000);
     t->run();
     return t.release();
 }
@@ -1425,10 +1429,10 @@ void connectClient(
                 SSLContext sslcontext(
                     trustpath, verifyCertificate, randFile);
 
-                cout << "connecting to " << host << ":" << portNumber 
+                cout << "connecting to " << host << ":" << portNumber
                     << " using SSL" << endl;
 
-                client->connect (host, portNumber, sslcontext, userName, 
+                client->connect (host, portNumber, sslcontext, userName,
                         password);
             }
 #else
@@ -1470,26 +1474,11 @@ void connectClient(
 
 int main(int argc, char** argv)
 {
-
-  // char connection[50] = "localhost:5988";
-  char *address_string = NULL;
-
-    Uint32 repetitions = 1;
-
-    // Get environment variables:
-
-    String pegasusHome;
-    pegasusHome = "/";
-    // GetEnvironmentVariables(argv[0], pegasusHome);
-
-    // Get options (from command line and from configuration file); this
-    // removes corresponding options and their arguments fromt he command
-    // line.
-
     // Get options (from command line and from configuration file); this
     // removes corresponding options and their arguments fromt he command
     // line.
 
+    String pegasusHome = "/";
     OptionManager om;
 
     try
@@ -1505,16 +1494,16 @@ int main(int argc, char** argv)
     // Check to see if user asked for help (-h otpion):
     if (om.valueEquals("help", "true"))
     {
-                String header = "Usage ";
-                header.append(argv[0]);
-                header.append(" -parameters host [host]");
+        String header = "Usage ";
+        header.append(argv[0]);
+        header.append(" -parameters host [host]");
 
-                String trailer = "Assumes localhost:5988 if host not specified";
-                trailer.append("\nHost may be of the form name or name:port");
-                trailer.append("\nPort 5988 assumed if port number missing.");
-                om.printOptionsHelpTxt(header, trailer);
+        String trailer = "Assumes localhost:5988 if host not specified";
+        trailer.append("\nHost may be of the form name or name:port");
+        trailer.append("\nPort 5988 assumed if port number missing.");
+        om.printOptionsHelpTxt(header, trailer);
 
-         exit(0);
+        exit(0);
     }
     if (om.valueEquals("version","true"))
     {
@@ -1527,12 +1516,12 @@ int main(int argc, char** argv)
     om.lookupValue("namespace", tmp);
     CIMNamespaceName localNameSpace = CIMNamespaceName (tmp);
     globalNamespace = localNameSpace;
-    cout << "Namespace = " << localNameSpace << endl;
+    cout << "Namespace = " << localNameSpace.getString() << endl;
 
     Boolean verboseTest = om.isTrue("verbose");
 
 
-    // Set up number of test repetitions.  
+    // Set up number of test repetitions.
     // Will repeat entire test this number of times
     // Default is zero
     // String repeats;
@@ -1571,26 +1560,36 @@ int main(int argc, char** argv)
        cout << "ignoreErrors = " << ignoreErrors << endl;
     }
 
-    Boolean useSLP =  false;
     Boolean localConnection = (om.valueEquals("local", "true"))? true: false;
     Boolean useSSL =  om.isTrue("ssl");
 
-     Array<String> connectionList;
-    if (argc > 1 && !localConnection)
-                 for (Sint32 i = 1; i < argc; i++)
-                     connectionList.append(argv[i]);
-
-    // setup default connection definitions if needed
-    if (useSSL)
+    if ((argc > 2) || (localConnection && (argc > 1)))
     {
+        cerr << argv[0] << ": Error:  Multiple targets specified." << endl;
+        exit(1);
+    }
+
+    String connectionTarget;
+
+    if (argc > 1)
+    {
+        connectionTarget = argv[1];
+    }
+    else
+    {
+        if (useSSL)
+        {
 #ifdef PEGASUS_HAS_SSL
-        connectionList.append("localhost:5989");
+            connectionTarget = "localhost:5989";
 #else
-        PEGASUS_ASSERT(false);
+            PEGASUS_ASSERT(false);
 #endif
+        }
+        else
+        {
+            connectionTarget = "localhost:5988";
+        }
     }
-    else if(useSLP == false && argc < 2)
-        connectionList.append("localhost:5988");
 
     // timeout
     Uint32 timeout = 30000;
@@ -1600,67 +1599,64 @@ int main(int argc, char** argv)
     Uint32 clients = 1;
     om.lookupIntegerValue("simultaneous",clients);
 
-    String host;
-    Uint32 portNumber;
-    for (Uint32 i = 0; i < connectionList.size(); i++)
-    {
     // ----------------------------------------
-        // * Get host and port number from hostport
-        // ----------------------------------------
-        HostLocator addr(connectionList[i]);
-        String host = addr.getHost();
-        Uint32 portNumber = 0;
-        if (addr.isPortSpecified())
-        {
-            portNumber = addr.getPort();
-        }
+    // * Get host and port number from hostport
+    // ----------------------------------------
+    HostLocator addr(connectionTarget);
+    String host = addr.getHost();
+    Uint32 portNumber = 0;
+    if (addr.isPortSpecified())
+    {
+        portNumber = addr.getPort();
+    }
 
-        Array<CIMClient*> clientConnections;
+    Array<CIMClient*> clientConnections;
 
-        CIMClient* client;
-        for(Uint32 i = 0; i < clients; i++)
-        {
-            client = new CIMClient();
-            clientConnections.append(client);
-        }
+    CIMClient* client;
+    for (Uint32 i = 0; i < clients; i++)
+    {
+        client = new CIMClient();
+        clientConnections.append(client);
+    }
 
-        // connect the clients
-        for(Uint32 i=0; i<clients; i++)
-        {
-            connectClient(clientConnections[i], host, portNumber, userName, 
-                password, useSSL, localConnection, timeout);
-        }
+    // connect the clients
+    for (Uint32 i = 0; i < clients; i++)
+    {
+        connectClient(clientConnections[i], host, portNumber, userName,
+            password, useSSL, localConnection, timeout);
+    }
 
-        // run tests
-        Array<Thread *> clientThreads;
-        Stopwatch elapsedTime;
-        testStart("Begin tests...");
-        elapsedTime.reset();
-        elapsedTime.start();
+    // run tests
+    Array<Thread *> clientThreads;
+    Stopwatch elapsedTime;
+    testStart("Begin tests...");
+    elapsedTime.reset();
+    elapsedTime.start();
 
-        for(Uint32 i=0; i< clientConnections.size(); i++)
-        {
-            clientThreads.append(runTests(clientConnections[i], 
-                        repeatTestCount, activeTest, verboseTest, i,
-                        ignoreErrors));
-        }
+    for (Uint32 i = 0; i < clientConnections.size(); i++)
+    {
+        clientThreads.append(runTests(
+            clientConnections[i], repeatTestCount, activeTest, verboseTest, i,
+               ignoreErrors));
+    }
 
-        for(Uint32 i=0; i< clientThreads.size(); i++)
-        {
-            clientThreads[i]->join();
-        }
-      
-        cout << "+++++ Overall time taken for the operation +++++" << endl;
-        elapsedTime.stop();
-        testEnd(elapsedTime.getElapsed());
+    for (Uint32 i = 0; i < clientThreads.size(); i++)
+    {
+        clientThreads[i]->join();
+    }
 
-        // clean up
-        for(Uint32 i=0; i< clientConnections.size(); i++){
-        if(clientConnections[i]) delete clientConnections[i];
-        }
-            for(Uint32 i=0; i < clientThreads.size(); i++){
-                if(clientThreads[i]) delete clientThreads[i];
-        }
+    cout << "+++++ Overall time taken for the operation +++++" << endl;
+    elapsedTime.stop();
+    testEnd(elapsedTime.getElapsed());
+
+    // clean up
+    for (Uint32 i = 0; i< clientConnections.size(); i++)
+    {
+        delete clientConnections[i];
+    }
+    for (Uint32 i = 0; i < clientThreads.size(); i++)
+    {
+        delete clientThreads[i];
     }
 
     if (errorCount.get() == 0)
