@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 //
@@ -313,7 +311,7 @@ String benchmarkTestCommand::_promptForPassword( ostream& outPrintWriter )
 #ifdef PEGASUS_SSL_RANDOMFILE
         randFile = FileSystem::getAbsolutePath(
              pegasusHome, PEGASUS_SSLCLIENT_RANDOMFILE);
-#endif 
+#endif
         SSLContext  sslcontext (certpath, verifyCertificate, randFile);
 
         if (!_userNameSet)
@@ -328,7 +326,7 @@ String benchmarkTestCommand::_promptForPassword( ostream& outPrintWriter )
         client.connect(host, portNumber, sslcontext,  _userName, _password );
 #else
         PEGASUS_ASSERT(false);
-#endif  
+#endif
     }
     else
     {
@@ -354,13 +352,11 @@ String benchmarkTestCommand::_promptForPassword( ostream& outPrintWriter )
  */
 void benchmarkTestCommand::setCommand (Uint32 argc, char* argv [])
 {
-    Uint32         i              = 0;
-    Uint32         c              = 0;
-    String         httpVersion    = String ();
-    String         httpMethod     = String ();
-    String         timeoutStr     = String ();
-    String         GetOptString   = String ();
-    getoopt        getOpts;
+    String httpVersion;
+    String httpMethod;
+    String timeoutStr;
+    String GetOptString;
+    getoopt getOpts;
 
     //
     //  Construct GetOptString
@@ -404,7 +400,7 @@ void benchmarkTestCommand::setCommand (Uint32 argc, char* argv [])
     //
     //  Get options and arguments from the command line
     //
-    for (i =  getOpts.first (); i <  getOpts.last (); i++)
+    for (Uint32 i = getOpts.first(); i < getOpts.last(); i++)
     {
         if (getOpts [i].getType () == Optarg::LONGFLAG)
         {
@@ -416,7 +412,7 @@ void benchmarkTestCommand::setCommand (Uint32 argc, char* argv [])
         }
         else /* getOpts [i].getType () == FLAG */
         {
-            c = getOpts [i].getopt () [0];
+            Uint32 c = getOpts [i].getopt () [0];
 
             switch (c)
             {
@@ -609,7 +605,7 @@ void benchmarkTestCommand::setCommand (Uint32 argc, char* argv [])
                         //
                         //  Invalid debug option
                         //
-                        throw InvalidOptionArgumentException( 
+                        throw InvalidOptionArgumentException(
                             debugOptionStr,
                             _OPTION_DEBUG);
                     }
@@ -676,7 +672,7 @@ void benchmarkTestCommand::setCommand (Uint32 argc, char* argv [])
     }
     else
     {
-        if (_timeout <= 0)
+        if (_timeout == 0)
         {
             //
             //  Timeout out of valid range
@@ -1461,7 +1457,7 @@ Uint32 benchmarkTestCommand::execute (ostream& outPrintWriter,
 
         if (_generateReport)
         {
-             benchmarkTestCommand::_getSystemConfiguration( 
+             benchmarkTestCommand::_getSystemConfiguration(
                  outPrintWriter, errPrintWriter);
         }
 
@@ -1499,7 +1495,7 @@ Uint32 benchmarkTestCommand::execute (ostream& outPrintWriter,
                        (const char *)_startTime.getCString());
                }
             }
-    
+
             testID++;
             if (!_testIDSet || (testID == _testID))
             {
