@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -82,7 +80,7 @@ static const CIMName PROPERTY_NAME_USERNAME        = CIMName ("Username");
 static const CIMName PROPERTY_NAME_NAMESPACE       = CIMName ("Namespace");
 
 /**
-    This constant represents the name of the authorizations property in 
+    This constant represents the name of the authorizations property in
     the schema
 */
 static const CIMName PROPERTY_NAME_AUTHORIZATION   = CIMName ("Authorization");
@@ -93,11 +91,6 @@ static const CIMName PROPERTY_NAME_AUTHORIZATION   = CIMName ("Authorization");
 */
 static const char USAGE []                        = "Usage: ";
 
-/**
-    This constant represents the getoopt argument designator
-*/
-static const char GETOPT_ARGUMENT_DESIGNATOR      = ':';
-
 /*
     These constants represent the operation modes supported by the CLI.
     Any new operation should be added here.
@@ -158,12 +151,6 @@ static const char CIMOM_NOT_RUNNING [] =
 static const char CIMOM_NOT_RUNNING_KEY [] =
     "Clients.cimauth.CIMAuthCommand.CIMOM_NOT_RUNNING";
 
-static const char FILE_NOT_READABLE [] =
-    "Unable to read the config file.";
-
-static const char FILE_NOT_READABLE_KEY [] =
-    "Clients.cimauth.CIMAuthCommand.FILE_NOT_READABLE";
-
 static const char ADD_AUTH_FAILURE [] =
     "Failed to add authorizations.";
 
@@ -206,12 +193,6 @@ static const char REMOVE_AUTH_SUCCESS [] =
 static const char REMOVE_AUTH_SUCCESS_KEY [] =
     "Clients.cimauth.CIMAuthCommand.REMOVE_AUTH_SUCCESS";
 
-static const char NO_AUTHS_FOUND [] =
-    "No user authorizations found for listing.";
-
-static const char NO_AUTHS_FOUND_KEY [] =
-    "Clients.cimauth.CIMAuthCommand.NO_AUTHS_FOUND";
-
 static const char AUTH_SCHEMA_NOT_LOADED [] =
     "Please restore the internal repository on the CIM Server.";
 
@@ -243,11 +224,6 @@ static const char ERR_USAGE [] =
     "Use '--help' to obtain command syntax.";
 //l10n end default messages and resource keys
 
-/**
-    The constant representing the user provider class name
-*/
-static const char PG_USER_MGR_PROV_CLASS []    = "PG_UserManager";
-
 
 static const char   LONG_HELP []  = "help";
 
@@ -463,11 +439,6 @@ CIMAuthCommand::CIMAuthCommand ()
     */
 
     usage.reserveCapacity(200);
-    //l10n
-    //localize usage keyword:
-    //MessageLoaderParms parms("Clients.CLI.USAGE_STRING","usage: ");
-    //String USAGE_L = MessageLoader::getMessage(parms);
-    //usage.append(USAGE_L);
     usage.append(USAGE);
     usage.append(COMMAND_NAME);
 
