@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -134,26 +132,26 @@ const Uint32 CIMCRLCommand::_OPERATION_TYPE_VERSION = 5;
 static const CIMName PROPERTY_NAME_ISSUERNAME = CIMName ("IssuerName");
 
 /**
-    This constant represents the name of the lastUpdate 
+    This constant represents the name of the lastUpdate
     property in the schema
 */
 static const CIMName PROPERTY_NAME_LASTUPDATE   = CIMName ("LastUpdate");
 
 /**
-    This constant represents the name of the nextUpdate 
+    This constant represents the name of the nextUpdate
     property in the schema
 */
 static const CIMName PROPERTY_NAME_NEXTUPDATE   = CIMName ("NextUpdate");
 
 /**
-    This constant represents the name of the revokedSerialNumbers 
+    This constant represents the name of the revokedSerialNumbers
     property in the schema
 */
 static const CIMName PROPERTY_NAME_REVOKED_SERIAL_NUMBERS =
                                       CIMName ("RevokedSerialNumbers");
 
 /**
-    This constant represents the name of the revocationDates 
+    This constant represents the name of the revocationDates
     property in the schema
 */
 static const CIMName PROPERTY_NAME_REVOCATION_DATES =
@@ -189,7 +187,7 @@ static const char CONNECTION_TIMEOUT [] =
                 "Connection timed out.";
 
 static const char CONNECTION_TIMEOUT_KEY [] =
-                "Clients.cimcrl.CIMCRLCommand._CONNECTION_TIMEOUT";
+                "Clients.cimcrl.CIMCRLCommand.CONNECTION_TIMEOUT";
 
 static const char ADD_CRL_SUCCESS [] =
                 "CRL added successfully.";
@@ -209,11 +207,11 @@ static const char CRL_NOT_FOUND [] =
 static const char CRL_NOT_FOUND_KEY [] =
                 "Clients.cimcrl.CIMCRLCommand.CRL_NOT_FOUND";
 
-static const char CERT_SCHEMA_NOT_LOADED []  =
+static const char CRL_SCHEMA_NOT_LOADED []  =
                 "Please restore the internal repository on the CIM Server.";
 
-static const char CERT_SCHEMA_NOT_LOADED_KEY []  =
-                "Clients.cimcrl.CIMCRLCommand.CERT_SCHEMA_NOT_LOADED";
+static const char CRL_SCHEMA_NOT_LOADED_KEY []  =
+                "Clients.cimcrl.CIMCRLCommand.CRL_SCHEMA_NOT_LOADED";
 
 // Return codes
 
@@ -247,14 +245,14 @@ CIMCRLCommand::CIMCRLCommand ()
     _usage.append (COMMAND_NAME);
 
     //
-    // Add option 
+    // Add option
     //
     _usage.append (" -").append (_OPTION_ADD);
     _usage.append (" -").append (_OPTION_CRLFILE).append (" crlfile");
     _usage.append ("\n");
 
     //
-    // Remove option 
+    // Remove option
     //
     //_usage.append ("                   -").append (_OPTION_REMOVE);
     _usage.append("       ").append (COMMAND_NAME);
@@ -339,12 +337,12 @@ String CIMCRLCommand::_formatCIMDateTime(const String& cimDateTimeStr)
     Uint32 minute = 0;
     Uint32 second = 0;
     Uint32 microsecond = 0;
-    Uint32 timezone = 0;
+    Sint32 timezone = 0;
 
-    sscanf(cimDateTimeStr.getCString(), "%04d%02d%02d%02d%02d%02d.%06d%04d",
+    sscanf(cimDateTimeStr.getCString(), "%04u%02u%02u%02u%02u%02u.%06u%04d",
            &year, &month, &day, &hour, &minute, &second,
            &microsecond, &timezone);
- 
+
     char monthString[5];
 
     switch (month)
@@ -392,13 +390,11 @@ String CIMCRLCommand::_formatCIMDateTime(const String& cimDateTimeStr)
    }
 
    char dateTimeStr[80];
-   sprintf(dateTimeStr, "%s %d, %d  %d:%02d:%02d (%03d%02d)",
+   sprintf(dateTimeStr, "%s %u, %u  %u:%02u:%02u (%+03d%02u)",
            monthString, day, year, hour, minute, second,
            timezone/60, timezone%60);
 
-   String retVal = String(dateTimeStr);
-
-   return (retVal);
+   return String(dateTimeStr);
 }
 
 
@@ -600,16 +596,16 @@ void CIMCRLCommand::_listCRL (
 
         outPrintWriter << "Revoked Certificates:" << endl;
 
-        for (Uint32 i = 0; i < revokedSerialNumbers.size(); i++)
+        for (Uint32 j = 0; j < revokedSerialNumbers.size(); j++)
         {
             String revocationDateStr =
-                _formatCIMDateTime(revocationDates[i].toString());
+                _formatCIMDateTime(revocationDates[j].toString());
 
             //
             // Display the revoked serial numbers and the revocation dates
             //
             outPrintWriter <<
-                "    Serial Number: " << revokedSerialNumbers[i] << endl;
+                "    Serial Number: " << revokedSerialNumbers[j] << endl;
             outPrintWriter <<
                 "        Revocation Date: " << revocationDateStr << endl;
             outPrintWriter << endl;
@@ -917,18 +913,17 @@ Uint32 CIMCRLCommand::execute (
     {
         client.connectLocal();
     }
-    catch(const CannotConnectException& cce)
+    catch (const CannotConnectException&)
     {
-        errPrintWriter << localizeMessage( MSG_PATH,
-                                 CANNOT_CONNECT_CIMSERVER_NOT_RUNNING_KEY,
-                                 CANNOT_CONNECT_CIMSERVER_NOT_RUNNING) << endl;
-        return ( RC_CONNECTION_FAILED );
+        errPrintWriter << localizeMessage(MSG_PATH,
+            CANNOT_CONNECT_CIMSERVER_NOT_RUNNING_KEY,
+            CANNOT_CONNECT_CIMSERVER_NOT_RUNNING) << endl;
+        return RC_CONNECTION_FAILED;
     }
-    catch(const Exception& e)
+    catch (const Exception& e)
     {
-        //l10n
         errPrintWriter << e.getMessage() << endl;
-        return (RC_ERROR);
+        return RC_ERROR;
     }
 
     //
@@ -948,27 +943,27 @@ Uint32 CIMCRLCommand::execute (
                 if (code == CIM_ERR_INVALID_CLASS)
                 {
                     errPrintWriter << localizeMessage(MSG_PATH,
-                       CERT_SCHEMA_NOT_LOADED_KEY,
-                       CERT_SCHEMA_NOT_LOADED) << endl;
+                       CRL_SCHEMA_NOT_LOADED_KEY,
+                       CRL_SCHEMA_NOT_LOADED) << endl;
                 }
                 else
                 {
                     errPrintWriter << e.getMessage() << endl;
                 }
 
-                return ( RC_ERROR );
+                return RC_ERROR;
             }
-            catch (const ConnectionTimeoutException& cte)
-            {                       
+            catch (const ConnectionTimeoutException&)
+            {
                 errPrintWriter << localizeMessage(MSG_PATH,
-                                           CONNECTION_TIMEOUT_KEY,
-                                           CONNECTION_TIMEOUT);
-                return ( RC_CONNECTION_TIMEOUT );
+                    CONNECTION_TIMEOUT_KEY,
+                    CONNECTION_TIMEOUT);
+                return RC_CONNECTION_TIMEOUT;
             }
             catch (const Exception& e)
             {
                 errPrintWriter << e.getMessage() << endl;
-                return ( RC_ERROR );
+                return RC_ERROR;
             }
             break;
 
@@ -991,26 +986,26 @@ Uint32 CIMCRLCommand::execute (
                 else if (code == CIM_ERR_INVALID_CLASS)
                 {
                     errPrintWriter << localizeMessage(MSG_PATH,
-                        CERT_SCHEMA_NOT_LOADED_KEY,
-                        CERT_SCHEMA_NOT_LOADED) << endl;
+                        CRL_SCHEMA_NOT_LOADED_KEY,
+                        CRL_SCHEMA_NOT_LOADED) << endl;
                 }
                 else
                 {
                     errPrintWriter << e.getMessage() << endl;
                 }
-                return ( RC_ERROR );
+                return RC_ERROR;
             }
-            catch (const ConnectionTimeoutException& cte)
+            catch (const ConnectionTimeoutException&)
             {
                 errPrintWriter << localizeMessage(MSG_PATH,
-                                           CONNECTION_TIMEOUT_KEY,
-                                           CONNECTION_TIMEOUT);
-                return ( RC_CONNECTION_TIMEOUT );
+                    CONNECTION_TIMEOUT_KEY,
+                    CONNECTION_TIMEOUT);
+                return RC_CONNECTION_TIMEOUT;
             }
             catch (const Exception& e)
             {
                 errPrintWriter << e.getMessage() << endl;
-                return ( RC_ERROR );
+                return RC_ERROR;
             }
             break;
 
@@ -1033,26 +1028,26 @@ Uint32 CIMCRLCommand::execute (
                 else if (code == CIM_ERR_INVALID_CLASS)
                 {
                     errPrintWriter << localizeMessage(MSG_PATH,
-                        CERT_SCHEMA_NOT_LOADED_KEY,
-                        CERT_SCHEMA_NOT_LOADED) << endl;
+                        CRL_SCHEMA_NOT_LOADED_KEY,
+                        CRL_SCHEMA_NOT_LOADED) << endl;
                 }
                 else
                 {
                     errPrintWriter << e.getMessage() << endl;
                 }
-                return ( RC_ERROR );
+                return RC_ERROR;
             }
-            catch (const ConnectionTimeoutException& cte)
+            catch (const ConnectionTimeoutException&)
             {
                 errPrintWriter << localizeMessage(MSG_PATH,
-                                           CONNECTION_TIMEOUT_KEY,
-                                           CONNECTION_TIMEOUT);
-                return ( RC_CONNECTION_TIMEOUT );
+                    CONNECTION_TIMEOUT_KEY,
+                    CONNECTION_TIMEOUT);
+                return RC_CONNECTION_TIMEOUT;
             }
             catch (const Exception& e)
             {
                 errPrintWriter << e.getMessage() << endl;
-                return ( RC_ERROR );
+                return RC_ERROR;
             }
             break;
     }
