@@ -1,37 +1,35 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
 //
-//==============================================================================
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
-/* This is a simplistic display program for the CIMOM performance 
+/* This is a simplistic display program for the CIMOM performance
     characteristics.
     This version simply gets the instances of the performace class and displays
     the resulting average counts.
@@ -214,13 +212,9 @@ void GetOptions(
     char** argv,
     const String& testHome)
 {
-    static const char* outputFormats[] = { "xml", "mof", "txt"};
-    static const Uint32 NUM_OUTPUTFORMATS = sizeof(outputFormats) /
-        sizeof(outputFormats[0]);
-
     static struct OptionRow optionsTable[] =
     //The values in the OptionRows below are:
-    //optionname, defaultvalue, is required, type, domain, domainsize, flag, 
+    //optionname, defaultvalue, is required, type, domain, domainsize, flag,
     //  hlpmsg
     {
         {"port", "5988", false, Option::INTEGER, 0, 0, "p",
@@ -389,7 +383,7 @@ int main(int argc, char** argv)
     // line.
 
     OptionManager om;
-    
+
     try
     {
         String testHome = ".";
@@ -491,7 +485,7 @@ int main(int argc, char** argv)
 
         // First print the header for table of values
         printf("%-25s%10s %10s %10s %10s %10s\n",
-            "Operation", "Number of", "Server", "Provider", "Request", 
+            "Operation", "Number of", "Server", "Provider", "Request",
             "Response");
 
         printf("%-25s%10s %10s %10s %10s %10s\n",
@@ -518,7 +512,7 @@ int main(int argc, char** argv)
             // Note that for the moment it is simply an integer.
             Uint32 pos;
             CIMProperty p;
-            // Operation Type is decoded as const char*, hence type has 
+            // Operation Type is decoded as const char*, hence type has
             // changed from string to const char*
             const char* statName = NULL;
             CIMValue v;
@@ -540,7 +534,7 @@ int main(int argc, char** argv)
 
             // Get number of requests property - "NumberofOperations"
             Uint64 numberOfRequests = 0;
-            if ((pos = instance.findProperty("NumberOfOperations")) != 
+            if ((pos = instance.findProperty("NumberOfOperations")) !=
                 PEG_NOT_FOUND)
             {
 
@@ -569,7 +563,7 @@ int main(int argc, char** argv)
             Sint64 averageCimomTime = 0;
             Uint64 totalCT = 0;
 
-            if ((pos = instance.findProperty("CimomElapsedTime")) != 
+            if ((pos = instance.findProperty("CimomElapsedTime")) !=
                 PEG_NOT_FOUND)
             {
                 p = (instance.getProperty(pos));
@@ -582,7 +576,7 @@ int main(int argc, char** argv)
                 }
                 else
                 {
-                    cerr << "Error Property value " << "CimomElapsedTime" << 
+                    cerr << "Error Property value " << "CimomElapsedTime" <<
                         endl;
                 }
             }
@@ -601,7 +595,7 @@ int main(int argc, char** argv)
             Uint64 averageProviderTime = 0;
             Uint64 totalPT = 0;
 
-            if ((pos = instance.findProperty("ProviderElapsedTime")) != 
+            if ((pos = instance.findProperty("ProviderElapsedTime")) !=
                 PEG_NOT_FOUND)
             {
                 p = (instance.getProperty(pos));
@@ -642,7 +636,7 @@ int main(int argc, char** argv)
                 }
                 else
                 {
-                    cerr << "RequestSize is not of type CIMTYPE_SINT64" << 
+                    cerr << "RequestSize is not of type CIMTYPE_SINT64" <<
                         endl ;
                 }
             }
@@ -688,7 +682,7 @@ int main(int argc, char** argv)
 
             printf("%-25s"
                 "%10"  PEGASUS_64BIT_CONVERSION_WIDTH "u"
-                "%11" PEGASUS_64BIT_CONVERSION_WIDTH "u"
+                "%11" PEGASUS_64BIT_CONVERSION_WIDTH "d"
                 "%11" PEGASUS_64BIT_CONVERSION_WIDTH "u"
                 "%11" PEGASUS_64BIT_CONVERSION_WIDTH "u"
                 "%11" PEGASUS_64BIT_CONVERSION_WIDTH "u\n",
