@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -89,11 +87,6 @@ static const CIMName _PROPERTY_PROVIDER_NAME = CIMName("Name");
 */
 static const char USAGE[] = "Usage: ";
 
-/**
-    This constant represents the getoopt argument designator
-*/
-static const char GETOPT_ARGUMENT_DESIGNATOR = ':';
-
 /*
     These constants represent the operation modes supported by the CLI.
     Any new operation should be added here.
@@ -139,12 +132,6 @@ static const Uint32 OPERATION_TYPE_VERSION = 6;
     The constants representing the messages.
 */
 
-static const char NOT_PRIVILEGED_USER[] =
-    "Error, you must have superuser privilege to run cimprovider.";
-
-static const char NOT_PRIVILEGED_USER_KEY[] =
-    "Clients.cimprovider.CIMProviderCommand.NOT_PRIVILEGED_USER";
-
 static const char CIMOM_NOT_RUNNING[] =
     "The CIM server may not be running.";
 
@@ -225,12 +212,6 @@ static const char CANNOT_START_PROVIDER[] =
 static const char CANNOT_START_PROVIDER_KEY[] =
     "Clients.cimprovider.CIMProviderCommand.CANNOT_START_PROVIDER";
 
-static const char PROVIDER_NOT_REGISTERED[] =
-    "Specified provider was not registered.";
-
-static const char PROVIDER_NOT_REGISTERED_KEY[] =
-    "Clients.cimprovider.CIMProviderCommand.PROVIDER_NOT_REGISTERED";
-
 static const char DELETEING_PROVIDER_MODULE[] =
     "Deleting provider module...";
 
@@ -255,12 +236,6 @@ static const char STOPING_PROVIDER_MODULE[] =
 static const char STOPING_PROVIDER_MODULE_KEY[] =
     "Clients.cimprovider.CIMProviderCommand.STOPING_PROVIDER_MODULE";
 
-static const char NO_MODULE_REGISTERED[] =
-    "No modules registered for listing.";
-
-static const char NO_MODULE_REGISTERED_KEY[] =
-    "Clients.cimprovider.CIMProviderCommand.NO_MODULE_REGISTERED";
-
 static const char ERR_MODULE_NOT_REGISTERED[] =
     "Specified provider module was not registered.";
 
@@ -285,12 +260,6 @@ static const char REQUIRED_ARGS_MISSING[] =
 static const char REQUIRED_ARGS_MISSING_KEY[] =
     "Clients.cimprovider.CIMProviderCommand.REQUIRED_ARGS_MISSING";
 
-static const char INVALID_ARGS[] =
-    "Invalid arguments.";
-
-static const char INVALID_ARGS_KEY[] =
-    "Clients.cimprovider.CIMProviderCommand.INVALID_ARGS";
-
 static const char UNEXPECTED_OPTION[] = "Unexpected Option.";
 
 static const char UNEXPECTED_OPTION_KEY[] =
@@ -564,7 +533,7 @@ CIMProviderCommand::CIMProviderCommand()
     usage.append("                   --").append(LONG_HELP).append("\n");
     usage.append("                   --").append(LONG_VERSION).append("\n");
 
-    usage.append("Options : \n");
+    usage.append("Options:\n");
     usage.append("    -d         - "
         "Disable the specified CIM provider module\n");
     usage.append("    -e         - "
@@ -577,7 +546,10 @@ CIMProviderCommand::CIMProviderCommand()
     usage.append("    -p         - Specify the provider for the operation\n");
 
     usage.append("    -r         - "
-        "Remove specified provider module and its contained providers\n");
+        "Remove the registration for a provider (if specified)\n"
+        "                 or for the specified provider module and all the "
+            "providers\n"
+        "                 it contains\n");
     usage.append("    -s         - "
         "Display the status of registered provider modules\n");
     usage.append("    --version  - Display CIM Server version number\n");
