@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
 //
-//==============================================================================
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -74,11 +72,6 @@ static const CIMNamespaceName _DEFAULT_SUBSCRIPTION_NAMESPACE  =
  */
 static const char USAGE[] = "Usage: ";
 
-/**
-    This constant represents the getoopt argument designator
- */
-static const char GETOPT_ARGUMENT_DESIGNATOR = ':';
-
 /*
     These constants represent the operation modes supported by the CLI.
     Any new operation should be added here.
@@ -134,18 +127,6 @@ static const char CIMOM_NOT_RUNNING[] =
 static const char CIMOM_NOT_RUNNING_KEY[] =
     "Clients.cimsub.CIMSubCommand.CIMOM_NOT_RUNNING";
 
-static const char ENABLE_SUBSCRIPTION_FAILURE[] =
-    "Failed to enable subscription.";
-
-static const char ENABLE_SUBSCRIPTION_FAILURE_KEY[] =
-    "Clients.cimsub.CIMSubCommand.ENABLE_SUBSCRIPTION_FAILURE";
-
-static const char DISABLE_SUBSCRIPTION_FAILURE[] =
-    "Failed to disable subscription.";
-
-static const char DISABLE_SUBSCRIPTION_FAILURE_KEY[] =
-    "Clients.cimsub.CIMSubCommand.DISABLE_SUBSCRIPTION_FAILURE";
-
 static const char SUBSCRIPTION_NOT_FOUND_FAILURE[] =
     "The requested subscription could not be found.";
 
@@ -185,17 +166,6 @@ static const char REQUIRED_OPTION_MISSING[] =
 static const char REQUIRED_OPTION_MISSING_KEY[] =
     "Clients.cimsub.CIMSubCommand.REQUIRED_OPTION_MISSING";
 
-static const char INVALID_ARGS[] =
-    "Invalid arguments.";
-
-static const char INVALID_ARGS_KEY[] =
-    "Clients.cimsub.CIMSubCommand.INVALID_ARGS";
-
-static const char UNEXPECTED_OPTION[] = "Unexpected Option.";
-
-static const char UNEXPECTED_OPTION_KEY[] =
-    "Clients.cimsub.CIMSubCommand.UNEXPECTED_OPTION";
-
 static const char ERR_USAGE_KEY[] =
     "Clients.cimsub.CIMSubCommand.ERR_USAGE";
 
@@ -928,13 +898,13 @@ Uint32 CIMSubCommand::execute(
         switch (_operationType)
         {
             case OPERATION_TYPE_ENABLE:
-                return(_findAndModifyState(STATE_ENABLED, 
+                return(_findAndModifyState(STATE_ENABLED,
                     subscriptionNS, _filterName, filterNS,
                     _handlerName, handlerNS, _handlerCreationClass,
                     outPrintWriter));
 
             case OPERATION_TYPE_DISABLE:
-                return (_findAndModifyState(STATE_DISABLED, 
+                return (_findAndModifyState(STATE_DISABLED,
                     subscriptionNS, _filterName, filterNS,
                     _handlerName, handlerNS, _handlerCreationClass,
                     outPrintWriter));
@@ -980,7 +950,7 @@ Uint32 CIMSubCommand::execute(
                           namespaceNames.append(handlerNS);
                      }
                           _listHandlers(_handlerName, namespaceNames,
-                               _handlerCreationClass, _verbose, 
+                               _handlerCreationClass, _verbose,
                                outPrintWriter, errPrintWriter);
                 }
             break;
@@ -1185,14 +1155,10 @@ void CIMSubCommand::_parseHandlerName(
 
             // Parse the handler class and name
 
-            String nameSubstring = handlerString.subString(
-                nsDelimiterIndex+1);
-            Uint32 slen = classDelimiterIndex -
-                nsDelimiterIndex - 1;
+            Uint32 slen = classDelimiterIndex - nsDelimiterIndex - 1;
             handlerCreationClass =
                 handlerString.subString(nsDelimiterIndex+1, slen);
-            handlerName = handlerString.subString(
-                classDelimiterIndex+1);
+            handlerName = handlerString.subString(classDelimiterIndex+1);
         }
     }
 }
@@ -1536,7 +1502,7 @@ Boolean CIMSubCommand::_findSubscription(
     CIMObjectPath& subscriptionFound)
 {
     Array<CIMObjectPath> subscriptionPaths;
-    String handlerCreationClass = PEGASUS_CLASSNAME_LSTNRDST_CIMXML.getString();
+    String handlerCreationClass;
     if (handlerCC != String::EMPTY)
     {
         handlerCreationClass = handlerCC;
@@ -1574,7 +1540,7 @@ Boolean CIMSubCommand::_findSubscription(
             {
                 CIMObjectPath handlerRef;
                 if(_handlerMatches(subPath, subscriptionNamespace,
-                    handlerName, handlerNamespace, handlerCreationClass, 
+                    handlerName, handlerNamespace, handlerCreationClass,
                     handlerNS, handlerRef))
                 {
                     subscriptionFound = subPath;
@@ -1591,7 +1557,7 @@ Boolean CIMSubCommand::_findSubscription(
 //
 Uint32 CIMSubCommand::_findAndModifyState(
     const Uint16 newState,
-    const CIMNamespaceName& subscriptionNamespace, 
+    const CIMNamespaceName& subscriptionNamespace,
     const String& filterName,
     const CIMNamespaceName& filterNamespace,
     const String& handlerName,
@@ -1627,7 +1593,7 @@ Uint32 CIMSubCommand::_findAndModifyState(
         handlerNS = subscriptionNS;
     }
 
-    // Find subscriptions in the namespace specified by the user 
+    // Find subscriptions in the namespace specified by the user
     if (_findSubscription(subscriptionNS, filterName, filterNS,
         handlerName, handlerNS, handlerCreationClass, subscriptionFound))
     {
@@ -1982,7 +1948,7 @@ void CIMSubCommand::_listFilters(
     {
         if (listOutputTable[_FILTER_LIST_NAME_COLUMN].size() > 0)
         {
-           _printFiltersVerbose(listOutputTable, queryLangsFound, 
+           _printFiltersVerbose(listOutputTable, queryLangsFound,
                outPrintWriter);
         }
     }
@@ -2249,7 +2215,7 @@ void CIMSubCommand::_getSubscriptionList(
     CIMNamespaceName filterNamespace;
     CIMNamespaceName handlerNamespace;
     CIMNamespaceName subscriptionNamespace = _DEFAULT_SUBSCRIPTION_NAMESPACE;
-    String handlerCreationClass = PEGASUS_CLASSNAME_LSTNRDST_CIMXML.getString();
+    String handlerCreationClass;
     if (!subscriptionNSIn.isNull())
     {
         subscriptionNamespace = subscriptionNSIn;
@@ -2486,9 +2452,9 @@ void CIMSubCommand::_printSubscriptionsVerbose(
     {
        indexes.append (i);
     }
-    _bubbleIndexSort(listOutputTable[_SUBSCRIPTION_LIST_HANDLER_COLUMN], 0, 
+    _bubbleIndexSort(listOutputTable[_SUBSCRIPTION_LIST_HANDLER_COLUMN], 0,
             indexes);
-    _bubbleIndexSort(listOutputTable[_SUBSCRIPTION_LIST_FILTER_COLUMN], 0, 
+    _bubbleIndexSort(listOutputTable[_SUBSCRIPTION_LIST_FILTER_COLUMN], 0,
             indexes);
     _bubbleIndexSort(listOutputTable[_SUBSCRIPTION_LIST_NS_COLUMN], 0, indexes);
     for (Uint32 i = 0; i < maxEntries; i++)
@@ -2496,10 +2462,10 @@ void CIMSubCommand::_printSubscriptionsVerbose(
         outPrintWriter << "Namespace:         " <<
             (listOutputTable[_SUBSCRIPTION_LIST_NS_COLUMN])[indexes[i]] << endl;
         outPrintWriter << "Filter:            " <<
-            (listOutputTable[_SUBSCRIPTION_LIST_FILTER_COLUMN])[indexes[i]] 
+            (listOutputTable[_SUBSCRIPTION_LIST_FILTER_COLUMN])[indexes[i]]
             << endl;
         outPrintWriter << "Handler:           " <<
-            (listOutputTable[_SUBSCRIPTION_LIST_HANDLER_COLUMN])[indexes[i]] 
+            (listOutputTable[_SUBSCRIPTION_LIST_HANDLER_COLUMN])[indexes[i]]
             << endl;
         outPrintWriter << "Query:             " << querysFound[indexes[i]]
                 << endl;
@@ -2790,7 +2756,7 @@ void CIMSubCommand::_getEmailInfo(
     Array <String> mailCc, mailTo;
     subjectString = String::EMPTY;
     mailTo.append(String::EMPTY);
-    Uint32 pos = 
+    Uint32 pos =
         handlerInstance.findProperty(PEGASUS_PROPERTYNAME_LSTNRDST_MAILTO);
     if( pos != PEG_NOT_FOUND)
     {
@@ -2830,7 +2796,7 @@ void CIMSubCommand::_getEmailInfo(
 String CIMSubCommand::_getPersistenceType(const CIMInstance& handlerInstance)
 {
     Uint16 persistenceType = 1;
-    Uint32 pos = 
+    Uint32 pos =
         handlerInstance.findProperty(PEGASUS_PROPERTYNAME_PERSISTENCETYPE);
     if (pos != PEG_NOT_FOUND)
     {
@@ -2966,7 +2932,7 @@ void CIMSubCommand::_printColumns(
     {
         for (Uint32 column = 0; column < maxColumns-1; column++)
         {
-            Uint32 outputItemSize = 
+            Uint32 outputItemSize =
                 (listOutputTable[column])[indexes[i]].size();
             Uint32 fillerLen = maxColumnWidth[column] + TITLE_SEPERATOR_LEN -
                 outputItemSize;
@@ -3052,7 +3018,7 @@ int main (int argc, char* argv[])
         parms.msg_src_path = MSG_PATH;
         cerr << COMMAND_NAME <<
             ": " << MessageLoader::getMessage(parms) << endl;
-        
+
         exit (Command::RC_ERROR);
     }
     retCode = command->execute(cout, cerr);
