@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -119,7 +117,7 @@ const char   CIMTrustCommand::_OPTION_TYPE= 'T';
 /**
     The option character used to specify the authority type.
  */
-const String   CIMTrustCommand::_ARG_TYPE_AUTHORITY = "a"; 
+const String   CIMTrustCommand::_ARG_TYPE_AUTHORITY = "a";
 
 /**
     The option character used to specify the authority issued end-entity type.
@@ -211,7 +209,7 @@ static const CIMName PROPERTY_NAME_SUBJECTNAME  = CIMName ("SubjectName");
     This constant represents the name of the RegisteredUserName
     property in the schema
 */
-static const CIMName PROPERTY_NAME_REGISTERED_USER_NAME  
+static const CIMName PROPERTY_NAME_REGISTERED_USER_NAME
                                             = CIMName ("RegisteredUserName");
 
 /**
@@ -266,12 +264,6 @@ static const char   LONG_HELP []  = "help";
 
 static const char   LONG_VERSION []  = "version";
 
-static const char PASSWORD_PROMPT []  =
-                "Please enter your password: ";
-
-static const char PASSWORD_BLANK []  =
-                "Password cannot be blank. Please re-enter your password.";
-
 static const char REQUIRED_ARGS_MISSING [] =
                 "Required arguments missing.";
 
@@ -279,17 +271,17 @@ static const char REQUIRED_ARGS_MISSING_KEY [] =
                 "Clients.cimtrust.CIMTrustCommand.REQUIRED_ARGS_MISSING";
 
 static const char CANNOT_CONNECT_CIMSERVER_NOT_RUNNING [] =
-                "Cannot connect to CIM Server, CIM Server may not be running.";
+                "Cannot connect to CIM Server; CIM Server may not be running.";
 
 static const char CANNOT_CONNECT_CIMSERVER_NOT_RUNNING_KEY [] =
                 "Clients.cimtrust."
-                    "CIMTrustCommand._CANNOT_CONNECT_CIMSERVER_NOT_RUNNING";
+                    "CIMTrustCommand.CANNOT_CONNECT_CIMSERVER_NOT_RUNNING";
 
 static const char CONNECTION_TIMEOUT [] =
                 "Connection timed out.";
 
 static const char CONNECTION_TIMEOUT_KEY [] =
-                "Clients.cimtrust.CIMTrustCommand._CONNECTION_TIMEOUT";
+                "Clients.cimtrust.CIMTrustCommand.CONNECTION_TIMEOUT";
 
 static const char ADD_CERT_FAILURE []    =
                 "Failed to add certificate.";
@@ -301,13 +293,13 @@ static const char ADD_CERTIFICATE_SUCCESS [] =
                 "Certificate added successfully.";
 
 static const char ADD_CERTIFICATE_SUCCESS_KEY [] =
-                "Clients.cimtrust.CIMTrustCommand.ADD_CERTIFICATE_SUCCESS";
+                "Clients.cimtrust.CIMTrustCommand.ADD_CERT_SUCCESS";
 
 static const char REMOVE_CERTIFICATE_SUCCESS [] =
                 "Certificate removed successfully.";
 
 static const char REMOVE_CERTIFICATE_SUCCESS_KEY [] =
-                "Clients.cimtrust.CIMTrustCommand.REMOVE_CERTIFICATE_SUCCESS";
+                "Clients.cimtrust.CIMTrustCommand.REMOVE_CERT_SUCCESS";
 
 static const char CERT_ALREADY_EXISTS []        =
                 "Specified certificate already exists.";
@@ -343,7 +335,7 @@ static const char CERT_WITHOUT_ASSOCIATED_USER_KEY [] =
     "Clients.cimtrust.CIMTrustCommand.CERT_WITHOUT_ASSOCIATED_USER";
 
 static const char CERT_WITHOUT_ASSOCIATED_USER [] =
-    "NOTE: No user name will be associated with the certificate" 
+    "NOTE: No user name will be associated with the certificate"
     " in the truststore.";
 
 static const char INVALID_SYSTEM_USER [] =
@@ -352,11 +344,6 @@ static const char INVALID_SYSTEM_USER [] =
 static const char INVALID_SYSTEM_USER_KEY [] =
                 "Clients.cimtrust.CIMTrustCommand.INVALID_SYSTEM_USER";
 
-/**
-    The constant representing the trust manager provider class name
-*/
-static const char PG_SSLTRUST_MGR_PROV_CLASS []    = "PG_SSLTrustManager";
-
 // Return codes
 
 static const Uint32 RC_CONNECTION_FAILED = 2;
@@ -534,9 +521,9 @@ String CIMTrustCommand::_formatCIMDateTime(const String& cimDateTimeStr)
    Uint32 minute = 0;
    Uint32 second = 0;
    Uint32 microsecond = 0;
-   Uint32 timezone = 0;
+   Sint32 timezone = 0;
 
-   sscanf(cimDateTimeStr.getCString(), "%04d%02d%02d%02d%02d%02d.%06d%04d",
+   sscanf(cimDateTimeStr.getCString(), "%04u%02u%02u%02u%02u%02u.%06u%04d",
           &year, &month, &day, &hour, &minute, &second,
           &microsecond, &timezone);
 
@@ -588,13 +575,11 @@ String CIMTrustCommand::_formatCIMDateTime(const String& cimDateTimeStr)
    }
 
    char dateTimeStr[80];
-   sprintf(dateTimeStr, "%s %d, %d  %d:%02d:%02d (%03d%02d)",
+   sprintf(dateTimeStr, "%s %u, %u  %u:%02u:%02u (%+03d%02u)",
            monthString, day, year, hour, minute, second,
            timezone/60, timezone%60);
 
-   String retVal = String(dateTimeStr);
-
-   return (retVal);
+   return String(dateTimeStr);
 }
 
 
@@ -685,12 +670,12 @@ void CIMTrustCommand::_addCertificate (
         PEGASUS_CLASSNAME_CERTIFICATE, kbArray);
 
     //
-    // If an associated username has not been specified, display an 
+    // If an associated username has not been specified, display an
     // informational message.
     //
     if ( !_certUserSet )
     {
-          outPrintWriter << localizeMessage(MSG_PATH, 
+          outPrintWriter << localizeMessage(MSG_PATH,
                             CERT_WITHOUT_ASSOCIATED_USER_KEY,
                             CERT_WITHOUT_ASSOCIATED_USER) << endl;
     }
@@ -741,7 +726,7 @@ void CIMTrustCommand::_removeCertificate (
 
         kbArray.append(kb);
     }
-    else 
+    else
     {
         //
         // Pass the subject name
@@ -916,9 +901,9 @@ void CIMTrustCommand::_listCertificates (
         outPrintWriter << "Issuer: " << issuer << endl;
         outPrintWriter << "Serial Number: " << serialNumber << endl;
         outPrintWriter << "Subject: " << subjectName << endl;
-        outPrintWriter << "Registered User Name: " 
+        outPrintWriter << "Registered User Name: "
                        << registeredUserName << endl;
-        outPrintWriter << "Type: " 
+        outPrintWriter << "Type: "
                        << typeStr << endl;
         outPrintWriter << "Validity:" << endl;
         outPrintWriter << "    NotBefore: " << notBeforeStr << endl;
@@ -1188,7 +1173,7 @@ void CIMTrustCommand::setCommand (Uint32 argc, char* argv [])
                         //
                         // Both the subject and serial number may not be
                         // specified.
-                        // 
+                        //
                         throw UnexpectedOptionException(_OPTION_SERIALNUMBER);
                     }
 
@@ -1275,7 +1260,7 @@ void CIMTrustCommand::setCommand (Uint32 argc, char* argv [])
             //
             throw MissingOptionException(_OPTION_CERTUSER);
         }
-         
+
     }
 
     if ( _operationType == _OPERATION_TYPE_REMOVE ||
@@ -1395,21 +1380,20 @@ Uint32 CIMTrustCommand::execute (
 
     try
     {
-        _connectToServer( client, outPrintWriter);
+        _connectToServer(client, outPrintWriter);
     }
-    catch(CannotConnectException& cce)
+    catch (CannotConnectException&)
     {
-        outPrintWriter << localizeMessage( MSG_PATH,
-                              CANNOT_CONNECT_CIMSERVER_NOT_RUNNING_KEY,
-                              CANNOT_CONNECT_CIMSERVER_NOT_RUNNING) 
-                       << endl;
-        return ( RC_CONNECTION_FAILED );
+        outPrintWriter << localizeMessage(MSG_PATH,
+            CANNOT_CONNECT_CIMSERVER_NOT_RUNNING_KEY,
+            CANNOT_CONNECT_CIMSERVER_NOT_RUNNING)
+            << endl;
+        return RC_CONNECTION_FAILED;
     }
-    catch(Exception& e)
+    catch (Exception& e)
     {
-        //l10n
         outPrintWriter << e.getMessage() << endl;
-        return (RC_ERROR);
+        return RC_ERROR;
     }
 
     //
@@ -1422,12 +1406,12 @@ Uint32 CIMTrustCommand::execute (
             {
                 _addCertificate( client, outPrintWriter );
             }
-            catch (ConnectionTimeoutException& cte)
+            catch (ConnectionTimeoutException&)
             {
                 outPrintWriter << localizeMessage(MSG_PATH,
-                                           CONNECTION_TIMEOUT_KEY,
-                                           CONNECTION_TIMEOUT);
-                return ( RC_CONNECTION_TIMEOUT );
+                    CONNECTION_TIMEOUT_KEY,
+                    CONNECTION_TIMEOUT) << endl;
+                return RC_CONNECTION_TIMEOUT;
             }
             catch (CIMException& e)
             {
@@ -1441,36 +1425,36 @@ Uint32 CIMTrustCommand::execute (
                 }
                 else if (code == CIM_ERR_ALREADY_EXISTS)
                 {
-                     outPrintWriter << localizeMessage(MSG_PATH,
-                            ADD_CERT_FAILURE_KEY, ADD_CERT_FAILURE) << endl;
+                    outPrintWriter << localizeMessage(MSG_PATH,
+                        ADD_CERT_FAILURE_KEY, ADD_CERT_FAILURE) << endl;
 
-                     outPrintWriter << localizeMessage(MSG_PATH,
-                            CERT_ALREADY_EXISTS_KEY,
-                            CERT_ALREADY_EXISTS) << endl;
-                     errPrintWriter << e.getMessage()  << endl;
-                     return ( RC_CERTIFICATE_ALREADY_EXISTS );
+                    outPrintWriter << localizeMessage(MSG_PATH,
+                        CERT_ALREADY_EXISTS_KEY,
+                        CERT_ALREADY_EXISTS) << endl;
+                    errPrintWriter << e.getMessage()  << endl;
+                    return RC_CERTIFICATE_ALREADY_EXISTS;
                 }
                 else if (code == CIM_ERR_INVALID_CLASS)
                 {
-                     outPrintWriter << localizeMessage(MSG_PATH,
-                            ADD_CERT_FAILURE_KEY, ADD_CERT_FAILURE) << endl;
-                     outPrintWriter << localizeMessage(MSG_PATH,
-                       CERT_SCHEMA_NOT_LOADED_KEY,
-                       CERT_SCHEMA_NOT_LOADED) << endl;
+                    outPrintWriter << localizeMessage(MSG_PATH,
+                        ADD_CERT_FAILURE_KEY, ADD_CERT_FAILURE) << endl;
+                    outPrintWriter << localizeMessage(MSG_PATH,
+                        CERT_SCHEMA_NOT_LOADED_KEY,
+                        CERT_SCHEMA_NOT_LOADED) << endl;
                 }
                 else
                 {
-                        errPrintWriter << e.getMessage() << endl;
+                    errPrintWriter << e.getMessage() << endl;
                 }
 
-                return ( RC_ERROR );
+                return RC_ERROR;
             }
             catch (Exception& e)
             {
                 outPrintWriter << localizeMessage(MSG_PATH,
-                        ADD_CERT_FAILURE_KEY,
-                        ADD_CERT_FAILURE) << endl << e.getMessage() << endl;
-                return ( RC_ERROR );
+                    ADD_CERT_FAILURE_KEY,
+                    ADD_CERT_FAILURE) << endl << e.getMessage() << endl;
+                return RC_ERROR;
             }
             break;
 
@@ -1479,12 +1463,12 @@ Uint32 CIMTrustCommand::execute (
             {
                 _removeCertificate ( client, outPrintWriter );
             }
-            catch (ConnectionTimeoutException& cte)
+            catch (ConnectionTimeoutException&)
             {
                 outPrintWriter << localizeMessage(MSG_PATH,
-                                           CONNECTION_TIMEOUT_KEY,
-                                           CONNECTION_TIMEOUT);
-                return ( RC_CONNECTION_TIMEOUT );
+                    CONNECTION_TIMEOUT_KEY,
+                    CONNECTION_TIMEOUT);
+                return RC_CONNECTION_TIMEOUT;
             }
             catch (CIMException& e)
             {
@@ -1507,7 +1491,7 @@ Uint32 CIMTrustCommand::execute (
                             CERT_NOT_FOUND_KEY, CERT_NOT_FOUND) << endl;
 
                     errPrintWriter << e.getMessage()  << endl;
-                    return ( RC_CERTIFICATE_DOES_NOT_EXIST );
+                    return RC_CERTIFICATE_DOES_NOT_EXIST;
                 }
                 else if (code == CIM_ERR_INVALID_CLASS)
                 {
@@ -1523,7 +1507,7 @@ Uint32 CIMTrustCommand::execute (
                 {
                     errPrintWriter << e.getMessage() << endl;
                 }
-                return ( RC_ERROR );
+                return RC_ERROR;
             }
             catch (Exception& e)
             {
@@ -1532,7 +1516,7 @@ Uint32 CIMTrustCommand::execute (
                         REMOVE_CERT_FAILURE) << endl
                         << e.getMessage() << endl;
 
-                return ( RC_ERROR );
+                return RC_ERROR;
             }
             break;
 
@@ -1541,12 +1525,12 @@ Uint32 CIMTrustCommand::execute (
             {
                 _listCertificates ( client, outPrintWriter );
             }
-            catch (ConnectionTimeoutException& cte)
+            catch (ConnectionTimeoutException&)
             {
                 outPrintWriter << localizeMessage(MSG_PATH,
-                                           CONNECTION_TIMEOUT_KEY,
-                                           CONNECTION_TIMEOUT);
-                return ( RC_CONNECTION_TIMEOUT );
+                    CONNECTION_TIMEOUT_KEY,
+                    CONNECTION_TIMEOUT);
+                return RC_CONNECTION_TIMEOUT;
             }
             catch (CIMException& e)
             {
@@ -1554,18 +1538,18 @@ Uint32 CIMTrustCommand::execute (
 
                 if (code == CIM_ERR_NOT_FOUND)
                 {
-                     return ( RC_CERTIFICATE_DOES_NOT_EXIST );
+                     return RC_CERTIFICATE_DOES_NOT_EXIST;
                 }
                 if (code == CIM_ERR_FAILED || code == CIM_ERR_NOT_SUPPORTED)
                 {
-                        outPrintWriter << localizeMessage(MSG_PATH,
-                            LIST_CERT_FAILURE_KEY, LIST_CERT_FAILURE) << endl;
+                    outPrintWriter << localizeMessage(MSG_PATH,
+                         LIST_CERT_FAILURE_KEY, LIST_CERT_FAILURE) << endl;
                     errPrintWriter << e.getMessage() << endl;
                 }
                 else if (code == CIM_ERR_INVALID_CLASS)
                 {
-                        outPrintWriter << localizeMessage(MSG_PATH,
-                            LIST_CERT_FAILURE_KEY, LIST_CERT_FAILURE) << endl;
+                    outPrintWriter << localizeMessage(MSG_PATH,
+                        LIST_CERT_FAILURE_KEY, LIST_CERT_FAILURE) << endl;
                     outPrintWriter << localizeMessage(MSG_PATH,
                         CERT_SCHEMA_NOT_LOADED_KEY,
                         CERT_SCHEMA_NOT_LOADED) << endl;
@@ -1575,14 +1559,14 @@ Uint32 CIMTrustCommand::execute (
                     errPrintWriter << e.getMessage() << endl;
                 }
 
-                return ( RC_ERROR );
+                return RC_ERROR;
             }
             catch (Exception& e)
             {
-                    outPrintWriter << localizeMessage(MSG_PATH,
-                        LIST_CERT_FAILURE_KEY,
-                        LIST_CERT_FAILURE) << endl << e.getMessage() << endl;
-                return ( RC_ERROR );
+                outPrintWriter << localizeMessage(MSG_PATH,
+                    LIST_CERT_FAILURE_KEY,
+                    LIST_CERT_FAILURE) << endl << e.getMessage() << endl;
+                return RC_ERROR;
             }
             break;
 
@@ -1593,7 +1577,7 @@ Uint32 CIMTrustCommand::execute (
             break;
     }
 
-    return (RC_SUCCESS);
+    return RC_SUCCESS;
 }
 
 PEGASUS_NAMESPACE_END
