@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -78,11 +76,6 @@ static const CIMName PROPERTY_NAME_PASSWORD             = CIMName ("Password");
 */
 static const char USAGE []                     = "Usage: ";
 
-/**
-    This constant represents the getoopt argument designator
-*/
-static const char GETOPT_ARGUMENT_DESIGNATOR   = ':';
-
 /*
     These constants represent the operation modes supported by the CLI.
     Any new operation should be added here.
@@ -207,12 +200,6 @@ static const char REQUIRED_ARGS_MISSING [] =
 static const char REQUIRED_ARGS_MISSING_KEY [] =
     "Clients.cimuser.CIMUserCommand.REQUIRED_ARGS_MISSING";
 
-static const char INVALID_ARGS [] =
-    "Invalid arguments.";
-
-static const char INVALID_ARGS_KEY [] =
-    "Clients.cimuser.CIMUserCommand.INVALID_ARGS";
-
 static const char USER_ALREADY_EXISTS [] =
     "Specified user name already exist.";
 
@@ -225,12 +212,6 @@ static const char USER_NOT_FOUND [] =
 static const char USER_NOT_FOUND_KEY [] =
     "Clients.cimuser.CIMUserCommand.USER_NOT_FOUND";
 
-static const char USERNAME_REQUIRED [] =
-    "User name is required.";
-
-static const char USERNAME_REQUIRED_KEY [] =
-    "Clients.cimuser.CIMUserCommand.USERNAME_REQUIRED";
-
 /**
     The option character used to specify add user.
 */
@@ -295,7 +276,7 @@ static const char   NEW_PASS_PARAM[]             = "NewPassword";
 static const char   PASSWORD_PROMPT []  =
                         "Please enter your password: ";
 
-static const char   PASSWORD_PROMPT_KEY [] = 
+static const char   PASSWORD_PROMPT_KEY [] =
     "Clients.cimuser.CIMUserCommand.PASSWORD_PROMPT";
 
 static const char   OLD_PASSWORD_PROMPT []  =
@@ -319,19 +300,19 @@ static const char   NEW_PASSWORD_PROMPT_KEY []  =
 static const char   PASSWORD_DOES_NOT_MATCH []  =
     "Passwords do not match. Please Re-enter.";
 
-static const char   PASSWORD_DOES_NOT_MATCH_KEY []  = 
+static const char   PASSWORD_DOES_NOT_MATCH_KEY []  =
     "Clients.cimuser.CIMUserCommand.PASSWORD_DOES_NOT_MATCH";
 
 static const char   PASSWORD_SAME_ERROR []  =
     "Error, new and old passwords cannot be same.";
 
-static const char   PASSWORD_SAME_ERROR_KEY []  = 
+static const char   PASSWORD_SAME_ERROR_KEY []  =
     "Clients.cimuser.CIMUserCommand.PASSWORD_SAME_ERROR";
 
-static const char ERR_USAGE [] = 
+static const char ERR_USAGE [] =
     "Use '--help' to obtain command syntax.";
 
-static const char ERR_USAGE_KEY [] = 
+static const char ERR_USAGE_KEY [] =
     "Clients.cimuser.CIMUserCommand.ERR_USAGE";
 
 static const char   LONG_HELP []  = "help";
@@ -900,9 +881,9 @@ void CIMUserCommand::setCommand (
 
                 if (pw == String::EMPTY)
                 {
-                    errPrintWriter << localizeMessage(MSG_PATH, 
-                                                      PASSWORD_BLANK_KEY, 
-                                                      PASSWORD_BLANK) 
+                    errPrintWriter << localizeMessage(MSG_PATH,
+                                                      PASSWORD_BLANK_KEY,
+                                                      PASSWORD_BLANK)
                                    << endl;
                     continue;
                 }
@@ -910,7 +891,7 @@ void CIMUserCommand::setCommand (
                 {
                     errPrintWriter << localizeMessage(MSG_PATH,
                                                  PASSWORD_DOES_NOT_MATCH_KEY,
-                                                 PASSWORD_DOES_NOT_MATCH_KEY) 
+                                                 PASSWORD_DOES_NOT_MATCH_KEY)
                                    << endl;
                     pw = String::EMPTY;
                 }
@@ -936,7 +917,7 @@ void CIMUserCommand::setCommand (
             {
                 cerr << localizeMessage(MSG_PATH,
                                         PASSWORD_SAME_ERROR_KEY,
-                                        PASSWORD_SAME_ERROR) 
+                                        PASSWORD_SAME_ERROR)
                     << endl;
                 exit (1);
             }
@@ -952,9 +933,9 @@ void CIMUserCommand::setCommand (
                 pw = System::getPassword(OLD_PASSWORD_PROMPT);
                 if (pw == String::EMPTY)
                 {
-                    errPrintWriter << localizeMessage(MSG_PATH, 
-                                                      PASSWORD_BLANK_KEY, 
-                                                      PASSWORD_BLANK) 
+                    errPrintWriter << localizeMessage(MSG_PATH,
+                                                      PASSWORD_BLANK_KEY,
+                                                      PASSWORD_BLANK)
                                    << endl;
                     continue;
                 }
@@ -982,7 +963,7 @@ void CIMUserCommand::setCommand (
                 {
                     errPrintWriter << localizeMessage(MSG_PATH,
                                                     PASSWORD_DOES_NOT_MATCH_KEY,
-                                                    PASSWORD_DOES_NOT_MATCH) 
+                                                    PASSWORD_DOES_NOT_MATCH)
                                    << endl;
                     newPw = String::EMPTY;
                 }
@@ -991,9 +972,9 @@ void CIMUserCommand::setCommand (
             _newpassword = newPw ;
             if (_newpassword == _password)
             {
-                cerr << localizeMessage(MSG_PATH, 
-                                        PASSWORD_SAME_ERROR_KEY, 
-                                        PASSWORD_SAME_ERROR) 
+                cerr << localizeMessage(MSG_PATH,
+                                        PASSWORD_SAME_ERROR_KEY,
+                                        PASSWORD_SAME_ERROR)
                     << endl;
                 exit (-1);
             }
@@ -1081,7 +1062,7 @@ Uint32 CIMUserCommand::execute (
     catch(const Exception&)
     {
         outPrintWriter << localizeMessage(MSG_PATH,CIMOM_NOT_RUNNING_KEY,
-                                          CIMOM_NOT_RUNNING) 
+                                          CIMOM_NOT_RUNNING)
                       << endl;
         return 1;
     }
@@ -1102,27 +1083,27 @@ Uint32 CIMUserCommand::execute (
 
                 if (code == CIM_ERR_FAILED)
                 {
-                    outPrintWriter 
+                    outPrintWriter
                         << localizeMessage(MSG_PATH, ADD_USER_FAILURE_KEY,
-                                           ADD_USER_FAILURE) 
+                                           ADD_USER_FAILURE)
                         << endl;
                     errPrintWriter << e.getMessage() << endl;
                 }
                 else if (code == CIM_ERR_NOT_SUPPORTED)
                 {
-                    outPrintWriter 
+                    outPrintWriter
                         << localizeMessage(MSG_PATH, ADD_USER_FAILURE_KEY,
-                                           ADD_USER_FAILURE) 
+                                           ADD_USER_FAILURE)
                         << endl;
                     errPrintWriter << e.getMessage()  << endl;
                 }
                 else if (code == CIM_ERR_ALREADY_EXISTS)
                 {
-                    outPrintWriter << localizeMessage(MSG_PATH, 
+                    outPrintWriter << localizeMessage(MSG_PATH,
                                                     ADD_USER_FAILURE_KEY,
                                                     ADD_USER_FAILURE)
                         << endl;
-                    outPrintWriter << localizeMessage(MSG_PATH, 
+                    outPrintWriter << localizeMessage(MSG_PATH,
                                                     USER_ALREADY_EXISTS_KEY,
                                                     USER_ALREADY_EXISTS)
                         << endl;
@@ -1132,11 +1113,11 @@ Uint32 CIMUserCommand::execute (
                 {
                     outPrintWriter << localizeMessage(MSG_PATH,
                                                       ADD_USER_FAILURE_KEY,
-                                                      ADD_USER_FAILURE) 
+                                                      ADD_USER_FAILURE)
                                    << endl;
                     outPrintWriter << localizeMessage(MSG_PATH,
                                                     AUTH_SCHEMA_NOT_LOADED_KEY,
-                                                     AUTH_SCHEMA_NOT_LOADED) 
+                                                     AUTH_SCHEMA_NOT_LOADED)
                                    << endl;
                 }
                 else
@@ -1149,7 +1130,7 @@ Uint32 CIMUserCommand::execute (
             {
                 outPrintWriter << localizeMessage(MSG_PATH,
                                                   ADD_USER_FAILURE_KEY,
-                                                  ADD_USER_FAILURE) 
+                                                  ADD_USER_FAILURE)
                     << endl << e.getMessage() << endl;
                 return (RC_ERROR);
             }
@@ -1167,7 +1148,7 @@ Uint32 CIMUserCommand::execute (
                 {
                     outPrintWriter << localizeMessage(MSG_PATH,
                                                 CHANGE_PASSWORD_FAILURE_KEY,
-                                                CHANGE_PASSWORD_FAILURE) 
+                                                CHANGE_PASSWORD_FAILURE)
                                    << endl;
                     errPrintWriter << e.getMessage() << endl;
                 }
@@ -1175,7 +1156,7 @@ Uint32 CIMUserCommand::execute (
                 {
                     outPrintWriter << localizeMessage(MSG_PATH,
                                                     CHANGE_PASSWORD_FAILURE_KEY,
-                                                    CHANGE_PASSWORD_FAILURE) 
+                                                    CHANGE_PASSWORD_FAILURE)
                                   << endl;
                     errPrintWriter << e.getMessage()  << endl;
                 }
@@ -1390,7 +1371,7 @@ void CIMUserCommand::_ModifyUser
     // throw exceptions and will be handled by the catch block. If new
     // return codes are added in future, they need to be handled here.
     //
-    CIMValue retValue = _client->invokeMethod(
+    _client->invokeMethod(
         PEGASUS_NAMESPACENAME_USER,
         reference,
         MODIFY_METHOD,
@@ -1490,7 +1471,7 @@ int main (int argc, char* argv[])
     AutoPtr<CIMUserCommand>  command;
     Uint32               retCode;
 
-    MessageLoader::_useProcessLocale = true; 
+    MessageLoader::_useProcessLocale = true;
     MessageLoader::setPegasusMsgHomeRelative(argv[0]);
 
     //
@@ -1498,7 +1479,7 @@ int main (int argc, char* argv[])
     //
     if (!System::isPrivilegedUser(System::getEffectiveUserName()))
     {
-        MessageLoaderParms parms(NOT_PRIVILEGED_USER_KEY, 
+        MessageLoaderParms parms(NOT_PRIVILEGED_USER_KEY,
                 NOT_PRIVILEGED_USER);
         parms.msg_src_path = MSG_PATH;
         cerr << MessageLoader::getMessage(parms) << endl;
