@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -132,13 +130,13 @@ static const char LONG_VERSION [] = "version";
 
 static const char REQUIRED_ARGS_MISSING [] = "Required arguments missing.";
 
-static const char REQUIRED_ARGS_MISSING_KEY [] = 
+static const char REQUIRED_ARGS_MISSING_KEY [] =
     "Clients.cimuser.CIMUserCommand.REQUIRED_ARGS_MISSING";
 
 static const char ERR_USAGE [] =
     "Use '--help' to obtain command syntax.";
 
-static const char ERR_USAGE_KEY [] = 
+static const char ERR_USAGE_KEY [] =
     "Clients.cimuser.CIMUserCommand.ERR_USAGE";
 
 /**
@@ -305,7 +303,7 @@ String OSInfoCommand::_promptForPassword( ostream& outPrintWriter )
     //  Construct host address
     //
 
-    if ((!_hostNameSet) && (!_portNumberSet) 
+    if ((!_hostNameSet) && (!_portNumberSet)
             && (!_userNameSet) && (!_passwordSet))
     {
         connectToLocal = true;
@@ -660,7 +658,7 @@ void OSInfoCommand::setCommand (Uint32 argc, char* argv [])
     }
     else
     {
-        if (_timeout <= 0)
+        if (_timeout == 0)
         {
             //
             //  Timeout out of valid range
@@ -699,10 +697,10 @@ static void formatCIMDateTime (const char* cimString, char* dateTime)
    int minute = 0;
    int second = 0;
    int microsecond = 0;
-   int timezone = 0;
+   int timeZone = 0;
    sscanf(cimString, "%04d%02d%02d%02d%02d%02d.%06d%04d",
           &year, &month, &day, &hour, &minute, &second,
-          &microsecond, &timezone);
+          &microsecond, &timeZone);
    char monthString[5];
    switch (month)
    {
@@ -723,11 +721,9 @@ static void formatCIMDateTime (const char* cimString, char* dateTime)
       default : { strcpy(dateTime, cimString); return; }
    }
 
-   sprintf(dateTime, "%s %d, %d  %d:%02d:%02d (%03d%02d)",
+   sprintf(dateTime, "%s %d, %d  %d:%02d:%02d (%+03d%02d)",
            monthString, day, year, hour, minute, second,
-           timezone/60, timezone%60);
-
-   return;
+           timeZone/60, timeZone%60);
 }
 
 
@@ -760,7 +756,7 @@ void OSInfoCommand::gatherProperties(CIMInstance &inst, Boolean cimFormat)
          Uint32 propertyValue;
          inst.getProperty(j).getValue().get(propertyValue);
          char tmpString[80];
-         sprintf(tmpString, "%d processes", propertyValue);
+         sprintf(tmpString, "%u processes", propertyValue);
          osNumberOfProcesses.assign(tmpString);
       }  // end if NumberOfProcesses
 
@@ -769,7 +765,7 @@ void OSInfoCommand::gatherProperties(CIMInstance &inst, Boolean cimFormat)
          Uint32 propertyValue;
          inst.getProperty(j).getValue().get(propertyValue);
          char tmpString[80];
-         sprintf(tmpString, "%d users", propertyValue);
+         sprintf(tmpString, "%u users", propertyValue);
          osNumberOfUsers.assign(tmpString);
       }  // end if NumberOfUsers
 
@@ -806,7 +802,7 @@ void OSInfoCommand::gatherProperties(CIMInstance &inst, Boolean cimFormat)
          else  // standard number of users
          {
             char users[80];
-            sprintf(users, "%d users", propertyValue);
+            sprintf(users, "%u users", propertyValue);
             osLicensedUsers.assign(users);
          }
       }   // end if NumberOfLicensedUsers
@@ -948,7 +944,7 @@ void OSInfoCommand::displayProperties(ostream& outPrintWriter)
       outPrintWriter << "  Number of Users: Unknown" << endl;
 
    if (osNumberOfProcesses != String::EMPTY)
-      outPrintWriter << "  Number of Processes: " << osNumberOfProcesses 
+      outPrintWriter << "  Number of Processes: " << osNumberOfProcesses
                      << endl;
    else
       outPrintWriter << "  Number of Processes: Unknown" << endl;
