@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -187,7 +185,7 @@ static const char OLD_CLASS_RETRIEVAL_ERROR [] =
                 "Error reading old repository class $0 in namespace $1.";
 
 static const char OLD_CLASS_RETRIEVAL_ERROR_KEY [] =
-            "Clients.repupgrade.RepositoryUpgrade.OLDCLASS_RETRIEVAL_ERROR";
+            "Clients.repupgrade.RepositoryUpgrade.OLD_CLASS_RETRIEVAL_ERROR";
 
 static const char OLD_DEPENDENT_CLASS_RETRIEVAL_ERROR [] =
   "Error reading old repository dependent class $0 in namespace $1.";
@@ -295,7 +293,7 @@ const char* RepositoryUpgrade::_ALL = "a";
 # elif defined(PEGASUS_OS_LINUX)
     const String OLD_REPOSITORY_PATH = "/var/opt/tog-pegasus/prev_repository";
     const String NEW_REPOSITORY_PATH = "/var/opt/tog-pegasus/repository";
-    const String RepositoryUpgrade::_LOG_PATH  = 
+    const String RepositoryUpgrade::_LOG_PATH  =
         "/var/opt/tog-pegasus/log/upgrade";
 # else
 #   undef REPUPGRADE_USE_RELEASE_DIRS
@@ -426,7 +424,7 @@ RepositoryUpgrade::RepositoryUpgrade ()
     _interopIgnoreClasses.append ( "PG_IndicationHandler" );
     _interopIgnoreClasses.append ( "PG_IndicationHandlerCIMXML" );
     _interopIgnoreClasses.append ( "PG_IndicationHandlerSNMPMapper" );
-    _interopIgnoreClasses.append ( "PG_IndicationSubscription" ); 
+    _interopIgnoreClasses.append ( "PG_IndicationSubscription" );
 
 }
 
@@ -1053,7 +1051,6 @@ void RepositoryUpgrade::_processClasses(
     //
 
     Uint32 oldCount = oldClasses.size();
-    Uint32 newCount = newClasses.size();
 
     for ( Uint32 oldclasses = 0; oldclasses < oldCount ; oldclasses++)
     {
@@ -1077,7 +1074,7 @@ void RepositoryUpgrade::_processClasses(
             }
 
             /** Ignore any "CIM_" classes in pegasus namespaces,
-             *  except root/cimv2. 
+             *  except root/cimv2.
                 Since they don't exist in 2.7 they must have been renamed
                 or deleted.
             */
@@ -1164,6 +1161,7 @@ void RepositoryUpgrade::_processExistingClasses(
                                OLD_CLASS_RETRIEVAL_ERROR,
                                existingClasses[i].getString(),
                                namespaceName.getString());
+            throw RepositoryUpgradeException(message);
         }
         catch (...)
         {
@@ -1198,6 +1196,7 @@ void RepositoryUpgrade::_processExistingClasses(
                                NEW_CLASS_RETRIEVAL_ERROR,
                                existingClasses[i].getString(),
                                namespaceName.getString());
+            throw RepositoryUpgradeException(message);
         }
         catch (...)
         {
@@ -1536,6 +1535,7 @@ Uint32 RepositoryUpgrade::_addClassToRepository (
                            OLD_CLASS_RETRIEVAL_ERROR,
                            className.getString(),
                            namespaceName.getString());
+        throw RepositoryUpgradeException(message);
     }
     catch (...)
     {
@@ -1583,7 +1583,7 @@ Uint32 RepositoryUpgrade::_addClassToRepository (
         }
         catch (CIMException& ce)
         {
-            if (ce.getCode() == CIM_ERR_NOT_FOUND)
+            if (ce.getCode() == CIM_ERR_INVALID_PARAMETER)
             {
                 CIMName dependentClassName(ce.getMessage());
 
@@ -1595,13 +1595,13 @@ Uint32 RepositoryUpgrade::_addClassToRepository (
                 //
                 if (! Contains( existingClasses, dependentClassName))
                 {
-                    // 
-                    // Check if the class that we depend on exists in 
+                    //
+                    // Check if the class that we depend on exists in
                     // the old repository.
                     // If it doesn't exist, error out.
                     //
                     try
-                    { 
+                    {
                         oldClass = _oldRepository->getClass(
                                             namespaceName,
                                             dependentClassName,
@@ -1709,7 +1709,6 @@ void RepositoryUpgrade::_addInstances(void)
                  << "class name : " <<  oldClassNames[ctr] << endl;
 #endif
                     Array<CIMInstance>         instances;
-                    Uint32                     n = 0;
                     Uint32                     ictr = 0;
 
                         instances = _oldRepository->enumerateInstancesForClass(
@@ -1889,7 +1888,7 @@ void RepositoryUpgrade::_logRequestToFile(
                 XmlWriter::indentedPrint (outFile, content, 0);
                 outFile.close();
             }
-        
+
             delete response;
         }
         nowMilliseconds = TimeValue::getCurrentTime().toMilliseconds();
@@ -2245,7 +2244,7 @@ int main (int argc, char* argv [])
     {
         RepositoryUpgrade   command;
         Uint32          retCode;
-        
+
         //l10n set message loading to process locale
         MessageLoader::_useProcessLocale = true;
 
