@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -96,7 +94,7 @@ public:
         }
         catch(Exception &e)
         {
-            cout << "Exception " << e.getMessage() 
+            cout << "Exception " << e.getMessage()
                  << " on enumerateClassNames open. Terminating." << endl;
             return false;
         }
@@ -379,7 +377,7 @@ void printHelp(char* name, OptionManager om)
     header.append(" -parameters [class]");
     header.append("  - Generate MOF output from the repository or client\n");
 
-    String trailer = 
+    String trailer =
         "\nAssumes  using repository interface and repository at\n";
     trailer.append("PEGASUS_HOME for repository unless -r specified");
     trailer.append("\nIf [class] exists only that class mof is output.");
@@ -491,7 +489,6 @@ int main(int argc, char** argv)
     Boolean verbose = om.isTrue("verbose");
 
     Boolean singleClass = true;
-    CIMName className;
 
     // Set the flags to determine whether we show all or simply some classes
     if(showAll)
@@ -572,10 +569,10 @@ int main(int argc, char** argv)
 
         location.append("/repository");
 
-        if (!FileSystem::exists(location) 
+        if (!FileSystem::exists(location)
                 || FileSystem::isDirectoryEmpty(location))
         {
-            cout << "Error. " << location << " does not exist or is empty." 
+            cout << "Error. " << location << " does not exist or is empty."
                  << endl;
             exit(1);
         }
@@ -601,8 +598,8 @@ int main(int argc, char** argv)
     }
     catch(Exception &e)
     {
-        cout << "Exception " << e.getMessage() 
-             << " on repository open. Terminating." 
+        cout << "Exception " << e.getMessage()
+             << " on repository open. Terminating."
              << endl;
         return false;
     }
@@ -621,7 +618,8 @@ int main(int argc, char** argv)
             if(showOnlyNames)
             {
                 for(Uint32 i = 0; i < qualifierDecls.size(); i++)
-                    cout << "Qualifier " << qualifierDecls[i].getName() << endl;
+                    cout << "Qualifier "
+                         << qualifierDecls[i].getName().getString() << endl;
             }
             if(showQualifiers || showAll)
             {
@@ -663,10 +661,6 @@ int main(int argc, char** argv)
     // get size for summary
     classCount = list.size();
 
-    Boolean localOnly = true;
-    Boolean includeQualifiers = true;
-    Boolean includeClassOrigin = true;
-
     if (!summary || !doNotShowClasses)
     {
         if(showOnlyNames)
@@ -683,6 +677,10 @@ int main(int argc, char** argv)
                 CIMClass cimClass;
                 try
                 {
+                    Boolean localOnly = true;
+                    Boolean includeQualifiers = true;
+                    Boolean includeClassOrigin = true;
+
                     cimClass = clRepository.getClass(nameSpace,
                                                      nextClass,
                                                      localOnly,
@@ -692,8 +690,8 @@ int main(int argc, char** argv)
                 catch(Exception& e)
                 {
                     // ErrorExit(e.getMessage());
-                    cout << "Class get error " << e.getMessage() 
-                         << " Class " << nextClass << endl;
+                    cout << "Class get error " << e.getMessage()
+                         << " Class " << nextClass.getString() << endl;
                 }
                 // Note we get and print ourselves rather than use the generic
                 // printMof
@@ -710,13 +708,13 @@ int main(int argc, char** argv)
     // Note that we can do this so we get all instances or just the given class
     }
     list.start();
-    if(showInstances | showAll)
+    if (showInstances || showAll)
     {
         // try Block around basic instance processing
         for(Uint32 j = 0; j < list.size(); j++)
         {
             CIMName className = list.next();
-            //cout << "Instances for " << className << endl;
+            //cout << "Instances for " << className.getString() << endl;
             try
             {
                 Boolean deepInheritance = true;
@@ -727,17 +725,19 @@ int main(int argc, char** argv)
                 if(showOnlyNames)
                 {
                     Array<CIMObjectPath> instanceNames;
-                    instanceNames = 
+                    instanceNames =
                         clRepository.enumerateInstanceNames(nameSpace,
                                                             className);
-                    for(Uint32 j = 0; j < instanceNames.size(); j++)
-                        cout << "Instance " << instanceNames[j].toString();
+                    for (Uint32 k = 0; k < instanceNames.size(); k++)
+                    {
+                        cout << "Instance " << instanceNames[k].toString();
+                    }
                 }
                 else    // Process complete instances
                 {
                 // Process inputClasslist to enumerate and print instances
                     Array<CIMInstance> namedInstances;
-                    namedInstances = 
+                    namedInstances =
                         clRepository.enumerateInstances(nameSpace,
                                                         className,
                                                         deepInheritance,
@@ -762,7 +762,7 @@ int main(int argc, char** argv)
             }
             catch(Exception& e)
             {
-                cout << "Error Instance Enumeration:" << e.getMessage() 
+                cout << "Error Instance Enumeration:" << e.getMessage()
                      << endl;
             }
         }
@@ -773,7 +773,7 @@ int main(int argc, char** argv)
         if(qualifierCount != 0)
             cout << "Qualifiers - " << qualifierCount << endl;
         if(classCount != 0)
-            cout << "Classes - " << classCount << " found and " 
+            cout << "Classes - " << classCount << " found and "
                  << classCountDisplayed
                  << " output" << endl;
         if(instanceCount != 0)
