@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -142,12 +140,6 @@ const char   WbemExecCommand::_DEBUG_OPTION1       = '1';
 */
 const char   WbemExecCommand::_DEBUG_OPTION2       = '2';
 
-static const char PASSWORD_PROMPT []  =
-                     "Please enter your password: ";
-
-static const char PASSWORD_BLANK []  =
-                     "Password cannot be blank. Please re-enter your password.";
-
 static const char   LONG_HELP []  = "help";
 
 static const char   LONG_VERSION []  = "version";
@@ -155,19 +147,13 @@ static const char   LONG_VERSION []  = "version";
 static const char MSG_PATH []               = "pegasus/pegasusCLI";
 static const char REQUIRED_ARGS_MISSING [] = "Required arguments missing.";
 
-static const char REQUIRED_ARGS_MISSING_KEY [] = 
+static const char REQUIRED_ARGS_MISSING_KEY [] =
     "Clients.cimuser.CIMUserCommand.REQUIRED_ARGS_MISSING";
 
-static const char ERR_OPTION_NOT_SUPPORTED [] =
-    "Invalid option. Use '--help' to obtain command syntax.";
-
-static const char ERR_OPTION_NOT_SUPPORTED_KEY [] = 
-    "Clients.CIMConfig.CIMConfigCommand.ERR_OPTION_NOT_SUPPORTED";
-
 static const char ERR_USAGE [] =
     "Use '--help' to obtain command syntax.";
 
-static const char ERR_USAGE_KEY [] = 
+static const char ERR_USAGE_KEY [] =
     "Clients.CIMConfig.CIMConfigCommand.ERR_USAGE";
 
 /**
@@ -341,10 +327,10 @@ WbemExecCommand::WbemExecCommand ()
             // Get environment variables:
             //
             const char* pegasusHome = getenv("PEGASUS_HOME");
-    
+
             String certpath = FileSystem::getAbsolutePath(
                     pegasusHome, PEGASUS_SSLCLIENT_CERTIFICATEFILE);
-    
+
             String randFile;
 
 #ifdef PEGASUS_SSL_RANDOMFILE
@@ -388,6 +374,43 @@ void WbemExecCommand::_printContent(
         //  Print XML response to the ostream
         //
         const char* content = responseMessage.getData () + contentOffset;
+
+#if defined(PEGASUS_DEBUG) && defined(PEGASUS_ENABLE_PROTOCOL_WSMAN)
+        //
+        // The response contains a unique Message ID. To allow
+        // predictable message IDs for static comparison tests, replace the
+        // response message Id with 0.
+        //
+        AutoArrayPtr<char> contentCopy;
+
+        if (const char* uuidStart = strstr(content, "<wsa:MessageID>"))
+        {
+            if (const char* uuidEnd = strstr(uuidStart, "</wsa:MessageID>"))
+            {
+                contentCopy.reset((
+                    strcpy(new char [strlen(content)+1],content)));
+
+                // The message ID starts after the last ':' char. (See,
+                // DSP0226 R5.4.4-1.). Position to the last ':' char.
+                const char* colonPos = uuidEnd;
+                for ( ; colonPos >= uuidStart && *colonPos != ':'; colonPos--);
+
+                char* beginPtr = contentCopy.get() + (colonPos+1 - content);
+                char* endPtr   = contentCopy.get() + (uuidEnd - content);
+
+                // Replace the response messageID with 0.
+                for (; beginPtr < endPtr; beginPtr++)
+                {
+                    if (*beginPtr != '-')
+                    {
+                        *beginPtr = '0';
+                    }
+                }
+
+                content = contentCopy.get();
+            }
+        }
+#endif
         XmlWriter::indentedPrint (oStream, content, 0);
     }
 }
@@ -416,7 +439,6 @@ void WbemExecCommand::_handleResponse( Buffer           responseMessage,
     Uint32                       contentLength;
     Uint32                       contentOffset       = 0;
     HTTPMessage                  httpMessage(responseMessage, 0);
-    Boolean                      needsAuthentication = false;
 
     httpMessage.parse(startLine, headers, contentLength);
     if( contentLength > 0 )
@@ -1067,7 +1089,7 @@ void WbemExecCommand::setCommand (Uint32 argc, char* argv [])
     }
     else
     {
-        if (_timeout <= 0)
+        if (_timeout == 0)
         {
             //
             //  Timeout out of valid range
@@ -1170,7 +1192,7 @@ int main (int argc, char* argv [])
     }
     catch (const CommandFormatException& cfe)
     {
-        cerr << WbemExecCommand::COMMAND_NAME << ": " << cfe.getMessage() 
+        cerr << WbemExecCommand::COMMAND_NAME << ": " << cfe.getMessage()
             << endl;
 
         MessageLoaderParms parms(ERR_USAGE_KEY,ERR_USAGE);
