@@ -1,35 +1,34 @@
 /*
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//%/////////////////////////////////////////////////////////////////////////////
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 */
+
 #include <sys/time.h>
 #include <sys/resource.h>
 #include <sys/types.h>
@@ -73,7 +72,7 @@
 
 static void _sigHandler(int signum)
 {
-    globals.signalMask |= (1 << signum);
+    globals.signalMask |= (1UL << signum);
 }
 
 /*
@@ -205,7 +204,7 @@ static void HandleOpenFileRequest(int sock)
             }
         }
         /* If the open call fails with ENOENT errno,then create the file.
-        If the umask is set to a non default value,then the file will not 
+        If the umask is set to a non default value,then the file will not
         get created with permissions specified in the open system call.
         So set the permissions for the file explicitly using fchmod.
         */
@@ -322,6 +321,8 @@ static void HandleStartProviderAgentRequest(int sock)
 
         if (pipe(from) != 0)
         {
+            close(to[0]);
+            close(to[1]);
             status = -1;
             break;
         }
@@ -333,6 +334,10 @@ static void HandleStartProviderAgentRequest(int sock)
         if (pid < 0)
         {
             Log(LL_SEVERE, "fork failed");
+            close(to[0]);
+            close(to[1]);
+            close(from[0]);
+            close(from[1]);
             status = -1;
             break;
         }
@@ -409,14 +414,14 @@ static void HandleStartProviderAgentRequest(int sock)
                 request.module);
             _exit(1);
         }
+
+        /* We are the parent process.  Close the child's ends of the pipes. */
+
+        close(to[0]);
+        close(from[1]);
     }
     while (0);
 
-    /* Close unused pipe descriptors. */
-
-    close(to[0]);
-    close(from[1]);
-
     /* Send response. */
 
     response.status = status;
@@ -449,7 +454,6 @@ static void HandleStartProviderAgentRequest(int sock)
 static void HandleDaemonizeExecutorRequest(int sock)
 {
     struct ExecutorDaemonizeExecutorResponse response;
-    int pid;
 
     memset(&response, 0, sizeof(response));
 
@@ -650,7 +654,7 @@ static void HandleAuthenticatePasswordRequest(int sock)
     while (0);
 
     Log(LL_TRACE, "Basic authentication attempt: username = %s, "
-        "successful = %s", 
+        "successful = %s",
         request.username, status == 0 ? "TRUE" : "FALSE" );
 
     /* Send response message. */
