@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -89,7 +87,10 @@ String getStatementString(const String& stmt)
 }
 
 
-void printProperty(CIMProperty& prop, Uint32 propNum, String& prefix)
+void printProperty(
+    const CIMProperty& prop,
+    Uint32 propNum,
+    const String& prefix)
 {
     // Recursive function to handle embedded object trees
 
@@ -98,12 +99,8 @@ void printProperty(CIMProperty& prop, Uint32 propNum, String& prefix)
 
     CIMValue val = prop.getValue();
 
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
     CIMType valType = val.getType();
     if (valType != CIMTYPE_OBJECT && valType != CIMTYPE_INSTANCE)
-#else
-    if (val.getType() != CIMTYPE_OBJECT)
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
     {
         // Not embedded object
         if (val.isNull())
@@ -119,7 +116,6 @@ void printProperty(CIMProperty& prop, Uint32 propNum, String& prefix)
     {
         // Embedded object, or array of objects
         Array<CIMObject> embObjs;
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
         if (val.isArray())
         {
             if (valType == CIMTYPE_INSTANCE)
@@ -152,18 +148,6 @@ void printProperty(CIMProperty& prop, Uint32 propNum, String& prefix)
             embObjs.append(tmpObj);
         }
     }
-#else
-    if (val.isArray())
-    {
-        val.get(embObjs);
-    }
-    else
-    {
-        CIMObject tmpObj;
-        val.get(tmpObj);
-        embObjs.append(tmpObj);
-    }
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
 
     for (Uint32 j = 0; j < embObjs.size(); j++)
     {
@@ -202,8 +186,7 @@ void printProperty(CIMProperty& prop, Uint32 propNum, String& prefix)
             {
                 for (Uint32 n = 0; n < cnt; n++)
                 {
-                    CIMProperty prop = embInst.getProperty(n);
-                    printProperty(prop, n, newPrefix);
+                    printProperty(embInst.getProperty(n), n, newPrefix);
                 }
             }
         }
