@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -45,6 +43,7 @@ PEGASUS_USING_STD;
 
 PEGASUS_NAMESPACE_BEGIN
 
+
 ///////////////////////////////////////////////////////////////////////////////
 //
 // CIMClientRep
@@ -56,7 +55,9 @@ CIMClientRep::CIMClientRep(Uint32 timeoutMilliseconds)
     MessageQueue(PEGASUS_QUEUENAME_CLIENT),
     _timeoutMilliseconds(timeoutMilliseconds),
     _connected(false),
-    _doReconnect(false)
+    _doReconnect(false),
+    _binaryRequest(false),
+    _binaryResponse(false)
 {
     //
     // Create Monitor and HTTPConnector
@@ -91,7 +92,7 @@ Uint32 _getShowType(String& s)
     return 0;
 }
 
-void CIMClientRep::_connect()
+void CIMClientRep::_connect(bool binaryRequest, bool binaryResponse)
 {
     //
     // Test for Display optons of the form
@@ -157,7 +158,9 @@ void CIMClientRep::_connect()
 
     AutoPtr<CIMOperationRequestEncoder> requestEncoder(
         new CIMOperationRequestEncoder(
-            httpConnection.get(), connectHost, &_authenticator, showOutput));
+            httpConnection.get(), connectHost, &_authenticator, showOutput,
+            binaryRequest,
+            binaryResponse));
 
     _responseDecoder.reset(responseDecoder.release());
     _httpConnection = httpConnection.release();
@@ -170,6 +173,8 @@ void CIMClientRep::_connect()
 
     _doReconnect = false;
     _connected = true;
+    _binaryRequest = binaryRequest;
+    _binaryResponse = binaryResponse;
     _httpConnection->setSocketWriteTimeout(_timeoutMilliseconds/1000+1);
 }
 
@@ -220,10 +225,11 @@ void CIMClientRep::connect(
         throw AlreadyConnectedException();
 
     //
-    // If the host is empty, set hostName to "localhost"
+    // If the host is empty and port is valid, set hostName to "localhost"
+    // Otherwise, HTTPConnector will use the unix domain socket.
     //
     String hostName = host;
-    if (host == String::EMPTY)
+    if (!host.size() && (portNumber != 0))
     {
         hostName = "localhost";
     }
@@ -246,8 +252,7 @@ void CIMClientRep::connect(
     _connectSSLContext.reset();
     _connectHost = hostName;
     _connectPortNumber = portNumber;
-
-    _connect();
+    _connect(_binaryRequest, _binaryResponse);
 }
 
 
@@ -292,12 +297,20 @@ void CIMClientRep::connect(
     _connectPortNumber = portNumber;
 
     _connectSSLContext.reset(new SSLContext(sslContext));
-    _connect();
+    _connect(_binaryRequest, _binaryResponse);
 }
 
 
 void CIMClientRep::connectLocal()
 {
+#if defined(PEGASUS_ENABLE_PROTOCOL_BINARY)
+    bool binaryRequest = true;
+    bool binaryResponse = true;
+#else
+    bool binaryRequest = false;
+    bool binaryResponse = false;
+#endif
+
     //
     // If already connected, bail out!
     //
@@ -314,7 +327,7 @@ void CIMClientRep::connectLocal()
     _connectSSLContext.reset();
     _connectHost = String::EMPTY;
     _connectPortNumber = 0;
-    _connect();
+    _connect(binaryRequest, binaryResponse);
 #else
 
     try
@@ -332,7 +345,7 @@ void CIMClientRep::connectLocal()
 
         _connectSSLContext.reset();
 
-        _connect();
+        _connect(binaryRequest, binaryResponse);
     }
     catch (const CannotConnectException &)
     {
@@ -363,7 +376,7 @@ void CIMClientRep::connectLocal()
         _connectSSLContext.reset(
             new SSLContext(String::EMPTY, NULL, randFile));
 
-        _connect();
+        _connect(binaryRequest, binaryResponse);
     }
 #endif
 }
@@ -464,7 +477,7 @@ CIMInstance CIMClientRep::getInstance(
 
     AutoPtr<CIMGetInstanceResponseMessage> destroyer(response);
 
-    return response->cimInstance;
+    return response->getCimInstance();
 }
 
 void CIMClientRep::deleteClass(
@@ -671,7 +684,7 @@ Array<CIMInstance> CIMClientRep::enumerateInstances(
 
     AutoPtr<CIMEnumerateInstancesResponseMessage> destroyer(response);
 
-    return response->cimNamedInstances;
+    return response->getNamedInstances();
 }
 
 Array<CIMObjectPath> CIMClientRep::enumerateInstanceNames(
@@ -1002,7 +1015,7 @@ Message* CIMClientRep::_doRequest(
 
     if (_doReconnect)
     {
-        _connect();
+        _connect(_binaryRequest, _binaryResponse);
         _doReconnect = false;
     }
 
@@ -1042,7 +1055,11 @@ Message* CIMClientRep::_doRequest(
 
     Uint64 startMilliseconds = TimeValue::getCurrentTime().toMilliseconds();
     Uint64 nowMilliseconds = startMilliseconds;
+#ifdef PEGASUS_DISABLE_CLIENT_TIMEOUT
+    Uint64 stopMilliseconds = (Uint64) -1;
+#else
     Uint64 stopMilliseconds = nowMilliseconds + _timeoutMilliseconds;
+#endif
 
     while (nowMilliseconds < stopMilliseconds)
     {
@@ -1200,7 +1217,7 @@ Message* CIMClientRep::_doRequest(
                 //
                 if (_doReconnect)
                 {
-                    _connect();
+                    _connect(_binaryRequest, _binaryResponse);
                 }
 
                 _requestEncoder->enqueue(response.release());
