@@ -1,37 +1,36 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
 #include <Pegasus/Common/Config.h>
+#include <Pegasus/Common/BinaryCodec.h>
 #include <iostream>
 #include <Pegasus/Common/Constants.h>
 #include <Pegasus/Common/XmlWriter.h>
@@ -47,13 +46,17 @@ CIMOperationRequestEncoder::CIMOperationRequestEncoder(
     MessageQueue* outputQueue,
     const String& hostName,
     ClientAuthenticator* authenticator,
-    Uint32 showOutput)
+    Uint32 showOutput,
+    bool binaryRequest,
+    bool binaryResponse)
     :
     MessageQueue(PEGASUS_QUEUENAME_OPREQENCODER),
     _outputQueue(outputQueue),
     _hostName(hostName.getCString()),
     _authenticator(authenticator),
-    _showOutput(showOutput)
+    _showOutput(showOutput),
+    _binaryRequest(binaryRequest),
+    _binaryResponse(binaryResponse)
 {
     dataStore_prt=NULL;
 }
@@ -71,6 +74,34 @@ void CIMOperationRequestEncoder::handleEnqueue()
 
     _authenticator->setRequestMessage(message);
 
+    //
+    // Encode request as binary request.
+    //
+
+    if (_binaryRequest)
+    {
+        CIMOperationRequestMessage* msg =
+            dynamic_cast<CIMOperationRequestMessage*>(message);
+
+        if (msg)
+        {
+            Buffer buf;
+
+            if (BinaryCodec::encodeRequest(buf, _hostName,
+                _authenticator->buildRequestAuthHeader(), msg, _binaryResponse))
+            {
+                _sendRequest(buf);
+                return;
+            }
+
+            // Drop through and encode as an XML request below.
+        }
+    }
+
+    //
+    // Encode request as an XML request.
+    //
+
     switch (message->getType())
     {
         case CIM_CREATE_CLASS_REQUEST_MESSAGE:
@@ -226,7 +257,7 @@ void CIMOperationRequestEncoder::_encodeCreateClassRequest(
             AcceptLanguageListContainer::NAME)).getLanguages(),
         ((ContentLanguageListContainer)message->operationContext.get(
             ContentLanguageListContainer::NAME)).getLanguages(),
-        params);
+        params, _binaryResponse);
     _sendRequest(buffer);
 }
 
@@ -259,7 +290,7 @@ void CIMOperationRequestEncoder::_encodeGetClassRequest(
             AcceptLanguageListContainer::NAME)).getLanguages(),
         ((ContentLanguageListContainer)message->operationContext.get(
             ContentLanguageListContainer::NAME)).getLanguages(),
-        params);
+        params, _binaryResponse);
 
     _sendRequest(buffer);
 }
@@ -280,7 +311,7 @@ void CIMOperationRequestEncoder::_encodeModifyClassRequest(
             AcceptLanguageListContainer::NAME)).getLanguages(),
         ((ContentLanguageListContainer)message->operationContext.get(
             ContentLanguageListContainer::NAME)).getLanguages(),
-        params);
+        params, _binaryResponse);
 
     _sendRequest(buffer);
 }
@@ -305,7 +336,7 @@ void CIMOperationRequestEncoder::_encodeEnumerateClassNamesRequest(
             AcceptLanguageListContainer::NAME)).getLanguages(),
         ((ContentLanguageListContainer)message->operationContext.get(
             ContentLanguageListContainer::NAME)).getLanguages(),
-        params);
+        params, _binaryResponse);
 
     _sendRequest(buffer);
 }
@@ -341,7 +372,7 @@ void CIMOperationRequestEncoder::_encodeEnumerateClassesRequest(
             AcceptLanguageListContainer::NAME)).getLanguages(),
         ((ContentLanguageListContainer)message->operationContext.get(
             ContentLanguageListContainer::NAME)).getLanguages(),
-        params);
+        params, _binaryResponse);
 
     _sendRequest(buffer);
 }
@@ -363,7 +394,7 @@ void CIMOperationRequestEncoder::_encodeDeleteClassRequest(
             AcceptLanguageListContainer::NAME)).getLanguages(),
         ((ContentLanguageListContainer)message->operationContext.get(
             ContentLanguageListContainer::NAME)).getLanguages(),
-        params);
+        params, _binaryResponse);
 
     _sendRequest(buffer);
 }
@@ -384,7 +415,7 @@ void CIMOperationRequestEncoder::_encodeCreateInstanceRequest(
             AcceptLanguageListContainer::NAME)).getLanguages(),
         ((ContentLanguageListContainer)message->operationContext.get(
             ContentLanguageListContainer::NAME)).getLanguages(),
-        params);
+        params, _binaryResponse);
 
     _sendRequest(buffer);
 }
@@ -421,7 +452,7 @@ void CIMOperationRequestEncoder::_encodeGetInstanceRequest(
             AcceptLanguageListContainer::NAME)).getLanguages(),
         ((ContentLanguageListContainer)message->operationContext.get(
             ContentLanguageListContainer::NAME)).getLanguages(),
-        params);
+        params, _binaryResponse);
 
     _sendRequest(buffer);
 }
@@ -449,7 +480,7 @@ void CIMOperationRequestEncoder::_encodeModifyInstanceRequest(
             AcceptLanguageListContainer::NAME)).getLanguages(),
         ((ContentLanguageListContainer)message->operationContext.get(
             ContentLanguageListContainer::NAME)).getLanguages(),
-        params);
+        params, _binaryResponse);
 
     _sendRequest(buffer);
 }
@@ -471,7 +502,7 @@ void CIMOperationRequestEncoder::_encodeEnumerateInstanceNamesRequest(
             AcceptLanguageListContainer::NAME)).getLanguages(),
         ((ContentLanguageListContainer)message->operationContext.get(
             ContentLanguageListContainer::NAME)).getLanguages(),
-        params);
+        params, _binaryResponse);
 
     _sendRequest(buffer);
 }
@@ -510,7 +541,7 @@ void CIMOperationRequestEncoder::_encodeEnumerateInstancesRequest(
             AcceptLanguageListContainer::NAME)).getLanguages(),
         ((ContentLanguageListContainer)message->operationContext.get(
             ContentLanguageListContainer::NAME)).getLanguages(),
-        params);
+        params, _binaryResponse);
 
     _sendRequest(buffer);
 }
@@ -531,7 +562,7 @@ void CIMOperationRequestEncoder::_encodeDeleteInstanceRequest(
             AcceptLanguageListContainer::NAME)).getLanguages(),
         ((ContentLanguageListContainer)message->operationContext.get(
             ContentLanguageListContainer::NAME)).getLanguages(),
-        params);
+        params, _binaryResponse);
 
     _sendRequest(buffer);
 }
@@ -555,7 +586,7 @@ void CIMOperationRequestEncoder::_encodeGetPropertyRequest(
             AcceptLanguageListContainer::NAME)).getLanguages(),
         ((ContentLanguageListContainer)message->operationContext.get(
             ContentLanguageListContainer::NAME)).getLanguages(),
-        params);
+        params, _binaryResponse);
 
     _sendRequest(buffer);
 }
@@ -583,7 +614,7 @@ void CIMOperationRequestEncoder::_encodeSetPropertyRequest(
             AcceptLanguageListContainer::NAME)).getLanguages(),
         ((ContentLanguageListContainer)message->operationContext.get(
             ContentLanguageListContainer::NAME)).getLanguages(),
-        params);
+        params, _binaryResponse);
 
     _sendRequest(buffer);
 }
@@ -603,7 +634,7 @@ void CIMOperationRequestEncoder::_encodeSetQualifierRequest(
             AcceptLanguageListContainer::NAME)).getLanguages(),
         ((ContentLanguageListContainer)message->operationContext.get(
             ContentLanguageListContainer::NAME)).getLanguages(),
-        params);
+        params, _binaryResponse);
 
     _sendRequest(buffer);
 }
@@ -625,7 +656,7 @@ void CIMOperationRequestEncoder::_encodeGetQualifierRequest(
             AcceptLanguageListContainer::NAME)).getLanguages(),
         ((ContentLanguageListContainer)message->operationContext.get(
             ContentLanguageListContainer::NAME)).getLanguages(),
-        params);
+        params, _binaryResponse);
 
     _sendRequest(buffer);
 }
@@ -643,7 +674,7 @@ void CIMOperationRequestEncoder::_encodeEnumerateQualifiersRequest(
             AcceptLanguageListContainer::NAME)).getLanguages(),
         ((ContentLanguageListContainer)message->operationContext.get(
             ContentLanguageListContainer::NAME)).getLanguages(),
-        params);
+        params, _binaryResponse);
 
     _sendRequest(buffer);
 }
@@ -665,7 +696,7 @@ void CIMOperationRequestEncoder::_encodeDeleteQualifierRequest(
             AcceptLanguageListContainer::NAME)).getLanguages(),
         ((ContentLanguageListContainer)message->operationContext.get(
             ContentLanguageListContainer::NAME)).getLanguages(),
-        params);
+        params, _binaryResponse);
 
     _sendRequest(buffer);
 }
@@ -699,7 +730,7 @@ void CIMOperationRequestEncoder::_encodeReferenceNamesRequest(
             AcceptLanguageListContainer::NAME)).getLanguages(),
         ((ContentLanguageListContainer)message->operationContext.get(
             ContentLanguageListContainer::NAME)).getLanguages(),
-        params);
+        params, _binaryResponse);
 
     _sendRequest(buffer);
 }
@@ -743,7 +774,7 @@ void CIMOperationRequestEncoder::_encodeReferencesRequest(
             AcceptLanguageListContainer::NAME)).getLanguages(),
         ((ContentLanguageListContainer)message->operationContext.get(
             ContentLanguageListContainer::NAME)).getLanguages(),
-        params);
+        params, _binaryResponse);
 
     _sendRequest(buffer);
 }
@@ -790,7 +821,7 @@ void CIMOperationRequestEncoder::_encodeAssociatorNamesRequest(
             AcceptLanguageListContainer::NAME)).getLanguages(),
         ((ContentLanguageListContainer)message->operationContext.get(
             ContentLanguageListContainer::NAME)).getLanguages(),
-        params);
+        params, _binaryResponse);
 
     _sendRequest(buffer);
 }
@@ -847,7 +878,7 @@ void CIMOperationRequestEncoder::_encodeAssociatorsRequest(
             AcceptLanguageListContainer::NAME)).getLanguages(),
         ((ContentLanguageListContainer)message->operationContext.get(
             ContentLanguageListContainer::NAME)).getLanguages(),
-        params);
+        params, _binaryResponse);
 
     _sendRequest(buffer);
 }
@@ -871,7 +902,7 @@ void CIMOperationRequestEncoder::_encodeExecQueryRequest(
             AcceptLanguageListContainer::NAME)).getLanguages(),
         ((ContentLanguageListContainer)message->operationContext.get(
             ContentLanguageListContainer::NAME)).getLanguages(),
-        params);
+        params, _binaryResponse);
 
     _sendRequest(buffer);
 }
@@ -886,7 +917,8 @@ void CIMOperationRequestEncoder::_encodeInvokeMethodRequest(
         ((AcceptLanguageListContainer)message->operationContext.get(
             AcceptLanguageListContainer::NAME)).getLanguages(),
         ((ContentLanguageListContainer)message->operationContext.get(
-            ContentLanguageListContainer::NAME)).getLanguages());
+            ContentLanguageListContainer::NAME)).getLanguages(),
+        _binaryResponse);
 
     _sendRequest(buffer);
 }
@@ -904,12 +936,16 @@ void CIMOperationRequestEncoder::_sendRequest(Buffer& buffer)
     }
     if (_showOutput & 2)
     {
-        Logger::put(Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
+        Logger::put(
+            Logger::STANDARD_LOG,
+            System::CIMSERVER,
+            Logger::INFORMATION,
             "CIMOperationRequestEncoder::SendRequest, XML content: $1",
             buffer.getData());
     }
 #endif
 
+
     HTTPMessage * http_request = new HTTPMessage(buffer);
 
     // these variables are needed to call HTTPMessage::parse, all we need
