@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -41,6 +39,7 @@
 #include <Pegasus/Common/HTTPMessage.h>
 #include <Pegasus/Common/CIMMessage.h>
 #include <Pegasus/Common/Exception.h>
+#include <Pegasus/Common/BinaryCodec.h>
 #include "CIMOperationResponseDecoder.h"
 
 #include <Pegasus/Common/MessageLoader.h>
@@ -108,10 +107,9 @@ void CIMOperationResponseDecoder::_handleHTTPMessage(HTTPMessage* httpMessage)
     //
     TimeValue networkEndTime = TimeValue::getCurrentTime();
 
-    String  connectClose;
     String  startLine;
     Array<HTTPHeader> headers;
-    char*   content;
+    const char* content;
     Uint32  contentLength;
     Boolean cimReconnect=false;
 
@@ -138,9 +136,10 @@ void CIMOperationResponseDecoder::_handleHTTPMessage(HTTPMessage* httpMessage)
     //
     // Check for Connection: Close
     //
+    const char* connectClose;
     if (HTTPMessage::lookupHeader(headers, "Connection", connectClose, false))
     {
-        if (String::equalNoCase(connectClose, "Close"))
+        if (System::strcasecmp(connectClose, "Close") == 0)
         {
             //reconnect and then resend next request.
             cimReconnect=true;
@@ -184,7 +183,7 @@ void CIMOperationResponseDecoder::_handleHTTPMessage(HTTPMessage* httpMessage)
     {
         Logger::put(Logger::STANDARD_LOG,
             System::CIMSERVER,
-            Logger::TRACE,
+            Logger::INFORMATION,
             "CIMOperationRequestDecoder::Response, XML content: $1",
             httpMessage->message.getData());
     }
@@ -275,7 +274,7 @@ void CIMOperationResponseDecoder::_handleHTTPMessage(HTTPMessage* httpMessage)
     //
     // Search for "CIMOperation" header:
     //
-    String cimOperation;
+    const char* cimOperation;
 
     if (!HTTPMessage::lookupHeader(
         headers, "CIMOperation", cimOperation, true))
@@ -307,23 +306,29 @@ void CIMOperationResponseDecoder::_handleHTTPMessage(HTTPMessage* httpMessage)
     // content-type header  value format:
     //              type "/" subtype *( ";" parameter )
     // ex. text/xml;Charset="utf8"
-    String cimContentType;
+    const char* cimContentType;
+    bool binaryResponse = false;
 
     if (HTTPMessage::lookupHeader(
             headers, "Content-Type", cimContentType, true))
     {
-        Uint32 len;
-        String contentTypeValue;
-        if ((len = cimContentType.find(';')) != PEG_NOT_FOUND)
-            contentTypeValue = cimContentType.subString(0,len);
-        else
-            contentTypeValue = cimContentType;
+        String type;
+        String charset;
 
-        if (!HTTPMessage::isSupportedContentType(contentTypeValue))
+        if (!HTTPMessage::parseContentTypeHeader(
+                cimContentType, type, charset) ||
+            ((!String::equalNoCase(type, "application/xml") &&
+             !String::equalNoCase(type, "text/xml")) ||
+            !String::equalNoCase(charset, "utf-8"))
+#if defined(PEGASUS_ENABLE_PROTOCOL_BINARY)
+            && !(binaryResponse=String::equalNoCase(
+                type, "application/x-openpegasus"))
+#endif
+        )
         {
             CIMClientMalformedHTTPException* malformedHTTPException = new
-                CIMClientMalformedHTTPException
-                    ("Bad Content-Type HTTP header; " + contentTypeValue);
+                CIMClientMalformedHTTPException(
+                    "Bad Content-Type HTTP header; " + String(cimContentType));
             ClientExceptionMessage * response =
                 new ClientExceptionMessage(malformedHTTPException);
 
@@ -354,19 +359,19 @@ void CIMOperationResponseDecoder::_handleHTTPMessage(HTTPMessage* httpMessage)
     // look for any cim status codes. The HTTPConnection level would have
     // added them here.
 
-    String cimStatusCodeValue;
+    const char* cimStatusCodeValue;
     Boolean found = HTTPMessage::lookupHeader(headers, "CIMStatusCode",
         cimStatusCodeValue, true);
     CIMStatusCode cimStatusCodeNumber = CIM_ERR_SUCCESS;
 
-    if (found == true &&
-        (cimStatusCodeNumber = (CIMStatusCode)
-         atoi(cimStatusCodeValue.getCString())) != CIM_ERR_SUCCESS)
+    if (found &&
+        (cimStatusCodeNumber = (CIMStatusCode) atoi(cimStatusCodeValue)) !=
+             CIM_ERR_SUCCESS)
     {
         String cimStatusCodeDescription;
         found = HTTPMessage::lookupHeader(headers, "CIMStatusCodeDescription",
             cimStatusCodeDescription, true);
-        if (found == true && cimStatusCodeDescription.size() > 0)
+        if (found && cimStatusCodeDescription.size() > 0)
         {
             try
             {
@@ -389,11 +394,12 @@ void CIMOperationResponseDecoder::_handleHTTPMessage(HTTPMessage* httpMessage)
         _outputQueue->enqueue(response);
         return;
     }
-    String serverTime;
+
+    const char* serverTime;
     if (HTTPMessage::lookupHeader(
             headers, "WBEMServerResponseTime", serverTime, true))
     {
-        Uint32 sTime = (Uint32) atol(serverTime.getCString());
+        Uint32 sTime = (Uint32) atol(serverTime);
         dataStore->setServerTime(sTime);
     }
 
@@ -401,14 +407,14 @@ void CIMOperationResponseDecoder::_handleHTTPMessage(HTTPMessage* httpMessage)
     // Calculate the beginning of the content from the message size and
     // the content length.
 
-    content = (char *) httpMessage->message.getData() +
+    content = httpMessage->message.getData() +
         httpMessage->message.size() - contentLength;
 
     //
     // If it is a method response, then dispatch it to be handled:
     //
 
-    if (!String::equalNoCase(cimOperation, "MethodResponse"))
+    if (System::strcasecmp(cimOperation, "MethodResponse") != 0)
     {
         MessageLoaderParms mlParms(
             "Client.CIMOperationResponseDecoder.EXPECTED_METHODRESPONSE",
@@ -431,16 +437,39 @@ void CIMOperationResponseDecoder::_handleHTTPMessage(HTTPMessage* httpMessage)
 
     dataStore->setResponseSize(contentLength);
     dataStore->setEndNetworkTime(networkEndTime);
-    _handleMethodResponse(content, httpMessage->contentLanguages,cimReconnect);
+    _handleMethodResponse(content, contentLength,
+        httpMessage->contentLanguages, cimReconnect, binaryResponse);
 }
 
 void CIMOperationResponseDecoder::_handleMethodResponse(
-    char* content,
+    const char* content,
+    Uint32 contentLength,
     const ContentLanguageList& contentLanguages,
-    Boolean cimReconnect)
+    Boolean cimReconnect,
+    Boolean binaryResponse)
 {
     Message* response = 0;
 
+    //
+    // Decode binary messages up-front and skip remainder:
+    //
+
+    if (binaryResponse)
+    {
+        // Note: this may throw an excpetion which will be caught by caller.
+
+        Buffer in(content, contentLength);
+
+        CIMResponseMessage* msg = BinaryCodec::decodeResponse(in);
+
+        msg->operationContext.set(
+            ContentLanguageListContainer(contentLanguages));
+        msg->setCloseConnect(cimReconnect);
+        _outputQueue->enqueue(msg);
+
+        return;
+    }
+
     //
     // Create and initialize XML parser:
     //
@@ -498,12 +527,12 @@ void CIMOperationResponseDecoder::_handleMethodResponse(
             CIMClientResponseException* responseException =
                 new CIMClientResponseException(mlString);
 
-            ClientExceptionMessage * response =
+            ClientExceptionMessage * clientExceptionMessage =
                 new ClientExceptionMessage(responseException);
 
-            response->setCloseConnect(cimReconnect);
+            clientExceptionMessage->setCloseConnect(cimReconnect);
 
-            _outputQueue->enqueue(response);
+            _outputQueue->enqueue(clientExceptionMessage);
             return;
         }
 
@@ -668,11 +697,6 @@ void CIMOperationResponseDecoder::_handleMethodResponse(
     }
     catch (XmlException& x)
     {
-        Logger::put(Logger::ERROR_LOG, System::CIMSERVER, Logger::TRACE,
-            "CIMOperationResponseDecoder::_handleMethodResponse - "
-                "XmlException has occurred. Message: $0",
-            x.getMessage());
-
         if (response)
         {
 //#ifdef PEGASUS_SNIA_INTEROP_TEST
@@ -1027,8 +1051,7 @@ CIMGetInstanceResponseMessage*
         return new CIMGetInstanceResponseMessage(
             messageId,
             cimException,
-            QueueIdStack(),
-            CIMInstance());
+            QueueIdStack());
     }
     else if (XmlReader::testStartTagOrEmptyTag(parser, entry, "IRETURNVALUE"))
     {
@@ -1045,11 +1068,12 @@ CIMGetInstanceResponseMessage*
 
         XmlReader::expectEndTag(parser, "IRETURNVALUE");
 
-        return new CIMGetInstanceResponseMessage(
+        CIMGetInstanceResponseMessage* msg = new CIMGetInstanceResponseMessage(
             messageId,
             cimException,
-            QueueIdStack(),
-            cimInstance);
+            QueueIdStack());
+        msg->setCimInstance(cimInstance);
+        return msg;
     }
     else
     {
@@ -1163,8 +1187,7 @@ CIMEnumerateInstancesResponseMessage*
             return new CIMEnumerateInstancesResponseMessage(
                 messageId,
                 cimException,
-                QueueIdStack(),
-                Array<CIMInstance>());
+                QueueIdStack());
         }
 
         if (XmlReader::testStartTagOrEmptyTag(parser, entry, "IRETURNVALUE"))
@@ -1184,11 +1207,15 @@ CIMEnumerateInstancesResponseMessage*
         }
     }
 
-    return new CIMEnumerateInstancesResponseMessage(
+    CIMEnumerateInstancesResponseMessage* msg;
+
+    msg = new CIMEnumerateInstancesResponseMessage(
         messageId,
         cimException,
-        QueueIdStack(),
-        namedInstances);
+        QueueIdStack());
+
+    msg->setNamedInstances(namedInstances);
+    return msg;
 }
 
 CIMDeleteInstanceResponseMessage*
