@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -56,6 +54,10 @@ extern char** environ;
 
 #ifdef PEGASUS_ENABLE_AUDIT_LOGGER
 
+#if defined(PEGASUS_OS_SOLARIS)
+extern char** environ;
+#endif
+
 PEGASUS_USING_STD;
 
 PEGASUS_NAMESPACE_BEGIN
@@ -393,7 +395,7 @@ void AuditLogger::logBasicAuthentication(
     MessageLoaderParms msgParms(
         "Common.AuditLogger.BASIC_AUTHENTICATION",
         "Basic authentication attempt: "
-        "successful = $0, user = $1, IP address = $2.",
+        "successful = $0, from IP address = $2, user = $1.",
         CIMValue(successful).toString(),
         userName,
         ipAddr);
@@ -415,8 +417,8 @@ void AuditLogger::logCertificateBasedAuthentication(
     MessageLoaderParms msgParms(
         "Common.AuditLogger.CERTIFICATE_BASED_AUTHENTICATION",
         "Certificate based authentication attempt: "
-            "successful = $0, issuer = $1, subject = $2, serialNumber = $3, "
-            "IP address = $4.",
+            "successful = $0, from IP address = $4, issuer = $1, "
+            "subject = $2, serialNumber = $3.",
         CIMValue(successful).toString(),
         issuerName,
         subjectName,
@@ -441,8 +443,8 @@ void AuditLogger::logCertificateBasedUserValidation(
     MessageLoaderParms msgParms(
         "Common.AuditLogger.CERTIFICATE_BASED_USER_VALIDATION",
         "Certificate based user validation attempt: "
-            "successful = $0, userName = $1, issuer = $2, subject = $3, "
-            "serialNumber = $4, IP address = $5.",
+            "successful = $0, from IP address = $5, userName = $1, "
+            "issuer = $2,  subject = $3, serialNumber = $4.",
         CIMValue(successful).toString(),
         userName,
         issuerName,
@@ -514,11 +516,9 @@ void AuditLogger::_writeAuditMessageToLog(
     Uint32 logLevel,
     MessageLoaderParms & msgParms)
 {
-    String localizedMsg = MessageLoader::getMessage(msgParms);
-
     String identifier = "cimserver audit";
 
-    Logger::put(Logger::AUDIT_LOG, identifier, logLevel, localizedMsg);
+    Logger::put_l(Logger::AUDIT_LOG, identifier, logLevel, msgParms);
 }
 
 String AuditLogger::_getModuleStatusValue(
