@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -61,7 +59,7 @@ Boolean _isInternalWriterUsed = true;
 // - Instantiate the smf helper class.
 Audit_zOS_SMF _smf;
 
-// Definition of the CIM operation types for the 
+// Definition of the CIM operation types for the
 // CIM operation SMF record.
 enum _smf_cim_oper_type {
     CLASS_OPERATION=0,
@@ -100,14 +98,14 @@ void AuditLogger::logCurrentConfig(
     // check if SMF is gathering this type of records.
     if (_smf.isRecording(CONFIGURATION) ||
         (! _isInternalWriterUsed) )
-    {   
+    {
         unsigned char * confRecord;
         unsigned char * cursor;
         int cursorOffset;
 
         _smf86_configuration * confSection;
         int nameLen;
-        int valueLen; 
+        int valueLen;
 
         // For all properties write a record.
         for (Uint32 i = 0; i < propertyNames.size(); i++)
@@ -136,12 +134,12 @@ void AuditLogger::logCurrentConfig(
             // Configutation is listed
             confSection->PropChange = 0;
 
-            // The variable values are starting 
+            // The variable values are starting
             // at the end of the subtype section.
             cursor = confRecord + sizeof(_smf86_configuration_record);
             cursorOffset = sizeof(_smf86_configuration);
 
-           // Set the propety name 
+           // Set the propety name
            confSection->NameOf = cursorOffset;
            confSection->NameNo = 1;
            confSection->NameLen = nameLen;
@@ -151,7 +149,7 @@ void AuditLogger::logCurrentConfig(
 
            cursor = cursor + nameLen;
            cursorOffset = cursorOffset + nameLen;
-           
+
            // Set the property value.
            confSection->ValueOf = cursorOffset;
            confSection->ValueNo = 1;
@@ -177,7 +175,7 @@ void AuditLogger::logCurrentRegProvider(
     // check if SMF is gathering this type of records.
     if (_smf.isRecording(CONFIGURATION) ||
         (! _isInternalWriterUsed) )
-    {   
+    {
         unsigned char * provStatRecord;
         unsigned char * cursor;
         int cursorOffset;
@@ -205,7 +203,7 @@ void AuditLogger::logCurrentRegProvider(
 
             // Initialize the header and product section.
             // The length is the total of subtype section + variable parts.
-            _smf.initMyProlog((_smf86_record_prolog *)provStatRecord, 
+            _smf.initMyProlog((_smf86_record_prolog *)provStatRecord,
                 PROVIDER_STATUS,
                 sizeof(_smf86_provider_status) + moduleNameLen );
 
@@ -231,15 +229,15 @@ void AuditLogger::logCurrentRegProvider(
                     Array<Uint16> moduleStatus;
                     // Get the module status
                     theValue.get(moduleStatus);
-                    // reset the smf record field 
+                    // reset the smf record field
                     provStatSection->CurrStatus = 0;
                     for (int j = 0; j < moduleStatus.size();j++)
                     {
-                        // Accumulate the status of the provider 
+                        // Accumulate the status of the provider
                         // by shifting a bit the value of moduleStatus
                         // times to the left to get the right bit set.
-                        provStatSection->CurrStatus = 
-                            provStatSection->CurrStatus + 
+                        provStatSection->CurrStatus =
+                            provStatSection->CurrStatus +
                             ( 1 << moduleStatus[j] );
                     }
 
@@ -250,7 +248,7 @@ void AuditLogger::logCurrentRegProvider(
             provStatSection->IsChanging=0;
             provStatSection->NewStatus=0;
 
-            // The variable values are starting 
+            // The variable values are starting
             // at the end of the subtype section.
             cursor = provStatRecord + sizeof(_smf86_provider_status_record);
             cursorOffset = sizeof(_smf86_provider_status);
@@ -300,7 +298,7 @@ void AuditLogger::logSetConfigProperty(
 
         // allocate the full record.
         confRecord = (unsigned char *) calloc(1,
-                          sizeof(_smf86_configuration_record) 
+                          sizeof(_smf86_configuration_record)
                           + nameLen + valueLen + newValueLen );
 
         // Initialize the header and product section.
@@ -323,7 +321,7 @@ void AuditLogger::logSetConfigProperty(
         {
             // It is a planed configuration change.
             confSection->PropChange = 2;
-        } 
+        }
         else
         {
             // It is a current configuration change.
@@ -331,12 +329,12 @@ void AuditLogger::logSetConfigProperty(
         }
 
 
-        // The variable values are starting 
+        // The variable values are starting
         // at the end of the subtype section.
         cursor = confRecord + sizeof(_smf86_configuration_record);
         cursorOffset = sizeof(_smf86_configuration);
 
-        // set the propety name 
+        // set the propety name
         confSection->NameOf = cursorOffset;
         confSection->NameNo = 1;
         confSection->NameLen = nameLen;
@@ -383,7 +381,7 @@ void AuditLogger::logUpdateClassOperation(
     // check if SMF is gathering this type of records.
     if (_smf.isRecording(CIM_OPERATION) ||
         (! _isInternalWriterUsed) )
-    {   
+    {
         _writeCIMOperationRecord(
             CLASS_OPERATION, userName, statusCode,
             ipAddr, cimMethodName, className.getString(),
@@ -403,7 +401,7 @@ void AuditLogger::logUpdateQualifierOperation(
     // check if SMF is gathering this type of records.
     if (_smf.isRecording(CIM_OPERATION) ||
         (! _isInternalWriterUsed) )
-    {   
+    {
         _writeCIMOperationRecord(
             QUALIFER_OPERATION, userName, statusCode,
             ipAddr, cimMethodName, className.getString(),
@@ -425,8 +423,8 @@ void AuditLogger::logUpdateInstanceOperation(
     // check if SMF is gathering this type of records.
     if (_smf.isRecording(CIM_OPERATION) ||
         (! _isInternalWriterUsed) )
-    {   
-        String cimInstanceName = 
+    {
+        String cimInstanceName =
             CIMObjectPath("", CIMNamespaceName(), instanceName.getClassName(),
             instanceName.getKeyBindings()).toString();
 
@@ -450,8 +448,8 @@ void AuditLogger::logInvokeMethodOperation(
     // check if SMF is gathering this type of records.
     if (_smf.isRecording(CIM_OPERATION) ||
         (! _isInternalWriterUsed) )
-    {   
-        String cimObjectName = 
+    {
+        String cimObjectName =
             CIMObjectPath("", CIMNamespaceName(), objectName.getClassName(),
             objectName.getKeyBindings()).toString();
 
@@ -470,7 +468,7 @@ void AuditLogger::logUpdateProvModuleStatus(
         // check if SMF is gathering this type of records.
     if (_smf.isRecording(CONFIGURATION) ||
         (! _isInternalWriterUsed) )
-    {   
+    {
         unsigned char * provStatRecord;
         unsigned char * cursor;
         int cursorOffset;
@@ -488,7 +486,7 @@ void AuditLogger::logUpdateProvModuleStatus(
 
         // Initialize the header and product section.
         // The length is the total of subtype section + variable parts.
-        _smf.initMyProlog((_smf86_record_prolog *)provStatRecord, 
+        _smf.initMyProlog((_smf86_record_prolog *)provStatRecord,
             PROVIDER_STATUS,
             sizeof(_smf86_provider_status) + moduleNameLen );
 
@@ -502,14 +500,14 @@ void AuditLogger::logUpdateProvModuleStatus(
         {
             for (int j = 0; j < currentModuleStatus.size();j++)
             {
-                // Accumulate the status of the provider 
+                // Accumulate the status of the provider
                 // by shifting a bit the value of moduleStatus
                 // times to the left to get the right bit set.
-                provStatSection->CurrStatus = 
-                    provStatSection->CurrStatus + 
+                provStatSection->CurrStatus =
+                    provStatSection->CurrStatus +
                     ( 1 << currentModuleStatus[j] );
             }
-            
+
         }
 
         // The provider does change.
@@ -519,18 +517,18 @@ void AuditLogger::logUpdateProvModuleStatus(
 
         if (newModuleStatus.size() > 0)
         {
-            // Accumulate the new status of the provider 
+            // Accumulate the new status of the provider
             // by shifting a bit the value of moduleStatus
             // times to the left to get the right bit set.
             for (int j = 0; j < newModuleStatus.size();j++)
             {
-                provStatSection->NewStatus = 
+                provStatSection->NewStatus =
                     provStatSection->NewStatus + ( 1 << newModuleStatus[j] );
             }
 
         }
 
-        // The variable values are starting 
+        // The variable values are starting
         // at the end of the subtype section.
         cursor = provStatRecord + sizeof(_smf86_provider_status_record);
         cursorOffset =  sizeof(_smf86_provider_status);
@@ -552,11 +550,11 @@ void AuditLogger::logUpdateProvModuleStatus(
 void AuditLogger::logLocalAuthentication(
     const String& userName,
     Boolean successful)
-{         
+{
     // check if SMF is gathering this type of records.
     if (_smf.isRecording(AUTHENTICATION) ||
         (! _isInternalWriterUsed) )
-    {   
+    {
         _writeAuthenticationRecord(LOCAL,userName,successful,
             "localhost");
     }
@@ -570,7 +568,7 @@ void AuditLogger::logBasicAuthentication(
     // check if SMF is gathering this type of records.
     if (_smf.isRecording(AUTHENTICATION) ||
         (! _isInternalWriterUsed) )
-    {   
+    {
         _writeAuthenticationRecord(BASIC,userName,successful,
             ipAddr);
     }
@@ -598,7 +596,7 @@ void AuditLogger::logCertificateBasedUserValidation(
     // check if SMF is gathering this type of records.
     if (_smf.isRecording(AUTHENTICATION) ||
         (! _isInternalWriterUsed) )
-    {   
+    {
         _writeAuthenticationRecord(ATTLS,userName,successful,
             ipAddr);
     }
@@ -612,10 +610,11 @@ void AuditLogger::setEnabled(Boolean enable)
     {
         if (!_auditLogFlag)
         {
-            Logger::put_l(Logger::STANDARD_LOG, System::CIMSERVER, 
+            Logger::put_l(Logger::STANDARD_LOG, System::CIMSERVER,
                 Logger::INFORMATION,
-                "Common.AuditLogger.ENABLE_AUDIT_LOG",
-                "Audit logging is enabled.");
+                MessageLoaderParms(
+                    "Common.AuditLogger.ENABLE_AUDIT_LOG",
+                    "Audit logging is enabled."));
 
             // only call the audit intiialzation call back if set.
             if (_auditLogInitializeCallback != 0)
@@ -628,10 +627,11 @@ void AuditLogger::setEnabled(Boolean enable)
     {
         if (_auditLogFlag)
         {
-            Logger::put_l(Logger::STANDARD_LOG, System::CIMSERVER, 
+            Logger::put_l(Logger::STANDARD_LOG, System::CIMSERVER,
                 Logger::INFORMATION,
-                "Common.AuditLogger.DISABLE_AUDIT_LOG",
-                "Audit logging is disabled.");
+                MessageLoaderParms(
+                    "Common.AuditLogger.DISABLE_AUDIT_LOG",
+                    "Audit logging is disabled."));
         }
     }
 
@@ -682,18 +682,18 @@ inline void AuditLogger::_writeCIMOperationRecord(
     // Allocate the full record.
     cimOperRecord = (unsigned char *) calloc(1,
         sizeof(_smf86_cim_operation_record)+
-        operNameLen + objPathLen + nameSpaceLen + 
+        operNameLen + objPathLen + nameSpaceLen +
         provNameLen + provModNameLen );
 
     // Initialize the header and product section.
     // The length is the total of subtype section + variable parts.
-    _smf.initMyProlog((_smf86_record_prolog *)cimOperRecord, 
+    _smf.initMyProlog((_smf86_record_prolog *)cimOperRecord,
         CIM_OPERATION, sizeof(_smf86_cim_operation)+
-        operNameLen + objPathLen + nameSpaceLen + 
+        operNameLen + objPathLen + nameSpaceLen +
         provNameLen + provModNameLen );
 
     // Set the pointer to the subtype section.
-    cimOperSection = (_smf86_cim_operation *) 
+    cimOperSection = (_smf86_cim_operation *)
         (cimOperRecord + sizeof(_smf86_record_prolog));
 
     // Set cim operation type.
@@ -712,12 +712,12 @@ inline void AuditLogger::_writeCIMOperationRecord(
                               (const char*)clientIP.getCString(),
                               sizeof(cimOperSection->ClientIP),false);
 
-    
+
     // The operation name starts from the end of the static record information.
     cursor = cimOperRecord + sizeof(_smf86_cim_operation_record);
     cursorOffset = sizeof(_smf86_cim_operation);
 
-    // Set operation name 
+    // Set operation name
     if (operNameLen > 0 )
     {
         cimOperSection->OperNameOf = cursorOffset;
@@ -727,14 +727,14 @@ inline void AuditLogger::_writeCIMOperationRecord(
                                   operNameLen,true);
         cursor = cursor + operNameLen;
         cursorOffset = cursorOffset + operNameLen;
-    } 
+    }
     else
     {
         cimOperSection->OperNameOf = 0;
         cimOperSection->OperNameLen = 0;
         cimOperSection->OperNameNo = 0;
     }
-    
+
     // Set object path
     if (objPathLen > 0 )
     {
@@ -806,7 +806,7 @@ inline void AuditLogger::_writeCIMOperationRecord(
         cimOperSection->ProvModNameLen = 0;
         cimOperSection->ProvModNameNo = 0;
     }
-    
+
     _writeAuditMessage(CIM_OPERATION,(char *)cimOperRecord);
     free(cimOperRecord);
 
@@ -828,7 +828,7 @@ inline void AuditLogger::_writeAuthenticationRecord(
 
     // Initialize the header and product section.
     // The length is the total of subtype section + variable parts.
-    _smf.initMyProlog((_smf86_record_prolog *)authenticationRecord, 
+    _smf.initMyProlog((_smf86_record_prolog *)authenticationRecord,
         AUTHENTICATION, sizeof(_smf86_authentication));
 
     // Set the pointer to the subtype section.
