@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -35,7 +33,7 @@
 #include "XmlReader.h"
 #include "XmlParser.h"
 #include "CIMName.h"
-#include "CIMNameUnchecked.h"
+#include "CIMNameCast.h"
 #include "BinaryStreamer.h"
 #include "CIMClassRep.h"
 #include "CIMInstanceRep.h"
@@ -230,14 +228,12 @@ void _unpack(const Buffer& in, Uint32& pos, CIMObject& x)
         }
     }
 }
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
 void _unpack(const Buffer& in, Uint32& pos, CIMInstance& x)
 {
     CIMObject tmp;
     _unpack(in, pos, tmp);
     x = CIMInstance(tmp);
 }
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
 
 template<class T>
 struct UnpackArray
@@ -348,7 +344,7 @@ void BinaryStreamer::_unpackName(
 {
     String tmp;
     Packer::unpackString(in, pos, tmp);
-    x = tmp.size() ? CIMNameUnchecked(tmp) : CIMName();
+    x = tmp.size() ? CIMNameCast(tmp) : CIMName();
 }
 
 void BinaryStreamer::_packQualifier(Buffer& out, const CIMQualifier& x)
@@ -470,7 +466,6 @@ void BinaryStreamer::_packValue(Buffer& out, const CIMValue& x)
                     Packer::packString(out, a[i].toString());
                 break;
             }
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
             case CIMTYPE_INSTANCE:
             {
                 const Array<CIMInstance>& a =
@@ -483,7 +478,6 @@ void BinaryStreamer::_packValue(Buffer& out, const CIMValue& x)
                 }
                 break;
             }
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
         }
     }
     else
@@ -535,7 +529,6 @@ void BinaryStreamer::_packValue(Buffer& out, const CIMValue& x)
                 Packer::packString(
                     out, CIMValueType<CIMObject>::ref(rep).toString());
                 break;
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
             case CIMTYPE_INSTANCE:
             {
                 CIMObject tmp(CIMValueType<CIMInstance>::ref(rep));
@@ -543,7 +536,6 @@ void BinaryStreamer::_packValue(Buffer& out, const CIMValue& x)
                     out, tmp.toString());
                 break;
             }
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
         }
     }
 }
@@ -642,11 +634,9 @@ void BinaryStreamer::_unpackValue(
             case CIMTYPE_OBJECT:
                 UnpackArray<CIMObject>::func(in, pos, arraySize, cimValue);
                 break;
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
             case CIMTYPE_INSTANCE:
                 UnpackArray<CIMInstance>::func(in, pos, arraySize, cimValue);
                 break;
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
         }
 
         x = cimValue;
@@ -720,11 +710,9 @@ void BinaryStreamer::_unpackValue(
             case CIMTYPE_OBJECT:
                 UnpackScalar<CIMObject>::func(in, pos, cimValue);
                 break;
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
             case CIMTYPE_INSTANCE:
                 UnpackScalar<CIMInstance>::func(in, pos, cimValue);
                 break;
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
         }
 
         x = cimValue;
@@ -774,11 +762,11 @@ void BinaryStreamer::_unpackProperty(
         name, value, arraySize, referenceClassName, classOrigin, propagated);
 
     UnpackQualifiers<CIMProperty>::func(in, pos, cimProperty);
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
     if (cimProperty.getType() == CIMTYPE_STRING)
     {
         CIMType realType = CIMTYPE_STRING;
-        if (cimProperty.findQualifier("EmbeddedInstance") != PEG_NOT_FOUND)
+        if (cimProperty.findQualifier(PEGASUS_QUALIFIERNAME_EMBEDDEDINSTANCE)
+            != PEG_NOT_FOUND)
         {
             // Note that this condition should only happen for properties in
             // class definitions, and only NULL values are recognized. We
@@ -787,13 +775,23 @@ void BinaryStreamer::_unpackProperty(
             PEGASUS_ASSERT(value.isNull());
             realType = CIMTYPE_INSTANCE;
         }
-        else if (cimProperty.findQualifier("EmbeddedObject") != PEG_NOT_FOUND)
+        else if (cimProperty.findQualifier(PEGASUS_QUALIFIERNAME_EMBEDDEDOBJECT)
+                 != PEG_NOT_FOUND)
         {
             // Note that this condition should only happen for properties in
             // class definitions, and only NULL values are recognized. We
             // currently don't handle embedded object types with default
             // values in the class definition.
+#if defined(PEGASUS_ENABLE_PROTOCOL_BINARY)
+            // The binary protocol (unlike the XML protocol) successfully
+            // transmits embedded object default values. But since they are
+            // not handled elsewhere, we discard the value.
+            cimProperty.setValue(
+                CIMValue(value.getType(),value.isArray(),value.getArraySize()));
+#else
             PEGASUS_ASSERT(value.isNull());
+#endif
+
             realType = CIMTYPE_OBJECT;
         }
 
@@ -809,7 +807,6 @@ void BinaryStreamer::_unpackProperty(
             cimProperty = tmpProperty;
         }
     }
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
     x = cimProperty;
 }
 
@@ -992,7 +989,6 @@ void BinaryStreamer::encode(
     PackQualifiers<CIMClassRep>::func(out, rep);
     _packProperties(out, rep);
     _packMethods(out, rep);
-    Packer::packBoolean(out, rep->_resolved);
 }
 
 void BinaryStreamer::decode(
@@ -1015,9 +1011,6 @@ void BinaryStreamer::decode(
     UnpackProperties<CIMClass>::func(in, pos, cimClass);
     UnpackMethods<CIMClass>::func(in, pos, cimClass);
 
-    Boolean resolved;
-    Packer::unpackBoolean(in, pos, resolved);
-    cimClass._rep->_resolved = resolved;
     x = cimClass;
 }
 
@@ -1031,7 +1024,6 @@ void BinaryStreamer::encode(
     _packObjectPath(out, x.getPath());
     PackQualifiers<CIMInstanceRep>::func(out, rep);
     _packProperties(out, rep);
-    Packer::packBoolean(out, rep->_resolved);
 }
 
 void BinaryStreamer::decode(
@@ -1050,9 +1042,6 @@ void BinaryStreamer::decode(
     UnpackQualifiers<CIMInstance>::func(in, pos, cimInstance);
     UnpackProperties<CIMInstance>::func(in, pos, cimInstance);
 
-    Boolean resolved;
-    Packer::unpackBoolean(in, pos, resolved);
-    cimInstance._rep->_resolved = resolved;
     x = cimInstance;
 }
 
