@@ -1,43 +1,47 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
 #include <Pegasus/Common/AutoPtr.h>
+#include <Pegasus/Common/StatisticalData.h>
 #include "CIMMessage.h"
+#include "XmlWriter.h"
 
 PEGASUS_USING_STD;
 
 PEGASUS_NAMESPACE_BEGIN
 
+#define PEGASUS_ARRAY_T ArraySint8
+# include "ArrayImpl.h"
+#undef PEGASUS_ARRAY_T
+
 void CIMResponseMessage::syncAttributes(const CIMRequestMessage* request)
 {
     // Propagate request attributes to the response, as necessary
@@ -47,6 +51,8 @@ void CIMResponseMessage::syncAttributes(const CIMRequestMessage* request)
 #ifndef PEGASUS_DISABLE_PERFINST
     setServerStartTime(request->getServerStartTime());
 #endif
+    binaryRequest = request->binaryRequest;
+    binaryResponse = request->binaryResponse;
 }
 
 CIMResponseMessage* CIMGetClassRequestMessage::buildResponse() const
@@ -67,8 +73,7 @@ CIMResponseMessage* CIMGetInstanceRequestMessage::buildResponse() const
         new CIMGetInstanceResponseMessage(
             messageId,
             CIMException(),
-            queueIds.copyAndPop(),
-            CIMInstance()));
+            queueIds.copyAndPop()));
     response->syncAttributes(this);
     return response.release();
 }
@@ -181,8 +186,7 @@ CIMResponseMessage* CIMEnumerateInstancesRequestMessage::buildResponse() const
         new CIMEnumerateInstancesResponseMessage(
             messageId,
             CIMException(),
-            queueIds.copyAndPop(),
-            Array<CIMInstance>()));
+            queueIds.copyAndPop()));
     response->syncAttributes(this);
     return response.release();
 }
@@ -491,17 +495,6 @@ CIMResponseMessage* CIMStopAllProvidersRequestMessage::buildResponse() const
     return response.release();
 }
 
-CIMResponseMessage* CIMInitializeProviderRequestMessage::buildResponse() const
-{
-    AutoPtr<CIMInitializeProviderResponseMessage> response(
-        new CIMInitializeProviderResponseMessage(
-            messageId,
-            CIMException(),
-            queueIds.copyAndPop()));
-    response->syncAttributes(this);
-    return response.release();
-}
-
 CIMResponseMessage*
     CIMInitializeProviderAgentRequestMessage::buildResponse() const
 {
@@ -528,14 +521,58 @@ CIMResponseMessage* CIMNotifyConfigChangeRequestMessage::buildResponse() const
 CIMMessage::CIMMessage(
     MessageType type,
     const String& messageId_)
-    : Message(type), messageId(messageId_)
+    : Message(type),
+      messageId(messageId_),
+      _languageContextThreadId(Threads::self())
+#ifndef PEGASUS_DISABLE_PERFINST
+      ,_serverStartTimeMicroseconds(0),
+      _providerTimeMicroseconds(0),
+      _totalServerTimeMicroseconds(0)
+#endif
 {
     operationContext.insert(
         AcceptLanguageListContainer(AcceptLanguageList()));
     operationContext.insert(
         ContentLanguageListContainer(ContentLanguageList()));
+
+    binaryRequest = false;
+    binaryResponse = false;
 }
 
+#ifndef PEGASUS_DISABLE_PERFINST
+void CIMMessage::endServer()
+{
+    PEGASUS_ASSERT(_serverStartTimeMicroseconds != 0);
+
+    _totalServerTimeMicroseconds =
+        TimeValue::getCurrentTime().toMicroseconds() -
+            _serverStartTimeMicroseconds;
+
+    Uint64 serverTimeMicroseconds =
+        _totalServerTimeMicroseconds - _providerTimeMicroseconds;
+
+    Uint16 statType = (Uint16)((getType() >= CIM_GET_CLASS_RESPONSE_MESSAGE) ?
+        getType() - CIM_GET_CLASS_RESPONSE_MESSAGE : getType() - 1);
+
+    StatisticalData::current()->addToValue(serverTimeMicroseconds, statType,
+        StatisticalData::PEGASUS_STATDATA_SERVER);
+
+    StatisticalData::current()->addToValue(_providerTimeMicroseconds, statType,
+        StatisticalData::PEGASUS_STATDATA_PROVIDER);
+
+    /* This adds the number of bytes read to the total.the request size
+       value must be stored (requSize) and passed to the StatisticalData
+       object at the end of processingm otherwise it will be the ONLY value
+       that is passed to the client which reports the current state of the
+       object, not the previous (one command ago) state */
+
+    StatisticalData::current()->addToValue(
+        StatisticalData::current()->requSize,
+        statType,
+        StatisticalData::PEGASUS_STATDATA_BYTES_READ);
+}
+#endif
+
 CIMRequestMessage::CIMRequestMessage(
     MessageType type_,
     const String& messageId_,
