@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -50,6 +48,8 @@
 #include <Pegasus/Common/ContentLanguageList.h>
 #include <Pegasus/Common/Pair.h>
 #include <Pegasus/Common/ArrayInternal.h>
+#include <Pegasus/Common/Threads.h>
+#include <Pegasus/Common/Thread.h>
 
 /*   ProviderType should become part of Pegasus/Common     PEP# 99
    #include <Pegasus/ProviderManager2/ProviderType.h>
@@ -69,34 +69,96 @@
 
 PEGASUS_NAMESPACE_BEGIN
 
+typedef Array<Sint8> ArraySint8;
+#define PEGASUS_ARRAY_T ArraySint8
+# include <Pegasus/Common/ArrayInter.h>
+#undef PEGASUS_ARRAY_T
+
 class PEGASUS_COMMON_LINKAGE CIMMessage : public Message
 {
 public:
 
     CIMMessage(MessageType type, const String& messageId_);
 
-#ifdef PEGASUS_DEBUG
-    virtual void print(PEGASUS_STD(ostream)& os, Boolean printHeader) const
+    /**
+        Updates the language context for the thread to the contents of the
+        AcceptLanguageContainer in the OperationContext.
+    */
+    void updateThreadLanguages()
     {
-        if (printHeader)
+        if (!Threads::equal(_languageContextThreadId, Threads::self()))
         {
-            os << "CIMMessage\n";
-            os << "{";
+            Thread::setLanguages(
+                ((AcceptLanguageListContainer)operationContext.get(
+                    AcceptLanguageListContainer::NAME)).getLanguages());
+            _languageContextThreadId = Threads::self();
         }
+    }
 
-        Message::print(os, false);
+#ifndef PEGASUS_DISABLE_PERFINST
+    //
+    // Needed for performance measurement
+    //
 
-        os << "    messageId=" << messageId << PEGASUS_STD(endl);
+    Uint64 getServerStartTime() const
+    {
+        return _serverStartTimeMicroseconds;
+    }
 
-        if (printHeader)
-        {
-            os << "}";
-        }
+    void setServerStartTime(Uint64 serverStartTimeMicroseconds)
+    {
+        _serverStartTimeMicroseconds = serverStartTimeMicroseconds;
+    }
+
+    void endServer();
+
+    Uint64 getProviderTime() const
+    {
+        return _providerTimeMicroseconds;
+    }
+
+    void setProviderTime(Uint64 providerTimeMicroseconds)
+    {
+        _providerTimeMicroseconds = providerTimeMicroseconds;
+    }
+
+    Uint64 getTotalServerTime() const
+    {
+        return _totalServerTimeMicroseconds;
+    }
+
+    void setTotalServerTime(Uint64 totalServerTimeMicroseconds)
+    {
+        _totalServerTimeMicroseconds = totalServerTimeMicroseconds;
     }
 #endif
 
     String messageId;
-        OperationContext operationContext;
+    OperationContext operationContext;
+
+    // This flag indicates that the original request was a binary request.
+    // That is the HTTP "Content-Type" header had a value of
+    // "application/x-openpegasus". It does not necessarily follow that
+    // the response to this request must also be binary. Binary requests
+    // may have XML responses.
+    Boolean binaryRequest;
+
+    // This flag indications that the ultimate response to this message
+    // must be sent as binary response. This means the original request's
+    // "Accept" HTTP header had a value of "application/x-openpegasus".
+    // Note that a binary response can be sent to an XML request as long
+    // as the "Accept" header is "application/x-openpegasus".
+    Boolean binaryResponse;
+
+private:
+
+    ThreadType _languageContextThreadId;
+
+#ifndef PEGASUS_DISABLE_PERFINST
+    Uint64 _serverStartTimeMicroseconds;
+    Uint64 _providerTimeMicroseconds;
+    Uint64 _totalServerTimeMicroseconds;
+#endif
 };
 
 
@@ -112,26 +174,6 @@ public:
 
     virtual CIMResponseMessage* buildResponse() const = 0;
 
-#ifdef PEGASUS_DEBUG
-    virtual void print(PEGASUS_STD(ostream)& os, Boolean printHeader) const
-    {
-        if (printHeader)
-        {
-            os << "CIMRequestMessage\n";
-            os << "{";
-        }
-
-        CIMMessage::print(os, false);
-
-        os << "    queueIds=" << "<not shown for now>" << PEGASUS_STD(endl);
-
-        if (printHeader)
-        {
-            os << "}";
-        }
-    }
-#endif
-
     QueueIdStack queueIds;
 };
 
@@ -565,29 +607,6 @@ public:
     {
     }
 
-#ifdef PEGASUS_DEBUG
-    virtual void print(PEGASUS_STD(ostream)& os, Boolean printHeader) const
-    {
-        if (printHeader)
-        {
-            os << "CIMEnumerateInstanceNamesRequestMessage\n";
-            os << "{";
-        }
-
-        CIMRequestMessage::print(os, false);
-
-        os << "    nameSpace=" << nameSpace << PEGASUS_STD(endl);
-        os << "    className=" << className << PEGASUS_STD(endl);
-        os << "    authType=" << authType << PEGASUS_STD(endl);
-        os << "    userName=" << userName << PEGASUS_STD(endl);
-
-        if (printHeader)
-        {
-            os << "}";
-        }
-    }
-#endif
-
     virtual CIMResponseMessage* buildResponse() const;
 };
 
@@ -1334,23 +1353,6 @@ public:
     virtual CIMResponseMessage* buildResponse() const;
 };
 
-class PEGASUS_COMMON_LINKAGE CIMInitializeProviderRequestMessage
-    : public CIMRequestMessage
-{
-public:
-    CIMInitializeProviderRequestMessage(
-        const String & messageId_,
-        const QueueIdStack& queueIds_)
-    : CIMRequestMessage(
-        CIM_INITIALIZE_PROVIDER_REQUEST_MESSAGE,
-        messageId_,
-        queueIds_)
-    {
-    }
-
-    virtual CIMResponseMessage* buildResponse() const;
-};
-
 // Used to pass initialization data to an Out-of-Process Provider Agent process
 class PEGASUS_COMMON_LINKAGE CIMInitializeProviderAgentRequestMessage
     : public CIMRequestMessage
@@ -1439,15 +1441,68 @@ public:
     CIMGetInstanceResponseMessage(
         const String& messageId_,
         const CIMException& cimException_,
-        const QueueIdStack& queueIds_,
-        const CIMInstance& cimInstance_)
+        const QueueIdStack& queueIds_)
     : CIMResponseMessage(CIM_GET_INSTANCE_RESPONSE_MESSAGE,
         messageId_, cimException_, queueIds_),
-        cimInstance(cimInstance_)
+        resolveCallback(0),
+        binaryEncoding(false)
     {
     }
 
-    CIMInstance cimInstance;
+    Boolean (*resolveCallback)(
+        CIMGetInstanceResponseMessage* msg,
+        CIMInstance& cimInstance);
+
+    Boolean binaryEncoding;
+
+    // For XML encoding:
+    Array<Sint8> instanceData;
+    Array<Sint8> referenceData;
+    CIMNamespaceName nameSpaceData;
+    String hostData;
+
+    // For Binary encoding:
+    Array<Uint8> binaryData;
+
+    CIMInstance& getCimInstance()
+    {
+        _resolve();
+        return _cimInstance;
+    }
+
+    const CIMConstInstance& getCimInstance() const
+    {
+        // Resolve the instance before returning it.  The resolve step requires
+        // non-const access, but does not fundamentally change the message
+        // contents.
+        const_cast<CIMGetInstanceResponseMessage*>(this)->_resolve();
+
+        // The CIMInstance is masqueraded as a CIMConstInstance for expedience,
+        // since the internal representations are the same.
+        return *((CIMConstInstance*)(void*)&_cimInstance);
+    }
+
+    void setCimInstance(const CIMInstance& x)
+    {
+        resolveCallback = 0;
+        _cimInstance = x;
+    }
+
+private:
+    CIMGetInstanceResponseMessage();
+    CIMGetInstanceResponseMessage(const CIMGetInstanceResponseMessage&);
+    CIMGetInstanceResponseMessage& operator=(
+        const CIMGetInstanceResponseMessage&);
+
+    void _resolve()
+    {
+        if (resolveCallback)
+        {
+            (*resolveCallback)(this, _cimInstance);
+        }
+    }
+
+    CIMInstance _cimInstance;
 };
 
 class PEGASUS_COMMON_LINKAGE CIMExportIndicationResponseMessage
@@ -1595,15 +1650,66 @@ public:
     CIMEnumerateInstancesResponseMessage(
         const String& messageId_,
         const CIMException& cimException_,
-        const QueueIdStack& queueIds_,
-        const Array<CIMInstance>& cimNamedInstances_)
-    : CIMResponseMessage(CIM_ENUMERATE_INSTANCES_RESPONSE_MESSAGE,
+        const QueueIdStack& queueIds_)
+    : CIMResponseMessage(
+        CIM_ENUMERATE_INSTANCES_RESPONSE_MESSAGE,
         messageId_, cimException_, queueIds_),
-        cimNamedInstances(cimNamedInstances_)
+        resolveCallback(0),
+        binaryEncoding(false)
     {
     }
 
-    Array<CIMInstance> cimNamedInstances;
+    Boolean (*resolveCallback)(
+        CIMEnumerateInstancesResponseMessage* msg,
+        Array<CIMInstance>& instances);
+
+    Boolean binaryEncoding;
+
+    // For XML encoding.
+    Array<ArraySint8> instancesData;
+    Array<ArraySint8> referencesData;
+    Array<String> hostsData;
+    Array<CIMNamespaceName> nameSpacesData;
+
+    // For binary encoding.
+    Array<Uint8> binaryData;
+
+    Array<CIMInstance>& getNamedInstances()
+    {
+        _resolve();
+        return _namedInstances;
+    }
+
+    const Array<CIMConstInstance>& getNamedInstances() const
+    {
+        // Resolve the instances before returning them.  The resolve step
+        // requires non-const access, but does not fundamentally change the
+        // message contents.
+        const_cast<CIMEnumerateInstancesResponseMessage*>(this)->_resolve();
+
+        // The Array<CIMInstance> is masqueraded as an Array<CIMConstInstance>
+        // for expedience, since the internal representations are the same.
+        return *((Array<CIMConstInstance>*)(void*)&_namedInstances);
+    }
+
+    void setNamedInstances(const Array<CIMInstance>& x)
+    {
+        resolveCallback = 0;
+        _namedInstances = x;
+    }
+
+private:
+
+    void _resolve()
+    {
+        if (resolveCallback)
+        {
+            (*resolveCallback)(this, _namedInstances);
+            resolveCallback = 0;
+        }
+    }
+
+    Array<CIMInstance> _namedInstances;
 };
 
 class PEGASUS_COMMON_LINKAGE CIMEnumerateInstanceNamesResponseMessage
@@ -2041,20 +2147,6 @@ public:
     }
 };
 
-class PEGASUS_COMMON_LINKAGE CIMInitializeProviderResponseMessage
-    : public CIMResponseMessage
-{
-public:
-    CIMInitializeProviderResponseMessage(
-        const String& messageId_,
-        const CIMException& cimException_,
-        const QueueIdStack& queueIds_)
-    : CIMResponseMessage(CIM_INITIALIZE_PROVIDER_RESPONSE_MESSAGE,
-        messageId_, cimException_, queueIds_)
-    {
-    }
-};
-
 class PEGASUS_COMMON_LINKAGE CIMInitializeProviderAgentResponseMessage
     : public CIMResponseMessage
 {
@@ -2083,6 +2175,7 @@ public:
     }
 };
 
+
 PEGASUS_NAMESPACE_END
 
 #endif /* Pegasus_CIMMessage_h */
