@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -97,7 +95,7 @@ CIMMessage* CIMMessageDeserializer::deserialize(char* buffer)
     else
     {
         // CIMResponseMessage is the only other CIMMessage type defined
-        Boolean found = XmlReader::testStartTag(parser, entry, "PGRESP");
+        found = XmlReader::testStartTag(parser, entry, "PGRESP");
         PEGASUS_ASSERT(found);
         message = _deserializeCIMResponseMessage(parser, type);
         XmlReader::expectEndTag(parser, "PGRESP");
@@ -317,9 +315,6 @@ CIMRequestMessage* CIMMessageDeserializer::_deserializeCIMRequestMessage(
         case CIM_STOP_ALL_PROVIDERS_REQUEST_MESSAGE:
             message = _deserializeCIMStopAllProvidersRequestMessage(parser);
             break;
-        case CIM_INITIALIZE_PROVIDER_REQUEST_MESSAGE:
-            message = _deserializeCIMInitializeProviderRequestMessage(parser);
-            break;
         case CIM_INITIALIZE_PROVIDER_AGENT_REQUEST_MESSAGE:
             message =
                 _deserializeCIMInitializeProviderAgentRequestMessage(parser);
@@ -489,9 +484,6 @@ CIMResponseMessage* CIMMessageDeserializer::_deserializeCIMResponseMessage(
         case CIM_STOP_ALL_PROVIDERS_RESPONSE_MESSAGE:
             message = _deserializeCIMStopAllProvidersResponseMessage(parser);
             break;
-        case CIM_INITIALIZE_PROVIDER_RESPONSE_MESSAGE:
-            message = _deserializeCIMInitializeProviderResponseMessage(parser);
-            break;
         case CIM_INITIALIZE_PROVIDER_AGENT_RESPONSE_MESSAGE:
             message =
                 _deserializeCIMInitializeProviderAgentResponseMessage(parser);
@@ -699,11 +691,11 @@ void CIMMessageDeserializer::_deserializeOperationContext(
 
     if (XmlReader::testStartTag(parser, entry, "PGOCPI"))
     {
-        CIMValue genericValue;
         CIMInstance module;
         CIMInstance provider;
         Boolean isRemoteNameSpace;
         String remoteInfo;
+        String provMgrPath;
 
         _deserializeCIMInstance(parser, module);
         _deserializeCIMInstance(parser, provider);
@@ -714,8 +706,15 @@ void CIMMessageDeserializer::_deserializeOperationContext(
         XmlReader::getValueElement(parser, CIMTYPE_STRING, genericValue);
         genericValue.get(remoteInfo);
 
-        operationContext.insert(ProviderIdContainer(
-            module, provider, isRemoteNameSpace, remoteInfo));
+        XmlReader::getValueElement(parser, CIMTYPE_STRING, genericValue);
+        genericValue.get(provMgrPath);
+
+        ProviderIdContainer pidc = ProviderIdContainer(module,
+                                                      provider,
+                                                      isRemoteNameSpace,
+                                                      remoteInfo);
+        pidc.setProvMgrPath(provMgrPath);
+        operationContext.insert(pidc);
         XmlReader::expectEndTag(parser, "PGOCPI");
     }
 
@@ -1829,21 +1828,6 @@ CIMMessageDeserializer::_deserializeCIMStopAllProvidersRequestMessage(
     return message;
 }
 
-//
-// _deserializeCIMInitializeProviderRequestMessage
-//
-CIMInitializeProviderRequestMessage*
-CIMMessageDeserializer::_deserializeCIMInitializeProviderRequestMessage(
-    XmlParser& parser)
-{
-    CIMInitializeProviderRequestMessage* message =
-        new CIMInitializeProviderRequestMessage(
-            String::EMPTY,         // messageId
-            QueueIdStack());       // queueIds
-
-    return message;
-}
-
 //
 // _deserializeCIMInitializeProviderAgentRequestMessage
 //
@@ -1970,8 +1954,9 @@ CIMMessageDeserializer::_deserializeCIMGetInstanceResponseMessage(
         new CIMGetInstanceResponseMessage(
             String::EMPTY,         // messageId
             CIMException(),        // cimException
-            QueueIdStack(),        // queueIds
-            cimInstance);
+            QueueIdStack());       // queueIds
+
+    message->setCimInstance(cimInstance);
 
     return message;
 }
@@ -2052,8 +2037,8 @@ CIMMessageDeserializer::_deserializeCIMEnumerateInstancesResponseMessage(
         new CIMEnumerateInstancesResponseMessage(
             String::EMPTY,         // messageId
             CIMException(),        // cimException
-            QueueIdStack(),        // queueIds
-            cimNamedInstances);
+            QueueIdStack());        // queueIds
+    message->setNamedInstances(cimNamedInstances);
 
     return message;
 }
@@ -2478,22 +2463,6 @@ CIMMessageDeserializer::_deserializeCIMStopAllProvidersResponseMessage(
     return message;
 }
 
-//
-// _deserializeCIMInitializeProviderResponseMessage
-//
-CIMInitializeProviderResponseMessage*
-CIMMessageDeserializer::_deserializeCIMInitializeProviderResponseMessage(
-    XmlParser& parser)
-{
-    CIMInitializeProviderResponseMessage* message =
-        new CIMInitializeProviderResponseMessage(
-            String::EMPTY,         // messageId
-            CIMException(),        // cimException
-            QueueIdStack());       // queueIds
-
-    return message;
-}
-
 //
 // _deserializeCIMInitializeProviderAgentResponseMessage
 //
