@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -282,10 +280,6 @@ void CIMMessageSerializer::_serializeCIMRequestMessage(
             _serializeCIMStopAllProvidersRequestMessage(
                 out, (CIMStopAllProvidersRequestMessage*)cimMessage);
             break;
-        case CIM_INITIALIZE_PROVIDER_REQUEST_MESSAGE:
-            _serializeCIMInitializeProviderRequestMessage(
-                out, (CIMInitializeProviderRequestMessage*)cimMessage);
-            break;
         case CIM_INITIALIZE_PROVIDER_AGENT_REQUEST_MESSAGE:
             _serializeCIMInitializeProviderAgentRequestMessage(
                 out, (CIMInitializeProviderAgentRequestMessage*)cimMessage);
@@ -478,10 +472,6 @@ void CIMMessageSerializer::_serializeCIMResponseMessage(
             _serializeCIMStopAllProvidersResponseMessage(
                 out, (CIMStopAllProvidersResponseMessage*)cimMessage);
             break;
-        case CIM_INITIALIZE_PROVIDER_RESPONSE_MESSAGE:
-            _serializeCIMInitializeProviderResponseMessage(
-                out, (CIMInitializeProviderResponseMessage*)cimMessage);
-            break;
         case CIM_INITIALIZE_PROVIDER_AGENT_RESPONSE_MESSAGE:
             _serializeCIMInitializeProviderAgentResponseMessage(
                 out, (CIMInitializeProviderAgentResponseMessage*)cimMessage);
@@ -672,6 +662,7 @@ void CIMMessageSerializer::_serializeOperationContext(
         _serializeCIMInstance(out, container.getProvider());
         XmlWriter::appendValueElement(out, container.isRemoteNameSpace());
         XmlWriter::appendValueElement(out, container.getRemoteInfo());
+        XmlWriter::appendValueElement(out, container.getProvMgrPath());
         XmlWriter::append(out, "</PGOCPI>\n");
     }
 
@@ -680,7 +671,7 @@ void CIMMessageSerializer::_serializeOperationContext(
         const CachedClassDefinitionContainer container =
             operationContext.get(CachedClassDefinitionContainer::NAME);
 
-        CIMClass cimClass = container.getClass();
+        CIMConstClass cimClass = container.getClass();
         XmlWriter::append(out, "<PGOCCCD>\n");
         XmlWriter::appendClassElement(out, cimClass);
         XmlWriter::append(out, "</PGOCCCD>\n");
@@ -1238,16 +1229,6 @@ void CIMMessageSerializer::_serializeCIMStopAllProvidersRequestMessage(
     // No additional attributes to serialize!
 }
 
-//
-// _serializeCIMInitializeProviderRequestMessage
-//
-void CIMMessageSerializer::_serializeCIMInitializeProviderRequestMessage(
-    Buffer& out,
-    CIMInitializeProviderRequestMessage* message)
-{
-    // No additional attributes to serialize!
-}
-
 //
 // _serializeCIMInitializeProviderAgentRequestMessage
 //
@@ -1312,7 +1293,7 @@ void CIMMessageSerializer::_serializeCIMGetInstanceResponseMessage(
     Buffer& out,
     CIMGetInstanceResponseMessage* message)
 {
-    _serializeCIMInstance(out, message->cimInstance);
+    _serializeCIMInstance(out, message->getCimInstance());
 }
 
 //
@@ -1354,9 +1335,11 @@ void CIMMessageSerializer::_serializeCIMEnumerateInstancesResponseMessage(
 {
     // Use PGINSTARRAY element to encapsulate the CIMInstance elements
     XmlWriter::append(out, "<PGINSTARRAY>\n");
-    for (Uint32 i=0; i < message->cimNamedInstances.size(); i++)
+
+    const Array<CIMInstance>& a = message->getNamedInstances();
+    for (Uint32 i=0; i < a.size(); i++)
     {
-        _serializeCIMInstance(out, message->cimNamedInstances[i]);
+        _serializeCIMInstance(out, a[i]);
     }
     XmlWriter::append(out, "</PGINSTARRAY>\n");
 }
@@ -1488,7 +1471,7 @@ void CIMMessageSerializer::_serializeCIMInvokeMethodResponseMessage(
     CIMInvokeMethodResponseMessage* message)
 {
     // Use PARAMVALUE element so we can preserve the CIMType information
-    _serializeCIMParamValue(        
+    _serializeCIMParamValue(
         out,
         CIMParamValue(String("ignore"), message->retValue, true));
 
@@ -1611,16 +1594,6 @@ void CIMMessageSerializer::_serializeCIMStopAllProvidersResponseMessage(
     // No additional attributes to serialize!
 }
 
-//
-// _serializeCIMInitializeProviderResponseMessage
-//
-void CIMMessageSerializer::_serializeCIMInitializeProviderResponseMessage(
-    Buffer& out,
-    CIMInitializeProviderResponseMessage* message)
-{
-    // No additional attributes to serialize!
-}
-
 //
 // _serializeCIMInitializeProviderAgentResponseMessage
 //
