@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
 //
-//==============================================================================
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -36,12 +34,14 @@
 #include <iostream>
 #include "HashTable.h"
 #include "CIMObjectPath.h"
-#include "Indentor.h"
 #include "CIMName.h"
-#include "XmlWriter.h"
+#include "CIMValue.h"
 #include "XmlReader.h"
 #include "ArrayInternal.h"
 #include "HostLocator.h"
+#include "System.h"
+#include "CIMKeyBindingRep.h"
+#include "CIMObjectPathRep.h"
 
 PEGASUS_NAMESPACE_BEGIN
 
@@ -138,47 +138,6 @@ static void _Sort(Array<CIMKeyBinding>& x)
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-class CIMKeyBindingRep
-{
-public:
-    CIMKeyBindingRep()
-    {
-    }
-
-    CIMKeyBindingRep(const CIMKeyBindingRep& x)
-        : _name(x._name), _value(x._value), _type(x._type)
-    {
-    }
-
-    CIMKeyBindingRep(
-        const CIMName& name,
-        const String& value,
-        CIMKeyBinding::Type type)
-        : _name(name), _value(value), _type(type)
-    {
-    }
-
-    ~CIMKeyBindingRep()
-    {
-    }
-
-    CIMKeyBindingRep& operator=(const CIMKeyBindingRep& x)
-    {
-        if (&x != this)
-        {
-            _name = x._name;
-            _value = x._value;
-            _type = x._type;
-        }
-        return *this;
-    }
-
-    CIMName _name;
-    String _value;
-    CIMKeyBinding::Type _type;
-};
-
-
 CIMKeyBinding::CIMKeyBinding()
 {
     _rep = new CIMKeyBindingRep();
@@ -223,9 +182,7 @@ CIMKeyBinding::CIMKeyBinding(const CIMName& name, const CIMValue& value)
 //  case CIMTYPE_REAL32:
 //  case CIMTYPE_REAL64:
     case CIMTYPE_OBJECT:
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
     case CIMTYPE_INSTANCE:
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
         // From PEP 194: EmbeddedObjects cannot be keys.
         throw TypeMismatchException();
         break;
@@ -315,9 +272,7 @@ Boolean CIMKeyBinding::equal(CIMValue value)
 //      case CIMTYPE_REAL32:
 //      case CIMTYPE_REAL64:
         case CIMTYPE_OBJECT:
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
         case CIMTYPE_INSTANCE:
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
             // From PEP 194: EmbeddedObjects cannot be keys.
             return false;
             break;
@@ -408,65 +363,6 @@ Boolean operator==(const CIMKeyBinding& x, const CIMKeyBinding& y)
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-class CIMObjectPathRep
-{
-public:
-    CIMObjectPathRep(): _refCounter(1)
-    {
-    }
-
-    CIMObjectPathRep(const CIMObjectPathRep& x)
-        : _refCounter(1), _host(x._host), _nameSpace(x._nameSpace),
-        _className(x._className), _keyBindings(x._keyBindings)
-    {
-    }
-
-    CIMObjectPathRep(
-        const String& host,
-        const CIMNamespaceName& nameSpace,
-        const CIMName& className,
-        const Array<CIMKeyBinding>& keyBindings)
-        : _refCounter(1), _host(host), _nameSpace(nameSpace),
-        _className(className), _keyBindings(keyBindings)
-    {
-    }
-
-    ~CIMObjectPathRep()
-    {
-    }
-
-    CIMObjectPathRep& operator=(const CIMObjectPathRep& x)
-    {
-        if (&x != this)
-        {
-            _host = x._host;
-            _nameSpace = x._nameSpace;
-            _className = x._className;
-            _keyBindings = x._keyBindings;
-        }
-        return *this;
-    }
-
-    static Boolean isValidHostname(const String& hostname)
-    {
-        HostLocator addr(hostname);
-
-        return addr.isValid();
-    }
-
-    // reference counter as member to avoid
-    // virtual function resolution overhead
-    AtomicInt _refCounter;
-    //
-    // Contains port as well (e.g., myhost:1234).
-    //
-    String _host;
-
-    CIMNamespaceName _nameSpace;
-    CIMName _className;
-    Array<CIMKeyBinding> _keyBindings;
-};
-
 template<class REP>
 inline void Ref(REP* rep)
 {
@@ -496,7 +392,7 @@ CIMObjectPath::CIMObjectPath(const String& objectName)
     // Test the objectName out to see if we get an exception
     CIMObjectPath tmpRef;
     tmpRef.set(objectName);
-    
+
     _rep = tmpRef._rep;
     Ref(_rep);
 }
@@ -576,7 +472,7 @@ void CIMObjectPath::set(
     {
         throw MalformedObjectNameException(host);
     }
-    
+
     _rep = _copyOnWriteCIMObjectPathRep(_rep);
 
     _rep->_host.assign(host);
@@ -1131,10 +1027,11 @@ String CIMObjectPath::_toStringCanonical() const
 Boolean CIMObjectPath::identical(const CIMObjectPath& x) const
 {
     return
-        String::equalNoCase(_rep->_host, x._rep->_host) &&
-        _rep->_nameSpace.equal(x._rep->_nameSpace) &&
-        _rep->_className.equal(x._rep->_className) &&
-        _rep->_keyBindings == x._rep->_keyBindings;
+        (_rep == x._rep) ||
+        (String::equalNoCase(_rep->_host, x._rep->_host) &&
+         _rep->_nameSpace.equal(x._rep->_nameSpace) &&
+         _rep->_className.equal(x._rep->_className) &&
+         (_rep->_keyBindings == x._rep->_keyBindings));
 }
 
 Uint32 CIMObjectPath::makeHashCode() const
