@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -56,7 +54,21 @@ class PEGASUS_COMMON_LINKAGE CIMKeyBinding
 {
 public:
 
-    enum Type { BOOLEAN, STRING, NUMERIC, REFERENCE };
+    /**
+        The CIMKeyBinding Type corresponds to the CIM-XML key binding
+        definition, in which the CIMType values are mapped into categories.
+    */
+    enum Type
+    {
+        /** Boolean type */
+        BOOLEAN,
+        /** String, Char16, and CIMDateTime types */
+        STRING,
+        /** Integer and real number types */
+        NUMERIC,
+        /** CIMObjectPath (reference) type */
+        REFERENCE
+    };
 
     /**
         Constructs a CIMKeyBinding object with null values.
@@ -191,8 +203,6 @@ PEGASUS_COMMON_LINKAGE Boolean operator==(
 # include <Pegasus/Common/ArrayInter.h>
 #undef PEGASUS_ARRAY_T
 
-class XmlWriter;
-
 /**
     The CIMObjectPath class represents the DMTF standard CIM object name or
     reference.  A reference is a property type that is used in an association.
@@ -412,7 +422,7 @@ public:
         @param nameSpace A CIMNamespaceName specifying the namespace name.
             A null name indicates that the object path does not contain
             a namespace attribute.
-        @param nameSpace A CIMName specifying the class name.
+        @param className A CIMName specifying the class name.
         @param keyBindings An Array of CIMKeyBinding objects specifying the
             key bindings.
         @exception MalformedObjectNameException If the host name String
@@ -451,7 +461,7 @@ public:
         @param nameSpace A CIMNamespaceName specifying the namespace name.
             A null name indicates that the object path does not contain
             a namespace attribute.
-        @param nameSpace A CIMName specifying the class name.
+        @param className A CIMName specifying the class name.
         @param keyBindings An Array of CIMKeyBinding objects specifying the
             key bindings.
         @exception MalformedObjectNameException If the host name String
@@ -582,6 +592,8 @@ private:
     String _toStringCanonical() const;
 
     CIMObjectPathRep* _rep;
+
+    friend class SQLiteStore;
 };
 
 /**
