@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -36,9 +34,7 @@
 #include "Resolver.h"
 #include "CIMQualifierDecl.h"
 #include "CIMName.h"
-#include "Indentor.h"
 #include "XmlWriter.h"
-#include "MofWriter.h"
 #include <Pegasus/Common/Tracer.h>
 #include <Pegasus/Common/MessageLoader.h>
 #include "StrLit.h"
@@ -50,7 +46,7 @@ PEGASUS_USING_STD;
 
 static CIMName _KEY("Key");
 
-CIMQualifierList::CIMQualifierList() : 
+CIMQualifierList::CIMQualifierList() :
                     _keyIndex(PEGASUS_ORDEREDSET_INDEX_UNKNOWN)
 {
 
@@ -76,29 +72,30 @@ CIMQualifierList& CIMQualifierList::add(const CIMQualifier& qualifier)
 
     _qualifiers.append(qualifier);
 
-     
     // Update key index:
-    if (_keyIndex == PEGASUS_ORDEREDSET_INDEX_UNKNOWN && 
+    if (_keyIndex == PEGASUS_ORDEREDSET_INDEX_UNKNOWN &&
             qualifier._rep->_name == _KEY)
-    {
         _keyIndex = _qualifiers.size()-1;
-    }
 
     return *this;
 }
-//ATTN: Why do we not do the outofbounds check here. KS 18 May 2k
+
 CIMQualifier& CIMQualifierList::getQualifier(Uint32 index)
 {
     return _qualifiers[index];
 }
 
-//ATTN: added ks 18 may 2001. Should we have outofbounds?
 void CIMQualifierList::removeQualifier(Uint32 index)
 {
     _qualifiers.remove(index);
     _keyIndex = PEGASUS_ORDEREDSET_INDEX_UNKNOWN;
 }
 
+void CIMQualifierList::clear()
+{
+    _qualifiers.clear();
+}
+
 Uint32 CIMQualifierList::find(const CIMName& name) const
 {
     return _qualifiers.find(name, generateCIMNameTag(name));
@@ -121,24 +118,13 @@ Boolean CIMQualifierList::isTrue(const CIMName& name) const
     return flag;
 }
 
-Uint32 CIMQualifierList::findReverse(const CIMName& name) const
-{
-    for (Uint32 i = _qualifiers.size(); i; --i)
-    {
-        if (name.equal(_qualifiers[i-1].getName()))
-            return i - 1;
-    }
-
-    return PEG_NOT_FOUND;
-}
-
 void CIMQualifierList::resolve(
     DeclContext* declContext,
     const CIMNamespaceName & nameSpace,
     CIMScope scope, // Scope of the entity being resolved.
     Boolean isInstancePart,
     CIMQualifierList& inheritedQualifiers,
-    Boolean propagateQualifiers)  // Apparently not used ks 24 mar 2002
+    Boolean propagateQualifiers)
 {
     _keyIndex = PEGASUS_ORDEREDSET_INDEX_UNKNOWN;
 
@@ -186,12 +172,11 @@ void CIMQualifierList::resolve(
             throw BadQualifierType(q.getName().getString ());
         }
 
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
         //----------------------------------------------------------------------
         // 3. If the qualifier is the EmbeddedInstance qualifier, then check
         // that the class specified by the qualifier exists in the namespace.
         //----------------------------------------------------------------------
-        if (q.getName().equal(CIMName("EmbeddedInstance")))
+        if (q.getName().equal(PEGASUS_QUALIFIERNAME_EMBEDDEDINSTANCE))
         {
             String className;
             q.getValue().get(className);
@@ -205,7 +190,6 @@ void CIMQualifierList::resolve(
                 throw BadQualifierType(embeddedInstType);
             }
         }
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
 
         //----------------------------------------------------------------------
         // 4. Check the scope: Must be legal for this qualifier
@@ -310,79 +294,43 @@ void CIMQualifierList::resolve(
     // already have those qualifiers:
     //--------------------------------------------------------------------------
 
-    for (Uint32 i = 0, n = inheritedQualifiers.getCount(); i < n; i++)
+    if (propagateQualifiers)
     {
-        CIMQualifier iq = inheritedQualifiers.getQualifier(i);
-
-        if (isInstancePart)
+        for (Uint32 i = 0, n = inheritedQualifiers.getCount(); i < n; i++)
         {
-            if (!(iq.getFlavor ().hasFlavor
-                  (CIMFlavor::TOINSTANCE)))
-                continue;
-        }
-        else
-        {
-            if (!(iq.getFlavor ().hasFlavor
-                  (CIMFlavor::TOSUBCLASS)))
-                continue;
-        }
+            CIMQualifier iq = inheritedQualifiers.getQualifier(i);
 
-        // If the qualifiers list does not already contain this qualifier,
-        // then propagate it (and set the propagated flag to true).  Else we
-        // keep current value. Note we have already eliminated any possibity
-        // that a nonoverridable qualifier can be in the list.
-        // Note that there is no exists() function ATTN:KS 25 Mar 2002
-        if (find(iq.getName()) != PEG_NOT_FOUND)
-            continue;
+            if (isInstancePart)
+            {
+                if (!(iq.getFlavor().hasFlavor(CIMFlavor::TOINSTANCE)))
+                    continue;
+            }
+            else
+            {
+                if (!(iq.getFlavor().hasFlavor(CIMFlavor::TOSUBCLASS)))
+                    continue;
+            }
 
-        CIMQualifier q = iq.clone();
-        q.setPropagated(true);
-        _qualifiers.insert(0, q);
+            // If the qualifiers list does not already contain this qualifier,
+            // then propagate it (and set the propagated flag to true).  Else
+            // we keep current value. Note we have already eliminated any
+            // possibility that a nonoverridable qualifier can be in the list.
+            if (find(iq.getName()) != PEG_NOT_FOUND)
+                continue;
+
+            CIMQualifier q = iq.clone();
+            q.setPropagated(true);
+            _qualifiers.insert(0, q);
+        }
     }
     PEG_METHOD_EXIT();
 }
 
-void CIMQualifierList::toXml(Buffer& out) const
-{
-    for (Uint32 i = 0, n = _qualifiers.size(); i < n; i++)
-        XmlWriter::appendQualifierElement(out, _qualifiers[i]);
-}
-
-/** toMof - Generates MOF output for a list of CIM Qualifiers.
-    The qualifiers may be class, property, parameter, etc.
-    The BNF for this is:
-    <pre>
-    qualifierList       = "[" qualifier *( "," qualifier ) "]"
-    </pre>
-    Produces qualifiers as a string on without nl.
-    */
-void CIMQualifierList::toMof(Buffer& out) const
-{
-    // if no qualifiers, return
-    if (_qualifiers.size() == 0)
-        return;
-
-    // Qualifier leading bracket.
-    out.append('[');
-
-    // Loop to list qualifiers
-    for (Uint32 i = 0, n = _qualifiers.size(); i < n; i++)
-    {
-        // if second or greater, add comma separator
-        if (i > 0)
-            out << STRLIT(", \n");
-        MofWriter::appendQualifierElement(out, _qualifiers[i]);
-    }
-
-    // Terminating bracket
-    out.append(']');
-}
-
-
 void CIMQualifierList::print(PEGASUS_STD(ostream) &os) const
 {
     Buffer tmp;
-    toXml(tmp);
+    for (Uint32 i = 0, n = getCount(); i < n; i++)
+        XmlWriter::appendQualifierElement(tmp, _qualifiers[i]);
     os << tmp.getData() << PEGASUS_STD(endl);
 }
 
@@ -444,4 +392,18 @@ Boolean CIMQualifierList::isKey() const
     return false;
 }
 
+CIMQualifierList& CIMQualifierList::addUnchecked(const CIMQualifier& qualifier)
+{
+    if (qualifier.isUninitialized())
+        throw UninitializedObjectException();
+
+    _qualifiers.append(qualifier);
+
+    if (_keyIndex == PEGASUS_ORDEREDSET_INDEX_UNKNOWN &&
+            qualifier._rep->_name == _KEY)
+        _keyIndex = _qualifiers.size()-1;
+
+    return *this;
+}
+
 PEGASUS_NAMESPACE_END
