@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -35,11 +33,8 @@
 #include <cstdio>
 #include <cctype>
 #include "CIMValue.h"
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
 #include "CIMInstance.h"
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
 #include "Union.h"
-#include "Indentor.h"
 #include "XmlWriter.h"
 #include "CommonUTF.h"
 #include "CIMValueRep.h"
@@ -166,12 +161,10 @@ inline void _toString(Buffer& out, const CIMObject& x)
 {
     out << x.toString();
 }
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
 inline void _toString(Buffer& out, const CIMInstance& x)
 {
     out << CIMObject(x).toString();
 }
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
 
 template<class T>
 void _toString(Buffer& out, const T* p, Uint32 size)
@@ -260,11 +253,9 @@ void CIMValueRep::release()
             case CIMTYPE_OBJECT:
                 CIMValueType<CIMObject>::destructArray(this);
                 break;
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
             case CIMTYPE_INSTANCE:
                 CIMValueType<CIMInstance>::destructArray(this);
                 break;
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
         }
     }
     else
@@ -300,11 +291,9 @@ void CIMValueRep::release()
             case CIMTYPE_OBJECT:
                 CIMValueType<CIMObject>::destruct(this);
                 break;
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
             case CIMTYPE_INSTANCE:
                 CIMValueType<CIMInstance>::destruct(this);
                 break;
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
         }
     }
 }
@@ -395,11 +384,9 @@ CIMValue::CIMValue(CIMType type, Boolean isArray, Uint32 arraySize)
         case CIMTYPE_OBJECT:
             CIMValueType<CIMObject>::setNull(_rep, type, isArray, arraySize);
             break;
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
         case CIMTYPE_INSTANCE:
             CIMValueType<CIMInstance>::setNull(_rep, type, isArray, arraySize);
             break;
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
 
         default:
             PEGASUS_ASSERT(0);
@@ -507,7 +494,6 @@ CIMValue::CIMValue(const CIMObject& x)
     _rep = new CIMValueRep;
     CIMValueType<CIMObject>::set(_rep, x.clone());
 }
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
 CIMValue::CIMValue(const CIMInstance& x)
 {
     if (x.isUninitialized())
@@ -519,7 +505,6 @@ CIMValue::CIMValue(const CIMInstance& x)
     _rep = new CIMValueRep;
     CIMValueType<CIMInstance>::set(_rep, x.clone());
 }
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
 CIMValue::CIMValue(const Array<Boolean>& x)
 {
     _rep = new CIMValueRep;
@@ -630,7 +615,6 @@ CIMValue::CIMValue(const Array<CIMObject>& x)
     CIMValueType<CIMObject>::setArray(_rep, tmp);
 }
 
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
 CIMValue::CIMValue(const Array<CIMInstance>& x)
 {
     Array<CIMInstance> tmp;
@@ -649,7 +633,6 @@ CIMValue::CIMValue(const Array<CIMInstance>& x)
     _rep = new CIMValueRep;
     CIMValueType<CIMInstance>::setArray(_rep, tmp);
 }
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
 
 void CIMValue::clear()
 {
@@ -736,10 +719,8 @@ Uint32 CIMValue::getArraySize() const
 
         case CIMTYPE_OBJECT:
             return CIMValueType<CIMObject>::arraySize(_rep);
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
         case CIMTYPE_INSTANCE:
         return CIMValueType<CIMInstance>::arraySize(_rep);
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
         default:
             PEGASUS_ASSERT(0);
     }
@@ -824,11 +805,9 @@ void CIMValue::setNullValue(CIMType type, Boolean isArray, Uint32 arraySize)
         case CIMTYPE_OBJECT:
             CIMValueType<CIMObject>::setNull(_rep, type, isArray, arraySize);
             break;
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
         case CIMTYPE_INSTANCE:
             CIMValueType<CIMInstance>::setNull(_rep, type, isArray, arraySize);
             break;
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
         default:
             PEGASUS_ASSERT(0);
     }
@@ -935,7 +914,6 @@ void CIMValue::set(const CIMObject& x)
     _release(_rep);
     CIMValueType<CIMObject>::set(_rep, x.clone());
 }
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
 void CIMValue::set(const CIMInstance& x)
 {
     if (x.isUninitialized())
@@ -947,7 +925,6 @@ void CIMValue::set(const CIMInstance& x)
     _release(_rep);
     CIMValueType<CIMInstance>::set(_rep, x.clone());
 }
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
 void CIMValue::set(const Array<Boolean>& x)
 {
     _release(_rep);
@@ -1056,7 +1033,6 @@ void CIMValue::set(const Array<CIMObject>& a)
     _release(_rep);
     CIMValueType<CIMObject>::setArray(_rep, tmp);
 }
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
 void CIMValue::set(const Array<CIMInstance>& a)
 {
     Array<CIMInstance> tmp;
@@ -1075,7 +1051,6 @@ void CIMValue::set(const Array<CIMInstance>& a)
     _release(_rep);
     CIMValueType<CIMInstance>::setArray(_rep, tmp);
 }
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
 void CIMValue::get(Boolean& x) const
 {
     if (_rep->type != CIMTYPE_BOOLEAN || _rep->isArray)
@@ -1223,7 +1198,6 @@ void CIMValue::get(CIMObject& x) const
         // changing the one we refer to as well.
         x = CIMValueType<CIMObject>::ref(_rep).clone();
 }
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
 void CIMValue::get(CIMInstance& x) const
 {
     if (_rep->type != CIMTYPE_INSTANCE || _rep->isArray)
@@ -1237,7 +1211,6 @@ void CIMValue::get(CIMInstance& x) const
         x = CIMValueType<CIMInstance>::ref(_rep).clone();
     }
 }
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
 void CIMValue::get(Array<Boolean>& x) const
 {
     if (_rep->type != CIMTYPE_BOOLEAN || !_rep->isArray)
@@ -1393,7 +1366,6 @@ void CIMValue::get(Array<CIMObject>& x) const
     }
 }
 
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
 void CIMValue::get(Array<CIMInstance>& x) const
 {
     if (_rep->type != CIMTYPE_INSTANCE || !_rep->isArray)
@@ -1413,7 +1385,6 @@ void CIMValue::get(Array<CIMInstance>& x) const
         }
     }
 }
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
 
 Boolean CIMValue::equal(const CIMValue& x) const
 {
@@ -1477,10 +1448,8 @@ Boolean CIMValue::equal(const CIMValue& x) const
 
             case CIMTYPE_OBJECT:
                 return CIMValueType<CIMObject>::equalArray(_rep, x._rep);
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
             case CIMTYPE_INSTANCE:
                 return CIMValueType<CIMInstance>::equalArray(_rep, x._rep);
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
             default:
                 PEGASUS_ASSERT(0);
         }
@@ -1537,11 +1506,9 @@ Boolean CIMValue::equal(const CIMValue& x) const
             case CIMTYPE_OBJECT:
                 return CIMValueType<CIMObject>::ref(_rep).identical(
                     CIMValueType<CIMObject>::ref(x._rep));
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
             case CIMTYPE_INSTANCE:
                 return CIMValueType<CIMInstance>::ref(_rep).identical(
                     CIMValueType<CIMInstance>::ref(x._rep));
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
             default:
                 PEGASUS_ASSERT(0);
         }
@@ -1683,7 +1650,6 @@ String CIMValue::toString() const
                 _toString(out, a.getData(), a.size());
                 break;
             }
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
             case CIMTYPE_INSTANCE:
             {
                 const Array<CIMInstance>& a =
@@ -1691,7 +1657,6 @@ String CIMValue::toString() const
                 _toString(out, a.getData(), a.size());
                 break;
             }
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
             default:
                 PEGASUS_ASSERT(0);
         }
@@ -1763,11 +1728,9 @@ String CIMValue::toString() const
             case CIMTYPE_OBJECT:
                 _toString(out, CIMValueType<CIMObject>::ref(_rep));
                 break;
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
             case CIMTYPE_INSTANCE:
                 _toString(out, CIMValueType<CIMInstance>::ref(_rep));
                 break;
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
             default:
                 PEGASUS_ASSERT(0);
         }
