@@ -1,34 +1,32 @@
+//%LICENSE////////////////////////////////////////////////////////////////
+//
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
+//
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
+//
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 /*
-//%2006////////////////////////////////////////////////////////////////////////
-//
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
-//
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-//
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-//
-//==============================================================================
 //
 //%/////////////////////////////////////////////////////////////////////////////
 */
@@ -55,8 +53,6 @@
 
 #define PEGASUS_QUEUENAME_HTTPACCEPTOR        "HTTPAcceptor"
 #define PEGASUS_QUEUENAME_HTTPCONNECTION      "HTTPConnection"
-#define PEGASUS_QUEUENAME_HTTPCONNECTOR       "HTTPConnector"
-#define PEGASUS_QUEUENAME_HTTPOPTIONS         "HTTPOptions"
 
 #define PEGASUS_QUEUENAME_HTTPAUTHDELEGATOR   "HTTPAuthenticatorDelegator"
 #define PEGASUS_QUEUENAME_OPREQDECODER        "CIMOpRequestDecoder"
@@ -83,7 +79,6 @@
 
 #define PEGASUS_QUEUENAME_WBEMEXECCLIENT      "WbemExecClient"
 #define PEGASUS_QUEUENAME_INTERNALCLIENT       "InternalClient"
-#define PEGASUS_QUEUENAME_BINARY_HANDLER       "BinaryMessageHandler"
 
 
 /*
@@ -114,7 +109,7 @@
      PEGASUS_QUEUENAME_CONTROLSERVICE "::CIMOMStatDataProvider"
 #endif
 
-#ifndef PEGASUS_DISABLE_CQL
+#ifdef PEGASUS_ENABLE_CQL
 # define PEGASUS_MODULENAME_CIMQUERYCAPPROVIDER \
      PEGASUS_QUEUENAME_CONTROLSERVICE "::CIMQueryCapabilitiesProvider"
 #endif
@@ -217,9 +212,9 @@
     "/opt/wbem/share/locale/ICU_Messages"
 # elif defined(PEGASUS_OS_PASE)
 #  define PEGASUS_CIMSERVER_START_FILE      \
-    "/QOpenSys/QIBM/UserData/UME/Pegasus/cimserver_start.conf"
+    "/QOpenSys/var/UME/cimserver_start.conf"
 #  define PEGASUS_CIMSERVER_START_LOCK_FILE \
-    "/QOpenSys/QIBM/UserData/UME/Pegasus/cimserver_start.lock"
+    "/QOpenSys/var/UME/cimserver_start.lock"
 #  define PEGASUS_REPOSITORY_DIR            \
     "/QOpenSys/QIBM/UserData/UME/Pegasus/repository"
 #  define PEGASUS_CURRENT_CONFIG_FILE_PATH  \
@@ -231,7 +226,7 @@
 #  define PEGASUS_SSLCLIENT_RANDOMFILE      \
     "/QOpenSys/QIBM/UserData/UME/Pegasus/ssl.rnd"
 #  define PEGASUS_SSLSERVER_RANDOMFILE      \
-    "/QOpenSys/QIBM/UserData/UME/Pegasus/ssl/keystore/cimserver.rnd"
+    "/QOpenSys/var/UME/cimserver.rnd"
 #  define PEGASUS_LOCAL_AUTH_DIR            "/QOpenSys/var/UME"
 #  define PEGASUS_LOCAL_DOMAIN_SOCKET_PATH  "/QOpenSys/var/UME/cimxml.socket"
 #  define PEGASUS_PAM_STANDALONE_PROC_NAME  \
@@ -301,7 +296,7 @@
 #  undef PEGASUS_LOCAL_DOMAIN_SOCKET_PATH   /* Not used */
 #  define PEGASUS_PROVIDER_AGENT_PROC_NAME  "/wbem_var/opt/wbem/bin/cimprovagt"
 #  undef PEGASUS_DEFAULT_MESSAGE_SOURCE     /* Not defined */
-# elif defined(PEGASUS_PLATFORM_ZOS_ZSERIES_IBM)
+# elif defined(PEGASUS_OS_ZOS)
 #  define PEGASUS_CIMSERVER_START_FILE      "/var/wbem/cimserver.pid"
 #  define PEGASUS_CIMSERVER_START_LOCK_FILE "/var/wbem/cimserver_start.lock"
 #  define PEGASUS_REPOSITORY_DIR            "/var/wbem/repository"
@@ -421,11 +416,11 @@
 #define PEGASUS_PARAMETER_ORDEREDSET_HASHSIZE 16
 #define PEGASUS_METHOD_ORDEREDSET_HASHSIZE 16
 
-/* defines a number value for an OrderedSet when either 
+/* defines a number value for an OrderedSet when either
    the index to a specific member is unknown, meaning not initialized
    (PEGASUS_ORDEREDSET_INDEX_UNKNOWN)
    of the specific member is not part of the list
-   (PEGASUS_ORDEREDSET_INDEX_NOTFOUND)   
+   (PEGASUS_ORDEREDSET_INDEX_NOTFOUND)
 */
 #define PEGASUS_ORDEREDSET_INDEX_NOTFOUND 0xFFFFFFFF
 #define PEGASUS_ORDEREDSET_INDEX_UNKNOWN 0xFFFFFFFE
@@ -439,6 +434,26 @@
 #define PEGASUS_MAX_USER_NAME_LEN 256
 #endif
 
+/*
+   Defines the min/max size of the memory trace buffer
+*/
+#define PEGASUS_TRC_BUFFER_MAX_SIZE_KB 1024*1024
+#define PEGASUS_TRC_BUFFER_MIN_SIZE_KB 16
+
+#ifdef PEGASUS_OS_ZOS
+# define PEGASUS_TRC_BUFFER_OOP_SIZE_DEVISOR 1
+#else
+# define PEGASUS_TRC_BUFFER_OOP_SIZE_DEVISOR 10
+#endif
+
+/*
+ * Minimum value for maxLogFileSizeKBytes config property.
+*/
+#if !defined(PEGASUS_USE_SYSLOGS)
+#define PEGASUS_MAXLOGFILESIZEKBYTES_CONFIG_PROPERTY_MINIMUM_VALUE 32
+#endif
+
+
 /*
 **==============================================================================
 **
@@ -496,7 +511,7 @@ PEGASUS_COMMON_LINKAGE
     extern const CIMName PEGASUS_CLASSNAME_FORMATTEDINDSUBSCRIPTION;
 PEGASUS_COMMON_LINKAGE extern const CIMName PEGASUS_CLASSNAME_INDHANDLER;
 PEGASUS_COMMON_LINKAGE extern const CIMName PEGASUS_CLASSNAME_LSTNRDST;
-PEGASUS_COMMON_LINKAGE 
+PEGASUS_COMMON_LINKAGE
     extern const CIMName PEGASUS_CLASSNAME_INDHANDLER_CIMXML;
 PEGASUS_COMMON_LINKAGE extern const CIMName PEGASUS_CLASSNAME_LSTNRDST_CIMXML;
 PEGASUS_COMMON_LINKAGE extern const CIMName PEGASUS_CLASSNAME_INDHANDLER_SNMP;
@@ -511,11 +526,14 @@ PEGASUS_COMMON_LINKAGE extern const CIMName PEGASUS_CLASSNAME___NAMESPACE;
 PEGASUS_COMMON_LINKAGE extern const CIMName PEGASUS_CLASSNAME_CIMOMSTATDATA;
 #endif
 
-#ifndef PEGASUS_DISABLE_CQL
+#ifdef PEGASUS_ENABLE_CQL
 PEGASUS_COMMON_LINKAGE
     extern const CIMName PEGASUS_CLASSNAME_CIMQUERYCAPABILITIES;
 #endif
 
+PEGASUS_COMMON_LINKAGE extern const CIMName PEGASUS_CLASSNAME_PROVIDERINDDATA;
+PEGASUS_COMMON_LINKAGE
+    extern const CIMName PEGASUS_CLASSNAME_SUBSCRIPTIONINDDATA;
 
 // Definitions for Interop Classes Accessed through Interop Control Provider
 
@@ -592,6 +610,20 @@ PEGASUS_COMMON_LINKAGE
 PEGASUS_COMMON_LINKAGE extern const CIMName PEGASUS_CLASSNAME_WBEMSLPTEMPLATE;
 #endif
 
+// DMTF Indications profile classes
+#ifdef PEGASUS_ENABLE_DMTF_INDICATION_PROFILE_SUPPORT
+PEGASUS_COMMON_LINKAGE
+    extern const CIMName PEGASUS_CLASSNAME_CIM_INDICATIONSERVICE;
+PEGASUS_COMMON_LINKAGE
+    extern const CIMName PEGASUS_CLASSNAME_CIM_INDICATIONSERVICECAPABILITIES;
+PEGASUS_COMMON_LINKAGE
+    extern const CIMName PEGASUS_CLASSNAME_PG_ELEMENTCAPABILITIES;
+PEGASUS_COMMON_LINKAGE
+    extern const CIMName PEGASUS_CLASSNAME_PG_HOSTEDINDICATIONSERVICE;
+PEGASUS_COMMON_LINKAGE
+    extern const CIMName PEGASUS_CLASSNAME_PG_SERVICEAFFECTSELEMENT;
+#endif
+
 //
 // Property Names Indication Subscriptions
 //
@@ -723,7 +755,7 @@ PEGASUS_COMMON_LINKAGE
     extern const CIMNamespaceName PEGASUS_NAMESPACENAME_CIMOMSTATDATA;
 #endif
 
-#ifndef PEGASUS_DISABLE_CQL
+#ifdef PEGASUS_ENABLE_CQL
 PEGASUS_COMMON_LINKAGE
     extern const CIMNamespaceName PEGASUS_NAMESPACENAME_CIMQUERYCAPABILITIES;
 #endif
@@ -765,6 +797,15 @@ PEGASUS_COMMON_LINKAGE extern const CIMName
 PEGASUS_COMMON_LINKAGE extern const
     CIMName PEGASUS_PROPERTYNAME_LSTNRDST_MAILCC;
 
+/**
+    The qualifier name of embedded objects/instances.
+*/
+PEGASUS_COMMON_LINKAGE extern const
+    CIMName PEGASUS_QUALIFIERNAME_EMBEDDEDOBJECT;
+
+PEGASUS_COMMON_LINKAGE extern const
+    CIMName PEGASUS_QUALIFIERNAME_EMBEDDEDINSTANCE;
+
 PEGASUS_NAMESPACE_END
 
 #endif /* defined(__cplusplus) */
