@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -41,6 +39,7 @@
 # include <windows.h>
 #else
 # include <unistd.h>
+# include <errno.h>
 # include <sys/types.h>
 # include <sys/time.h>
 # include <sys/resource.h>
@@ -74,6 +73,10 @@
 # include <as400_protos.h> // For fork400()
 #endif
 
+#ifdef PEGASUS_OS_ZOS
+# include <spawn.h>
+#endif
+
 PEGASUS_NAMESPACE_BEGIN
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -169,20 +172,33 @@ public:
         const char* path,
         int mode)
     {
+        FILE* fhandle = NULL;
         switch (mode)
         {
             case 'r':
-                return fopen(path, "r");
+                fhandle = fopen(path, "r");
+                break;
 
             case 'w':
-                return fopen(path, "w");
+                fhandle = fopen(path, "w");
+                break;
 
             case 'a':
-                return fopen(path, "a+");
+                fhandle = fopen(path, "a+");
+                break;
 
             default:
-                return NULL;
+                PEGASUS_ASSERT(fhandle);
+                break;
         }
+
+        if(!fhandle)
+        {
+            PEG_TRACE((TRC_SERVER, Tracer::LEVEL1,
+                "Open of file %s in mode %c failed: %s",path,mode,
+                (const char*) PEGASUS_SYSTEM_ERRORMSG.getCString()));
+        }
+        return fhandle;
     }
 
     virtual int renameFile(
@@ -208,8 +224,26 @@ public:
         AnonymousPipe*& readPipe,
         AnonymousPipe*& writePipe)
     {
+        PEG_METHOD_ENTER(TRC_SERVER,"ExecutorLoopbackImpl::startProviderAgent");
+
 #if !defined(PEGASUS_ENABLE_PRIVILEGE_SEPARATION)
 
+        // Resolve full path of "cimprovagt" program.
+
+        String path = FileSystem::getAbsolutePath(
+            pegasusHome.getCString(), PEGASUS_PROVIDER_AGENT_PROC_NAME);
+
+        // Create CString handles for cimprovagt arguments
+
+        CString agentProgramPath = path.getCString();
+        CString userNameCString = userName.getCString();
+
+# if defined(PEGASUS_DISABLE_PROV_USERCTXT)
+        const char* setUserContextFlag = "0";    // False
+# else
+        const char* setUserContextFlag = "1";    // True
+# endif
+
 # if defined(PEGASUS_OS_TYPE_WINDOWS)
 
         AutoMutex autoMutex(_mutex);
@@ -241,21 +275,16 @@ public:
         ZeroMemory(&siStartInfo, sizeof (STARTUPINFO));
         siStartInfo.cb = sizeof (STARTUPINFO);
 
-        // Build full path of "cimprovagt" program.
-
-        String path = FileSystem::getAbsolutePath(
-            pegasusHome.getCString(), PEGASUS_PROVIDER_AGENT_PROC_NAME);
-
         // Format command line.
 
         char cmdLine[2048];
 
         sprintf(cmdLine, "\"%s\" %s %s %s \"%s\" \"%s\"",
-            (const char*)path.getCString(),
-            "0",    // Do not set user context in cimprovagt
+            (const char*)agentProgramPath,
+            setUserContextFlag,
             readHandle,
             writeHandle,
-            (const char*)userName.getCString(),
+            (const char*)userNameCString,
             module);
 
         //  Create provider agent proess.
@@ -272,6 +301,7 @@ public:
             &siStartInfo,  //  STARTUPINFO
             &piProcInfo))  //  PROCESS_INFORMATION
         {
+            PEG_METHOD_EXIT();
             return -1;
         }
 
@@ -286,6 +316,7 @@ public:
         readPipe = pipeFromAgent.release();
         writePipe = pipeToAgent.release();
 
+        PEG_METHOD_EXIT();
         return 0;
 
 # else /* POSIX CASE FOLLOWS */
@@ -302,48 +333,107 @@ public:
 
         int to[2];
         int from[2];
+        char toPipeArg[32];
+        char fromPipeArg[32];
 
         do
         {
-            // Resolve full path of "cimprovagt".
-
-            String path = FileSystem::getAbsolutePath(
-                pegasusHome.getCString(), PEGASUS_PROVIDER_AGENT_PROC_NAME);
-
             // Create "to-agent" pipe:
 
             if (pipe(to) != 0)
+            {
+                PEG_METHOD_EXIT();
                 return -1;
+            }
 
             // Create "from-agent" pipe:
 
             if (pipe(from) != 0)
+            {
+                PEG_METHOD_EXIT();
                 return -1;
+            }
 
-            // Fork process:
+            // Initialize the cimprovagt pipe arguments:
 
-#  if defined(PEGASUS_OS_VMS)
-            pid = (int)vfork();
-# elif defined(PEGASUS_OS_PASE)
-            pid = (int)fork400("QUMEPRVAGT",0);
-#  else
-            pid = (int)fork();
-#  endif
+            sprintf(toPipeArg, "%d", to[0]);
+            sprintf(fromPipeArg, "%d", from[1]);
+
+            // Start provider agent:
+
+#  if defined(PEGASUS_OS_ZOS)
+            // zOS uses __spawn2() instead of fork() to start provider agent
+
+            struct __inheritance inherit;
+            const char *c_argv[7];
+
+            c_argv[0] = agentProgramPath;
+            c_argv[1] = setUserContextFlag;
+            c_argv[2] = toPipeArg;
+            c_argv[3] = fromPipeArg;
+            c_argv[4] = userNameCString;
+            c_argv[5] = module;
+            c_argv[6] = NULL;
+
+            // reset the inherit structure
+            memset(&inherit,0,sizeof(inherit));
+
+            // The provider agent should get a defined JobName.
+            inherit.flags=SPAWN_SETJOBNAME;
+            memcpy( inherit.jobname,"CFZOOPA ",
+                    sizeof(inherit.jobname));
+
+            PEG_TRACE((TRC_SERVER, Tracer::LEVEL4,
+                "Starting provider agent: %s %s %s %s %s %s %s",
+                (const char*)agentProgramPath,
+                c_argv[0],
+                c_argv[1],
+                c_argv[2],
+                c_argv[3],
+                c_argv[4],
+                c_argv[5]));
+
+            pid = __spawn2(agentProgramPath,0,NULL,&inherit,
+                           c_argv,(const char **)environ);
 
             if (pid < 0)
+            {
+                PEG_TRACE((TRC_SERVER, Tracer::LEVEL1,
+                    "Spawn of provider agent fails:%s "
+                        "( errno %d , reason code %08X )",
+                    strerror(errno) ,errno,__errno2()));
+                PEG_METHOD_EXIT();
                 return -1;
+            }
 
-            // If child proceses.
+#  else    // !defined(PEGASUS_OS_ZOS)
+
+#   if defined(PEGASUS_OS_VMS)
+            pid = (int)vfork();
+#   elif defined(PEGASUS_OS_PASE)
+            pid = (int)fork400("QUMEPRVAGT",0);
+#   else
+            pid = (int)fork();
+#   endif
+
+            if (pid < 0)
+            {
+                PEG_TRACE((TRC_SERVER, Tracer::LEVEL1,
+                     "Fork for provider agent fails: errno = %d",errno));
+                PEG_METHOD_EXIT();
+                return -1;
+            }
 
             if (pid == 0)
             {
-#  if !defined(PEGASUS_OS_VMS)
+                // Child process
+
+#   if !defined(PEGASUS_OS_VMS)
                 // Close unused pipe descriptors:
 
                 close(to[1]);
                 close(from[0]);
 
-
                 // Close unused descriptors. Leave stdin, stdout, stderr,
                 // and the child's pipe descriptors open.
 
@@ -358,40 +448,34 @@ public:
                     }
                 }
 
-#  endif /* !defined(PEGASUS_OS_VMS) */
+#   endif /* !defined(PEGASUS_OS_VMS) */
 
                 // Exec the cimprovagt program.
 
-                char toPipeArg[32];
-                char fromPipeArg[32];
-                sprintf(toPipeArg, "%d", to[0]);
-                sprintf(fromPipeArg, "%d", from[1]);
-
                 {
-                    CString cstr = path.getCString();
                     if (execl(
-                            cstr,
-                            cstr,
-#  if !defined(PEGASUS_DISABLE_PROV_USERCTXT) && !defined(PEGASUS_OS_ZOS)
-                            "1",    // Set user context in cimprovagt
-#  else
-                            "0",    // Do not set user context in cimprovagt
-#  endif
+                            agentProgramPath,
+                            agentProgramPath,
+                            setUserContextFlag,
                             toPipeArg,
                             fromPipeArg,
-                            (const char*)userName.getCString(),
+                            (const char*)userNameCString,
                             module,
                             (char*)0) == -1)
                     {
-                        PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL2,
+                        PEG_TRACE((TRC_SERVER, Tracer::LEVEL1,
                             "execl() failed.  errno = %d.", errno));
                         _exit(1);
                     }
                 }
             }
+#  endif /* PEGASUS_OS_ZOS */
         }
         while (0);
 
+        PEG_TRACE((TRC_SERVER, Tracer::LEVEL4,
+            "Provider agent started: pid(%d).", pid));
+
         // Close unused pipe descriptors.
 
         close(to[0]);
@@ -423,6 +507,7 @@ public:
 #   endif
 #  endif
 
+        PEG_METHOD_EXIT();
         return 0;
 
 # endif /* POSIX CASE */
