@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
 //
-//==============================================================================
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -56,6 +54,13 @@ PEGASUS_NAMESPACE_BEGIN
 
 static int _maxConnectionQueueLength = -1;
 
+Uint32 HTTPAcceptor::_socketWriteTimeout =
+    PEGASUS_DEFAULT_SOCKETWRITE_TIMEOUT_SECONDS;
+
+#ifndef PEGASUS_INTEGERS_BOUNDARY_ALIGNED
+Mutex HTTPAcceptor::_socketWriteTimeoutMutex;
+#endif
+
 ////////////////////////////////////////////////////////////////////////////////
 //
 // HTTPAcceptorRep
@@ -99,8 +104,15 @@ public:
 
     ~HTTPAcceptorRep()
     {
+        closeSocket();
         delete address;
     }
+
+    void closeSocket()
+    {
+        Socket::close(socket);
+    }
+
     struct sockaddr* address;
 
     SocketLength address_size;
@@ -131,9 +143,9 @@ HTTPAcceptor::HTTPAcceptor(Monitor* monitor,
      _connectionType(connectionType),
      _portNumber(portNumber),
      _sslcontext(sslcontext),
-     _sslContextObjectLock(sslContextObjectLock),
-     _idleConnectionTimeoutSeconds(0)
+     _sslContextObjectLock(sslContextObjectLock)
 {
+   PEGASUS_ASSERT(!_sslcontext == !_sslContextObjectLock);
    Socket::initializeInterface();
 
    /*
@@ -204,22 +216,14 @@ void HTTPAcceptor::handleEnqueue(Message *message)
             SocketMessage* socketMessage = (SocketMessage*)message;
 
             // If this is a connection request:
+            PEGASUS_ASSERT(socketMessage->socket == _rep->socket);
 
-            if (socketMessage->socket == _rep->socket &&
-                socketMessage->events & SocketMessage::READ)
-            {
-                _acceptConnection();
-            }
-            else
-            {
-                // ATTN! this can't happen!
-                PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
-                    "HTTPAcceptor::handleEnqueue: Invalid SOCKET_MESSAGE "
-                        "received.");
-           }
+            PEGASUS_ASSERT(socketMessage->events & SocketMessage::READ);
 
-           break;
-       }
+            _acceptConnection();
+
+            break;
+        }
 
        case CLOSE_CONNECTION_MESSAGE:
        {
@@ -246,9 +250,7 @@ void HTTPAcceptor::handleEnqueue(Message *message)
        }
 
        default:
-           // ATTN: need unexpected message error!
-           PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
-               "HTTPAcceptor::handleEnqueue: Invalid MESSAGE received.");
+           PEGASUS_ASSERT(false);
            break;
     }
 
@@ -259,14 +261,6 @@ void HTTPAcceptor::handleEnqueue(Message *message)
 void HTTPAcceptor::handleEnqueue()
 {
     Message* message = dequeue();
-
-    if (!message)
-    {
-        PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
-            "HTTPAcceptor::handleEnqueue(): No message on queue.");
-        return;
-    }
-
     handleEnqueue(message);
 }
 
@@ -276,9 +270,6 @@ void HTTPAcceptor::bind()
     {
         MessageLoaderParms parms("Common.HTTPAcceptor.ALREADY_BOUND",
             "HTTPAcceptor already bound");
-
-        PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
-            "HTTPAcceptor::bind: HTTPAcceptor already bound.");
         throw BindFailedException(parms);
     }
 
@@ -296,16 +287,7 @@ void HTTPAcceptor::bind()
 void HTTPAcceptor::_bind()
 {
 #ifdef PEGASUS_OS_PASE
-    // bind need ccsid is 819 
-    int orig_ccsid;
-    orig_ccsid = _SETCCSID(-1);
-    if (orig_ccsid == -1)
-    {
-        PEG_TRACE_STRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
-            String("HTTPAcceptor::_bind: Can not get current PASE CCSID."));
-        orig_ccsid = 1208;
-    }
-    PaseCcsid ccsid(819, orig_ccsid);
+    AutoPtr<PaseCcsid> ccsid;
 #endif
 
     PEGASUS_ASSERT(_rep != 0);
@@ -320,6 +302,18 @@ void HTTPAcceptor::_bind()
         // user.  Otherwise, the bind may fail with a vague "bind failed"
         // error.
         //
+#ifdef PEGASUS_OS_PASE
+        // PASE domain socket needs ccsid 819
+        int orig_ccsid;
+        orig_ccsid = _SETCCSID(-1);
+        if (orig_ccsid == -1)
+        {
+            PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL1,
+                    "HTTPAcceptor::_bind: Can not get current PASE CCSID.");
+            orig_ccsid = 1208;
+        }
+        ccsid.reset(new PaseCcsid(819, orig_ccsid));
+#endif
         if (System::exists(PEGASUS_LOCAL_DOMAIN_SOCKET_PATH))
         {
             if (!System::removeFile(PEGASUS_LOCAL_DOMAIN_SOCKET_PATH))
@@ -388,8 +382,6 @@ void HTTPAcceptor::_bind()
         _rep = 0;
         MessageLoaderParms parms("Common.HTTPAcceptor.FAILED_CREATE_SOCKET",
             "Failed to create socket");
-        PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
-            "HTTPAcceptor::_bind:  createSocket() _rep->socket failed");
         throw BindFailedException(parms);
     }
 
@@ -401,7 +393,7 @@ void HTTPAcceptor::_bind()
     int sock_flags;
     if ((sock_flags = fcntl(_rep->socket, F_GETFD, 0)) < 0)
     {
-        PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
+        PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL1,
             "HTTPAcceptor::_bind: fcntl(F_GETFD) failed");
     }
     else
@@ -409,7 +401,7 @@ void HTTPAcceptor::_bind()
         sock_flags |= FD_CLOEXEC;
         if (fcntl(_rep->socket, F_SETFD, sock_flags) < 0)
         {
-            PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
+            PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL1,
                 "HTTPAcceptor::_bind: fcntl(F_SETFD) failed");
         }
     }
@@ -426,13 +418,10 @@ void HTTPAcceptor::_bind()
     if (setsockopt(_rep->socket, SOL_SOCKET, SO_REUSEADDR,
             (char *)&opt, sizeof(opt)) < 0)
     {
-        Socket::close(_rep->socket);
         delete _rep;
         _rep = 0;
         MessageLoaderParms parms("Common.HTTPAcceptor.FAILED_SET_SOCKET_OPTION",
             "Failed to set socket option");
-        PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
-            "HTTPAcceptor::_bind: Failed to set socket option.");
         throw BindFailedException(parms);
     }
 
@@ -447,11 +436,8 @@ void HTTPAcceptor::_bind()
             "Failed to bind socket on port $0: $1.",
             _portNumber, PEGASUS_SYSTEM_NETWORK_ERRORMSG_NLS);
 
-        Socket::close(_rep->socket);
         delete _rep;
         _rep = 0;
-        PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
-            "HTTPAcceptor::_bind: Failed to bind socket.");
         throw BindFailedException(parms);
     }
 
@@ -477,7 +463,8 @@ void HTTPAcceptor::_bind()
     //
 #if !defined(PEGASUS_DISABLE_LOCAL_DOMAIN_SOCKET) && \
      (defined(PEGASUS_PLATFORM_LINUX_GENERIC_GNU) || \
-      defined(PEGASUS_PLATFORM_ZOS_ZSERIES_IBM))
+      defined(PEGASUS_OS_ZOS) || \
+      defined(PEGASUS_OS_PASE))
     if (_connectionType == LOCAL_CONNECTION)
     {
         if (::chmod(PEGASUS_LOCAL_DOMAIN_SOCKET_PATH,
@@ -491,12 +478,8 @@ void HTTPAcceptor::_bind()
                 PEGASUS_LOCAL_DOMAIN_SOCKET_PATH,
                 PEGASUS_SYSTEM_ERRORMSG_NLS );
 
-            Socket::close(_rep->socket);
             delete _rep;
             _rep = 0;
-            PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
-                "HTTPAcceptor::_bind: Failed to set domain socket "
-                    "permissions.");
             throw BindFailedException(parms);
         }
     }
@@ -512,12 +495,9 @@ void HTTPAcceptor::_bind()
             "Common.HTTPAcceptor.FAILED_LISTEN_SOCKET",
             "Failed to listen on socket {0}: {1}.",
             (int)_rep->socket,PEGASUS_SYSTEM_NETWORK_ERRORMSG_NLS );
-        
-        Socket::close(_rep->socket);
+
         delete _rep;
         _rep = 0;
-        PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
-            "HTTPAcceptor::_bind: Failed to bind socket(1).");
         throw BindFailedException(parms);
     }
 
@@ -527,16 +507,13 @@ void HTTPAcceptor::_bind()
             _rep->socket,
             SocketMessage::READ | SocketMessage::EXCEPTION,
             getQueueId(),
-            Monitor::ACCEPTOR)))
+            MonitorEntry::TYPE_ACCEPTOR)))
     {
-        Socket::close(_rep->socket);
         delete _rep;
         _rep = 0;
         MessageLoaderParms parms(
             "Common.HTTPAcceptor.FAILED_SOLICIT_SOCKET_MESSAGES",
             "Failed to solicit socket messaeges");
-        PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
-            "HTTPAcceptor::_bind: Failed to solicit socket messages(2).");
         throw BindFailedException(parms);
     }
 }
@@ -555,12 +532,12 @@ void HTTPAcceptor::closeConnectionSocket()
         //_monitor->unsolicitSocketMessages(_rep->socket);
 
         // close the socket
-        Socket::close(_rep->socket);
+        _rep->closeSocket();
         // Unlink Local Domain Socket Bug# 3312
         if (_connectionType == LOCAL_CONNECTION)
         {
 #ifndef PEGASUS_DISABLE_LOCAL_DOMAIN_SOCKET
-            PEG_TRACE_CSTRING(TRC_HTTP, Tracer::LEVEL2,
+            PEG_TRACE_CSTRING(TRC_HTTP, Tracer::LEVEL3,
                 "HTTPAcceptor::closeConnectionSocket Unlinking local "
                     "connection.");
             ::unlink(
@@ -572,7 +549,7 @@ void HTTPAcceptor::closeConnectionSocket()
     }
     else
     {
-        PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
+        PEG_TRACE_CSTRING(TRC_HTTP, Tracer::LEVEL2,
             "HTTPAcceptor::closeConnectionSocket failure _rep is null.");
     }
 }
@@ -588,7 +565,7 @@ void HTTPAcceptor::reopenConnectionSocket()
     }
     else
     {
-        PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
+        PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL1,
             "HTTPAcceptor::reopenConnectionSocket failure _rep is null.");
     }
 }
@@ -604,12 +581,12 @@ void HTTPAcceptor::reconnectConnectionSocket()
         // unregister the socket
         _monitor->unsolicitSocketMessages(_rep->socket);
         // close the socket
-        Socket::close(_rep->socket);
-        // Unlink Local Domain Socket Bug# 3312
+        _rep->closeSocket();
+        // Unlink Local Domain Socket
         if (_connectionType == LOCAL_CONNECTION)
         {
 #ifndef PEGASUS_DISABLE_LOCAL_DOMAIN_SOCKET
-            PEG_TRACE_CSTRING(TRC_HTTP, Tracer::LEVEL2,
+            PEG_TRACE_CSTRING(TRC_HTTP, Tracer::LEVEL3,
                 "HTTPAcceptor::reconnectConnectionSocket Unlinking local "
                     "connection." );
             ::unlink(
@@ -623,7 +600,7 @@ void HTTPAcceptor::reconnectConnectionSocket()
     }
     else
     {
-        PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
+        PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL1,
             "HTTPAcceptor::reconnectConnectionSocket failure _rep is null.");
     }
 }
@@ -660,20 +637,18 @@ Uint32 HTTPAcceptor::getPortNumber() const
 
 void HTTPAcceptor::setSocketWriteTimeout(Uint32 socketWriteTimeout)
 {
+#ifndef PEGASUS_INTEGERS_BOUNDARY_ALIGNED
+    AutoMutex lock(_socketWriteTimeoutMutex);
+#endif
     _socketWriteTimeout = socketWriteTimeout;
 }
 
-void HTTPAcceptor::setIdleConnectionTimeout(Uint32 idleConnectionTimeoutSeconds)
-{
-    _idleConnectionTimeoutSeconds = idleConnectionTimeoutSeconds;
-}
-
 void HTTPAcceptor::unbind()
 {
     if (_rep)
     {
         _portNumber = 0;
-        Socket::close(_rep->socket);
+        _rep->closeSocket();
 
         if (_connectionType == LOCAL_CONNECTION)
         {
@@ -690,7 +665,7 @@ void HTTPAcceptor::unbind()
     }
     else
     {
-        PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
+        PEG_TRACE_CSTRING(TRC_HTTP, Tracer::LEVEL1,
             "HTTPAcceptor::unbind failure _rep is null." );
     }
 }
@@ -776,21 +751,24 @@ void HTTPAcceptor::_acceptConnection()
         // TCPIP is down reconnect this acceptor
         if (getSocketError() == PEGASUS_NETWORK_TCPIP_STOPPED)
         {
-            PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
+            PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL1,
                 "Socket has an IO error. TCP/IP down. Try to reconnect.");
 
             reconnectConnectionSocket();
 
             return;
         }
-
-        Logger::put(Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
-            "HTTPAcceptor - accept() failure.  errno: $0", errno);
-
-        PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
-            "HTTPAcceptor: accept() failed");
+        PEG_TRACE((
+            TRC_DISCARDED_DATA,
+            Tracer::LEVEL1,
+            "HTTPAcceptor: accept() failed.  errno: %u",
+            errno));
         return;
     }
+
+    // Use an AutoPtr to ensure the socket handle is closed on exception
+    AutoPtr<SocketHandle, CloseSocketHandle> socketPtr(&socket);
+
 #ifndef PEGASUS_OS_TYPE_WINDOWS
     // We need to ensure that the socket number is not higher than
     // what fits into FD_SETSIZE, because we else won't be able to select on it
@@ -799,19 +777,15 @@ void HTTPAcceptor::_acceptConnection()
     {
         // the remote connection is invalid, destroy client address.
         delete accept_address;
-        
-        Logger::put(Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
-            "HTTPAcceptor out of available sockets. "
-                "Closing connection to the new client.");
 
         PEG_TRACE(
             (TRC_DISCARDED_DATA,
-             Tracer::LEVEL2,
-             "accept() returned too large socket number %d.",
+             Tracer::LEVEL1,
+             "HTTPAcceptor out of available sockets."
+                 "accept() returned too large socket number %u."
+                 "Closing connection to the new client.",
              socket));
-        
-        // close the connection
-        Socket::close(socket);
+
         return;
     }
 #endif
@@ -827,21 +801,20 @@ void HTTPAcceptor::_acceptConnection()
 #ifdef PEGASUS_ENABLE_IPV6
         char ipBuffer[PEGASUS_INET6_ADDRSTR_LEN];
         int rc;
-        if ((rc = System::getNameInfo(accept_address, 
-                address_size, 
+        if ((rc = System::getNameInfo(accept_address,
+                address_size,
                 ipBuffer,
-                PEGASUS_INET6_ADDRSTR_LEN, 
-                0, 
-                0, 
+                PEGASUS_INET6_ADDRSTR_LEN,
+                0,
+                0,
                 NI_NUMERICHOST)))
         {
-            Logger::put(Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
-                "HTTPAcceptor - getnameinfo() failure.  rc: $0", rc);
-
-            PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
-                "HTTPAcceptor: getnameinfo() failed");
+            PEG_TRACE((
+                TRC_DISCARDED_DATA,
+                Tracer::LEVEL1,
+                "HTTPAcceptor: getnameinfo() failed.  rc: %d",
+                rc));
             delete accept_address;
-            Socket::close(socket);
             return;
         }
         ipAddress = ipBuffer;
@@ -862,7 +835,7 @@ void HTTPAcceptor::_acceptConnection()
     int sock_flags;
     if ((sock_flags = fcntl(socket, F_GETFD, 0)) < 0)
     {
-        PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
+        PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL1,
             "HTTPAcceptor: fcntl(F_GETFD) failed");
     }
     else
@@ -870,21 +843,32 @@ void HTTPAcceptor::_acceptConnection()
         sock_flags |= FD_CLOEXEC;
         if (fcntl(socket, F_SETFD, sock_flags) < 0)
         {
-            PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
+            PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL1,
                 "HTTPAcceptor: fcntl(F_SETFD) failed");
         }
     }
 #endif
 
 
-    PEG_LOGGER_TRACE((Logger::STANDARD_LOG, System::CIMSERVER, 0,
-        "HTTPAcceptor - accept() success.  Socket: $1" ,socket));
+    PEG_TRACE((
+        TRC_HTTP,
+        Tracer::LEVEL3,
+        "HTTPAcceptor - accept() success.  Socket: %u",
+        socket));
 
     SharedPtr<MP_Socket> mp_socket(new MP_Socket(
         socket, _sslcontext, _sslContextObjectLock, ipAddress));
+    // mp_socket now has responsibility for closing the socket handle
+    socketPtr.release();
 
     mp_socket->disableBlocking();
-    mp_socket->setSocketWriteTimeout(_socketWriteTimeout);
+
+    {
+#ifndef PEGASUS_INTEGERS_BOUNDARY_ALIGNED
+        AutoMutex lock(_socketWriteTimeoutMutex);
+#endif
+        mp_socket->setSocketWriteTimeout(_socketWriteTimeout);
+    }
 
     // Perform the SSL handshake, if applicable.
 
@@ -892,27 +876,28 @@ void HTTPAcceptor::_acceptConnection()
 
     if (socketAcceptStatus < 0)
     {
-        PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
+        PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL1,
             "HTTPAcceptor: SSL_accept() failed");
-        mp_socket->close();
         return;
     }
 
     // Create a new connection and add it to the connection list:
 
-    HTTPConnection* connection = new HTTPConnection(_monitor, mp_socket,
-        ipAddress, this, static_cast<MessageQueue *>(_outputMessageQueue));
+    AutoPtr<HTTPConnection> connection(new HTTPConnection(
+        _monitor,
+        mp_socket,
+        ipAddress,
+        this,
+        _outputMessageQueue));
 
-    if (_idleConnectionTimeoutSeconds)
+    if (HTTPConnection::getIdleConnectionTimeout())
     {
-        connection->_idleConnectionTimeoutSeconds = 
-            _idleConnectionTimeoutSeconds;
         Time::gettimeofday(&connection->_idleStartTime);
     }
 
     if (socketAcceptStatus == 0)
     {
-        PEG_TRACE_CSTRING(TRC_HTTP, Tracer::LEVEL2,
+        PEG_TRACE_CSTRING(TRC_HTTP, Tracer::LEVEL1,
             "HTTPAcceptor: SSL_accept() pending");
         connection->_acceptPending = true;
         Time::gettimeofday(&connection->_acceptPendingStartTime);
@@ -924,22 +909,18 @@ void HTTPAcceptor::_acceptConnection()
     if (-1 ==  (index = _monitor->solicitSocketMessages(
             connection->getSocket(),
             SocketMessage::READ | SocketMessage::EXCEPTION,
-            connection->getQueueId(), Monitor::CONNECTION)) )
+            connection->getQueueId(), MonitorEntry::TYPE_CONNECTION)) )
     {
-        // ATTN-DE-P2-2003100503::TODO::Need to enhance code to return
-        // an error message to Client application.
-        PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
+        PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL1,
             "HTTPAcceptor::_acceptConnection: Attempt to allocate entry in "
                 "_entries table failed.");
-        delete connection;
-        Socket::close(socket);
         return;
     }
 
-    // Save the socket for cleanup later:
     connection->_entry_index = index;
     AutoMutex autoMut(_rep->_connection_mut);
-    _rep->connections.append(connection);
+    _rep->connections.append(connection.get());
+    connection.release();
 }
 
 PEGASUS_NAMESPACE_END
