@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -42,7 +40,7 @@
 #include "Socket.h"
 #include "TLS.h"
 #include "HTTPConnection.h"
-#include "MessageQueue.h"
+#include "HTTPAcceptor.h"
 #include "Monitor.h"
 #include "HTTPMessage.h"
 #include "Tracer.h"
@@ -97,7 +95,6 @@ static const char headerNameContentLanguage[] = "Content-Language";
 static const char headerNameTerminator[] = ": ";
 static const char headerValueSeparator[] = ", ";
 static const char headerLineTerminator[] = CRLF;
-static const char headerTerminator[] = CRLF CRLF;
 static const char chunkLineTerminator[] = CRLF;
 static const char chunkTerminator[] = CRLF;
 static const char chunkBodyTerminator[] = CRLF;
@@ -144,7 +141,8 @@ static void _throwEventFailure(const String &status, const String &detail,
     const char *file , Uint32 line)
 {
     String message = status + httpDetailDelimiter + detail;
-    PEG_TRACE_STRING(TRC_HTTP, Tracer::LEVEL2, message);
+    PEG_TRACE_CSTRING(TRC_HTTP, Tracer::LEVEL1,
+         (const char*)message.getCString());
     if (status == httpStatusInternal)
         throw AssertionFailureException(file, line, message);
     else throw Exception(message);
@@ -159,7 +157,7 @@ static void _throwEventFailure(const String &status, const String &detail,
 #define _socketWriteError()                                                   \
     do                                                                        \
     {                                                                         \
-        PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL2,                        \
+        PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL1,                        \
             "Socket write failed with error %d; could not write response "    \
                 "to client.  (Client may have timed out.)",                   \
             getSocketError()));                                               \
@@ -186,31 +184,53 @@ void * sigabrt_generator(void * parm)
 //
 ////////////////////////////////////////////////////////////////////////////////
 
+Uint32 HTTPConnection::_idleConnectionTimeoutSeconds = 0;
+
+#ifndef PEGASUS_INTEGERS_BOUNDARY_ALIGNED
+Mutex HTTPConnection::_idleConnectionTimeoutSecondsMutex;
+#endif
+
+void HTTPConnection::setIdleConnectionTimeout(
+    Uint32 idleConnectionTimeoutSeconds)
+{
+#ifndef PEGASUS_INTEGERS_BOUNDARY_ALIGNED
+    AutoMutex lock(_idleConnectionTimeoutSecondsMutex);
+#endif
+    _idleConnectionTimeoutSeconds = idleConnectionTimeoutSeconds;
+}
+
+Uint32 HTTPConnection::getIdleConnectionTimeout()
+{
+#ifndef PEGASUS_INTEGERS_BOUNDARY_ALIGNED
+    AutoMutex lock(_idleConnectionTimeoutSecondsMutex);
+#endif
+    return _idleConnectionTimeoutSeconds;
+}
+
 HTTPConnection::HTTPConnection(
     Monitor* monitor,
     SharedPtr<MP_Socket>& socket,
     const String& ipAddress,
-    MessageQueue* ownerMessageQueue,
+    HTTPAcceptor* owningAcceptor,
     MessageQueue* outputMessageQueue)
     :
     Base(PEGASUS_QUEUENAME_HTTPCONNECTION),
     _monitor(monitor),
     _socket(socket),
     _ipAddress(ipAddress),
-    _ownerMessageQueue(ownerMessageQueue),
+    _owningAcceptor(owningAcceptor),
     _outputMessageQueue(outputMessageQueue),
     _contentOffset(-1),
     _contentLength(-1),
     _connectionClosePending(false),
     _acceptPending(false),
-    _firstRead(true),
-    _idleConnectionTimeoutSeconds(0)
+    _firstRead(true)
 {
     PEG_METHOD_ENTER(TRC_HTTP, "HTTPConnection::HTTPConnection");
 
     _authInfo.reset(new AuthenticationInfo(true));
 
-#ifndef PEGASUS_PLATFORM_ZOS_ZSERIES_IBM
+#ifndef PEGASUS_OS_ZOS
     // Add SSL verification information to the authentication information
     if (_socket->isSecure())
     {
@@ -236,8 +256,8 @@ HTTPConnection::HTTPConnection(
     _connectionRequestCount = 0;
     _transferEncodingChunkOffset = 0;
 
-    PEG_TRACE_STRING(TRC_HTTP, Tracer::LEVEL2,
-        "Connection IP address = " + _ipAddress);
+    PEG_TRACE((TRC_HTTP, Tracer::LEVEL3,
+        "Connection IP address = %s",(const char*)_ipAddress.getCString()));
 
     _authInfo->setIpAddress(_ipAddress);
 
@@ -251,11 +271,11 @@ HTTPConnection::~HTTPConnection()
     // We need to acquire this mutex in order to give handleEnqueue()
     // a chance to finish processing. If we don't, we may run into a
     // situation where the connection is marked to be closed by the
-    // idle connection timeout mechanism and there are no pending 
-    // responses (the _responsePending flag is cleared in 
+    // idle connection timeout mechanism and there are no pending
+    // responses (the _responsePending flag is cleared in
     // _handleWriteEvent()). This causes the monitor to clean up the
-    // connection. But if processing is not out of 
-    // HTTPConnection::handleEnqueue(), we are running a risk of 
+    // connection. But if processing is not out of
+    // HTTPConnection::handleEnqueue(), we are running a risk of
     // accessing a deleted object and crashing cimserver.
     AutoMutex connectionLock(_connection_mut);
      _socket->close();
@@ -313,7 +333,7 @@ void HTTPConnection::handleEnqueue(Message *message)
 
 /*
  * Used on Server side to close outstanding connections waiting for SSL
- * handshake to complete if timeout expired or to close idle connections if 
+ * handshake to complete if timeout expired or to close idle connections if
  * idleConnectionTimeout config property value has specified.
  * Returns 'true' if connection is closed (or is closePending).
  * timeNow will be updated to current time if connection's _idleStartTime
@@ -330,27 +350,28 @@ Boolean HTTPConnection::closeConnectionOnTimeout(struct timeval* timeNow)
                  PEGASUS_SSL_ACCEPT_TIMEOUT_SECONDS) &&
             (timeNow->tv_sec > _acceptPendingStartTime.tv_sec))
         {
-            PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
+            PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL4,
                 "HTTPConnection: close acceptPending connection for timeout");
-            _closeConnection(); 
+            _closeConnection();
             return true;  // return 'true' to indicate connection was closed
         }
     }
     // else if connection timeout is active
-    else if (_idleConnectionTimeoutSeconds)
+    else if (getIdleConnectionTimeout())
     {
-        // For performance reasons timeNow is calculated only once in Monitor.
-        // Update timeNow if connection's _idleStartTime has more recent time.
+        // For performance reasons timeNow is calculated only once in
+        // Monitor. Update timeNow if connection's _idleStartTime has
+        // more recent time.
         if (timeNow->tv_sec < _idleStartTime.tv_sec)
         {
             Time::gettimeofday(timeNow);
         }
         else if ((Uint32)(timeNow->tv_sec - _idleStartTime.tv_sec) >
-            _idleConnectionTimeoutSeconds)
+            getIdleConnectionTimeout())
         {
-            PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL2,
+            PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL3,
                 "HTTPConnection: close idle connection for timeout "
-                "of %d seconds\n", _idleConnectionTimeoutSeconds));
+                "of %d seconds\n", getIdleConnectionTimeout()));
             _closeConnection();
             return true;  // return 'true' to indicate connection was closed
         }
@@ -370,7 +391,7 @@ Boolean HTTPConnection::closeConnectionOnTimeout(struct timeval* timeNow)
 Boolean HTTPConnection::_handleWriteEvent(Message &message)
 {
     static const char func[] = "HTTPConnection::_handleWriteEvent";
-    String httpStatus;
+    String httpStatusString;
     HTTPMessage& httpMessage = *(HTTPMessage*)&message;
     Buffer& buffer = httpMessage.message;
     Boolean isFirst = message.isFirst();
@@ -395,11 +416,7 @@ Boolean HTTPConnection::_handleWriteEvent(Message &message)
 
         if (_isClient() == false)
         {
-            // for null termination
-            buffer.reserveCapacity(messageLength + 1);
-            messageStart = (char *) buffer.getData();
-            messageStart[messageLength] = 0;
-            PEG_TRACE((TRC_XML_IO, Tracer::LEVEL2,
+            PEG_TRACE((TRC_XML_IO, Tracer::LEVEL4,
                 "<!-- Response: queue id: %u -->\n%s",
                 getQueueId(),
                 buffer.getData()));
@@ -424,7 +441,7 @@ Boolean HTTPConnection::_handleWriteEvent(Message &message)
             // save the first error
             if (httpMessage.cimException.getCode() != CIM_ERR_SUCCESS)
             {
-                httpStatus = httpMessage.cimException.getMessage();
+                httpStatusString = httpMessage.cimException.getMessage();
                 if (cimException.getCode() == CIM_ERR_SUCCESS)
                 {
                     cimException = httpMessage.cimException;
@@ -465,15 +482,13 @@ Boolean HTTPConnection::_handleWriteEvent(Message &message)
                     {
                         CIMStatusCode code = httpMessage.cimException.getCode();
                         String httpDetail(cimStatusCodeToString(code));
-                        char s[21];
-                        sprintf(s, "%u", code);
-                        String httpStatus(s);
-                        Buffer message = XmlWriter::formatHttpErrorRspMessage
-                            (httpStatus, String(), httpDetail);
-                        messageLength = message.size();
-                        message.reserveCapacity(messageLength+1);
-                        messageStart = (char *) message.getData();
-                        messageStart[messageLength] = 0;
+                        char s[11];
+                        sprintf(s, "%u", (unsigned int)code);
+                        String httpStatusCodeString(s);
+                        Buffer errorRsp = XmlWriter::formatHttpErrorRspMessage(
+                            httpStatusCodeString, String(), httpDetail);
+                        messageLength = errorRsp.size();
+                        messageStart = (char *) errorRsp.getData();
                     }
                     cimException = CIMException(cimException.getCode(),
                         String(messageStart, messageLength));
@@ -662,9 +677,10 @@ Boolean HTTPConnection::_handleWriteEvent(Message &message)
 
                         contentLengthStart[contentLengthLineLengthExpected] =
                             save;
-                        String operationName = headerNameOperation;
                         // look for 2-digit prefix (if mpost was use)
-                        HTTPMessage::lookupHeaderPrefix(headers, operationName,
+                        HTTPMessage::lookupHeaderPrefix(
+                            headers,
+                            headerNameOperation,
                             _mpostPrefix);
                     } // else chunk response is true
 
@@ -728,7 +744,7 @@ Boolean HTTPConnection::_handleWriteEvent(Message &message)
                             // content can be easily separated.
 
                             Boolean authrecExists = false;
-                            String authorization;
+                            const char* authorization;
                             if (HTTPMessage::lookupHeader(
                                     headers, "WWW-Authenticate",
                                     authorization, false))
@@ -772,18 +788,12 @@ Boolean HTTPConnection::_handleWriteEvent(Message &message)
 
         } // if not a client
 
-        PEG_TRACE_CSTRING(TRC_HTTP,Tracer::LEVEL4, 
+        PEG_TRACE_CSTRING(TRC_HTTP,Tracer::LEVEL4,
                 "HTTPConnection::_handleWriteEvent: Server write event.");
 
         SignalHandler::ignore(PEGASUS_SIGPIPE);
 
-        // use the next four lines to test the SIGABRT handler
-        //getSigHandle()->registerHandler(PEGASUS_SIGABRT, sig_act);
-        //getSigHandle()->activate(PEGASUS_SIGABRT);
-        //Thread t(sigabrt_generator, NULL, false);
-        //t.run();
-
-        char *sendStart = messageStart;
+        const char *sendStart = messageStart;
         Sint32 bytesWritten = 0;
 
         if (isFirst == true && isChunkResponse == true && bytesToWrite > 0)
@@ -793,7 +803,7 @@ Boolean HTTPConnection::_handleWriteEvent(Message &message)
             // dont include header terminator yet
             Uint32 headerLength = bytesToWrite;
             bytesToWrite -= headerLineTerminatorLength;
-            PEG_TRACE_CSTRING(TRC_HTTP,Tracer::LEVEL4, 
+            PEG_TRACE_CSTRING(TRC_HTTP,Tracer::LEVEL4,
               "HTTPConnection::_handleWriteEvent: "
               "Sending header for chunked reponses.");
 
@@ -809,10 +819,10 @@ Boolean HTTPConnection::_handleWriteEvent(Message &message)
                 _mpostPrefix << headerNameCode <<    headerValueSeparator <<
                 _mpostPrefix << headerNameDescription << headerValueSeparator <<
                 headerNameContentLanguage << headerLineTerminator;
-            sendStart = (char *) trailer.getData();
+            sendStart = trailer.getData();
             bytesToWrite = trailer.size();
 
-            PEG_TRACE_CSTRING(TRC_HTTP,Tracer::LEVEL4, 
+            PEG_TRACE_CSTRING(TRC_HTTP,Tracer::LEVEL4,
                     "HTTPConnection::_handleWriteEvent: "
                     "Sending trailer header for chunked responses.");
 
@@ -828,7 +838,7 @@ Boolean HTTPConnection::_handleWriteEvent(Message &message)
             bytesToWrite = headerLineTerminatorLength;
             sendStart = messageStart + headerLength - bytesToWrite;
 
-            PEG_TRACE_CSTRING(TRC_HTTP,Tracer::LEVEL4, 
+            PEG_TRACE_CSTRING(TRC_HTTP,Tracer::LEVEL4,
                     "HTTPConnection::_handleWriteEvent: "
                     "Sending header terminator for chunked responses.");
 
@@ -858,7 +868,7 @@ Boolean HTTPConnection::_handleWriteEvent(Message &message)
                 sendStart = chunkLine;
                 Sint32 chunkBytesToWrite = (Sint32)strlen(sendStart);
 
-                PEG_TRACE_CSTRING(TRC_HTTP,Tracer::LEVEL4, 
+                PEG_TRACE_CSTRING(TRC_HTTP,Tracer::LEVEL4,
                         "HTTPConnection::_handleWriteEvent: "
                         "Sending chunk with chunk line terminator.");
 
@@ -884,7 +894,7 @@ Boolean HTTPConnection::_handleWriteEvent(Message &message)
               sendStart = messageStart + messageLength - bytesRemaining;
               bytesToWrite = _Min(httpTcpBufferSize, bytesRemaining);
 
-              PEG_TRACE_CSTRING(TRC_HTTP,Tracer::LEVEL4, 
+              PEG_TRACE_CSTRING(TRC_HTTP,Tracer::LEVEL4,
                       "HTTPConnection::_handleWriteEvent: "
                       "Sending non-chunked data.");
 
@@ -949,15 +959,15 @@ Boolean HTTPConnection::_handleWriteEvent(Message &message)
 
                 if (traceTrailer)
                 {
-                    PEG_TRACE((TRC_XML_IO, Tracer::LEVEL2,
+                    PEG_TRACE((TRC_XML_IO, Tracer::LEVEL4,
                         "<!-- Trailer: queue id: %u -->\n%s",
                         getQueueId(),
                         trailer.getData()));
                 }
-                sendStart = (char *) trailer.getData();
+                sendStart = trailer.getData();
                 Sint32 chunkBytesToWrite = (Sint32) trailer.size();
 
-                PEG_TRACE_CSTRING(TRC_HTTP,Tracer::LEVEL4, 
+                PEG_TRACE_CSTRING(TRC_HTTP,Tracer::LEVEL4,
                         "HTTPConnection::_handleWriteEvent: "
                         "Sending the last chunk with chunk body terminator ");
 
@@ -973,12 +983,12 @@ Boolean HTTPConnection::_handleWriteEvent(Message &message)
 
     catch (Exception &e)
     {
-        httpStatus = e.getMessage();
+        httpStatusString = e.getMessage();
     }
     catch (...)
     {
-        httpStatus = HTTP_STATUS_INTERNALSERVERERROR;
-        PEG_TRACE_CSTRING(TRC_HTTP, Tracer::LEVEL2, "Unknown internal error");
+        httpStatusString = HTTP_STATUS_INTERNALSERVERERROR;
+        PEG_TRACE_CSTRING(TRC_HTTP, Tracer::LEVEL1, "Unknown internal error");
     }
 
     if (isLast == true)
@@ -997,7 +1007,7 @@ Boolean HTTPConnection::_handleWriteEvent(Message &message)
 
         _responsePending = false;
 
-        if (httpStatus.size() == 0)
+        if (httpStatusString.size() == 0)
         {
             PEG_TRACE((TRC_HTTP, Tracer::LEVEL4,
                 "A response has been sent (%d of %u bytes have been written). "
@@ -1026,21 +1036,21 @@ Boolean HTTPConnection::_handleWriteEvent(Message &message)
             }
             else
             {
-                // Update the connection idle time.
-                if (_idleConnectionTimeoutSeconds)
+                // Update connection idle time.
+                if (getIdleConnectionTimeout())
                 {
                     Time::gettimeofday(&_idleStartTime);
                 }
-                PEG_TRACE((TRC_HTTP, Tracer::LEVEL2,
-                    "Now setting state to %d", _MonitorEntry::IDLE));
-                _monitor->setState (_entry_index, _MonitorEntry::IDLE);
+                PEG_TRACE((TRC_HTTP, Tracer::LEVEL4,
+                    "Now setting state to %d", MonitorEntry::STATUS_IDLE));
+                _monitor->setState(_entry_index, MonitorEntry::STATUS_IDLE);
                 _monitor->tickle();
             }
             cimException = CIMException();
         }
     }
 
-    return httpStatus.size() == 0 ? false : true;
+    return httpStatusString.size() == 0 ? false : true;
 
 }
 
@@ -1163,7 +1173,7 @@ void HTTPConnection::_getContentLengthAndContentOffset()
     Boolean gotContentLanguage = false;
     Boolean gotTransferTE = false;
 
-    while ((sep = 
+    while ((sep =
         HTTPMessage::findSeparator(line, (Uint32)(size - (line - data)))))
     {
         char save = *sep;
@@ -1426,9 +1436,9 @@ void HTTPConnection::_closeConnection()
         }
 
         // still set to DYING
-        PEG_TRACE((TRC_HTTP, Tracer::LEVEL2,
-            "Now setting state to %d", _MonitorEntry::DYING));
-        _monitor->setState (_entry_index, _MonitorEntry::DYING);
+        PEG_TRACE((TRC_HTTP, Tracer::LEVEL4,
+            "Now setting state to %d", MonitorEntry::STATUS_DYING));
+        _monitor->setState(_entry_index, MonitorEntry::STATUS_DYING);
         _monitor->tickle();
     }
 
@@ -1440,11 +1450,6 @@ void HTTPConnection::_closeConnection()
     }
 
     PEG_METHOD_EXIT();
-
-//    Message* message= new CloseConnectionMessage(_socket->getSocket));
-//    message->dest = _ownerMessageQueue->getQueueId();
-//    SendForget(message);
-//    _ownerMessageQueue->enqueue(message);
 }
 
 Boolean HTTPConnection::isChunkRequested()
@@ -1477,8 +1482,7 @@ void HTTPConnection::setSocketWriteTimeout(Uint32 socketWriteTimeout)
 
 Boolean HTTPConnection::_isClient()
 {
-    return strcmp(get_owner().getQueueName(),
-        PEGASUS_QUEUENAME_HTTPCONNECTOR) == 0 ? true : false;
+    return (_owningAcceptor == 0);
 }
 
 /*
@@ -1686,18 +1690,18 @@ void HTTPConnection::_handleReadEventTransferEncoding()
                 remainderLength -= trailerLength;
 
                 // parse the trailer looking for the code and description
-                String startLine;
-                Array<HTTPHeader> headers;
-                Uint32 contentLength = 0;
+                String trailerStartLine;
+                Array<HTTPHeader> trailers;
+                Uint32 trailerContentLength = 0;
                 HTTPMessage httpTrailer(trailer);
-                httpTrailer.parse(startLine, headers, contentLength);
+                httpTrailer.parse(
+                    trailerStartLine, trailers, trailerContentLength);
 
-                String cimErrorName = headerNameError;
                 // first look for cim error. this is an http level error
                 Boolean found = false;
 
                 found = httpTrailer.lookupHeader(
-                    headers, cimErrorName, cimErrorValue, true);
+                    trailers, headerNameError, cimErrorValue, true);
 
                 if (found == true)
                 {
@@ -1706,14 +1710,18 @@ void HTTPConnection::_handleReadEventTransferEncoding()
                     // to make one up.
 
                     Buffer header(messageStart, headerLength);
-                    String startLine;
+                    String headerStartLine;
                     Array<HTTPHeader> headers;
-                    Uint32 contentLength = 0;
+                    Uint32 headerContentLength = 0;
                     HTTPMessage httpHeader(header);
-                    httpHeader.parse(startLine, headers, contentLength);
+                    httpHeader.parse(
+                        headerStartLine, headers, headerContentLength);
                     String httpVersion;
                     Boolean isValid = httpHeader.parseStatusLine(
-                        startLine, httpVersion, httpStatusCode,httpStatus);
+                        headerStartLine,
+                        httpVersion,
+                        httpStatusCode,
+                        httpStatus);
                     if (isValid == false || httpStatusCode == 0 ||
                             httpStatusCode == HTTP_STATUSCODE_OK)
                     {
@@ -1724,25 +1732,25 @@ void HTTPConnection::_handleReadEventTransferEncoding()
                 }
                 else
                 {
-                    String codeName = headerNameCode;
-                    String codeValue;
+                    const char* codeValue;
                     found = httpTrailer.lookupHeader(
-                        headers, codeName, codeValue, true);
-                    if (found == true && codeValue.size() > 0 &&
-                        (cimStatusCode = (CIMStatusCode)atoi(
-                             codeValue.getCString())) > 0)
+                        trailers, headerNameCode, codeValue, true);
+                    if (found && *codeValue &&
+                        (cimStatusCode = (CIMStatusCode)atoi(codeValue)) > 0)
                     {
                         HTTPMessage::lookupHeaderPrefix(
-                            headers, codeName, _mpostPrefix);
-                        httpStatus = _mpostPrefix + codeName +
+                            trailers, headerNameCode, _mpostPrefix);
+                        httpStatus = _mpostPrefix + headerNameCode +
                             headerNameTerminator + codeValue +
                             headerLineTerminator;
 
                         // look for cim status description
-                        String descriptionName = headerNameDescription;
                         String descriptionValue;
                         found = httpTrailer.lookupHeader(
-                            headers, descriptionName, descriptionValue, true);
+                            trailers,
+                            headerNameDescription,
+                            descriptionValue,
+                            true);
                         if (descriptionValue.size() == 0)
                         {
                             descriptionValue =
@@ -1750,14 +1758,14 @@ void HTTPConnection::_handleReadEventTransferEncoding()
                         }
 
                         httpStatus = httpStatus + _mpostPrefix +
-                            descriptionName + headerNameTerminator +
+                            headerNameDescription + headerNameTerminator +
                             descriptionValue + headerLineTerminator;
 
                     } // if found a cim status code
 
                     // Get Content-Language out of the trailer, if it is there
                     String contentLanguagesString;
-                    found = httpTrailer.lookupHeader(headers,
+                    found = httpTrailer.lookupHeader(trailers,
                         headerNameContentLanguage,
                         contentLanguagesString,
                         true);
@@ -1877,9 +1885,12 @@ void HTTPConnection::_handleReadEventFailure(
             delimiterFound + httpDetailDelimiter.size());
     }
 
-    PEG_TRACE_STRING(TRC_HTTP, Tracer::LEVEL2,
-        httpStatus + httpDetailDelimiter + httpDetail +
-            httpDetailDelimiter + cimError);
+    PEG_TRACE((TRC_HTTP, Tracer::LEVEL2,"%s%s%s%s%s",
+        (const char*)httpStatus.getCString(),
+        (const char*)httpDetailDelimiter.getCString(),
+        (const char*)httpDetail.getCString(),
+        (const char*)httpDetailDelimiter.getCString(),
+        (const char*)cimError.getCString()));
 
     Buffer message;
     message = XmlWriter::formatHttpErrorRspMessage(httpStatus, cimError,
@@ -1925,7 +1936,7 @@ void HTTPConnection::_handleReadEvent()
 
         if (socketAcceptStatus < 0)
         {
-            PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
+            PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL1,
                 "HTTPConnection: SSL_accept() failed");
             _closeConnection();
             PEG_METHOD_EXIT();
@@ -1934,14 +1945,14 @@ void HTTPConnection::_handleReadEvent()
         else if (socketAcceptStatus == 0)
         {
             // Not enough data yet to complete the SSL handshake
-            PEG_TRACE_CSTRING(TRC_HTTP, Tracer::LEVEL2,
+            PEG_TRACE_CSTRING(TRC_HTTP, Tracer::LEVEL4,
                 "HTTPConnection: SSL_accept() pending");
             PEG_METHOD_EXIT();
             return;
         }
         else
         {
-#ifndef PEGASUS_PLATFORM_ZOS_ZSERIES_IBM
+#ifndef PEGASUS_OS_ZOS
         // Add SSL verification information to the authentication information
             if (_socket->isSecure())
             {
@@ -1994,13 +2005,13 @@ void HTTPConnection::_handleReadEvent()
             {
                 _clearIncoming();
 
-                PEG_TRACE((TRC_HTTP, Tracer::LEVEL4,
+                PEG_TRACE((TRC_HTTP, Tracer::LEVEL2,
                       "This Request has non-valid CIM-HTTP Method: "
                       "%02X %02X %02X %02X %02X %02X",
                       buffer[0],buffer[1],buffer[2],
                       buffer[3],buffer[4],buffer[5]));
 
-                // Try to send message to client. 
+                // Try to send message to client.
                 // This function also closes the connection.
                 _handleReadEventFailure(HTTP_STATUS_NOTIMPLEMENTED);
 
@@ -2132,9 +2143,9 @@ void HTTPConnection::_handleReadEvent()
         if (_isClient() == false)
         {
             PEG_TRACE((
-                TRC_XML_IO, 
-                Tracer::LEVEL2,
-                "<!-- Request: queue id: %u -->\n%s", 
+                TRC_XML_IO,
+                Tracer::LEVEL4,
+                "<!-- Request: queue id: %u -->\n%s",
                 getQueueId(),
                 Tracer::getHTTPRequestMessage(
                     _incomingBuffer).get()));
@@ -2151,9 +2162,9 @@ void HTTPConnection::_handleReadEvent()
         //
         if (_isClient() == false)
         {
-            PEG_TRACE((TRC_HTTP, Tracer::LEVEL2,
-                "Now setting state to %d", _MonitorEntry::BUSY));
-            _monitor->setState (_entry_index, _MonitorEntry::BUSY);
+            PEG_TRACE((TRC_HTTP, Tracer::LEVEL4,
+                "Now setting state to %d", MonitorEntry::STATUS_BUSY));
+            _monitor->setState(_entry_index, MonitorEntry::STATUS_BUSY);
             _monitor->tickle();
         }
 
@@ -2166,7 +2177,24 @@ void HTTPConnection::_handleReadEvent()
             String httpStatus =
                 HTTP_STATUS_BADREQUEST + httpDetailDelimiter + e.getMessage();
             _handleReadEventFailure(httpStatus);
-        }   
+        }
+        catch (const exception& e)
+        {
+            String httpStatus =
+                HTTP_STATUS_BADREQUEST + httpDetailDelimiter + e.what();
+            _handleReadEventFailure(httpStatus);
+        }
+        catch (...)
+        {
+            MessageLoaderParms
+                mlParms("Common.HTTPConnection.UNKNOWN_EXCEPTION",
+                        "Unknown exception caught while parsing HTTP "
+                        "message.");
+            String mlString(MessageLoader::getMessage(mlParms));
+            String httpStatus =
+                HTTP_STATUS_BADREQUEST + httpDetailDelimiter + mlString;
+            _handleReadEventFailure(httpStatus);
+        }
 
         _clearIncoming();
     }
@@ -2205,8 +2233,8 @@ Boolean HTTPConnection::run(Uint32 milliseconds)
             catch (...)
             {
                 PEG_TRACE_CSTRING(
-                    TRC_DISCARDED_DATA, 
-                    Tracer::LEVEL2,
+                    TRC_DISCARDED_DATA,
+                    Tracer::LEVEL1,
                     "HTTPConnection::run handleEnqueue(msg) failure");
                 return true;
             }
