@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -38,43 +36,21 @@
 #include <Pegasus/Common/Exception.h>
 #include <Pegasus/Common/Config.h>
 #include <Pegasus/Common/MessageQueue.h>
-#include <Pegasus/Common/Pair.h>
 #include <Pegasus/Common/String.h>
 #include <Pegasus/Common/Message.h>
 #include <Pegasus/Common/ArrayInternal.h>
-#include <Pegasus/Common/Monitor.h>
 #include <Pegasus/Common/AuthenticationInfo.h>
 #include <Pegasus/Common/TLS.h>
-#include <Pegasus/Common/HTTPAcceptor.h>
 #include <Pegasus/Common/Linkage.h>
 #include <Pegasus/Common/SharedPtr.h>
 #include <Pegasus/Common/ContentLanguageList.h>
 #include <Pegasus/Common/Buffer.h>
+#include <Pegasus/Common/PegasusAssert.h>
 
 PEGASUS_NAMESPACE_BEGIN
 
-class HTTPConnector;
-
-class MessageQueueService;
-
-struct HTTPConnectionRep;
-
-/** This message is sent from a connection to its owner (so that the
-    owner can do any necessary cleanup).
-*/
-class CloseConnectionMessage : public Message
-{
-public:
-
-    CloseConnectionMessage(SocketHandle socket_)
-        : Message(CLOSE_CONNECTION_MESSAGE), socket(socket_) { }
-
-    SocketHandle socket;
-};
-
-/** This class represents an HTTP listener.
-*/
 class Monitor;
+class HTTPAcceptor;
 
 class PEGASUS_COMMON_LINKAGE HTTPConnection : public MessageQueue
 {
@@ -86,7 +62,7 @@ public:
         Monitor* monitor,
         SharedPtr<MP_Socket>& socket,
         const String& ipAddress,
-        MessageQueue * ownerMessageQueue,
+        HTTPAcceptor * owningAcceptor,
         MessageQueue * outputMessageQueue);
 
     /** Destructor. */
@@ -112,15 +88,18 @@ public:
 
     Boolean run(Uint32 milliseconds);
 
-    MessageQueue& get_owner()
+    HTTPAcceptor& getOwningAcceptor()
     {
-        return *_ownerMessageQueue;
+        PEGASUS_ASSERT(_owningAcceptor);
+        return *_owningAcceptor;
     }
 
     // was the request for chunking ?
     Boolean isChunkRequested();
 
     void setSocketWriteTimeout(Uint32 socketWriteTimeout);
+    static void setIdleConnectionTimeout(Uint32 idleConnectionTimeout);
+    static Uint32 getIdleConnectionTimeout();
 
     Boolean closeConnectionOnTimeout(struct timeval* timeNow);
 
@@ -166,7 +145,7 @@ private:
 
     SharedPtr<MP_Socket> _socket;
     String _ipAddress;
-    MessageQueue* _ownerMessageQueue;
+    HTTPAcceptor* _owningAcceptor;
     MessageQueue* _outputMessageQueue;
 
     Sint32 _contentOffset;
@@ -179,7 +158,7 @@ private:
     Uint32 _connectionRequestCount;
 
     /**
-        The _responsePending flag indicates whether a request has been
+        The _responsePending flag indicates whether the a request has been
         received on the connection and is awaiting a response.  It is set to
         true when a request is received on the connection and set to false
         when a response is sent.  The connection object must not be destructed
@@ -204,7 +183,7 @@ private:
     Boolean _acceptPending;
 
     // The _firstRead flag is set to false if the first bytes of a
-    // request was read and validated that it is a supported 
+    // request was read and validated that it is a supported
     // HTTP method "POST" or "M-POST".
     Boolean _firstRead;
 
@@ -237,7 +216,10 @@ private:
 
     // Idle connection timeout in seconds specified by Config property
     // idleConnectionTimeout.
-    Uint32 _idleConnectionTimeoutSeconds;
+    static Uint32 _idleConnectionTimeoutSeconds;
+#ifndef PEGASUS_INTEGERS_BOUNDARY_ALIGNED
+    static Mutex _idleConnectionTimeoutSecondsMutex;
+#endif
 
     friend class Monitor;
     friend class HTTPAcceptor;
