@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -35,13 +33,14 @@
 #include <iostream>
 #include <cstring>
 #include "HTTPMessage.h"
+#include "System.h"
 #include "ArrayIterator.h"
 
 PEGASUS_USING_STD;
 
 PEGASUS_NAMESPACE_BEGIN
 
-static const String _HTTP_HEADER_CONTENT_TYPE = "content-type";
+static const char* _HTTP_HEADER_CONTENT_TYPE = "content-type";
 
 //------------------------------------------------------------------------------
 //
@@ -67,19 +66,33 @@ static const String _HTTP_HEADER_CONTENT_TYPE = "content-type";
 
 char* HTTPMessage::findSeparator(const char* data, Uint32 size)
 {
-    const char* p = data;
-    const char* end = p + size;
-
-    while (p != end)
+    // [^\0\r\n]
+    static const unsigned char _skip[256] =
     {
-        if (*p == '\r')
-        {
-            size_t n = end - p;
+        0,1,1,1,1,1,1,1,1,1,0,1,1,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,
+        1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,
+        1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,
+        1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,
+        1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,
+        1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,
+        1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,
+        1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,
+    };
 
-            if (n >= 2 && p[1] == '\n')
-                return (char*)p;
-        }
-        else if (*p == '\n')
+    // Note that data is null-terminated.
+    const unsigned char* p = (const unsigned char*)data;
+
+    for (;;)
+    {
+        // Search for a '\0', '\r', or '\n'.
+        while (_skip[*p])
+            p++;
+
+        if (!p[0])
+            break;
+        if (p[0] == '\r' && p[1] == '\n')
+            return (char*)p;
+        if (p[0] == '\n')
             return (char*)p;
 
         p++;
@@ -204,8 +217,6 @@ void HTTPMessage::parse(
 
                 end++;
 
-                String name(line, (Uint32)(end - line));
-
                 // Get the value part:
 
                 char* start;
@@ -213,7 +224,9 @@ void HTTPMessage::parse(
                 for (start = colon + 1; start < sep && isspace(*start); start++)
                     ;
 
-                String value(start, (Uint32)(sep - start));
+                HTTPHeader header(
+                    Buffer(line, (Uint32)(end - line), 20),
+                    Buffer(start, (Uint32)(sep - start), 50));
 
                 // From the HTTP/1.1 specification (RFC 2616) section 4.2
                 // Message Headers:
@@ -239,7 +252,9 @@ void HTTPMessage::parse(
                 Uint32 headerIndex = 0;
                 for (; headerIndex < headers.size(); headerIndex++)
                 {
-                    if (headers[headerIndex].first == name)
+                    if (System::strcasecmp(
+                            headers[headerIndex].first.getData(),
+                            header.first.getData()) == 0)
                     {
                         break;
                     }
@@ -247,19 +262,13 @@ void HTTPMessage::parse(
 
                 if (headerIndex == headers.size())
                 {
-                    headers.append(HTTPHeader(name, value));
-                    PEG_LOGGER_TRACE((
-                        Logger::STANDARD_LOG, System::CIMSERVER, 0,
-                        "HTTP header name: $0,  HTTP header value: $1",
-                        name, value));
+                    headers.append(header);
                 }
                 else
                 {
-                    headers[headerIndex].second.append(", ").append(value);
-                    PEG_LOGGER_TRACE((
-                        Logger::STANDARD_LOG, System::CIMSERVER, 0,
-                        "HTTP header name: $0,  Updated HTTP header value: $1",
-                        name, headers[headerIndex].second));
+                    headers[headerIndex].second.append(", ", 2);
+                    headers[headerIndex].second.append(
+                        header.second.getData(), header.second.size());
                 }
             }
         }
@@ -292,11 +301,13 @@ void HTTPMessage::printAll(ostream& os) const
 
     for (Uint32 i = 0; i < headers.size(); i++)
     {
-        cout << headers[i].first << ": " << headers[i].second << endl;
+        cout << headers[i].first.getData() << ": " <<
+            headers[i].second.getData() << endl;
 
-        if (String::equalNoCase(headers[i].first, _HTTP_HEADER_CONTENT_TYPE))
+        if (System::strcasecmp(
+                headers[i].first.getData(), _HTTP_HEADER_CONTENT_TYPE) == 0)
         {
-            if (headers[i].second.find("image/") == 0)
+            if (strncmp(headers[i].second.getData(), "image/", 6) == 0)
                 image = true;
         }
     }
@@ -339,7 +350,7 @@ void HTTPMessage::printAll(ostream& os) const
 
 void HTTPMessage::lookupHeaderPrefix(
     Array<HTTPHeader>& headers_,
-    const String& fieldName,
+    const char* fieldName,
     String& prefix)
 {
     ArrayIterator<HTTPHeader> headers(headers_);
@@ -349,51 +360,52 @@ void HTTPMessage::lookupHeaderPrefix(
 
     for (Uint32 i = 0, n = headers.size(); i < n; i++)
     {
-        const String &h = headers[i].first;
+        const char* h = headers[i].first.getData();
 
-                if ((h.size() >= 3) &&
-                    (h[0] >= '0') && (h[0] <= '9') &&
-                    (h[1] >= '0') && (h[1] <= '9') &&
-                    (h[2] == Char16('-')))
+        if ((headers[i].first.size() >= 3) &&
+            (h[0] >= '0') && (h[0] <= '9') &&
+            (h[1] >= '0') && (h[1] <= '9') &&
+            (h[2] == '-'))
         {
-            String fieldNameCurrent = h.subString(3);
+            const char* fieldNameCurrent = h + 3;
 
             // ONLY fields starting with keyword can have prefixed according
             // to spec
-            if (String::equalNoCase(fieldNameCurrent, keyword) == false)
+            if (!String::equalNoCase(String(fieldNameCurrent, 3), keyword))
                 continue;
 
-            prefix = h.subString(0,3);
+            prefix = String(h, 3);
 
             // no field name given, just return the first prefix encountered
-            if (fieldName.size() == 0)
+            if (!fieldName)
                 break;
 
-            if (String::equalNoCase(fieldNameCurrent, fieldName) == false)
+            if (System::strcasecmp(fieldNameCurrent, fieldName) != 0)
                 prefix.clear();
             else break;
         }
     }
 }
 
-Boolean HTTPMessage::lookupHeader(
+Boolean HTTPMessage::_lookupHeaderIndex(
     Array<HTTPHeader>& headers_,
-    const String& fieldName,
-    String& fieldValue,
+    const char* fieldName,
+    Uint32& headerIndex,
     Boolean allowNamespacePrefix)
 {
     ArrayIterator<HTTPHeader> headers(headers_);
 
     for (Uint32 i = 0, n = headers.size(); i < n; i++)
     {
-        if (String::equalNoCase(headers[i].first, fieldName) ||
+        if ((System::strcasecmp(headers[i].first.getData(), fieldName) == 0) ||
             (allowNamespacePrefix && (headers[i].first.size() >= 3) &&
              (headers[i].first[0] >= '0') && (headers[i].first[0] <= '9') &&
              (headers[i].first[1] >= '0') && (headers[i].first[1] <= '9') &&
-             (headers[i].first[2] == Char16('-')) &&
-             String::equalNoCase(headers[i].first.subString(3), fieldName)))
+             (headers[i].first[2] == '-') &&
+             (System::strcasecmp(
+                  headers[i].first.getData() + 3, fieldName) == 0)))
         {
-            fieldValue = headers[i].second;
+            headerIndex = i;
             return true;
         }
     }
@@ -402,6 +414,42 @@ Boolean HTTPMessage::lookupHeader(
     return false;
 }
 
+Boolean HTTPMessage::lookupHeader(
+    Array<HTTPHeader>& headers,
+    const char* fieldName,
+    String& fieldValue,
+    Boolean allowNamespacePrefix)
+{
+    Uint32 index = PEG_NOT_FOUND;
+
+    if (_lookupHeaderIndex(headers, fieldName, index, allowNamespacePrefix))
+    {
+        fieldValue = String(
+            headers[index].second.getData(),
+            headers[index].second.size());
+        return true;
+    }
+
+    return false;
+}
+
+Boolean HTTPMessage::lookupHeader(
+    Array<HTTPHeader>& headers,
+    const char* fieldName,
+    const char*& fieldValue,
+    Boolean allowNamespacePrefix)
+{
+    Uint32 index = PEG_NOT_FOUND;
+
+    if (_lookupHeaderIndex(headers, fieldName, index, allowNamespacePrefix))
+    {
+        fieldValue = headers[index].second.getData();
+        return true;
+    }
+
+    return false;
+}
+
 Boolean HTTPMessage::parseRequestLine(
     const String& startLine,
     String& methodName,
@@ -475,48 +523,70 @@ Boolean HTTPMessage::parseStatusLine(
     return true;
 }
 
-Boolean HTTPMessage::isSupportedContentType(const String& cimContentType)
+Boolean HTTPMessage::parseContentTypeHeader(
+    const char* contentTypeHeader,
+    String& type,
+    String& charset)
 {
-    CString cstr = cimContentType.getCString();
-    const char *str = (const char*) cstr;
+    const char* str = contentTypeHeader;
+    skipHeaderWhitespace(str);
 
-    if (!expectHeaderToken(str, "application/xml"))
+    // Get the type string
+
+    const char* end = str;
+    while (*end && (*end != ' ') && (*end != '\t') && (*end != ';'))
     {
-        str = (const char*) cstr;
-        if (!expectHeaderToken(str, "text/xml"))
+        end++;
+    }
+
+    type.assign(str, end-str);
+    str = end;
+    skipHeaderWhitespace(str);
+
+    // Get the charset
+
+    if (*str == ';')
+    {
+        str++;
+        if (!expectHeaderToken(str, "charset") ||
+            !expectHeaderToken(str, "="))
         {
             return false;
         }
-    }
+        skipHeaderWhitespace(str);
 
-    // Check for missing charset.
-    skipHeaderWhitespace(str);
-    if (!*str)
-    {
-        return true; //We assume "utf-8".
-    }
-
-    if (!expectHeaderToken(str, ";") || !expectHeaderToken(str, "charset") ||
-        !expectHeaderToken (str, "="))
-    {
-        return false;
-    }
-
-    
-    // charset is present, should be "utf-8" or utf-8, case insensitive.
-    const char* strReset = str;
-    if (!expectHeaderToken(str, "\"utf-8\""))//check for string "utf-8"
-    {
-        str = strReset;
-        if(!expectHeaderToken(str, "utf-8"))//check for string utf-8
+        // The value may optionally be enclosed in quotes
+        if (*str == '"')
         {
-            return false;  //If charset is neither "utf-8" nor utf-8
+            str++;
+            end = strchr(str, '"');
+            if (!end)
+            {
+                return false;
+            }
+            charset.assign(str, end-str);
+            str = end + 1;
+        }
+        else
+        {
+            end = str;
+            while (*end && (*end != ' ') && (*end != '\t'))
+            {
+                end++;
+            }
+            charset.assign(str, end-str);
+            str = end;
         }
     }
+    else
+    {
+        // No charset specified; assume UTF-8.
+        charset = "utf-8";
+    }
 
-    // Check for any extra characters
     skipHeaderWhitespace(str);
 
+    // Check for unexpected characters at the end of the value
     return !*str;
 }
 
