@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -35,6 +33,7 @@
 #include <fstream>
 #include <cstring>
 #include <Pegasus/Common/Logger.h>
+#include <Pegasus/Common/Tracer.h>
 #include <Pegasus/Common/System.h>
 #include <Pegasus/Common/FileSystem.h>
 #include <Pegasus/Common/MessageLoader.h>
@@ -49,8 +48,6 @@ PEGASUS_USING_STD;
 
 PEGASUS_NAMESPACE_BEGIN
 
-// Maximum logfile size is defined as 32 MB = 32 * 1024 * 1024
-# define PEGASUS_MAX_LOGFILE_SIZE 0X2000000
 
 const Uint32 Logger::TRACE = (1 << 0);
 const Uint32 Logger::INFORMATION = (1 << 1);
@@ -74,6 +71,7 @@ const Uint32 Logger::_NUM_LOGLEVEL = 5;
 
 Uint32 Logger::_severityMask;
 
+
 ///////////////////////////////////////////////////////////////////////////////
 //
 // LoggerRep
@@ -127,8 +125,7 @@ static const char* fileNames[] =
     "PegasusTrace.log",
     "PegasusStandard.log",
     "PegasusAudit.log",
-    "PegasusError.log",
-    "PegasusDebug.log"
+    "PegasusError.log"
 };
 static const char* lockFileName = "PegasusLog.lock";
 
@@ -200,9 +197,6 @@ public:
 
         _logFileNames[Logger::ERROR_LOG] = _constructFileName(homeDirectory,
                                                fileNames[Logger::ERROR_LOG]);
-
-        _logFileNames[Logger::DEBUG_LOG] = _constructFileName(homeDirectory,
-                                               fileNames[Logger::DEBUG_LOG]);
     }
 
     ~LoggerRep()
@@ -232,7 +226,7 @@ public:
         if (logLevel & Logger::FATAL) tmp =       "FATAL   ";
 
 # ifndef PEGASUS_OS_VMS
-        // Acquire AutoMutex (for thread sync) 
+        // Acquire AutoMutex (for thread sync)
         // and AutoFileLock (for Process Sync).
         AutoMutex am(_mutex);
         AutoFileLock fileLock(_loggerLockFileName);
@@ -240,11 +234,11 @@ public:
         Uint32  logFileSize = 0;
 
         // Read logFileSize to check if the logfile needs to be pruned.
-        FileSystem::getFileSize(String(_logFileNames[logFileType]), 
+        FileSystem::getFileSize(String(_logFileNames[logFileType]),
                                        logFileSize);
 
-        // Check if the size of the logfile is exceeding 32MB.
-        if ( logFileSize > PEGASUS_MAX_LOGFILE_SIZE)
+        // Check if the size of the logfile is exceeding _maxLogFileSizeBytes.
+        if ( logFileSize > _maxLogFileSizeBytes)
         {
             // Prepare appropriate file name based on the logFileType.
             // Eg: if Logfile name is PegasusStandard.log, pruned logfile name
@@ -287,16 +281,23 @@ public:
         logFileStream.close();
     }
 
+    static void setMaxLogFileSize(Uint32 maxLogFileSizeBytes)
+    {
+        _maxLogFileSizeBytes = maxLogFileSizeBytes;
+    }
 private:
 
     CString _logFileNames[int(Logger::NUM_LOGS)];
 
+    static Uint32 _maxLogFileSizeBytes;
 # ifndef PEGASUS_OS_VMS
     CString _loggerLockFileName;
     Mutex _mutex;
 # endif
 };
 
+Uint32 LoggerRep::_maxLogFileSizeBytes;
+
 #endif    // !defined(PEGASUS_USE_SYSLOGS)
 
 
@@ -311,61 +312,31 @@ void Logger::_putInternal(
     const String& systemId,
     const Uint32 logComponent, // FUTURE: Support logComponent mask
     Uint32 logLevel,
-    const String& formatString,
-    const String& messageId,
-    const Formatter::Arg& arg0,
-    const Formatter::Arg& arg1,
-    const Formatter::Arg& arg2,
-    const Formatter::Arg& arg3,
-    const Formatter::Arg& arg4,
-    const Formatter::Arg& arg5,
-    const Formatter::Arg& arg6,
-    const Formatter::Arg& arg7,
-    const Formatter::Arg& arg8,
-    const Formatter::Arg& arg9)
+    const String& message)
 {
-    // Test for logLevel against severity mask to determine
-    // if we write this log.
-    if ((_severityMask & logLevel) != 0)
+    if (!_rep)
+       _rep = new LoggerRep(_homeDirectory);
+
+    // Call the actual logging routine is in LoggerRep.
+    _rep->log(logFileType, systemId, logLevel, message);
+
+    // PEP 315
+    // The trace can be routed into the log. The logged trace messages are
+    // logged with logFileType of Logger::TRACE_LOG.
+    // To avoid a cirular writing of these messages, log messages with
+    // logFileType of Logger::TRACE_LOG are never send to the trace.
+    if (Logger::TRACE_LOG != logFileType)
     {
-        if (!_rep)
-           _rep = new LoggerRep(_homeDirectory);
-
-
-        // l10n start
-        // The localized message to be sent to the system log.
-        String localizedMsg;
-
-        // If the caller specified a messageId, then load the localized
-        // message in the locale of the server process.
-        if (messageId != String::EMPTY)
+        // For all other logFileType's send the log messages to the trace.
+        // But do not write log messages to trace when the trace facility is
+        // set to log. This avoids double messages.
+        if (Tracer::TRACE_FACILITY_LOG != Tracer::getTraceFacility())
         {
-            // A message ID was specified.  Use the MessageLoader.
-            MessageLoaderParms msgParms(messageId, formatString);
-            msgParms.useProcessLocale = true;
-            msgParms.arg0 = arg0;
-            msgParms.arg1 = arg1;
-            msgParms.arg2 = arg2;
-            msgParms.arg3 = arg3;
-            msgParms.arg4 = arg4;
-            msgParms.arg5 = arg5;
-            msgParms.arg6 = arg6;
-            msgParms.arg7 = arg7;
-            msgParms.arg8 = arg8;
-            msgParms.arg9 = arg9;
-
-            localizedMsg = MessageLoader::getMessage(msgParms);
+            PEG_TRACE_CSTRING(
+                TRC_LOGMSG,
+                Tracer::LEVEL1,
+                (const char*) message.getCString());
         }
-        else
-        {  // No message ID.  Use the Pegasus formatter
-              localizedMsg = Formatter::format(formatString,
-                arg0, arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8, arg9);
-        }
-// l10n end
-
-
-       // Call the actual logging routine is in LoggerRep.
-       _rep->log(logFileType, systemId, logLevel, localizedMsg);
     }
 }
 
@@ -394,8 +365,8 @@ void Logger::put(
     if (wouldLog(logLevel))
     {
         Logger::_putInternal(logFileType, systemId, 0, logLevel,
-            formatString, String::EMPTY, arg0, arg1, arg2, arg3,
-            arg4, arg5, arg6, arg7, arg8, arg9);
+            Formatter::format(formatString, arg0, arg1, arg2, arg3,
+                arg4, arg5, arg6, arg7, arg8, arg9));
     }
 }
 
@@ -407,8 +378,7 @@ void Logger::put(
 {
     if (wouldLog(logLevel))
     {
-        Logger::_putInternal(logFileType, systemId, 0, logLevel,
-            formatString, String::EMPTY);
+        Logger::_putInternal(logFileType, systemId, 0, logLevel, formatString);
     }
 }
 
@@ -422,7 +392,7 @@ void Logger::put(
     if (wouldLog(logLevel))
     {
         Logger::_putInternal(logFileType, systemId, 0, logLevel,
-            formatString, String::EMPTY, arg0);
+            Formatter::format(formatString, arg0));
     }
 }
 
@@ -437,7 +407,7 @@ void Logger::put(
     if (wouldLog(logLevel))
     {
         Logger::_putInternal(logFileType, systemId, 0, logLevel,
-            formatString, String::EMPTY, arg0, arg1);
+            Formatter::format(formatString, arg0, arg1));
     }
 }
 
@@ -453,7 +423,7 @@ void Logger::put(
     if (wouldLog(logLevel))
     {
         Logger::_putInternal(logFileType, systemId, 0, logLevel,
-            formatString, String::EMPTY, arg0, arg1, arg2);
+            Formatter::format(formatString, arg0, arg1, arg2));
     }
 }
 
@@ -461,86 +431,14 @@ void Logger::put_l(
     LogFileType logFileType,
     const String& systemId,
     Uint32 logLevel,
-    const String& messageId,
-    const String& formatString,
-    const Formatter::Arg& arg0,
-    const Formatter::Arg& arg1,
-    const Formatter::Arg& arg2,
-    const Formatter::Arg& arg3,
-    const Formatter::Arg& arg4,
-    const Formatter::Arg& arg5,
-    const Formatter::Arg& arg6,
-    const Formatter::Arg& arg7,
-    const Formatter::Arg& arg8,
-    const Formatter::Arg& arg9)
+    const MessageLoaderParms& msgParms)
 {
     if (wouldLog(logLevel))
     {
+        MessageLoaderParms parms = msgParms;
+        parms.useProcessLocale = true;
         Logger::_putInternal(logFileType, systemId, 0, logLevel,
-            formatString, messageId, arg0, arg1, arg2, arg3, arg4, arg5,
-            arg6, arg7, arg8, arg9);
-    }
-}
-
-void Logger::put_l(
-     LogFileType logFileType,
-     const String& systemId,
-     Uint32 logLevel,
-     const String& messageId,
-     const String& formatString)
-{
-    if (wouldLog(logLevel))
-    {
-        Logger::_putInternal(logFileType, systemId, 0, logLevel,
-        formatString, messageId);
-    }
-}
-
-void Logger::put_l(
-     LogFileType logFileType,
-     const String& systemId,
-     Uint32 logLevel,
-     const String& messageId,
-     const String& formatString,
-     const Formatter::Arg& arg0)
-{
-    if (wouldLog(logLevel))
-    {
-        Logger::_putInternal(logFileType, systemId, 0, logLevel,
-            formatString, messageId, arg0);
-    }
-}
-
-void Logger::put_l(
-     LogFileType logFileType,
-     const String& systemId,
-     Uint32 logLevel,
-     const String& messageId,
-     const String& formatString,
-     const Formatter::Arg& arg0,
-     const Formatter::Arg& arg1)
-{
-    if (wouldLog(logLevel))
-    {
-        Logger::_putInternal(logFileType, systemId, 0, logLevel,
-            formatString, messageId, arg0, arg1);
-    }
-}
-
-void Logger::put_l(
-     LogFileType logFileType,
-     const String& systemId,
-     Uint32 logLevel,
-     const String& messageId,
-     const String& formatString,
-     const Formatter::Arg& arg0,
-     const Formatter::Arg& arg1,
-     const Formatter::Arg& arg2)
-{
-    if (wouldLog(logLevel))
-    {
-        Logger::_putInternal(logFileType, systemId, 0, logLevel,
-            formatString, messageId, arg0, arg1, arg2);
+            MessageLoader::getMessage(parms));
     }
 }
 
@@ -548,168 +446,12 @@ void Logger::trace(
     LogFileType logFileType,
     const String& systemId,
     const Uint32 logComponent,
-    const String& formatString,
-    const Formatter::Arg& arg0,
-    const Formatter::Arg& arg1,
-    const Formatter::Arg& arg2,
-    const Formatter::Arg& arg3,
-    const Formatter::Arg& arg4,
-    const Formatter::Arg& arg5,
-    const Formatter::Arg& arg6,
-    const Formatter::Arg& arg7,
-    const Formatter::Arg& arg8,
-    const Formatter::Arg& arg9)
+    const String& message)
 {
     if (wouldLog(Logger::TRACE))
     {
         Logger::_putInternal(logFileType, systemId, logComponent, Logger::TRACE,
-            formatString, String::EMPTY, arg0, arg1, arg2, arg3, arg4, arg5,
-            arg6, arg7, arg8, arg9);
-    }
-}
-
-void Logger::trace(
-    LogFileType logFileType,
-    const String& systemId,
-    const Uint32 logComponent,
-    const String& formatString)
-{
-    if (wouldLog(Logger::TRACE))
-    {
-        Logger::_putInternal(logFileType, systemId, logComponent, Logger::TRACE,
-            formatString, String::EMPTY);
-    }
-}
-
-void Logger::trace(
-    LogFileType logFileType,
-    const String& systemId,
-    const Uint32 logComponent,
-    const String& formatString,
-    const Formatter::Arg& arg0)
-{
-    if (wouldLog(Logger::TRACE))
-    {
-        Logger::_putInternal(logFileType, systemId, logComponent, Logger::TRACE,
-            formatString, String::EMPTY, arg0);
-    }
-}
-
-void Logger::trace(
-    LogFileType logFileType,
-    const String& systemId,
-    const Uint32 logComponent,
-    const String& formatString,
-    const Formatter::Arg& arg0,
-    const Formatter::Arg& arg1)
-{
-    if (wouldLog(Logger::TRACE))
-    {
-        Logger::_putInternal(logFileType, systemId, logComponent, Logger::TRACE,
-            formatString, String::EMPTY, arg0, arg1);
-    }
-}
-
-void Logger::trace(
-    LogFileType logFileType,
-    const String& systemId,
-    const Uint32 logComponent,
-    const String& formatString,
-    const Formatter::Arg& arg0,
-    const Formatter::Arg& arg1,
-    const Formatter::Arg& arg2)
-{
-    if (wouldLog(Logger::TRACE))
-    {
-        Logger::_putInternal(logFileType, systemId, logComponent, Logger::TRACE,
-            formatString, String::EMPTY, arg0, arg1, arg2);
-    }
-}
-
-void Logger::trace_l(
-    LogFileType logFileType,
-    const String& systemId,
-    const Uint32 logComponent,
-    const String& messageId,
-    const String& formatString,
-    const Formatter::Arg& arg0,
-    const Formatter::Arg& arg1,
-    const Formatter::Arg& arg2,
-    const Formatter::Arg& arg3,
-    const Formatter::Arg& arg4,
-    const Formatter::Arg& arg5,
-    const Formatter::Arg& arg6,
-    const Formatter::Arg& arg7,
-    const Formatter::Arg& arg8,
-    const Formatter::Arg& arg9)
-{
-    if (wouldLog(Logger::TRACE))
-    {
-        Logger::_putInternal(logFileType, systemId, logComponent, Logger::TRACE,
-            formatString, messageId, arg0, arg1, arg2, arg3, arg4, arg5, arg6,
-            arg7, arg8, arg9);
-    }
-}
-
-void Logger::trace_l(
-    LogFileType logFileType,
-    const String& systemId,
-    const Uint32 logComponent,
-    const String& messageId,
-    const String& formatString)
-{
-    if (wouldLog(Logger::TRACE))
-    {
-        Logger::_putInternal(logFileType, systemId, logComponent, Logger::TRACE,
-            formatString, messageId);
-    }
-}
-
-void Logger::trace_l(
-    LogFileType logFileType,
-    const String& systemId,
-    const Uint32 logComponent,
-    const String& messageId,
-    const String& formatString,
-    const Formatter::Arg& arg0)
-{
-    if (wouldLog(Logger::TRACE))
-    {
-        Logger::_putInternal(logFileType, systemId, logComponent, Logger::TRACE,
-            formatString, messageId, arg0);
-    }
-}
-
-void Logger::trace_l(
-    LogFileType logFileType,
-    const String& systemId,
-    const Uint32 logComponent,
-    const String& messageId,
-    const String& formatString,
-    const Formatter::Arg& arg0,
-    const Formatter::Arg& arg1)
-{
-    if (wouldLog(Logger::TRACE))
-    {
-        Logger::_putInternal(logFileType, systemId, logComponent, Logger::TRACE,
-            formatString, messageId, arg0, arg1);
-    }
-}
-
-void Logger::trace_l(
-    LogFileType logFileType,
-    const String& systemId,
-    const Uint32 logComponent,
-    const String& messageId,
-    const String& formatString,
-    const Formatter::Arg& arg0,
-    const Formatter::Arg& arg1,
-    const Formatter::Arg& arg2)
-{
-    if (wouldLog(Logger::TRACE))
-    {
-        Logger::_putInternal(logFileType, systemId, logComponent, Logger::TRACE,
-            formatString, messageId, arg0, arg1, arg2);
+            message);
     }
 }
 
@@ -820,4 +562,11 @@ Boolean Logger::isValidlogLevel(const String logLevel)
     return validlogLevel;
 }
 
+#if !defined (PEGASUS_USE_SYSLOGS)
+void Logger::setMaxLogFileSize(Uint32 maxLogFileSizeBytes)
+{
+     LoggerRep::setMaxLogFileSize(maxLogFileSizeBytes);
+}
+#endif
+
 PEGASUS_NAMESPACE_END
