@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -39,6 +37,7 @@
 #include "Socket.h"
 #include <Pegasus/Common/Tracer.h>
 #include <Pegasus/Common/HTTPConnection.h>
+#include <Pegasus/Common/HTTPAcceptor.h>
 #include <Pegasus/Common/MessageQueueService.h>
 #include <Pegasus/Common/Exception.h>
 #include "ArrayIterator.h"
@@ -300,8 +299,6 @@ void Tickler::_initialize()
     //
 
     Socket::close(_listenSocket);
-    _listenSocket = PEGASUS_INVALID_SOCKET;
-
     Socket::disableBlocking(_serverSocket);
     Socket::disableBlocking(_clientSocket);
 }
@@ -314,25 +311,13 @@ void Tickler::_uninitialize()
 
     try
     {
-        if (_serverSocket != PEGASUS_INVALID_SOCKET)
-        {
-            Socket::close(_serverSocket);
-            _serverSocket = PEGASUS_INVALID_SOCKET;
-        }
-        if (_clientSocket != PEGASUS_INVALID_SOCKET)
-        {
-            Socket::close(_clientSocket);
-            _clientSocket = PEGASUS_INVALID_SOCKET;
-        }
-        if (_listenSocket != PEGASUS_INVALID_SOCKET)
-        {
-            Socket::close(_listenSocket);
-            _listenSocket = PEGASUS_INVALID_SOCKET;
-        }
+        Socket::close(_serverSocket);
+        Socket::close(_clientSocket);
+        Socket::close(_listenSocket);
     }
     catch (...)
     {
-        PEG_TRACE_CSTRING(TRC_HTTP, Tracer::LEVEL4,
+        PEG_TRACE_CSTRING(TRC_HTTP, Tracer::LEVEL2,
             "Failed to close tickle sockets");
     }
     Socket::uninitializeInterface();
@@ -356,15 +341,16 @@ Monitor::Monitor()
 
     // Create a MonitorEntry for the Tickler and set its state to IDLE so the
     // Monitor will watch for its events.
-    _MonitorEntry entry(_tickler.getReadHandle(), 1, INTERNAL);
-    entry._status = _MonitorEntry::IDLE;
-    _entries.append(entry);
+    _entries.append(MonitorEntry(
+        _tickler.getReadHandle(),
+        1,
+        MonitorEntry::STATUS_IDLE,
+        MonitorEntry::TYPE_TICKLER));
 
     // Start the count at 1 because _entries[0] is the Tickler
     for (int i = 1; i < numberOfMonitorEntriesToAllocate; i++)
     {
-       _MonitorEntry entry(0, 0, 0);
-       _entries.append(entry);
+        _entries.append(MonitorEntry());
     }
 }
 
@@ -381,11 +367,11 @@ void Monitor::tickle()
 
 void Monitor::setState(
     Uint32 index,
-    _MonitorEntry::entry_status status)
+    MonitorEntry::Status status)
 {
-    AutoMutex autoEntryMutex(_entry_mut);
+    AutoMutex autoEntryMutex(_entriesMutex);
     // Set the state to requested state
-    _entries[index]._status = status;
+    _entries[index].status = status;
 }
 
 void Monitor::run(Uint32 milliseconds)
@@ -395,43 +381,44 @@ void Monitor::run(Uint32 milliseconds)
     fd_set fdread;
     FD_ZERO(&fdread);
 
-    AutoMutex autoEntryMutex(_entry_mut);
+    AutoMutex autoEntryMutex(_entriesMutex);
 
-    ArrayIterator<_MonitorEntry> entries(_entries);
+    ArrayIterator<MonitorEntry> entries(_entries);
 
     // Check the stopConnections flag.  If set, clear the Acceptor monitor
     // entries
     if (_stopConnections.get() == 1)
     {
-        for ( int indx = 0; indx < (int)entries.size(); indx++)
+        for (Uint32 indx = 0; indx < entries.size(); indx++)
         {
-            if (entries[indx]._type == Monitor::ACCEPTOR)
+            if (entries[indx].type == MonitorEntry::TYPE_ACCEPTOR)
             {
-                if ( entries[indx]._status.get() != _MonitorEntry::EMPTY)
+                if (entries[indx].status != MonitorEntry::STATUS_EMPTY)
                 {
-                   if ( entries[indx]._status.get() == _MonitorEntry::IDLE ||
-                        entries[indx]._status.get() == _MonitorEntry::DYING )
-                   {
-                       // remove the entry
-                       entries[indx]._status = _MonitorEntry::EMPTY;
-                   }
-                   else
-                   {
-                       // set status to DYING
-                      entries[indx]._status = _MonitorEntry::DYING;
-                   }
-               }
-           }
+                    if (entries[indx].status == MonitorEntry::STATUS_IDLE ||
+                        entries[indx].status == MonitorEntry::STATUS_DYING)
+                    {
+                        // remove the entry
+                        entries[indx].status = MonitorEntry::STATUS_EMPTY;
+                    }
+                    else
+                    {
+                        // set status to DYING
+                        entries[indx].status = MonitorEntry::STATUS_DYING;
+                    }
+                }
+            }
         }
         _stopConnections = 0;
         _stopConnectionsSem.signal();
     }
 
-    for (int indx = 0; indx < (int)entries.size(); indx++)
+    for (Uint32 indx = 0; indx < entries.size(); indx++)
     {
-        const _MonitorEntry &entry = entries[indx];
-        if ((entry._status.get() == _MonitorEntry::DYING) &&
-            (entry._type == Monitor::CONNECTION))
+        const MonitorEntry& entry = entries[indx];
+
+        if ((entry.status == MonitorEntry::STATUS_DYING) &&
+            (entry.type == MonitorEntry::TYPE_CONNECTION))
         {
             MessageQueue *q = MessageQueue::lookup(entry.queueId);
             PEGASUS_ASSERT(q != 0);
@@ -456,7 +443,7 @@ void Monitor::run(Uint32 milliseconds)
                 continue;
             }
             h._connectionClosePending = false;
-            MessageQueue &o = h.get_owner();
+            HTTPAcceptor &o = h.getOwningAcceptor();
             Message* message= new CloseConnectionMessage(entry.socket);
             message->dest = o.getQueueId();
 
@@ -472,9 +459,9 @@ void Monitor::run(Uint32 milliseconds)
             // unlocked will not result in an ArrayIndexOutOfBounds
             // exception.
 
-            _entry_mut.unlock();
+            _entriesMutex.unlock();
             o.enqueue(message);
-            _entry_mut.lock();
+            _entriesMutex.lock();
 
             // After enqueue a message and the autoEntryMutex has been
             // released and locked again, the array of _entries can be
@@ -493,16 +480,16 @@ void Monitor::run(Uint32 milliseconds)
         because we have to traverse the entire array.
     */
     SocketHandle maxSocketCurrentPass = 0;
-    for (int indx = 0; indx < (int)entries.size(); indx++)
+    for (Uint32 indx = 0; indx < entries.size(); indx++)
     {
-       if (maxSocketCurrentPass < entries[indx].socket)
-           maxSocketCurrentPass = entries[indx].socket;
+        if (maxSocketCurrentPass < entries[indx].socket)
+            maxSocketCurrentPass = entries[indx].socket;
 
-       if (entries[indx]._status.get() == _MonitorEntry::IDLE)
-       {
-           _idleEntries++;
-           FD_SET(entries[indx].socket, &fdread);
-       }
+        if (entries[indx].status == MonitorEntry::STATUS_IDLE)
+        {
+            _idleEntries++;
+            FD_SET(entries[indx].socket, &fdread);
+        }
     }
 
     /*
@@ -511,7 +498,7 @@ void Monitor::run(Uint32 milliseconds)
     */
     maxSocketCurrentPass++;
 
-    _entry_mut.unlock();
+    _entriesMutex.unlock();
 
     //
     // The first argument to select() is ignored on Windows and it is not
@@ -523,7 +510,9 @@ void Monitor::run(Uint32 milliseconds)
 #else
     int events = select(maxSocketCurrentPass, &fdread, NULL, NULL, &tv);
 #endif
-    _entry_mut.lock();
+    int selectErrno = getSocketError();
+
+    _entriesMutex.lock();
 
     struct timeval timeNow;
     Time::gettimeofday(&timeNow);
@@ -535,14 +524,14 @@ void Monitor::run(Uint32 milliseconds)
 
     if (events == PEGASUS_SOCKET_ERROR)
     {
-        PEG_TRACE((TRC_HTTP, Tracer::LEVEL4,
-            "Monitor::run - errorno = %d has occurred on select.", errno));
+        PEG_TRACE((TRC_HTTP, Tracer::LEVEL1,
+            "Monitor::run - select() returned error %d.", selectErrno));
         // The EBADF error indicates that one or more or the file
         // descriptions was not valid. This could indicate that
         // the entries structure has been corrupted or that
         // we have a synchronization error.
 
-        PEGASUS_ASSERT(errno != EBADF);
+        PEGASUS_ASSERT(selectErrno != EBADF);
     }
     else if (events)
     {
@@ -550,27 +539,27 @@ void Monitor::run(Uint32 milliseconds)
             "Monitor::run select event received events = %d, monitoring %d "
                 "idle entries",
             events, _idleEntries));
-        for (int indx = 0; indx < (int)entries.size(); indx++)
+        for (Uint32 indx = 0; indx < entries.size(); indx++)
         {
             // The Monitor should only look at entries in the table that are
             // IDLE (i.e., owned by the Monitor).
-            if ((entries[indx]._status.get() == _MonitorEntry::IDLE) &&
+            if ((entries[indx].status == MonitorEntry::STATUS_IDLE) &&
                 (FD_ISSET(entries[indx].socket, &fdread)))
             {
-                MessageQueue *q = MessageQueue::lookup(entries[indx].queueId);
+                MessageQueue* q = MessageQueue::lookup(entries[indx].queueId);
+                PEGASUS_ASSERT(q != 0);
                 PEG_TRACE((TRC_HTTP, Tracer::LEVEL4,
-                    "Monitor::run indx = %d, queueId =  %d, q = %p",
+                    "Monitor::run indx = %d, queueId = %d, q = %p",
                     indx, entries[indx].queueId, q));
-                PEGASUS_ASSERT(q !=0);
 
                 try
                 {
-                    if (entries[indx]._type == Monitor::CONNECTION)
+                    if (entries[indx].type == MonitorEntry::TYPE_CONNECTION)
                     {
                         PEG_TRACE((TRC_HTTP, Tracer::LEVEL4,
-                            "entries[indx].type for indx = %d is "
-                                "Monitor::CONNECTION",
+                            "entries[%d].type is TYPE_CONNECTION",
                             indx));
+
                         HTTPConnection *dst =
                             reinterpret_cast<HTTPConnection *>(q);
                         dst->_entry_index = indx;
@@ -587,30 +576,26 @@ void Monitor::run(Uint32 milliseconds)
                         // we received data (avoiding extra queue lookup below).
                         if (!dst->closeConnectionOnTimeout(&timeNow))
                         {
+                            PEG_TRACE((TRC_HTTP, Tracer::LEVEL4,
+                                "Entering HTTPConnection::run() for "
+                                    "indx = %d, queueId = %d, q = %p",
+                                indx, entries[indx].queueId, q));
 
-                        PEG_TRACE((TRC_HTTP, Tracer::LEVEL4,
-                            "Monitor::_dispatch: entering run() for "
-                                "indx = %d, queueId = %d, q = %p",
-                            dst->_entry_index,
-                                dst->_monitor->
-                                    _entries[dst->_entry_index].queueId,
-                            dst));
-
-                        try
-                        {
-                            dst->run(1);
-                        }
-                        catch (...)
-                        {
+                            try
+                            {
+                                dst->run(1);
+                            }
+                            catch (...)
+                            {
+                                PEG_TRACE_CSTRING(TRC_HTTP, Tracer::LEVEL1,
+                                    "Caught exception from "
+                                    "HTTPConnection::run()");
+                            }
                             PEG_TRACE_CSTRING(TRC_HTTP, Tracer::LEVEL4,
-                                "Monitor::_dispatch: exception received");
-                        }
-                        PEG_TRACE((TRC_HTTP, Tracer::LEVEL4,
-                            "Monitor::_dispatch: exited run() for index %d",
-                            dst->_entry_index));
+                                "Exited HTTPConnection::run()");
                         }
                     }
-                    else if (entries[indx]._type == Monitor::INTERNAL)
+                    else if (entries[indx].type == MonitorEntry::TYPE_TICKLER)
                     {
                         _tickler.reset();
                     }
@@ -620,21 +605,19 @@ void Monitor::run(Uint32 milliseconds)
                             "Non-connection entry, indx = %d, has been "
                                 "received.",
                             indx));
-                        int events = 0;
-                        events |= SocketMessage::READ;
                         Message* msg = new SocketMessage(
-                            entries[indx].socket, events);
-                        entries[indx]._status = _MonitorEntry::BUSY;
-                        _entry_mut.unlock();
+                            entries[indx].socket, SocketMessage::READ);
+                        entries[indx].status = MonitorEntry::STATUS_BUSY;
+                        _entriesMutex.unlock();
                         q->enqueue(msg);
-                        _entry_mut.lock();
+                        _entriesMutex.lock();
 
                         // After enqueue a message and the autoEntryMutex has
                         // been released and locked again, the array of
-                        // entries can be changed. The ArrayIterator has be
-                        // reset with the original _entries
+                        // entries can be changed. The ArrayIterator has to be
+                        // reset with the latest _entries.
                         entries.reset(_entries);
-                        entries[indx]._status = _MonitorEntry::IDLE;
+                        entries[indx].status = MonitorEntry::STATUS_IDLE;
                     }
                 }
                 catch (...)
@@ -644,10 +627,12 @@ void Monitor::run(Uint32 milliseconds)
             // else check for accept pending (ie. SSL handshake pending) or
             // idle connection timeouts for sockets from which we did not
             // receive data.
-            else if ((entries[indx]._status.get() == _MonitorEntry::IDLE) &&
-                entries[indx]._type == Monitor::CONNECTION)
+            else if ((entries[indx].status == MonitorEntry::STATUS_IDLE) &&
+                entries[indx].type == MonitorEntry::TYPE_CONNECTION)
+
             {
-                MessageQueue *q = MessageQueue::lookup(entries[indx].queueId);
+                MessageQueue* q = MessageQueue::lookup(entries[indx].queueId);
+                PEGASUS_ASSERT(q != 0);
                 HTTPConnection *dst = reinterpret_cast<HTTPConnection *>(q);
                 dst->_entry_index = indx;
                 dst->closeConnectionOnTimeout(&timeNow);
@@ -658,12 +643,13 @@ void Monitor::run(Uint32 milliseconds)
     // to check if there are any pending SSL handshakes that have timed out.
     else
     {
-        for (int indx = 0; indx < (int)entries.size(); indx++)
+        for (Uint32 indx = 0; indx < entries.size(); indx++)
         {
-            if ((entries[indx]._status.get() == _MonitorEntry::IDLE) &&
-                entries[indx]._type == Monitor::CONNECTION)
+            if ((entries[indx].status == MonitorEntry::STATUS_IDLE) &&
+                entries[indx].type == MonitorEntry::TYPE_CONNECTION)
             {
-                MessageQueue *q = MessageQueue::lookup(entries[indx].queueId);
+                MessageQueue* q = MessageQueue::lookup(entries[indx].queueId);
+                PEGASUS_ASSERT(q != 0);
                 HTTPConnection *dst = reinterpret_cast<HTTPConnection *>(q);
                 dst->_entry_index = indx;
                 dst->closeConnectionOnTimeout(&timeNow);
@@ -695,37 +681,33 @@ int Monitor::solicitSocketMessages(
     SocketHandle socket,
     Uint32 events,
     Uint32 queueId,
-    int type)
+    Uint32 type)
 {
     PEG_METHOD_ENTER(TRC_HTTP, "Monitor::solicitSocketMessages");
-    AutoMutex autoMut(_entry_mut);
+    AutoMutex autoMut(_entriesMutex);
+
     // Check to see if we need to dynamically grow the _entries array
-    // We always want the _entries array to 2 bigger than the
+    // We always want the _entries array to be 2 bigger than the
     // current connections requested
     _solicitSocketCount++;  // bump the count
-    int size = (int)_entries.size();
-    if ((int)_solicitSocketCount >= (size-1))
+
+    for (Uint32 i = _entries.size(); i < _solicitSocketCount + 1; i++)
     {
-        for (int i = 0; i < ((int)_solicitSocketCount - (size-1)); i++)
-        {
-            _MonitorEntry entry(0, 0, 0);
-            _entries.append(entry);
-        }
+        _entries.append(MonitorEntry());
     }
 
-    int index;
-    for (index = 1; index < (int)_entries.size(); index++)
+    for (Uint32 index = 1; index < _entries.size(); index++)
     {
         try
         {
-            if (_entries[index]._status.get() == _MonitorEntry::EMPTY)
+            if (_entries[index].status == MonitorEntry::STATUS_EMPTY)
             {
                 _entries[index].socket = socket;
                 _entries[index].queueId  = queueId;
-                _entries[index]._type = type;
-                _entries[index]._status = _MonitorEntry::IDLE;
+                _entries[index].type = type;
+                _entries[index].status = MonitorEntry::STATUS_IDLE;
 
-                return index;
+                return (int)index;
             }
         }
         catch (...)
@@ -741,19 +723,17 @@ int Monitor::solicitSocketMessages(
 void Monitor::unsolicitSocketMessages(SocketHandle socket)
 {
     PEG_METHOD_ENTER(TRC_HTTP, "Monitor::unsolicitSocketMessages");
-    AutoMutex autoMut(_entry_mut);
+    AutoMutex autoMut(_entriesMutex);
 
     /*
         Start at index = 1 because _entries[0] is the tickle entry which
-        never needs to be EMPTY;
+        never needs to be reset to EMPTY;
     */
-    unsigned int index;
-    for (index = 1; index < _entries.size(); index++)
+    for (Uint32 index = 1; index < _entries.size(); index++)
     {
         if (_entries[index].socket == socket)
         {
-            _entries[index]._status = _MonitorEntry::EMPTY;
-            _entries[index].socket = PEGASUS_INVALID_SOCKET;
+            _entries[index].reset();
             _solicitSocketCount--;
             break;
         }
@@ -766,57 +746,15 @@ void Monitor::unsolicitSocketMessages(SocketHandle socket)
         first NON EMPTY.  This prevents the positions, of the NON EMPTY
         entries, from being changed.
     */
-    index = _entries.size() - 1;
-    while (_entries[index]._status.get() == _MonitorEntry::EMPTY)
+    for (Uint32 index = _entries.size() - 1;
+         (_entries[index].status == MonitorEntry::STATUS_EMPTY) &&
+             (index >= MAX_NUMBER_OF_MONITOR_ENTRIES);
+         index--)
     {
-        if (_entries.size() > MAX_NUMBER_OF_MONITOR_ENTRIES)
-                _entries.remove(index);
-        index--;
+        _entries.remove(index);
     }
+
     PEG_METHOD_EXIT();
 }
 
-// Note: this is no longer called with PEP 183.
-ThreadReturnType PEGASUS_THREAD_CDECL Monitor::_dispatch(void* parm)
-{
-    HTTPConnection *dst = reinterpret_cast<HTTPConnection *>(parm);
-    PEG_TRACE((TRC_HTTP, Tracer::LEVEL4,
-        "Monitor::_dispatch: entering run() for indx  = %d, queueId = %d, "
-            "q = %p",
-        dst->_entry_index,
-        dst->_monitor->_entries[dst->_entry_index].queueId,
-        dst));
-
-    try
-    {
-        dst->run(1);
-    }
-    catch (...)
-    {
-        PEG_TRACE_CSTRING(TRC_HTTP, Tracer::LEVEL4,
-            "Monitor::_dispatch: exception received");
-    }
-    PEG_TRACE((TRC_HTTP, Tracer::LEVEL4,
-        "Monitor::_dispatch: exited run() for index %d", dst->_entry_index));
-
-    PEGASUS_ASSERT(dst->_monitor->_entries[dst->_entry_index]._status.get() ==
-        _MonitorEntry::BUSY);
-
-    // Once the HTTPConnection thread has set the status value to either
-    // Monitor::DYING or Monitor::IDLE, it has returned control of the
-    // connection to the Monitor.  It is no longer permissible to access the
-    // connection or the entry in the _entries table.
-    if (dst->_connectionClosePending)
-    {
-        dst->_monitor->_entries[dst->_entry_index]._status =
-            _MonitorEntry::DYING;
-    }
-    else
-    {
-        dst->_monitor->_entries[dst->_entry_index]._status =
-            _MonitorEntry::IDLE;
-    }
-    return 0;
-}
-
 PEGASUS_NAMESPACE_END
