@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -35,6 +33,11 @@
 #include "Time.h"
 #include "PegasusAssert.h"
 #include "Once.h"
+#include "Exception.h"
+#include "System.h"
+
+#define MUTEX_LOCK_FAILED_KEY "Common.InternalException.MUTEX_LOCK_FAILED"
+#define MUTEX_LOCK_FAILED_MSG "Failed to acquire mutex lock: $0"
 
 PEGASUS_NAMESPACE_BEGIN
 
@@ -91,46 +94,62 @@ void Mutex::lock()
 {
     PEGASUS_DEBUG_ASSERT(_magic);
 
-    switch (pthread_mutex_lock(&_rep.mutex))
-    {
-        case 0:
-#if defined(PEGASUS_DEBUG)
-            _rep.count++;
-#endif
-            break;
+    int r = pthread_mutex_lock(&_rep.mutex);
 
-        default:
-            throw WaitFailed(Threads::self());
+    if (r == 0)
+    {
+#if defined(PEGASUS_DEBUG)
+        _rep.count++;
+#endif
+    }
+    else
+    {
+        if (r != -1)
+        {
+            // Special behavior for Single UNIX Specification, Version 3
+            errno = r;
+        }
+
+        throw Exception(MessageLoaderParms(
+            MUTEX_LOCK_FAILED_KEY,
+            MUTEX_LOCK_FAILED_MSG,
+            PEGASUS_SYSTEM_ERRORMSG_NLS));
     }
 }
 
-void Mutex::try_lock()
+Boolean Mutex::try_lock()
 {
     PEGASUS_DEBUG_ASSERT(_magic);
 
     int r = pthread_mutex_trylock(&_rep.mutex);
-    if (r == -1)
-        r=errno;
-    switch (r)
+
+    if (r == 0)
     {
-        case 0:
 #if defined(PEGASUS_DEBUG)
-            _rep.count++;
+        _rep.count++;
 #endif
-            break;
-
-        case EBUSY:
-            throw AlreadyLocked(Threads::self());
-
-        default:
-            throw WaitFailed(Threads::self());
+        return true;
     }
+
+    if (r != -1)
+    {
+        // Special behavior for Single UNIX Specification, Version 3
+        errno = r;
+    }
+
+    if (errno == EBUSY)
+    {
+        return false;
+    }
+
+    throw Exception(MessageLoaderParms(
+        MUTEX_LOCK_FAILED_KEY,
+        MUTEX_LOCK_FAILED_MSG,
+        PEGASUS_SYSTEM_ERRORMSG_NLS));
 }
 
-void Mutex::timed_lock(Uint32 milliseconds)
+Boolean Mutex::timed_lock(Uint32 milliseconds)
 {
-    PEGASUS_DEBUG_ASSERT(_magic);
-
     struct timeval now;
     struct timeval finish;
     struct timeval remaining;
@@ -144,34 +163,19 @@ void Mutex::timed_lock(Uint32 milliseconds)
         finish.tv_usec = usec % 1000000;
     }
 
-    for (;;)
+    while (!try_lock())
     {
-        int r=pthread_mutex_trylock(&_rep.mutex);
-        if (r == -1)
-            r = errno;
-        switch (r)
+        gettimeofday(&now, NULL);
+
+        if (Time::subtract(&remaining, &finish, &now))
         {
-            case 0:
-#if defined(PEGASUS_DEBUG)
-                _rep.count++;
-#endif
-                return;
-
-            case EBUSY:
-            {
-                gettimeofday(&now, NULL);
-
-                if (Time::subtract(&remaining, &finish, &now))
-                    throw TimeOut(Threads::self());
-
-                Threads::yield();
-                break;
-            }
-
-            default:
-                throw WaitFailed(Threads::self());
+            return false;
         }
+
+        Threads::yield();
     }
+
+    return true;
 }
 
 void Mutex::unlock()
@@ -183,12 +187,12 @@ void Mutex::unlock()
     _rep.count--;
 #endif
 
-    if (pthread_mutex_unlock(&_rep.mutex) != 0)
-        throw Permission(Threads::self());
+    int rc = pthread_mutex_unlock(&_rep.mutex);
+    // All documented error codes represent coding errors.
+    PEGASUS_ASSERT(rc == 0);
 }
 
-#if defined(PEGASUS_OS_LINUX) || \
-    (defined(PEGASUS_OS_ZOS) && !(__TARGET_LIB__ < 0x41090000))
+#if defined(PEGASUS_OS_LINUX)
 void Mutex::reinitialize()
 {
     pthread_mutex_init(&_rep.mutex, &_attr);
@@ -244,39 +248,58 @@ void Mutex::lock()
     DWORD rc = WaitForSingleObject(_rep.handle, INFINITE);
 
     if (rc == WAIT_FAILED)
-        throw WaitFailed(Threads::self());
+    {
+        throw Exception(MessageLoaderParms(
+            MUTEX_LOCK_FAILED_KEY,
+            MUTEX_LOCK_FAILED_MSG,
+            PEGASUS_SYSTEM_ERRORMSG_NLS));
+    }
 
     _rep.count++;
 }
 
-void Mutex::try_lock()
+Boolean Mutex::try_lock()
 {
     PEGASUS_DEBUG_ASSERT(_magic);
 
     DWORD rc = WaitForSingleObject(_rep.handle, 0);
 
     if (rc == WAIT_TIMEOUT)
-        throw AlreadyLocked(Threads::self());
+    {
+        return false;
+    }
 
     if (rc == WAIT_FAILED)
-        throw WaitFailed(Threads::self());
+    {
+        throw Exception(MessageLoaderParms(
+            MUTEX_LOCK_FAILED_KEY,
+            MUTEX_LOCK_FAILED_MSG,
+            PEGASUS_SYSTEM_ERRORMSG_NLS));
+    }
 
     _rep.count++;
+    return true;
 }
 
-void Mutex::timed_lock(Uint32 milliseconds)
+Boolean Mutex::timed_lock(Uint32 milliseconds)
 {
     PEGASUS_DEBUG_ASSERT(_magic);
 
     DWORD rc = WaitForSingleObject(_rep.handle, milliseconds);
 
     if (rc == WAIT_TIMEOUT)
-        throw TimeOut(Threads::self());
+        return false;
 
     if (rc == WAIT_FAILED)
-        throw WaitFailed(Threads::self());
+    {
+        throw Exception(MessageLoaderParms(
+            MUTEX_LOCK_FAILED_KEY,
+            MUTEX_LOCK_FAILED_MSG,
+            PEGASUS_SYSTEM_ERRORMSG_NLS));
+    }
 
     _rep.count++;
+    return true;
 }
 
 void Mutex::unlock()
