@@ -1,38 +1,37 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
 #include <Pegasus/Common/ObjectNormalizer.h>
 #include <Pegasus/Common/ArrayInternal.h>
+#include <Pegasus/Common/Constants.h>
 
 PEGASUS_NAMESPACE_BEGIN
 
@@ -43,6 +42,11 @@ void ObjectNormalizer::setEnableNormalization(Boolean value)
     _enableNormalization = value;
 }
 
+Boolean ObjectNormalizer::getEnableNormalization()
+{
+    return _enableNormalization;
+}
+
 CIMQualifier _processQualifier(
     CIMConstQualifier& referenceQualifier,
     CIMConstQualifier& cimQualifier)
@@ -110,22 +114,12 @@ CIMProperty ObjectNormalizer::processProperty(
     CIMType instPropType = instProperty.getType();
     if (referencePropType != instPropType)
     {
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
-        // CMPI Providers cannot return a CIMTYPE_INSTANCE, so if the
-        // referenceProperty type is CIMTYPE_INSTANCE and the instProperty
-        // type is CIMTYPE_OBJECT, ignore the mismatch. The Normalizer
-        // will correct it.
-        if (referencePropType != CIMTYPE_INSTANCE ||
-            instPropType != CIMTYPE_OBJECT)
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
-        {
-            MessageLoaderParms message(
-                "Common.ObjectNormalizer.INVALID_PROPERTY_TYPE",
-                "Invalid property type: $0",
-                instProperty.getName().getString());
+        MessageLoaderParms message(
+            "Common.ObjectNormalizer.INVALID_PROPERTY_TYPE",
+            "Invalid property type: $0",
+            instProperty.getName().getString());
 
-            throw CIMException(CIM_ERR_FAILED, message);
-        }
+        throw CIMException(CIM_ERR_FAILED, message);
     }
 
     // TODO: check array size?
@@ -143,21 +137,7 @@ CIMProperty ObjectNormalizer::processProperty(
     // update value
     if (!instProperty.getValue().isNull())
     {
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
-        // This happens ONLY when the referencePropType is CIMTYPE_INSTANCE
-        // and the cimPropType is CIMTYPE_OBJECT, otherwise an exception
-        // would have been thrown. Correct the mismatch here.
-        if (referencePropType != instPropType)
-        {
-            CIMObject tmpObject;
-            instProperty.getValue().get(tmpObject);
-            normalizedProperty.setValue(CIMInstance(tmpObject));
-        }
-        else
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
-        {
-            normalizedProperty.setValue(instProperty.getValue());
-        }
+        normalizedProperty.setValue(instProperty.getValue());
     }
 
     // update class origin
@@ -196,12 +176,13 @@ CIMProperty ObjectNormalizer::processProperty(
             }
         }
     }
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
 #ifdef PEGASUS_SNIA_INTEROP_COMPATIBILITY
     else if (referenceProperty.getType() == CIMTYPE_INSTANCE)
     {
-        Uin32 refPos = referenceProperty.findQualifier("EmbeddedInstance");
-        Uin32 cimPos = instProperty.findQualifier("EmbeddedInstance");
+        Uin32 refPos = referenceProperty.findQualifier(
+                           PEGASUS_QUALIFIERNAME_EMBEDDEDINSTANCE);
+        Uin32 cimPos = instProperty.findQualifier(
+                           PEGASUS_QUALIFIERNAME_EMBEDDEDINSTANCE);
         if (refPos != PEG_NOT_FOUND && cimPos == PEG_NOT_FOUND)
         {
             instProperty.addQualifier(refProperty.getQualifier(pos));
@@ -216,7 +197,8 @@ CIMProperty ObjectNormalizer::processProperty(
     {
         if (referenceProperty.getType() == CIMTYPE_INSTANCE)
         {
-            Uint32 pos = referenceProperty.findQualifier("EmbeddedInstance");
+            Uint32 pos = referenceProperty.findQualifier(
+                             PEGASUS_QUALIFIERNAME_EMBEDDEDINSTANCE);
 
             PEGASUS_ASSERT(pos != PEG_NOT_FOUND);
 
@@ -305,8 +287,6 @@ CIMProperty ObjectNormalizer::processProperty(
             }
         }
     }
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
-
     return normalizedProperty;
 }
 
@@ -482,9 +462,9 @@ CIMObjectPath ObjectNormalizer::processInstanceObjectPath(
     }
 
     CIMObjectPath normalizedObjectPath(
-        _cimClass.getPath().getHost(),
-        _cimClass.getPath().getNameSpace(),
-        _cimClass.getClassName());
+        cimObjectPath.getHost(),
+        cimObjectPath.getNameSpace(),
+        cimObjectPath.getClassName());
 
     Array<CIMKeyBinding> normalizedKeys;
 
