@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -73,6 +71,7 @@ void Option::setDomain(const Array<String>& domain)
 ////////////////////////////////////////////////////////////////////////////////
 
 OptionManager::OptionManager()
+    :_msgPath("")
 {
 
 }
@@ -164,6 +163,89 @@ void OptionManager::registerOptions(OptionRow* optionRow, Uint32 numOptions)
     }
 }
 
+void OptionManager::registerOptions(
+    OptionRowWithMsg* optionRow,
+    Uint32 numOptions)
+{
+    for (Uint32 i = 0; i < numOptions; i++)
+    {
+        // Get option name:
+
+        if (!optionRow[i].optionName)
+        {
+            throw NullPointer();
+        }
+
+        String optionName = optionRow[i].optionName;
+
+        // Get default value:
+
+        String defaultValue;
+
+        if (optionRow[i].defaultValue)
+        {
+            defaultValue = optionRow[i].defaultValue;
+        }
+        // Get the required flag:
+
+        Boolean required = optionRow[i].required != 0;
+
+        // Get the type:
+
+        Option::Type type = optionRow[i].type;
+
+        // Get the domain:
+
+        Array<String> domain;
+
+        if (optionRow[i].domain)
+        {
+            Uint32 domainSize = optionRow[i].domainSize;
+
+            for (Uint32 j = 0; j < domainSize; j++)
+            {
+                domain.append(optionRow[i].domain[j]);
+            }
+        }
+
+        // Get commandLineOptionName:
+
+        String commandLineOptionName;
+
+        if (optionRow[i].commandLineOptionName)
+        {
+            commandLineOptionName = optionRow[i].commandLineOptionName;
+        }
+        // get optionHelp Message String
+
+        String optionHelpMessage;
+
+        if (optionRow[i].optionHelpMessage)
+        {
+            optionHelpMessage = optionRow[i].optionHelpMessage;
+        }
+
+        String messageKey = String();
+        if (optionRow[i].messageKey)
+        {
+            messageKey = optionRow[i].messageKey;
+        }
+
+        // Add the option:
+
+        Option* option = new Option(
+            optionName,
+            defaultValue,
+            required,
+            type,
+            domain,
+            commandLineOptionName,
+            optionHelpMessage,
+            messageKey);
+
+        registerOption(option);
+    }
+}
 void OptionManager::mergeCommandLine(
     int& argc,
     char**& argv,
@@ -476,19 +558,50 @@ void OptionManager::print() const
     cout << endl;
 }
 
+void OptionManager::setMessagePath(String messagePath)
+{
+    _msgPath = messagePath;
+}
+/* This is utility function to create help string for the option*/
+String createOptionHelpString(Option* option)
+{
+    String defMsg = " -";
+    defMsg.append(option->getCommandLineOptionName());
+    defMsg.append("  ");
+    defMsg.append(option->getOptionName());
+    defMsg.append(". ");
+    defMsg.append(option->getOptionHelpMessage());
+    defMsg.append(". Default(");
+    defMsg.append(option->getDefaultValue());
+    defMsg.append(")\n");
+    return defMsg;
+}
+
 void OptionManager::printOptionsHelp() const
 {
     for (Uint32 i = 0; i < _options.size(); i++)
     {
+        String str;
         Option* option = _options[i];
-        cout << " -";
-        cout << option->getCommandLineOptionName() << "  ";
-        cout << option->getOptionName() << ". ";
-        cout << option->getOptionHelpMessage();
-        cout << ". Default(" << option->getDefaultValue() << ")\n";
+        String defMsg = createOptionHelpString(option);
+        CString cstr = defMsg.getCString();
+        const String messageKey = option->getMessageKey();
+        CString msgKeyCString = messageKey.getCString();
+        if (String::compare(messageKey, String::EMPTY))
+        {
+            MessageLoaderParms parms(
+                (const char*)msgKeyCString,
+                (const char*)cstr);
+            parms.msg_src_path = _msgPath;
+            str = MessageLoader::getMessage(parms);
+        }
+        else
+        {
+            str = defMsg;
+        }
+        cout << str;
     }
     cout << endl;
-
 }
 
 void OptionManager::printOptionsHelpTxt(
@@ -513,7 +626,8 @@ Option::Option(
     Type type,
     const Array<String>& domain,
     const String& commandLineOptionName,
-    const String& optionHelpMessage)
+    const String& optionHelpMessage,
+    const String& messageKey)
     :
     _optionName(optionName),
     _defaultValue(defaultValue),
@@ -523,6 +637,7 @@ Option::Option(
     _domain(domain),
     _commandLineOptionName(commandLineOptionName),
     _optionHelpMessage(optionHelpMessage),
+    _messageKey(messageKey),
     _resolved(false)
 {
     if (!isValid(_value))
@@ -538,8 +653,8 @@ Option::Option(const Option& x)
     _type(x._type),
     _domain(x._domain),
     _commandLineOptionName(x._commandLineOptionName),
-    _optionHelpMessage(x._optionHelpMessage)
-
+    _optionHelpMessage(x._optionHelpMessage),
+    _messageKey(x._messageKey)
 {
 }
 
@@ -560,6 +675,7 @@ Option& Option::operator=(const Option& x)
         _domain = x._domain;
         _commandLineOptionName = x._commandLineOptionName;
         _optionHelpMessage = x._optionHelpMessage;
+        _messageKey = x._messageKey;
     }
     return *this;
 }
@@ -641,7 +757,7 @@ String OMConfigFileSyntaxError::_formatMessage(
     const String& file, Uint32 line)
 {
     char buffer[32];
-    sprintf(buffer, "%d", line);
+    sprintf(buffer, "%u", line);
     MessageLoaderParms parms(
         "Common.OptionManager.SYNTAX_ERR_CONFIG_FILE",
         "Syntax error in configuration file: ");
