@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -57,6 +55,7 @@ PEGASUS_NAMESPACE_BEGIN
 
 class Option;
 struct OptionRow;
+struct OptionRowWithMsg;
 
 typedef Option* OptionPtr;
 
@@ -255,6 +254,12 @@ public:
     */
     void registerOptions(OptionRow* options, Uint32 numOptions);
 
+    /**
+        Provides a simple way to register several options at once along
+        with their corresponding message keys
+    */
+    void registerOptions(OptionRowWithMsg* options, Uint32 numOptions);
+
     /** Merge option values from the command line. Searches the command
         line for registered options whose names are given by the
         Option::getCommandLineOptionName() method. Validation is performed
@@ -357,8 +362,11 @@ public:
     /** Print Complete Help Text message including header before the options
         help and trailer after the options help
     */
-    void printOptionsHelpTxt(const String& header, const String& trailer) const;
+    void printOptionsHelpTxt(
+        const String& header,
+        const String& trailer) const;
 
+    void setMessagePath(String messagePath);
 
 private:
 
@@ -368,6 +376,8 @@ private:
     Option* _lookupOptionByCommandLineOptionName(const String& name);
 
     Array<Option*> _options;
+
+    String _msgPath;
 };
 
 //////////////////////////////////////////////////////////////////
@@ -419,6 +429,9 @@ public:
 
         @param optionHelpMessage Text message that defines option. To be used
             in Usage messages.
+
+        @param messageKey Unique key for globalizing option help message. To
+            be used in Usage messages.
     */
     Option(
         const String& optionName,
@@ -427,7 +440,8 @@ public:
         Type type,
         const Array<String>& domain = Array<String>(),
         const String& commandLineOptionName = String(),
-        const String& optionHelpMessage = String());
+        const String& optionHelpMessage = String(),
+        const String& messageKey = String());
 
     Option(const Option& x);
 
@@ -522,6 +536,13 @@ public:
         _commandLineOptionName = commandLineOptionName;
     }
 
+    /**
+        Accesor. Get the  message key
+    */
+    const String& getMessageKey() const
+    {
+        return _messageKey;
+    }
     /** Accesor. Returns true if an option value was ever obtained for
         this option.
     */
@@ -545,6 +566,7 @@ private:
     Array<String> _domain;
     String _commandLineOptionName;
     String _optionHelpMessage;
+    String _messageKey;
     Boolean _resolved;
 };
 
@@ -612,6 +634,20 @@ struct OptionRow
     with a static object.
 */
 
+/* Optionrow structure with messageKey for corresponding option */
+struct OptionRowWithMsg
+{
+    const char* optionName;
+    const char* defaultValue;
+    int required;
+    Option::Type type;
+    char** domain;
+    Uint32 domainSize;
+    const char* commandLineOptionName;
+    const char* messageKey;
+    const char* optionHelpMessage;
+};
+
 /** Exception class */
 class PEGASUS_COMMON_LINKAGE OMMissingCommandLineOptionArgument
     : public Exception
