@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -55,14 +53,6 @@
 #ifdef PEGASUS_OS_PASE
 # include <ILEWrapper/ILEUtilities.h>
 #endif
-//
-// Typedef's for OpenSSL callback functions.
-//
-extern "C"
-{
-    typedef void (* CRYPTO_SET_LOCKING_CALLBACK)(int, int, const char *, int);
-    typedef unsigned long (* CRYPTO_SET_ID_CALLBACK)(void);
-};
 
 typedef struct x509_store_ctx_st X509_STORE_CTX;
 
@@ -92,14 +82,9 @@ const int SSLCallbackInfo::SSL_CALLBACK_INDEX = 0;
 //
 #ifdef PEGASUS_HAS_SSL
 
-// Mutex for SSL locks which will get initialized by AutoArrayPtr constructor.
-AutoArrayPtr<Mutex> SSLContextRep::_sslLocks;
-
-// Mutex for _countRep.
-Mutex SSLContextRep::_countRepMutex;
-
-// Initialise _count for SSLContextRep objects.
-int SSLContextRep::_countRep = 0;
+AutoArrayPtr<Mutex> SSLEnvironmentInitializer::_sslLocks;
+int SSLEnvironmentInitializer::_instanceCount = 0;
+Mutex SSLEnvironmentInitializer::_instanceCountMutex;
 
 
 //
@@ -253,6 +238,7 @@ int SSLCallback::verificationCRLCallback(
     if (X509_STORE_get_by_subject(
             &crlStoreCtx, X509_LU_CRL, issuerName, &obj) <= 0)
     {
+        X509_STORE_CTX_cleanup(&crlStoreCtx);
         PEG_TRACE_CSTRING(TRC_SSL, Tracer::LEVEL3,
             "---> SSL: No CRL by that issuer");
         PEG_METHOD_EXIT();
@@ -294,11 +280,14 @@ int SSLCallback::verificationCRLCallback(
             PEG_TRACE_CSTRING(TRC_SSL, Tracer::LEVEL2,
                 "---> SSL: Certificate is revoked");
             X509_STORE_CTX_set_error(ctx, X509_V_ERR_CERT_REVOKED);
+            X509_CRL_free(crl);
             PEG_METHOD_EXIT();
             return 1;
         }
     }
 
+    X509_CRL_free(crl);
+
     PEG_TRACE_CSTRING(TRC_SSL, Tracer::LEVEL4,
         "---> SSL: Certificate is not revoked at this level");
 
@@ -319,7 +308,6 @@ int SSLCallback::verificationCallback(int preVerifyOk, X509_STORE_CTX* ctx)
     char   buf[256];
     X509   *currentCert;
     SSL    *ssl;
-    int    verifyError = X509_V_OK;
     int    revoked = -1;
 
     PEG_TRACE((TRC_SSL, Tracer::LEVEL4,
@@ -403,7 +391,7 @@ int SSLCallback::verificationCallback(int preVerifyOk, X509_STORE_CTX* ctx)
     //
     if (!preVerifyOk)
     {
-        PEG_TRACE((TRC_SSL, Tracer::LEVEL4,
+        PEG_TRACE((TRC_SSL, Tracer::LEVEL2,
             "---> SSL: certificate default verification error: %s",
             (const char*)errorStr.getCString()));
     }
@@ -434,7 +422,7 @@ int SSLCallback::verificationCallback(int preVerifyOk, X509_STORE_CTX* ctx)
         (CIMDateTime::getDifference(
              CIMDateTime::getCurrentDateTime(), notBefore) > 0))
     {
-        PEG_TRACE_CSTRING(TRC_SSL, Tracer::LEVEL4,
+        PEG_TRACE_CSTRING(TRC_SSL, Tracer::LEVEL2,
             "Certificate was not yet valid.");
 
         X509_STORE_CTX_set_error(ctx, X509_V_ERR_CERT_NOT_YET_VALID);
@@ -448,7 +436,7 @@ int SSLCallback::verificationCallback(int preVerifyOk, X509_STORE_CTX* ctx)
     // This is because OpenSSL retains the original default error in case
     // we want to use it later.
     // To set the error, we could use X509_STORE_CTX_set_error(ctx,
-    // verifyError); but there is no real benefit to doing that here.
+    // X509_V_OK); but there is no real benefit to doing that here.
     //
     if (exData->_rep->verifyCertificateCallback == NULL)
     {
@@ -468,7 +456,7 @@ int SSLCallback::verificationCallback(int preVerifyOk, X509_STORE_CTX* ctx)
         }
         else // verification failed, handshake will be immediately terminated
         {
-            PEG_TRACE((TRC_SSL, Tracer::LEVEL4,
+            PEG_TRACE((TRC_SSL, Tracer::LEVEL1,
                 "--> SSL: _rep->verifyCertificateCallback() returned error %d",
                 exData->_rep->peerCertificate[0]->getErrorCode()));
 
@@ -489,68 +477,6 @@ extern "C" int prepareForCallback(int preVerifyOk, X509_STORE_CTX *ctx)
     return SSLCallback::verificationCallback(preVerifyOk, ctx);
 }
 
-//
-// Implement OpenSSL locking callback.
-//
-void pegasus_locking_callback(
-    int mode,
-    int type,
-    const char* file,
-    int line)
-{
-    // Check whether the mode is lock or unlock.
-
-    if ( mode & CRYPTO_LOCK )
-    {
-        /*PEG_TRACE((TRC_SSL, Tracer::LEVEL4,
-                "Now locking for type %d", type));*/
-        SSLContextRep::_sslLocks.get()[type].lock( );
-    }
-    else
-    {
-        /*PEG_TRACE((TRC_SSL, Tracer::LEVEL4,
-                "Now unlocking for type %d", type));*/
-        SSLContextRep::_sslLocks.get()[type].unlock( );
-    }
-}
-
-//
-// Initialize OpenSSL Locking and id callbacks.
-//
-void SSLContextRep::init_ssl()
-{
-     // Allocate Memory for _sslLocks. SSL locks needs to be able to handle
-     // up to CRYPTO_num_locks() different mutex locks.
-     PEG_TRACE_CSTRING(TRC_SSL, Tracer::LEVEL4,
-           "Initialized SSL callback.");
-
-     _sslLocks.reset(new Mutex[CRYPTO_num_locks()]);
-
-#if defined(PEGASUS_HAVE_PTHREADS) && !defined(PEGASUS_OS_VMS)
-     // Set the ID callback. The ID callback returns a thread ID.
-     CRYPTO_set_id_callback((CRYPTO_SET_ID_CALLBACK) pthread_self);
-#endif
-
-     // Set the locking callback to pegasus_locking_callback.
-
-     CRYPTO_set_locking_callback(
-         (CRYPTO_SET_LOCKING_CALLBACK) pegasus_locking_callback);
-
-}
-
-// Free OpenSSL Locking and id callbacks.
-void SSLContextRep::free_ssl()
-{
-    // Cleanup _sslLocks and set locking & id callback to NULL.
-
-    CRYPTO_set_locking_callback(NULL);
-    CRYPTO_set_id_callback     (NULL);
-    PEG_TRACE_CSTRING(TRC_SSL, Tracer::LEVEL4,
-             "Freed SSL callback.");
-    _sslLocks.reset();
-}
-
-
 //
 // SSL context area
 //
@@ -568,64 +494,16 @@ SSLContextRep::SSLContextRep(
     PEG_METHOD_ENTER(TRC_SSL, "SSLContextRep::SSLContextRep()");
 
     _trustStore = trustStore;
-
     _certPath = certPath;
-
     _keyPath = keyPath;
-
     _crlPath = crlPath;
-
-    _crlStore = NULL;
-
     _certificateVerifyFunction = verifyCert;
 
     //
     // If a truststore and/or peer verification function is specified,
     // enable peer verification
     //
-    if (trustStore != String::EMPTY || verifyCert != NULL)
-    {
-        _verifyPeer = true;
-    }
-    else
-    {
-        _verifyPeer = false;
-    }
-
-    //
-    // Initialize SSL callbacks and increment the SSLContextRep object _counter.
-    //
-    {
-       AutoMutex autoMut(_countRepMutex);
-
-       PEG_TRACE((TRC_SSL, Tracer::LEVEL4,
-                "Value of Countrep in constructor %d", _countRep));
-        if ( _countRep == 0 )
-        {
-            init_ssl();
-
-            //
-            // load SSL library
-            //
-            PEG_TRACE_CSTRING(TRC_SSL, Tracer::LEVEL4,
-                "Before calling SSL_load_error_strings");
-
-            SSL_load_error_strings();
-
-            PEG_TRACE_CSTRING(TRC_SSL, Tracer::LEVEL4,
-                "After calling SSL_load_error_strings");
-
-            PEG_TRACE_CSTRING(TRC_SSL, Tracer::LEVEL4,
-                "Before calling SSL_library_init");
-
-            SSL_library_init();
-
-            PEG_TRACE_CSTRING(TRC_SSL, Tracer::LEVEL4,
-                "After calling SSL_library_init");
-        }
-
-        _countRep++;
-    }  // mutex unlocks here
+    _verifyPeer = (trustStore != String::EMPTY || verifyCert != NULL);
 
     _randomInit(randomFile);
 
@@ -642,25 +520,12 @@ SSLContextRep::SSLContextRep(const SSLContextRep& sslContextRep)
     _certPath = sslContextRep._certPath;
     _keyPath = sslContextRep._keyPath;
     _crlPath = sslContextRep._crlPath;
-    _crlStore = sslContextRep._crlStore;
     _verifyPeer = sslContextRep._verifyPeer;
     _certificateVerifyFunction = sslContextRep._certificateVerifyFunction;
     _randomFile = sslContextRep._randomFile;
 
-    // Initialize SSL callbacks and increment the SSLContextRep object _counter.
-    {
-        AutoMutex autoMut(_countRepMutex);
-        PEG_TRACE((TRC_SSL, Tracer::LEVEL4,
-            "Value of Countrep in copy constructor %d", _countRep));
-        if ( _countRep == 0 )
-        {
-            init_ssl();
-        }
-
-        _countRep++;
-    }  // mutex unlocks here
-
     _sslContext = _makeSSLContext();
+
     PEG_METHOD_EXIT();
 }
 
@@ -674,21 +539,6 @@ SSLContextRep::~SSLContextRep()
 
     SSL_CTX_free(_sslContext);
 
-    // Decrement the SSLContextRep object _counter.
-    {
-        AutoMutex autoMut(_countRepMutex);
-        _countRep--;
-        // Free SSL locks if no instances of SSLContextRep exist.
-
-        PEG_TRACE((TRC_SSL, Tracer::LEVEL4,
-            "Value of Countrep in destructor %d", _countRep));
-        if ( _countRep == 0 )
-        {
-            free_ssl();
-            ERR_free_strings();
-        }
-
-    }
     PEG_METHOD_EXIT();
 }
 
@@ -710,7 +560,7 @@ void SSLContextRep::_randomInit(const String& randomFile)
         //
         if ( randomFile == String::EMPTY )
         {
-            PEG_TRACE_CSTRING(TRC_SSL, Tracer::LEVEL4,
+            PEG_TRACE_CSTRING(TRC_SSL, Tracer::LEVEL1,
                 "Random seed file is required.");
             PEG_METHOD_EXIT();
             MessageLoaderParms parms(
@@ -728,8 +578,9 @@ void SSLContextRep::_randomInit(const String& randomFile)
             retVal = RAND_load_file(randomFile.getCString(), -1);
             if ( retVal < 0 )
             {
-                PEG_TRACE_STRING(TRC_SSL, Tracer::LEVEL4,
-                    String("Not enough seed data in seed file: ") + randomFile);
+                PEG_TRACE((TRC_SSL, Tracer::LEVEL1,
+                    "Not enough seed data in seed file: %s",
+                    (const char*)randomFile.getCString()));
                 PEG_METHOD_EXIT();
                 // do not put in $0 in default message, but pass in filename
                 // for bundle message
@@ -742,8 +593,9 @@ void SSLContextRep::_randomInit(const String& randomFile)
         }
         else
         {
-            PEG_TRACE_STRING(TRC_SSL, Tracer::LEVEL4,
-                String("seed file - " + randomFile + " does not exist."));
+            PEG_TRACE((TRC_SSL, Tracer::LEVEL1,
+                "Seed file \'%s\' does not exist.",
+                (const char*)randomFile.getCString()));
             PEG_METHOD_EXIT();
             MessageLoaderParms parms(
                 "Common.SSLContext.SEED_FILE_DOES_NOT_EXIST",
@@ -770,7 +622,7 @@ void SSLContextRep::_randomInit(const String& randomFile)
             int  seedRet = RAND_status();
             if ( seedRet == 0 )
             {
-                PEG_TRACE((TRC_SSL, Tracer::LEVEL4,
+                PEG_TRACE((TRC_SSL, Tracer::LEVEL1,
                     "Not enough seed data in random seed file, "
                         "RAND_status = %d",
                     seedRet));
@@ -792,7 +644,7 @@ void SSLContextRep::_randomInit(const String& randomFile)
     {
         // generate random number for pase must use specify function
         unsigned char prn[1024];
-        umeGenerateRandomNumber(prn);
+        umeGenerateRandomNumber(prn, sizeof(prn));
         RAND_seed(prn, 1024);
     }
 #endif
@@ -800,7 +652,7 @@ void SSLContextRep::_randomInit(const String& randomFile)
     int seedRet = RAND_status();
     if (seedRet == 0)
     {
-        PEG_TRACE((TRC_SSL, Tracer::LEVEL4,
+        PEG_TRACE((TRC_SSL, Tracer::LEVEL1,
             "Not enough seed data, RAND_status = %d",
             seedRet));
         PEG_METHOD_EXIT();
@@ -914,17 +766,17 @@ SSL_CTX* SSLContextRep::_makeSSLContext()
             //
             // load certificates from the trust store
             //
-            PEG_TRACE_STRING(TRC_SSL, Tracer::LEVEL2,
-                String("---> SSL: Loading certificates from the trust store: " +
-                    _trustStore));
+            PEG_TRACE((TRC_SSL, Tracer::LEVEL3,
+                "---> SSL: Loading certificates from the trust store: %s",
+                (const char*)_trustStore.getCString()));
 
             if ((!SSL_CTX_load_verify_locations(
                      sslContext, NULL, _trustStore.getCString())) ||
                 (!SSL_CTX_set_default_verify_paths(sslContext)))
             {
-                PEG_TRACE_STRING(TRC_SSL, Tracer::LEVEL2,
-                    String("---> SSL: Could not load certificates from the "
-                        "trust store: " + _trustStore));
+                PEG_TRACE((TRC_SSL, Tracer::LEVEL1,
+                    "---> SSL: Could not load certificates from the "
+                    "trust store: %s ",(const char*)_trustStore.getCString()));
                 MessageLoaderParms parms(
                     "Common.SSLContext.COULD_NOT_LOAD_CERTIFICATES",
                     "Could not load certificates in to trust store.");
@@ -949,17 +801,18 @@ SSL_CTX* SSLContextRep::_makeSSLContext()
                 //
                 // load certificates from the trust store
                 //
-                PEG_TRACE_STRING(TRC_SSL, Tracer::LEVEL2,
-                    String("---> SSL: Loading certificates from the trust "
-                        "store: " + _trustStore));
+                PEG_TRACE((TRC_SSL, Tracer::LEVEL3,
+                    "---> SSL: Loading certificates from the trust store: %s",
+                    (const char*)_trustStore.getCString()));
 
                 if ((!SSL_CTX_load_verify_locations(
                          sslContext, _trustStore.getCString(), NULL)) ||
                     (!SSL_CTX_set_default_verify_paths(sslContext)))
                 {
-                    PEG_TRACE_STRING(TRC_SSL, Tracer::LEVEL2,
-                        String("---> SSL: Could not load certificates from the "
-                            "trust store: " + _trustStore));
+                    PEG_TRACE((TRC_SSL, Tracer::LEVEL1,
+                        "---> SSL: Could not load certificates from the "
+                        "trust store: %s",
+                        (const char*)_trustStore.getCString()));
                     MessageLoaderParms parms(
                         "Common.SSLContext.COULD_NOT_LOAD_CERTIFICATES",
                         "Could not load certificates in to trust store.");
@@ -972,9 +825,9 @@ SSL_CTX* SSLContextRep::_makeSSLContext()
                 //
                 // no certificates found in the trust store
                 //
-                PEG_TRACE_STRING(TRC_SSL, Tracer::LEVEL2,
-                    String("---> SSL: No certificates to load from the trust "
-                        "store: " + _trustStore));
+                PEG_TRACE((TRC_SSL, Tracer::LEVEL2,
+                    "---> SSL: No certificates to load from the "
+                    "trust store: %s",(const char*)_trustStore.getCString()));
             }
         }
     }
@@ -985,7 +838,12 @@ SSL_CTX* SSLContextRep::_makeSSLContext()
         // one CRL for cimserver?
         X509_LOOKUP* pLookup;
 
-        _crlStore = X509_STORE_new();
+        _crlStore.reset(X509_STORE_new());
+        if (_crlStore.get() == NULL)
+        {
+            PEG_METHOD_EXIT();
+            throw PEGASUS_STD(bad_alloc)();
+        }
 
         // the validity of the crlstore was checked in ConfigManager
         // during server startup
@@ -996,12 +854,12 @@ SSL_CTX* SSLContextRep::_makeSSLContext()
                 (const char*)_crlPath.getCString()));
 
             if ((pLookup = X509_STORE_add_lookup(
-                     _crlStore, X509_LOOKUP_hash_dir())) == NULL)
+                     _crlStore.get(), X509_LOOKUP_hash_dir())) == NULL)
             {
                 MessageLoaderParms parms(
                     "Common.SSLContext.COULD_NOT_LOAD_CRLS",
                     "Could not load certificate revocation list.");
-                X509_STORE_free(_crlStore);
+                _crlStore.reset();
                 PEG_METHOD_EXIT();
                 throw SSLException(parms);
             }
@@ -1019,12 +877,12 @@ SSL_CTX* SSLContextRep::_makeSSLContext()
                 (const char*)_crlPath.getCString()));
 
             if ((pLookup = X509_STORE_add_lookup(
-                   _crlStore, X509_LOOKUP_file())) == NULL)
+                   _crlStore.get(), X509_LOOKUP_file())) == NULL)
             {
                 MessageLoaderParms parms(
                     "Common.SSLContext.COULD_NOT_LOAD_CRLS",
                     "Could not load certificate revocation list.");
-                X509_STORE_free(_crlStore);
+                _crlStore.reset();
                 PEG_METHOD_EXIT();
                 throw SSLException(parms);
             }
@@ -1049,15 +907,16 @@ SSL_CTX* SSLContextRep::_makeSSLContext()
         //
         // load the specified server certificates
         //
-        PEG_TRACE_STRING(TRC_SSL, Tracer::LEVEL2,
-            String("---> SSL: Loading server certificate from: " + _certPath));
+        PEG_TRACE((TRC_SSL, Tracer::LEVEL3,
+            "---> SSL: Loading server certificate from: %s",
+            (const char*)_certPath.getCString()));
 
         if (SSL_CTX_use_certificate_file(sslContext,
             _certPath.getCString(), SSL_FILETYPE_PEM) <=0)
         {
-            PEG_TRACE_STRING(TRC_SSL, Tracer::LEVEL2,
-                String("---> SSL: No server certificate found in " +
-                    _certPath));
+            PEG_TRACE((TRC_SSL, Tracer::LEVEL1,
+                "---> SSL: No server certificate found in %s",
+                (const char*)_certPath.getCString()));
             MessageLoaderParms parms(
                 "Common.SSLContext.COULD_NOT_GET_SERVER_CERTIFICATE",
                 "Could not get server certificate.");
@@ -1074,8 +933,9 @@ SSL_CTX* SSLContextRep::_makeSSLContext()
         //
         if (_keyPath == String::EMPTY)
         {
-            PEG_TRACE_STRING(TRC_SSL, Tracer::LEVEL2,
-                String("---> SSL: loading private key from: " + _certPath));
+            PEG_TRACE((TRC_SSL, Tracer::LEVEL3,
+                "---> SSL: Key file empty, loading private key from "
+                "certificate file: %s",(const char*)_certPath.getCString()));
             //
             // load the private key and check for validity
             //
@@ -1098,8 +958,9 @@ SSL_CTX* SSLContextRep::_makeSSLContext()
     //
     if (_keyPath != String::EMPTY && !keyLoaded)
     {
-        PEG_TRACE_STRING(TRC_SSL, Tracer::LEVEL2,
-            String("---> SSL: loading private key from: " + _keyPath));
+        PEG_TRACE((TRC_SSL, Tracer::LEVEL3,
+            "---> SSL: loading private key from: %s",
+            (const char*)_keyPath.getCString()));
         //
         // load given private key and check for validity
         //
@@ -1128,8 +989,9 @@ Boolean SSLContextRep::_verifyPrivateKey(SSL_CTX *ctx, const String& keyPath)
 
     if (!is)
     {
-        PEG_TRACE_STRING(TRC_SSL, Tracer::LEVEL2,
-            String("failed to open private key file: " + keyPath));
+        PEG_TRACE((TRC_SSL, Tracer::LEVEL1,
+            "---> SSL: failed to open private key file: %s",
+            (const char*)keyPath.getCString()));
         return false;
     }
 
@@ -1141,7 +1003,7 @@ Boolean SSLContextRep::_verifyPrivateKey(SSL_CTX *ctx, const String& keyPath)
     if (!pkey)
     {
         PEG_TRACE_CSTRING(
-            TRC_SSL, Tracer::LEVEL2, "failed to create private key");
+            TRC_SSL, Tracer::LEVEL1, "---> SSL: failed to create private key");
         return false;
     }
 
@@ -1154,8 +1016,9 @@ Boolean SSLContextRep::_verifyPrivateKey(SSL_CTX *ctx, const String& keyPath)
     if (SSL_CTX_use_PrivateKey(ctx, pkey) <= 0)
     {
         EVP_PKEY_free(pkey);
-        PEG_TRACE_STRING(TRC_SSL, Tracer::LEVEL2,
-            String("---> SSL: no private key found in " + keyPath));
+        PEG_TRACE((TRC_SSL, Tracer::LEVEL3,
+            "---> SSL: no private key found in %s",
+            (const char*)keyPath.getCString()));
         PEG_METHOD_EXIT();
         return false;
     }
@@ -1166,7 +1029,7 @@ Boolean SSLContextRep::_verifyPrivateKey(SSL_CTX *ctx, const String& keyPath)
 
     if (!SSL_CTX_check_private_key(ctx))
     {
-        PEG_TRACE_CSTRING(TRC_SSL, Tracer::LEVEL2,
+        PEG_TRACE_CSTRING(TRC_SSL, Tracer::LEVEL1,
             "---> SSL: Private and public key do not match");
         PEG_METHOD_EXIT();
         return false;
@@ -1208,14 +1071,14 @@ String SSLContextRep::getCRLPath() const
     return _crlPath;
 }
 
-X509_STORE* SSLContextRep::getCRLStore() const
+SharedPtr<X509_STORE, FreeX509STOREPtr> SSLContextRep::getCRLStore() const
 {
     return _crlStore;
 }
 
 void SSLContextRep::setCRLStore(X509_STORE* store)
 {
-    _crlStore = store;
+    _crlStore.reset(store);
 }
 
 Boolean SSLContextRep::isPeerVerificationEnabled() const
@@ -1229,6 +1092,37 @@ SSLCertificateVerifyFunction*
     return _certificateVerifyFunction;
 }
 
+void SSLContextRep::validateCertificate()
+{
+    BIO* in = BIO_new_file(_certPath.getCString(), "r");
+    PEGASUS_ASSERT(in != NULL);
+    X509* cert = PEM_read_bio_X509(in, NULL, 0, NULL);
+    BIO_free(in);
+    PEGASUS_ASSERT(cert != NULL);
+
+    if (X509_cmp_current_time(X509_get_notBefore(cert)) > 0)
+    {
+        X509_free(cert);
+        MessageLoaderParms parms(
+           "Common.SSLContext.CERTIFICATE_NOT_YET_VALID",
+           "Certificate $0 is not yet valid.",
+           _certPath);
+        throw SSLException(parms);
+    }
+
+    if (X509_cmp_current_time(X509_get_notAfter(cert)) < 0)
+    {
+        X509_free(cert);
+        MessageLoaderParms parms(
+           "Common.SSLContext.CERTIFICATE_EXPIRED",
+           "Certificate $0 has expired.",
+           _certPath);
+        throw SSLException(parms);
+    }
+
+    X509_free(cert);
+}
+
 #else
 
 //
@@ -1272,7 +1166,10 @@ String SSLContextRep::getTrustStoreUserName() const { return String::EMPTY; }
 
 String SSLContextRep::getCRLPath() const { return String::EMPTY; }
 
-X509_STORE* SSLContextRep::getCRLStore() const { return NULL; }
+SharedPtr<X509_STORE, FreeX509STOREPtr> SSLContextRep::getCRLStore() const
+{
+    return SharedPtr<X509_STORE, FreeX509STOREPtr>();
+}
 
 void SSLContextRep::setCRLStore(X509_STORE* store) { }
 
@@ -1284,9 +1181,7 @@ SSLCertificateVerifyFunction*
     return NULL;
 }
 
-void SSLContextRep::init_ssl() {}
-
-void SSLContextRep::free_ssl() {}
+void SSLContextRep::validateCertificate() { }
 
 #endif // end of PEGASUS_HAS_SSL
 
@@ -1404,7 +1299,7 @@ String SSLContext::getCRLPath() const
 X509_STORE* SSLContext::getCRLStore() const
 {
 #ifdef PEGASUS_ENABLE_SSL_CRL_VERIFICATION
-    return _rep->getCRLStore();
+    return _rep->getCRLStore().get();
 #else
     MessageLoaderParms parms(
         "Common.Exception.SSL_CRL_NOT_ENABLED_EXCEPTION",
@@ -1432,6 +1327,11 @@ SSLCertificateVerifyFunction*
     return _rep->getSSLCertificateVerifyFunction();
 }
 
+void SSLContext::_validateCertificate()
+{
+    _rep->validateCertificate();
+}
+
 ///////////////////////////////////////////////////////////////////////////////
 //
 // SSLCertificateInfo
@@ -1637,23 +1537,23 @@ String SSLCertificateInfo::toString() const
     s.append(_rep->issuerName);
     s.append("\n");
 
-    sprintf(buf, "Depth: %d\n", _rep->depth);
+    sprintf(buf, "Depth: %u\n", _rep->depth);
     s.append(buf);
 
-    sprintf(buf, "Error code: %d\n", _rep->errorCode);
+    sprintf(buf, "Error code: %u\n", _rep->errorCode);
     s.append(buf);
 
-    sprintf(buf, "Response (preverify) code: %d\n", _rep->respCode);
+    sprintf(buf, "Response (preverify) code: %u\n", _rep->respCode);
     s.append(buf);
 
     s.append("Error string: ");
     s.append(_rep->errorString);
     s.append("\n");
 
-    sprintf(buf, "Version number: %d\n", _rep->versionNumber);
+    sprintf(buf, "Version number: %u\n", _rep->versionNumber);
     s.append(buf);
 
-    sprintf(buf, "Serial number: %lu\n", _rep->serialNumber);
+    sprintf(buf, "Serial number: %lu\n", (unsigned long)_rep->serialNumber);
     s.append(buf);
 
     s.append("Not before date: ");
