@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -43,7 +41,7 @@
 #ifdef PEGASUS_HAS_SSL
 typedef struct x509_store_st X509_STORE;
 #else
-#define X509_STORE void
+# define X509_STORE int
 #endif
 
 PEGASUS_NAMESPACE_BEGIN
@@ -53,7 +51,6 @@ class SSLContextRep;
 class SSLContext;
 class SSLSocket;
 class CIMServer;
-class CIMxmlIndicationHandler;
 class SSLCertificateInfo;
 class SSLCallback;
 class SSLContextManager;
@@ -78,15 +75,34 @@ class PEGASUS_COMMON_LINKAGE SSLCallbackInfo
 {
 public:
 
-    // index to the application-specific data in the SSL connection object
+    /**
+        Index to the application-specific data in the SSL connection object.
+    */
     static const int SSL_CALLBACK_INDEX;
 
+    /**
+        Constructs an SSLCallbackInfo object with a specified certificate
+        verification function.
+        @param verifyCert A SSLCertificateVerifyFunction pointer specifying
+            the callback function to use to verify a certificate.
+    */
     SSLCallbackInfo(SSLCertificateVerifyFunction* verifyCert);
 
+    /**
+        Constructs an SSLCallbackInfo object with a specified certificate
+        verification function and CRL store.
+        @param verifyCert A SSLCertificateVerifyFunction pointer specifying
+            the callback function to use to verify a certificate.
+        @param crlStore An X509_STORE pointer specifying a CRL store to check
+            whether a certificate has been revoked.
+    */
     SSLCallbackInfo(
         SSLCertificateVerifyFunction* verifyCert,
         X509_STORE* crlStore);
 
+    /**
+        Destructs an SSLCallbackInfo object.
+    */
     ~SSLCallbackInfo();
 
 private:
@@ -116,47 +132,80 @@ class PEGASUS_COMMON_LINKAGE SSLCertificateInfo
 {
 public:
 
-    //
-    // Certificate validation result codes.
-    //
+    /**
+        Certificate validation result code corresponding to the OpenSSL error
+        code X509_V_OK.
+    */
     static const int V_OK;
 
+    /** OpenSSL error code X509_V_ERR_UNABLE_TO_GET_ISSUER_CERT. */
     static const int V_ERR_UNABLE_TO_GET_ISSUER_CERT;
+    /** OpenSSL error code X509_V_ERR_UNABLE_TO_GET_CRL. */
     static const int V_ERR_UNABLE_TO_GET_CRL;
+    /** OpenSSL error code X509_V_ERR_UNABLE_TO_DECRYPT_CERT_SIGNATURE. */
     static const int V_ERR_UNABLE_TO_DECRYPT_CERT_SIGNATURE;
+    /** OpenSSL error code X509_V_ERR_UNABLE_TO_DECRYPT_CRL_SIGNATURE. */
     static const int V_ERR_UNABLE_TO_DECRYPT_CRL_SIGNATURE;
+    /** OpenSSL error code X509_V_ERR_UNABLE_TO_DECODE_ISSUER_PUBLIC_KEY. */
     static const int V_ERR_UNABLE_TO_DECODE_ISSUER_PUBLIC_KEY;
+    /** OpenSSL error code X509_V_ERR_CERT_SIGNATURE_FAILURE. */
     static const int V_ERR_CERT_SIGNATURE_FAILURE;
+    /** OpenSSL error code X509_V_ERR_CRL_SIGNATURE_FAILURE. */
     static const int V_ERR_CRL_SIGNATURE_FAILURE;
+    /** OpenSSL error code X509_V_ERR_CERT_NOT_YET_VALID. */
     static const int V_ERR_CERT_NOT_YET_VALID;
+    /** OpenSSL error code X509_V_ERR_CERT_HAS_EXPIRED. */
     static const int V_ERR_CERT_HAS_EXPIRED;
+    /** OpenSSL error code X509_V_ERR_CRL_NOT_YET_VALID. */
     static const int V_ERR_CRL_NOT_YET_VALID;
+    /** OpenSSL error code X509_V_ERR_CRL_HAS_EXPIRED. */
     static const int V_ERR_CRL_HAS_EXPIRED;
+    /** OpenSSL error code X509_V_ERR_ERROR_IN_CERT_NOT_BEFORE_FIELD. */
     static const int V_ERR_ERROR_IN_CERT_NOT_BEFORE_FIELD;
+    /** OpenSSL error code X509_V_ERR_ERROR_IN_CERT_NOT_AFTER_FIELD. */
     static const int V_ERR_ERROR_IN_CERT_NOT_AFTER_FIELD;
+    /** OpenSSL error code X509_V_ERR_ERROR_IN_CRL_LAST_UPDATE_FIELD. */
     static const int V_ERR_ERROR_IN_CRL_LAST_UPDATE_FIELD;
+    /** OpenSSL error code X509_V_ERR_ERROR_IN_CRL_NEXT_UPDATE_FIELD. */
     static const int V_ERR_ERROR_IN_CRL_NEXT_UPDATE_FIELD;
+    /** OpenSSL error code X509_V_ERR_OUT_OF_MEM. */
     static const int V_ERR_OUT_OF_MEM;
+    /** OpenSSL error code X509_V_ERR_DEPTH_ZERO_SELF_SIGNED_CERT. */
     static const int V_ERR_DEPTH_ZERO_SELF_SIGNED_CERT;
+    /** OpenSSL error code X509_V_ERR_SELF_SIGNED_CERT_IN_CHAIN. */
     static const int V_ERR_SELF_SIGNED_CERT_IN_CHAIN;
+    /** OpenSSL error code X509_V_ERR_UNABLE_TO_GET_ISSUER_CERT_LOCALLY. */
     static const int V_ERR_UNABLE_TO_GET_ISSUER_CERT_LOCALLY;
+    /** OpenSSL error code X509_V_ERR_UNABLE_TO_VERIFY_LEAF_SIGNATURE. */
     static const int V_ERR_UNABLE_TO_VERIFY_LEAF_SIGNATURE;
+    /** OpenSSL error code X509_V_ERR_CERT_CHAIN_TOO_LONG. */
     static const int V_ERR_CERT_CHAIN_TOO_LONG;
+    /** OpenSSL error code X509_V_ERR_CERT_REVOKED. */
     static const int V_ERR_CERT_REVOKED;
+    /** OpenSSL error code X509_V_ERR_INVALID_CA. */
     static const int V_ERR_INVALID_CA;
+    /** OpenSSL error code X509_V_ERR_PATH_LENGTH_EXCEEDED. */
     static const int V_ERR_PATH_LENGTH_EXCEEDED;
+    /** OpenSSL error code X509_V_ERR_INVALID_PURPOSE. */
     static const int V_ERR_INVALID_PURPOSE;
+    /** OpenSSL error code X509_V_ERR_CERT_UNTRUSTED. */
     static const int V_ERR_CERT_UNTRUSTED;
+    /** OpenSSL error code X509_V_ERR_CERT_REJECTED. */
     static const int V_ERR_CERT_REJECTED;
+    /** OpenSSL error code X509_V_ERR_SUBJECT_ISSUER_MISMATCH. */
     static const int V_ERR_SUBJECT_ISSUER_MISMATCH;
+    /** OpenSSL error code X509_V_ERR_AKID_SKID_MISMATCH. */
     static const int V_ERR_AKID_SKID_MISMATCH;
+    /** OpenSSL error code X509_V_ERR_AKID_ISSUER_SERIAL_MISMATCH. */
     static const int V_ERR_AKID_ISSUER_SERIAL_MISMATCH;
+    /** OpenSSL error code X509_V_ERR_KEYUSAGE_NO_CERTSIGN. */
     static const int V_ERR_KEYUSAGE_NO_CERTSIGN;
 
+    /** OpenSSL error code X509_V_ERR_APPLICATION_VERIFICATION. */
     static const int V_ERR_APPLICATION_VERIFICATION;
 
 
-    /** Constructor for a SSLCertificateInfo object.
+    /** Constructor for an SSLCertificateInfo object.
         Note: Do not use this constructor, instead use the private constructor.
         The constructor is not for client applications use, it is intended to be
         used only by the CIMServer.
@@ -175,7 +224,7 @@ public:
         const int errorCode,
         const int respCode);
 
-    /** Copy constructor for a SSLCertificateInfo object.
+    /** Copy constructor for an SSLCertificateInfo object.
         @param certificateInfo SSLCertificateInfo object to copy
     */
     SSLCertificateInfo(const SSLCertificateInfo& certificateInfo);
@@ -253,7 +302,7 @@ public:
 
 private:
 
-    /** Constructor for a SSLCertificateInfo object.
+    /** Constructor for an SSLCertificateInfo object.
         @param subjectName subject name of the certificate.
         @param issuerName  issuer name of the certificate.
         @param version version number value from the certificate.
@@ -302,7 +351,7 @@ class PEGASUS_COMMON_LINKAGE SSLContext
 {
 public:
 
-    /** Constructor for a SSLContext object.
+    /** Constructor for an SSLContext object.
         @param trustStore file path of the trust store
         @param verifyCert  function pointer to a certificate verification
         call back function.  A null pointer indicates that no callback is
@@ -310,15 +359,15 @@ public:
         @param randomFile  file path of a random file that may be used as a seed
         for random number generation by OpenSSL.
 
-        NOTE: 
+        NOTE:
         For platforms that support /dev/random(urandom), the /dev/random
-        files will be used to seed OpenSSL.  The specified random file 
-        may be used as a fallback when /dev/random(urandom) is unavailable 
-        or fails.  Using /dev/random to seed OpenSSL is more secure than using 
+        files will be used to seed OpenSSL.  The specified random file
+        may be used as a fallback when /dev/random(urandom) is unavailable
+        or fails.  Using /dev/random to seed OpenSSL is more secure than using
         a random file.
 
         An empty random file string indicates that a random file should not
-        be used. If sufficient randomness is not achieved using /dev/random 
+        be used. If sufficient randomness is not achieved using /dev/random
         and/or a random file, an SSLException is thrown.
 
         @exception SSLException indicates failure to create an SSL context.
@@ -328,8 +377,15 @@ public:
         SSLCertificateVerifyFunction* verifyCert,
         const String& randomFile = String::EMPTY);
 
+    /**
+        Constructs an SSLContext by copying another SSLContext object.
+        @param sslContext The SSLContext object to copy
+    */
     SSLContext(const SSLContext& sslContext);
 
+    /**
+        Destructs an SSLContext object.
+    */
     ~SSLContext();
 
     /** Gets the truststore path of the SSLContext object.  This may be a
@@ -348,13 +404,11 @@ public:
     */
     String getKeyPath() const;
 
-    //PEP187
     /** Gets the certificate revocation list path of the SSLContext object.
         @return a string containing the crl path
     */
     String getCRLPath() const;
 
-    //PEP187
     /** Gets the certificate revocation store of the SSLContext object.
         @return a string containing the crl store
     */
@@ -381,26 +435,26 @@ public:
     */
     SSLCertificateVerifyFunction* getSSLCertificateVerifyFunction() const;
 
-    /** Constructor for a SSLContext object. This constructor is intended
+    /** Constructor for an SSLContext object. This constructor is intended
         to be used by the CIMServer or CIMClient.
         @param trustStore file path of the trust store.
         @param certPath  file path of the server certificate.
-        @param KeyPath  file path of the private key.
+        @param keyPath  file path of the private key.
         @param verifyCert  function pointer to a certificate verification
         call back function.  A null pointer indicates that no callback is
         requested for certificate verification.
         @param randomFile  file path of a random file that may be used as a seed
         for random number generation by OpenSSL.
 
-        NOTE: 
+        NOTE:
         For platforms that support /dev/random(urandom), the /dev/random
-        files will be used to seed OpenSSL.  The specified random file 
-        may be used as a fallback when /dev/random(urandom) is unavailable 
-        or fails.  Using /dev/random to seed OpenSSL is more secure than using 
+        files will be used to seed OpenSSL.  The specified random file
+        may be used as a fallback when /dev/random(urandom) is unavailable
+        or fails.  Using /dev/random to seed OpenSSL is more secure than using
         a random file.
 
         An empty random file string indicates that a random file should not
-        be used. If sufficient randomness is not achieved using /dev/random 
+        be used. If sufficient randomness is not achieved using /dev/random
         and/or a random file, an SSLException is thrown.
 
         @exception SSLException indicates failure to create an SSL context.
@@ -413,8 +467,7 @@ public:
         const String& randomFile);
 
 
-    //PEP187
-    /** Constructor for a SSLContext object. This constructor is intended
+    /** Constructor for an SSLContext object. This constructor is intended
         to be used by the CIMServer or CIMClient.
         @param trustStore file path of the trust store.
         @param certPath  file path of the server certificate.
@@ -426,15 +479,15 @@ public:
         @param randomFile  file path of a random file that may be used as a seed
         for random number generation by OpenSSL.
 
-        NOTE: 
+        NOTE:
         For platforms that support /dev/random(urandom), the /dev/random
-        files will be used to seed OpenSSL.  The specified random file 
-        may be used as a fallback when /dev/random(urandom) is unavailable 
-        or fails.  Using /dev/random to seed OpenSSL is more secure than using 
+        files will be used to seed OpenSSL.  The specified random file
+        may be used as a fallback when /dev/random(urandom) is unavailable
+        or fails.  Using /dev/random to seed OpenSSL is more secure than using
         a random file.
 
         An empty random file string indicates that a random file should not
-        be used. If sufficient randomness is not achieved using /dev/random 
+        be used. If sufficient randomness is not achieved using /dev/random
         and/or a random file, an SSLException is thrown.
 
         @exception SSLException indicates failure to create an SSL context.
@@ -448,7 +501,7 @@ public:
         const String& randomFile);
 
 #ifdef PEGASUS_USE_DEPRECATED_INTERFACES
-    /** Constructor for a SSLContextRep object.
+    /** Constructor for an SSLContextRep object.
         @param trustStore  trust store file path
         @param certPath  server certificate file path
         @param keyPath  server key file path
@@ -479,14 +532,12 @@ private:
     SSLContext();
     SSLContext& operator=(const SSLContext& sslContext);
 
+    void _validateCertificate();
+
     SSLContextRep* _rep;
 
     friend class SSLSocket;
-
     friend class CIMServer;
-
-    friend class CIMxmlIndicationHandler;
-
     friend class SSLContextManager;
 };
 
