@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -102,7 +100,7 @@ Boolean Socket::timedConnect(
 #endif
         if (selectResult == 0)
         {
-            PEG_TRACE_CSTRING(TRC_HTTP, Tracer::LEVEL2,
+            PEG_TRACE_CSTRING(TRC_HTTP, Tracer::LEVEL1,
                 "select() timed out waiting for the socket connection to be "
                     "established.");
             return false;
@@ -120,7 +118,7 @@ Boolean Socket::timedConnect(
             }
             else
             {
-                PEG_TRACE((TRC_HTTP, Tracer::LEVEL2,
+                PEG_TRACE((TRC_HTTP, Tracer::LEVEL1,
                     "Did not connect, getsockopt() returned optval = %d",
                     optval));
                 return false;
@@ -128,14 +126,14 @@ Boolean Socket::timedConnect(
         }
         else
         {
-            PEG_TRACE((TRC_HTTP, Tracer::LEVEL2,
+            PEG_TRACE((TRC_HTTP, Tracer::LEVEL1,
                 "select() returned error code %d",
                 getSocketError()));
             return false;
         }
     }
 
-    PEG_TRACE((TRC_HTTP, Tracer::LEVEL2,
+    PEG_TRACE((TRC_HTTP, Tracer::LEVEL1,
         "connect() returned error code %d",
         getSocketError()));
     return false;
@@ -229,19 +227,23 @@ Sint32 Socket::timedWrite(
     }
 }
 
-void Socket::close(SocketHandle socket)
+void Socket::close(SocketHandle& socket)
 {
-    if (socket != -1)
+    if (socket != PEGASUS_INVALID_SOCKET)
     {
 #ifdef PEGASUS_OS_TYPE_WINDOWS
         if (!closesocket(socket))
-            socket = -1;
+        {
+            socket = PEGASUS_INVALID_SOCKET;
+        }
 #else
         int status;
         PEGASUS_RETRY_SYSTEM_CALL(::close(socket), status);
 
         if (status == 0)
-            socket = -1;
+        {
+            socket = PEGASUS_INVALID_SOCKET;
+        }
 #endif
     }
 }
@@ -268,8 +270,14 @@ void Socket::initializeInterface()
     {
         WSADATA tmp;
 
-        if (WSAStartup(0x202, &tmp) == SOCKET_ERROR)
-            WSACleanup();
+        int err = WSAStartup(0x202, &tmp);
+        if (err != 0)
+        {
+            throw Exception(MessageLoaderParms(
+                "Common.Socket.WSASTARTUP_FAILED.WINDOWS",
+                "WSAStartup failed with error $0.",
+                err));
+        }
     }
 
     _socketInterfaceRefCount++;
@@ -358,8 +366,9 @@ SocketHandle Socket::createSocket(int domain, int type, int protocol)
         {
             Logger::put_l(
                 Logger::STANDARD_LOG, System::CIMSERVER, Logger::INFORMATION,
-                "Common.Socket.WAIT_FOR_TCPIP",
-                "TCP/IP temporary unavailable.");
+                MessageLoaderParms(
+                    "Common.Socket.WAIT_FOR_TCPIP",
+                    "TCP/IP temporary unavailable."));
             sendTcpipMsg = false;
         }
 
