@@ -1,39 +1,35 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
-#if defined(PEGASUS_PLATFORM_ZOS_ZSERIES_IBM)
 #include <Pegasus/Common/Config.h>
-#endif
 
 #include <fstream>
 #include <cctype>  // for tolower()
@@ -183,6 +179,128 @@ char *System::extract_file_path(const char *fullpath, char *dirname)
     return dirname;
 }
 
+String System::getHostName()
+{
+    static String _hostname;
+    static MutexType _mutex = PEGASUS_MUTEX_INITIALIZER;
+
+    // Use double-checked locking pattern to avoid overhead of
+    // mutex on subsequent calls.
+
+    if (0 == _hostname.size())
+    {
+        mutex_lock(&_mutex);
+
+        if (0 == _hostname.size())
+        {
+            char hostname[PEGASUS_MAXHOSTNAMELEN + 1];
+            // If gethostname() fails, an empty or truncated value is used.
+            hostname[0] = 0;
+            gethostname(hostname, sizeof(hostname));
+            hostname[sizeof(hostname)-1] = 0;
+            _hostname.assign(hostname);
+        }
+
+        mutex_unlock(&_mutex);
+    }
+
+    return _hostname;
+}
+
+static String _getFullyQualifiedHostName()
+{
+    char hostName[PEGASUS_MAXHOSTNAMELEN + 1];
+
+    // Get the short name of the local host.
+    // If gethostname() fails, an empty or truncated value is used.
+    hostName[0] = 0;
+    gethostname(hostName, sizeof(hostName));
+    hostName[sizeof(hostName)-1] = 0;
+
+#if defined(PEGASUS_OS_ZOS)|| \
+    defined(PEGASUS_OS_VMS)
+
+    String fqName;
+    struct addrinfo *resolv;
+    struct addrinfo hint;
+    struct hostent *he;
+
+    memset (&hint, 0, sizeof(struct addrinfo));
+    hint.ai_flags = AI_CANONNAME;
+    hint.ai_family = AF_UNSPEC; // any family
+    hint.ai_socktype = 0;       // any socket type
+    hint.ai_protocol = 0;       // any protocol
+    int success = System::getAddrInfo(hostName, NULL, &hint, &resolv);
+    if (success==0)
+    {
+        // assign fully qualified hostname
+        fqName.assign(resolv->ai_canonname);
+    }
+    else
+    {
+        if ((he = System::getHostByName(hostName)))
+        {
+            strncpy(hostName, he->h_name, sizeof(hostName) - 1);
+        }
+        // assign hostName
+        // if gethostbyname was successful assign that result
+        // else assign unqualified hostname
+        fqName.assign(hostName);
+    }
+    if (resolv)
+    {
+        freeaddrinfo(resolv);
+    }
+
+    return fqName;
+
+#else /* !PEGASUS_OS_ZOS && !PEGASUS_OS_VMS */
+
+    char hostEntryBuffer[8192];
+    struct hostent hostEntryStruct;
+    struct hostent* hostEntry = System::getHostByName(
+        hostName, &hostEntryStruct, hostEntryBuffer, sizeof (hostEntryBuffer));
+
+    if (hostEntry)
+    {
+        strncpy(hostName, hostEntry->h_name, sizeof(hostName) - 1);
+    }
+    return String(hostName);
+
+#endif
+}
+
+String System::getFullyQualifiedHostName()
+{
+    static String _hostname;
+    static MutexType _mutex = PEGASUS_MUTEX_INITIALIZER;
+
+    // Use double-checked locking pattern to avoid overhead of
+    // mutex on subsequent calls.
+
+    if (0 == _hostname.size())
+    {
+        mutex_lock(&_mutex);
+
+        if (0 == _hostname.size())
+        {
+            try
+            {
+                _hostname = _getFullyQualifiedHostName();
+            }
+            catch (...)
+            {
+                mutex_unlock(&_mutex);
+                throw;
+            }
+        }
+
+        mutex_unlock(&_mutex);
+    }
+
+    return _hostname;
+}
+
 Boolean System::getHostIP(const String &hostName, int *af, String &hostIP)
 {
 #ifdef PEGASUS_ENABLE_IPV6
@@ -192,12 +310,12 @@ Boolean System::getHostIP(const String &hostName, int *af, String &hostIP)
     // Check for valid IPV4 address, if found return ipv4 address
     *af = AF_INET;
     hints.ai_family = *af;
-    hints.ai_protocol = IPPROTO_TCP;   
+    hints.ai_protocol = IPPROTO_TCP;
     hints.ai_socktype = SOCK_STREAM;
     if (!getAddrInfo(hostName.getCString(), 0, &hints, &info))
     {
         char ipAddress[PEGASUS_INET_ADDRSTR_LEN];
-        HostAddress::convertBinaryToText(info->ai_family, 
+        HostAddress::convertBinaryToText(info->ai_family,
             &(reinterpret_cast<struct sockaddr_in*>(info->ai_addr))->sin_addr,
             ipAddress,
             PEGASUS_INET_ADDRSTR_LEN);
@@ -206,7 +324,7 @@ Boolean System::getHostIP(const String &hostName, int *af, String &hostIP)
         return true;
     }
 
-    // Check for valid IPV6 Address. 
+    // Check for valid IPV6 Address.
     *af = AF_INET6;
     hints.ai_family = *af;
     hints.ai_protocol = IPPROTO_TCP;
@@ -234,7 +352,7 @@ Boolean System::getHostIP(const String &hostName, int *af, String &hostIP)
 
     char hostEntryBuffer[8192];
     struct hostent hostEntryStruct;
-    hostEntry = getHostByName(hostNamePtr, &hostEntryStruct, 
+    hostEntry = getHostByName(hostNamePtr, &hostEntryStruct,
         hostEntryBuffer, sizeof (hostEntryBuffer));
 
     if (hostEntry)
@@ -301,7 +419,7 @@ Boolean System::isIPv6StackActive()
 // ------------------------------------------------------------------------
 // Convert a hostname into a a single host unique integer representation
 // ------------------------------------------------------------------------
-Boolean System::_acquireIP(const char* hostname, int *af, void *dst)
+Boolean System::acquireIP(const char* hostname, int *af, void *dst)
 {
 #ifdef PEGASUS_ENABLE_IPV6
     String ipAddress;
@@ -314,7 +432,11 @@ Boolean System::_acquireIP(const char* hostname, int *af, void *dst)
 #else
     *af = AF_INET;
     Uint32 ip = 0xFFFFFFFF;
-    if (!hostname) return 0xFFFFFFFF;
+    if (!hostname)
+    {
+        *af = 0xFFFFFFFF;
+        return false;
+    }
 
 ////////////////////////////////////////////////////////////////////////////////
 // This code used to check if the first character of "hostname" was alphabetic
@@ -339,7 +461,7 @@ Boolean System::_acquireIP(const char* hostname, int *af, void *dst)
     {
         char hostEntryBuffer[8192];
         struct hostent hostEntryStruct;
-        hostEntry = getHostByName(hostname, &hostEntryStruct, 
+        hostEntry = getHostByName(hostname, &hostEntryStruct,
             hostEntryBuffer, sizeof (hostEntryBuffer));
 
         if (!hostEntry)
@@ -366,8 +488,8 @@ Boolean System::_acquireIP(const char* hostname, int *af, void *dst)
         // those it fits all platforms
         char hostEntryBuffer[8192];
         struct hostent hostEntryStruct;
-        hostEntry = 
-            getHostByAddr((const char*) &tmp_addr, sizeof(tmp_addr), AF_INET, 
+        hostEntry =
+            getHostByAddr((const char*) &tmp_addr, sizeof(tmp_addr), AF_INET,
                 &hostEntryStruct, hostEntryBuffer, sizeof (hostEntryBuffer));
 
         if (hostEntry == 0)
@@ -407,7 +529,7 @@ Boolean System::resolveHostNameAtDNS(
     // takes to answer
     char hostEntryBuffer[8192];
     struct hostent hostEntryStruct;
-    hostEntry = getHostByName(hostname, &hostEntryStruct, 
+    hostEntry = getHostByName(hostname, &hostEntryStruct,
         hostEntryBuffer, sizeof (hostEntryBuffer));
 
     if (hostEntry == 0)
@@ -435,7 +557,7 @@ Boolean System::resolveIPAtDNS(Uint32 ip_addr, Uint32 * resolvedIP)
     struct hostent *entry;
 
     entry = getHostByAddr((const char *) &ip_addr, sizeof(ip_addr), AF_INET);
-    
+
     if (entry == 0)
     {
         // error, couldn't resolve the ip
@@ -470,8 +592,12 @@ Boolean System::isLoopBack(int af, void *binIPAddress)
             return !memcmp(&ip6, binIPAddress, sizeof (ip6));
 #endif
         case AF_INET:
-            Uint32 n = ntohl( *(Uint32*)binIPAddress);
-            return !memcmp(&ip4, &n, sizeof (ip4));       
+        {
+            Uint32 tmp;
+            memcpy(&tmp, binIPAddress, sizeof(Uint32));
+            Uint32 n = ntohl(tmp);
+            return !memcmp(&ip4, &n, sizeof (ip4));
+        }
     }
 
     return false;
@@ -506,7 +632,7 @@ Boolean System::isLocalHost(const String &hostName)
         }
 
         res2 = res2root;
-        while (res2) 
+        while (res2)
         {
             if (!memcmp(
                     &(reinterpret_cast<struct sockaddr_in*>(res1->ai_addr))->
@@ -521,7 +647,7 @@ Boolean System::isLocalHost(const String &hostName)
             res2 = res2->ai_next;
         }
         res1 = res1->ai_next;
-    }   
+    }
     if (res1root)
     {
         freeaddrinfo(res1root);
@@ -533,7 +659,7 @@ Boolean System::isLocalHost(const String &hostName)
     if (isLocal)
     {
         return true;
-    } 
+    }
 
     hints.ai_family = AF_INET6;
     res1root = res2root = 0;
@@ -623,7 +749,7 @@ Boolean System::isLocalHost(const String &hostName)
         if (String::equalNoCase(hostName,String("localhost"))) return true;
         char localHostName[PEGASUS_MAXHOSTNAMELEN];
         CString cstringLocalHostName = System::getHostName().getCString();
-        strcpy(localHostName, (const char*) cstringLocalHostName); 
+        strcpy(localHostName, (const char*) cstringLocalHostName);
         // given hostname equals what system returns as local hostname ?
         if (String::equalNoCase(hostName,localHostName)) return true;
         Uint32 hostIP;
@@ -666,9 +792,9 @@ Boolean System::isLocalHost(const String &hostName)
 }
 
 struct hostent* System::getHostByName(
-    const char* name, 
-    struct hostent* he, 
-    char* buf, 
+    const char* name,
+    struct hostent* he,
+    char* buf,
     size_t len)
 {
     int hostEntryErrno = 0;
@@ -678,17 +804,17 @@ struct hostent* System::getHostByName(
     do
     {
 #if defined(PEGASUS_OS_LINUX)
-        gethostbyname_r(name, 
-            he, 
-            buf, 
-            len, 
-            &hostEntry, 
+        gethostbyname_r(name,
+            he,
+            buf,
+            len,
+            &hostEntry,
             &hostEntryErrno);
 #elif defined(PEGASUS_OS_SOLARIS)
-        hostEntry = gethostbyname_r((char *)name, 
-                        he, 
-                        buf, 
-                        len, 
+        hostEntry = gethostbyname_r((char *)name,
+                        he,
+                        buf,
+                        len,
                         &hostEntryErrno);
 #elif defined(PEGASUS_OS_ZOS)
         char hostName[PEGASUS_MAXHOSTNAMELEN + 1];
@@ -714,11 +840,11 @@ struct hostent* System::getHostByName(
 }
 
 struct hostent* System::getHostByAddr(
-    const char *addr, 
-    int len, 
+    const char *addr,
+    int len,
     int type,
-    struct hostent* he, 
-    char* buf, 
+    struct hostent* he,
+    char* buf,
     size_t buflen)
 {
     int hostEntryErrno = 0;
@@ -728,28 +854,28 @@ struct hostent* System::getHostByAddr(
     do
     {
 #if defined(PEGASUS_OS_LINUX)
-        gethostbyaddr_r(addr, 
-            len, 
-            type, 
-            he, 
-            buf, 
-            buflen, 
-            &hostEntry, 
+        gethostbyaddr_r(addr,
+            len,
+            type,
+            he,
+            buf,
+            buflen,
+            &hostEntry,
             &hostEntryErrno);
 #elif defined(PEGASUS_OS_SOLARIS)
         char hostEntryBuffer[8192];
         struct hostent hostEntryStruct;
 
-        hostEntry = gethostbyaddr_r(addr, 
-                        len, 
-                        type, 
-                        he, 
-                        buf, 
-                        buflen, 
+        hostEntry = gethostbyaddr_r(addr,
+                        len,
+                        type,
+                        he,
+                        buf,
+                        buflen,
                         &hostEntryErrno);
 #else
-        hostEntry = gethostbyaddr(addr, 
-                        len, 
+        hostEntry = gethostbyaddr(addr,
+                        len,
                         type);
         hostEntryErrno = h_errno;
 #endif
@@ -764,17 +890,26 @@ struct hostent* System::getHostByAddr(
     defined(PEGASUS_ENABLE_IPV6)
 
 int System::getAddrInfo(
-    const char *hostname, 
+    const char *hostname,
     const char *servname,
-    const struct addrinfo *hints, 
+    const struct addrinfo *hints,
     struct addrinfo **res)
 {
     int rc = 0;
-    unsigned int maxTries = 5; 
+    unsigned int maxTries = 5;
 
-    while ((rc = getaddrinfo(hostname, 
-                     servname, 
-                     hints, 
+#ifdef PEGASUS_OS_PASE
+    CString hostNameCString;
+    if (String::equalNoCase(hostname, "localhost"))
+    {
+        hostNameCString = getHostName().getCString();
+        hostname = (const char*)hostNameCString;
+    }
+#endif
+
+    while ((rc = getaddrinfo(hostname,
+                     servname,
+                     hints,
                      res)) == EAI_AGAIN &&
            maxTries-- > 0)
         ;
@@ -782,23 +917,23 @@ int System::getAddrInfo(
 }
 
 int System::getNameInfo(
-    const struct sockaddr *sa, 
+    const struct sockaddr *sa,
     size_t salen,
-    char *host, 
-    size_t hostlen, 
-    char *serv, 
-    size_t servlen, 
+    char *host,
+    size_t hostlen,
+    char *serv,
+    size_t servlen,
     int flags)
 {
     int rc = 0;
-    unsigned int maxTries = 5; 
+    unsigned int maxTries = 5;
 
-    while ((rc = getnameinfo(sa, 
-                     salen, 
-                     host, 
-                     hostlen, 
-                     serv, 
-                     servlen, 
+    while ((rc = getnameinfo(sa,
+                     salen,
+                     host,
+                     hostlen,
+                     serv,
+                     servlen,
                      flags)) == EAI_AGAIN &&
            maxTries-- > 0)
         ;
