@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -106,9 +104,9 @@ class PEGASUS_COMMON_LINKAGE System
 {
 public:
 
-    /* Creates a String object containing the system message 
-       from  the errno and if supported from a second level error 
-       number. The _NLS Method is looking up an internationalized version of 
+    /* Creates a String object containing the system message
+       from  the errno and if supported from a second level error
+       number. The _NLS Method is looking up an internationalized version of
        the message.
         @param errorCode  The system errno.
         @param errorCode2 The secondary error number like errno2 on z/OS
@@ -160,6 +158,17 @@ public:
 
     static Boolean removeFile(const char* path);
 
+    /**
+        Renames a file.  If the new name refers to an existing file, it is
+        removed and replaced with the renamed file.  The rename operation is
+        performed atomically.
+        @param oldPath A character string containing the name of the file to
+            rename.
+        @param newPath A character string containing the name to which to
+            rename the file.
+        @return A Boolean indicating whether the rename operation was
+            successful.
+    */
     static Boolean renameFile(const char* oldPath, const char* newPath);
 
     static Boolean copyFile(const char* fromPath, const char* toPath);
@@ -168,45 +177,45 @@ public:
     static String getFullyQualifiedHostName ();
     static String getSystemCreationClassName ();
 
-    // The following 2 methods are wrappers around system functions 
+    // The following 2 methods are wrappers around system functions
     // gethostbyname/gethostbyaddr or gethostbyname_r/gethostbyaddr_r.
     // In addition to calling corresponding system functions, these
     // methods introduce re-tries when errno is set to TRY_AGAIN.
     // Optional parameters are required to cover systems which use '_r'
     // versions of the system functions.
     static struct hostent* getHostByName(
-        const char* name, 
-        struct hostent* he = 0, 
-        char* buf = 0, 
+        const char* name,
+        struct hostent* he = 0,
+        char* buf = 0,
         size_t len = 0);
     static struct hostent* getHostByAddr(
-        const char *addr, 
-        int len, 
+        const char *addr,
+        int len,
         int type,
-        struct hostent* he = 0, 
-        char* buf = 0, 
+        struct hostent* he = 0,
+        char* buf = 0,
         size_t buflen = 0);
 
 #if defined(PEGASUS_OS_ZOS) || \
     defined(PEGASUS_OS_VMS) || \
     defined(PEGASUS_ENABLE_IPV6)
 
-    // The following 2 methods are wrappers around system functions 
-    // getaddrinfo/getnameinfo. 
+    // The following 2 methods are wrappers around system functions
+    // getaddrinfo/getnameinfo.
     // In addition to calling corresponding system functions, these
     // methods introduce re-tries on EAI_AGAIN error returns.
     static int getAddrInfo(
-        const char *hostname, 
+        const char *hostname,
         const char *servname,
-        const struct addrinfo *hints, 
+        const struct addrinfo *hints,
         struct addrinfo **res);
     static int getNameInfo(
-        const struct sockaddr *sa, 
+        const struct sockaddr *sa,
         size_t salen,
-        char *host, 
-        size_t hostlen, 
-        char *serv, 
-        size_t servlen, 
+        char *host,
+        size_t hostlen,
+        char *serv,
+        size_t servlen,
         int flags);
 
 #endif
@@ -217,13 +226,13 @@ public:
 
     // Gets IP address in binary form. af indicates the type of
     // address (ipv4 or ipv6) returned. Address will be copied to dst.
-    static Boolean _acquireIP(const char* hostname, int *af, void *dst);
+    static Boolean acquireIP(const char* hostname, int *af, void *dst);
 
     /**
         Returns true if IPv6 stack is active by checking return code from
         Socket::createSocket() and getSocketError() calls.
 
-        ATTN: We return true if some error other than 
+        ATTN: We return true if some error other than
         PEGASUS_INVALID_ADDRESS_FAMILY is returned while creating the socket
         because we will not be sure whether the IPv6 stack is active or not
         from the returned error code. Return value of "true" from this method
