@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
 //
-//==============================================================================
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -162,44 +160,13 @@ Boolean System::removeFile(const char* path)
 
 Boolean System::renameFile(const char* oldPath, const char* newPath)
 {
+    if (exists(oldPath))
+    {
+        removeFile(newPath);
+    }
     return rename(oldPath, newPath) == 0;
 }
 
-String System::getHostName()
-{
-    static String _hostname;
-    if (0 == _hostname.size())
-    {
-        char hostname[PEGASUS_MAXHOSTNAMELEN + 1];
-        //initialize the buffer to handle the case where gethostname fails.
-        hostname[0] = 0;
-        gethostname(hostname, sizeof(hostname));
-        hostname[sizeof(hostname)-1] = 0;
-        _hostname.assign(hostname);
-    }
-    return _hostname;
-}
-
-String System::getFullyQualifiedHostName ()
-{
-    static char FQHostName[PEGASUS_MAXHOSTNAMELEN + 1];
-
-    if (!*FQHostName)
-    {
-        String hostname = getHostName();
-        struct hostent* hostEnt;
-
-        hostEnt = getHostByName((const char *)hostname.getCString());
-        if (hostEnt == NULL)
-        {
-            return String::EMPTY;
-        }
-        strncpy(FQHostName, hostEnt->h_name, sizeof(FQHostName)-1);
-    }
-
-    return FQHostName;
-}
-
 String System::getSystemCreationClassName ()
 {
     return "CIM_ComputerSystem";
@@ -934,66 +901,6 @@ void System::closelog()
     // Not implemented
 }
 
-#ifdef PEGASUS_ENABLE_IPV6
-void _getInterfaceAddrs(Array<String> &ips, int af)
-{
-    SOCKET sock;
-
-    if (INVALID_SOCKET != (sock = WSASocket(af, SOCK_RAW,
-        0, NULL, 0, 0)))
-    {
-        DWORD  bytesReturned;
-        char buf[2048];
-        int interfaces = 0;
-        char str[PEGASUS_INET6_ADDRSTR_LEN];
-        void *p;
-        if (0 == WSAIoctl(sock, SIO_ADDRESS_LIST_QUERY, NULL, 0,
-            buf, 2048, &bytesReturned, NULL,
-            NULL))
-        {
-
-            SOCKET_ADDRESS_LIST *addr_list;
-            SOCKET_ADDRESS *addr;
-            struct sockaddr *sin;
-            addr_list = (SOCKET_ADDRESS_LIST *)buf;
-            addr = addr_list->Address;
-            for (sin = (struct sockaddr *) addr->lpSockaddr ;
-                interfaces < addr_list->iAddressCount;
-                interfaces++)
-            {
-                if (af == AF_INET)
-                {
-                    p = &((struct sockaddr_in*)sin)->sin_addr;
-                }
-                else
-                {
-                    p = &((struct sockaddr_in6*)sin)->sin6_addr;
-                }
-                // Don't gather loopback addrs
-                if (!System::isLoopBack(af, p))
-                {
-                    HostAddress::convertBinaryToText(af, p, str, sizeof(str));
-                    ips.append(str);
-                }
-                addr++;
-                sin = (struct sockaddr*)addr->lpSockaddr;
-            }
-        }
-    }
-}
-#endif
-
-Array<String> System::getInterfaceAddrs()
-{
-    Array<String> ips;
-
-#ifdef PEGASUS_ENABLE_IPV6
-    _getInterfaceAddrs(ips, AF_INET);
-    _getInterfaceAddrs(ips, AF_INET6);
-#endif
-
-    return ips;
-}
 
 
 // System ID constants for Logger::put and Logger::trace
@@ -1057,6 +964,67 @@ Boolean System::isIpOnNetworkInterface(Uint32 inIP)
     return false;
 }
 
+#ifdef PEGASUS_ENABLE_IPV6
+void _getInterfaceAddrs(Array<String> &ips, int af)
+{
+    SOCKET sock;
+
+    if (INVALID_SOCKET != (sock = WSASocket(af, SOCK_RAW,
+        0, NULL, 0, 0)))
+    {
+        DWORD  bytesReturned;
+        char buf[2048];
+        int interfaces = 0;
+        char str[PEGASUS_INET6_ADDRSTR_LEN];
+        void *p;
+        if (0 == WSAIoctl(sock, SIO_ADDRESS_LIST_QUERY, NULL, 0,
+            buf, 2048, &bytesReturned, NULL,
+            NULL))
+        {
+
+            SOCKET_ADDRESS_LIST *addr_list;
+            SOCKET_ADDRESS *addr;
+            struct sockaddr *sin;
+            addr_list = (SOCKET_ADDRESS_LIST *)buf;
+            addr = addr_list->Address;
+            for (sin = (struct sockaddr *) addr->lpSockaddr ;
+                interfaces < addr_list->iAddressCount;
+                interfaces++)
+            {
+                if (af == AF_INET)
+                {
+                    p = &((struct sockaddr_in*)sin)->sin_addr;
+                }
+                else
+                {
+                    p = &((struct sockaddr_in6*)sin)->sin6_addr;
+                }
+                // Don't gather loopback addrs
+                if (!System::isLoopBack(af, p))
+                {
+                    HostAddress::convertBinaryToText(af, p, str, sizeof(str));
+                    ips.append(str);
+                }
+                addr++;
+                sin = (struct sockaddr*)addr->lpSockaddr;
+            }
+        }
+    }
+}
+#endif
+
+Array<String> System::getInterfaceAddrs()
+{
+    Array<String> ips;
+
+#ifdef PEGASUS_ENABLE_IPV6
+    _getInterfaceAddrs(ips, AF_INET);
+    _getInterfaceAddrs(ips, AF_INET6);
+#endif
+
+    return ips;
+}
+
 String System::getErrorMSG_NLS(int errorCode,int errorCode2)
 {
     LPVOID winErrorMsg = NULL;
@@ -1065,11 +1033,11 @@ String System::getErrorMSG_NLS(int errorCode,int errorCode2)
             FORMAT_MESSAGE_ALLOCATE_BUFFER |
             FORMAT_MESSAGE_FROM_SYSTEM |
             FORMAT_MESSAGE_IGNORE_INSERTS,
-            NULL, 
+            NULL,
             errorCode,
             MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT),
-            (LPTSTR)&winErrorMsg, 
-            0, 
+            (LPTSTR)&winErrorMsg,
+            0,
             NULL))
     {
         MessageLoaderParms parms(
@@ -1077,7 +1045,7 @@ String System::getErrorMSG_NLS(int errorCode,int errorCode2)
             "$0 (error code $1)",(char*)winErrorMsg,errorCode);
         LocalFree(winErrorMsg);
         return MessageLoader::getMessage(parms);
-    } 
+    }
 
     MessageLoaderParms parms(
         "Common.System.ERROR_MESSAGE.STANDARD",
@@ -1099,11 +1067,11 @@ String System::getErrorMSG(int errorCode,int errorCode2)
             FORMAT_MESSAGE_ALLOCATE_BUFFER |
             FORMAT_MESSAGE_FROM_SYSTEM |
             FORMAT_MESSAGE_IGNORE_INSERTS,
-            NULL, 
+            NULL,
             errorCode,
             MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT),
-            (LPTSTR)&winErrorMsg, 
-            0, 
+            (LPTSTR)&winErrorMsg,
+            0,
             NULL))
     {
         buffer.append((char*)winErrorMsg);
@@ -1117,6 +1085,7 @@ String System::getErrorMSG(int errorCode,int errorCode2)
     return buffer;
 }
 
+
 ///////////////////////////////////////////////////////////////////////////////
 // AutoFileLock class
 ///////////////////////////////////////////////////////////////////////////////
@@ -1136,7 +1105,7 @@ AutoFileLock::AutoFileLock(const char* fileName)
        && (GetLastError() != ERROR_ALREADY_EXISTS)
        && (GetLastError() != ERROR_SUCCESS))
    {
-       PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL2,
+       PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL1,
           "AutoFileLock: Failed to open lock file '%s', error code %d.",
           fileName, GetLastError()));
        return;
@@ -1145,7 +1114,7 @@ AutoFileLock::AutoFileLock(const char* fileName)
    OVERLAPPED l={0,0,0,0,0};
    if(LockFileEx(_hFile,LOCKFILE_EXCLUSIVE_LOCK, 0, 0, 0, &l) == 0)
    {
-       PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL2,
+       PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL1,
            "AutoFileLock: Failed to Acquire lock on file %s, error code %d.",
            fileName, GetLastError()));
        CloseHandle(_hFile);
@@ -1168,4 +1137,5 @@ AutoFileLock::~AutoFileLock()
     }
 }
 
+
 PEGASUS_NAMESPACE_END
