@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -40,6 +38,13 @@
 #if defined(PEGASUS_OS_TYPE_WINDOWS)
 # include <sys/timeb.h>
 #endif
+#if defined(PEGASUS_OS_ZOS)
+# include <unistd.h>
+#endif
+
+#if defined(PEGASUS_OS_SOLARIS)
+# include <unistd.h>
+#endif
 
 PEGASUS_NAMESPACE_BEGIN
 
@@ -78,8 +83,7 @@ void Threads::sleep(int msec)
     }
     while (end.millitm > now.millitm && end.time >= now.time);
 
-#elif defined(PEGASUS_PLATFORM_ZOS_ZSERIES_IBM)
-    int seconds;
+#else
     if (msec < 1000)
     {
         usleep(msec*1000);
@@ -91,6 +95,7 @@ void Threads::sleep(int msec)
         // Usleep the remaining micro seconds
         usleep( (msec*1000) % 1000000 );
     }
+
 #endif
 }
 
@@ -143,6 +148,8 @@ static inline int _get_stack_multiplier()
     return _multiplier;
 #elif defined(PEGASUS_PLATFORM_HPUX_PARISC_ACC)
     return 2;
+#elif defined(PEGASUS_OS_AIX)
+    return 2;
 #else
     return 1;
 #endif
@@ -171,7 +178,7 @@ int Threads::create(
 
     if (type == DETACHED)
     {
-#if defined(PEGASUS_PLATFORM_ZOS_ZSERIES_IBM)
+#if defined(PEGASUS_OS_ZOS)
         int ds = 1;
         pthread_attr_setdetachstate(&attr, &ds);
 #else
@@ -196,14 +203,11 @@ int Threads::create(
 
     // Scheduling policy:
 
-#if defined(PEGASUS_PLATFORM_SOLARIS_SPARC_GNU) || \
-    defined(PEGASUS_PLATFORM_SOLARIS_SPARC_CC)
-# if defined SUNOS_5_7
-    pthread_attr_setschedpolicy(&attr, SCHED_RR);
-# else
+#if defined(PEGASUS_OS_SOLARIS)
+
     pthread_attr_setschedpolicy(&attr, SCHED_OTHER);
-# endif
-#endif // PEGASUS_PLATFORM_SOLARIS_SPARC_GNU
+
+#endif /* defined(PEGASUS_OS_SOLARIS) */
 
     // Create thread:
 
