@@ -1,68 +1,137 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
 #include <Pegasus/Common/Config.h>
+#include <Pegasus/Common/Constants.h>
 #include <Pegasus/Common/Tracer.h>
+#include <Pegasus/Common/TraceFileHandler.h>
+#include <Pegasus/Common/TraceLogHandler.h>
+#include <Pegasus/Common/TraceMemoryHandler.h>
 #include <Pegasus/Common/Thread.h>
 #include <Pegasus/Common/System.h>
 #include <Pegasus/Common/HTTPMessage.h>
+#include <Pegasus/Common/StringConversion.h>
+#include <Pegasus/Common/FileSystem.h>
 
 PEGASUS_USING_STD;
 
 PEGASUS_NAMESPACE_BEGIN
 
+/**
+    String constants for naming the various Trace components.
+    These strings will used when turning on tracing for the respective
+    components.  The component list must be kept in sync with the
+    TraceComponentId enumeration.
+
+    The tracer uses the _traceComponentMask in form of a 64bit field to mask
+    the user configured components.
+    Please ensure that no more than 64 components are specified in the
+    TRACE_COMPONENT_LIST.
+
+    The following example shows the usage of trace component names.
+    The setTraceComponents method is used to turn on tracing for the
+    components: Config and Repository. The component names are passed as a
+    comma separated list.
+
+       Tracer::setTraceComponents("Config,Repository");
+*/
+static char const* TRACE_COMPONENT_LIST[] =
+{
+    "Xml",
+    "XmlIO",
+    "Http",
+    "Repository",
+    "Dispatcher",
+    "OsAbstraction",
+    "Config",
+    "IndicationHandler",
+    "Authentication",
+    "Authorization",
+    "UserManager",
+    "Shutdown",
+    "Server",
+    "IndicationService",
+    "MessageQueueService",
+    "ProviderManager",
+    "ObjectResolution",
+    "WQL",
+    "CQL",
+    "Thread",
+    "CIMExportRequestDispatcher",
+    "SSL",
+    "ControlProvider",
+    "CIMOMHandle",
+    "L10N",
+    "ExportClient",
+    "Listener",
+    "DiscardedData",
+    "ProviderAgent",
+    "IndicationFormatter",
+    "StatisticalData",
+    "CMPIProvider",
+    "IndicationGeneration",
+    "IndicationReceipt",
+    "CMPIProviderInterface",
+    "WsmServer",
+    "LogMessages"
+};
+
+
+// Defines the value values for trace facilities
+// Keep the TRACE_FACILITY_LIST in sync with the TRACE_FACILITY_INDEX,
+// so that the index matches the according string in the list.
+char const* Tracer::TRACE_FACILITY_LIST[] =
+{
+    "File",
+    "Log",
+    "Memory",
+    0
+};
+
+
 // Set the trace levels
 // These levels will be compared against a trace level mask to determine
 // if a specific trace level is enabled
 
+const Uint32 Tracer::LEVEL0 =  0;
 const Uint32 Tracer::LEVEL1 = (1 << 0);
 const Uint32 Tracer::LEVEL2 = (1 << 1);
 const Uint32 Tracer::LEVEL3 = (1 << 2);
 const Uint32 Tracer::LEVEL4 = (1 << 3);
-
-// Set the return codes
-const Boolean Tracer::_SUCCESS = 1;
-const Boolean Tracer::_FAILURE = 0;
+const Uint32 Tracer::LEVEL5 = (1 << 4);
 
 // Set the Enter and Exit messages
 const char Tracer::_METHOD_ENTER_MSG[] = "Entering method";
 const char Tracer::_METHOD_EXIT_MSG[]  = "Exiting method";
 
-// Set Log messages
-const char Tracer::_LOG_MSG[] =
-    "LEVEL1 may only be used with trace macros "
-        "PEG_METHOD_ENTER/PEG_METHOD_EXIT.";
-
 // Initialize singleton instance of Tracer
 Tracer* Tracer::_tracerInstance = 0;
 
@@ -80,7 +149,9 @@ const Uint32 Tracer::_STRLEN_MAX_UNSIGNED_INT = 21;
 const Uint32 Tracer::_STRLEN_MAX_PID_TID = 21;
 
 // Initialize public indicator of trace state
-Boolean Tracer::_traceOn = false;
+Boolean Tracer::_traceOn=false;
+Uint32  Tracer::_traceLevelMask=0;
+Uint64  Tracer::_traceComponentMask=(Uint64)0;
 
 ////////////////////////////////////////////////////////////////////////////////
 // Tracer constructor
@@ -88,13 +159,19 @@ Boolean Tracer::_traceOn = false;
 // Single Instance of Tracer is maintained for each process.
 ////////////////////////////////////////////////////////////////////////////////
 Tracer::Tracer()
-    : _traceComponentMask(new Boolean[_NUM_COMPONENTS]),
-      _traceLevelMask(0),
-      _traceHandler(new TraceFileHandler())
+    : _traceMemoryBufferSize(PEGASUS_TRC_DEFAULT_BUFFER_SIZE_KB),
+      _traceFacility(TRACE_FACILITY_FILE),
+      _runningOOP(false),
+      _traceHandler(0)
 {
-    // Initialize ComponentMask array to false
-    for (Uint32 index=0;index < _NUM_COMPONENTS;
-        (_traceComponentMask.get())[index++]=false);
+
+    // The tracer uses a 64bit field to mask the user configured components.
+    // This assert ensures that no more than 64 components are specified in the
+    // TRACE_COMPONENT_LIST.
+    PEGASUS_ASSERT(_NUM_COMPONENTS <= 64);
+
+    // Instantiate trace handler according to configured facility
+    _setTraceHandler(_traceFacility);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -102,17 +179,92 @@ Tracer::Tracer()
 ////////////////////////////////////////////////////////////////////////////////
 Tracer::~Tracer()
 {
+    delete _traceHandler;
     delete _tracerInstance;
 }
 
 
+////////////////////////////////////////////////////////////////////////////////
+//Factory function for the trace handler instances.
+////////////////////////////////////////////////////////////////////////////////
+void Tracer::_setTraceHandler( Uint32 traceFacility )
+{
+    TraceHandler * oldTrcHandler = _traceHandler;
+
+    switch(traceFacility)
+    {
+        case TRACE_FACILITY_LOG:
+            _traceFacility = TRACE_FACILITY_LOG;
+            _traceHandler = new TraceLogHandler();
+            break;
+
+        case TRACE_FACILITY_MEMORY:
+            _traceFacility = TRACE_FACILITY_MEMORY;
+            _traceHandler = new TraceMemoryHandler();
+            break;
+
+        case TRACE_FACILITY_FILE:
+        default:
+            _traceFacility = TRACE_FACILITY_FILE;
+            _traceHandler = new TraceFileHandler();
+    }
+    delete oldTrcHandler;
+}
+
+////////////////////////////////////////////////////////////////////////////////
+// Validates if a given file path if it is eligible for writing traces.
+////////////////////////////////////////////////////////////////////////////////
+Boolean Tracer::_isValidTraceFile(String fileName)
+{
+    // Check if the file path is a directory
+    FileSystem::translateSlashes(fileName);
+    if (FileSystem::isDirectory(fileName))
+    {
+        return false;
+    }
+
+    // Check if the file exists and is writable
+    if (FileSystem::exists(fileName))
+    {
+        return FileSystem::canWrite(fileName);
+    }
+
+    // Check if directory is writable
+    Uint32 index = fileName.reverseFind('/');
+
+    if (index != PEG_NOT_FOUND)
+    {
+        String dirName = fileName.subString(0,index);
+
+        if (dirName.size() == 0)
+        {
+            dirName = "/";
+        }
+
+        if (!FileSystem::isDirectory(dirName))
+        {
+            return false;
+        }
+
+        return FileSystem::canWrite(dirName);
+    }
+
+    String currentDir;
+
+    // Check if there is permission to write in the
+    // current working directory
+    FileSystem::getCurrentDirectory(currentDir);
+
+    return FileSystem::canWrite(currentDir);
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 //Traces the given message - Overloaded for including FileName and Line number
 ////////////////////////////////////////////////////////////////////////////////
 void Tracer::_trace(
     const char* fileName,
     const Uint32 lineNum,
-    const Uint32 traceComponent,
+    const TraceComponentId traceComponent,
     const char* fmt,
     va_list argList)
 {
@@ -125,7 +277,7 @@ void Tracer::_trace(
         _STRLEN_MAX_UNSIGNED_INT + (_STRLEN_MAX_PID_TID * 2) + 8];
     sprintf(
        message,
-       "[%d:%s:%s:%u]: ",
+       "[%u:%s:%s:%u]: ",
        System::getPID(),
        Threads::id().buffer,
        fileName,
@@ -139,9 +291,9 @@ void Tracer::_trace(
 //Traces the message in the given CIMException object.
 ////////////////////////////////////////////////////////////////////////////////
 void Tracer::_traceCIMException(
-    const Uint32 traceComponent,
+    const TraceComponentId traceComponent,
     const CIMException& cimException)
-{        
+{
     // get the CIMException trace message string
     CString traceMsg =
         TraceableCIMException(cimException).getTraceDescription().getCString();
@@ -177,8 +329,8 @@ SharedArrayPtr<char> Tracer::getHTTPRequestMessage(
         {
             // Suppress the user/passwd info
             HTTPMessage::skipHeaderWhitespace(line);
-            for ( char* userpass = (char*)line ; 
-                userpass < sep; 
+            for ( char* userpass = (char*)line ;
+                userpass < sep;
                 *userpass = 'X', userpass++);
 
             break;
@@ -196,7 +348,7 @@ SharedArrayPtr<char> Tracer::getHTTPRequestMessage(
 void Tracer::_traceMethod(
     const char* fileName,
     const Uint32 lineNum,
-    const Uint32 traceComponent,
+    const TraceComponentId traceComponent,
     const char* methodEntryExit,
     const char* method)
 {
@@ -209,55 +361,39 @@ void Tracer::_traceMethod(
     // assume Method entry/exit string 15 characters long
     // +1 space character
     message = new char[ strlen(fileName) +
-        _STRLEN_MAX_UNSIGNED_INT + (_STRLEN_MAX_PID_TID * 2) + 8 
+        _STRLEN_MAX_UNSIGNED_INT + (_STRLEN_MAX_PID_TID * 2) + 8
         + 16];
 
     sprintf(
        message,
-       "[%d:%s:%s:%u]: %s ",
+       "[%u:%s:%s:%u]: %s ",
        System::getPID(),
        Threads::id().buffer,
        fileName,
        lineNum,
        methodEntryExit);
-        
+
     _traceCString(traceComponent, message, method);
 
     delete [] message;
 }
 
-
-////////////////////////////////////////////////////////////////////////////////
-//Checks if trace is enabled for the given component and level
-////////////////////////////////////////////////////////////////////////////////
-Boolean Tracer::isTraceEnabled(
-    const Uint32 traceComponent,
-    const Uint32 traceLevel)
-{
-    Tracer* instance = _getInstance();
-    if (traceComponent >= _NUM_COMPONENTS)
-    {
-        return false;
-    }
-    return (((instance->_traceComponentMask.get())[traceComponent]) &&
-            (traceLevel & instance->_traceLevelMask));
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 //Called by all trace interfaces with variable arguments
 //to log message to trace file
 ////////////////////////////////////////////////////////////////////////////////
 void Tracer::_trace(
-    const Uint32 traceComponent,
+    const TraceComponentId traceComponent,
     const char* message,
     const char* fmt,
     va_list argList)
 {
     char* msgHeader;
+    Uint32 msgLen;
+    Uint32 usec,sec;
 
     // Get the current system time and prepend to message
-    String currentTime = System::getCurrentASCIITime();
-    CString timeStamp = currentTime.getCString();
+    System::getCurrentTimeUsec(sec,usec);
 
     //
     // Allocate messageHeader.
@@ -267,42 +403,36 @@ void Tracer::_trace(
     // Construct the message header
     // The message header is in the following format
     // timestamp: <component name> [file name:line number]
+    //
+    // Format string length calculation:
+    //        11(sec)+ 2('s-')+11(usec)+4('us: ')+1(' ')+1(\0) = 30
     if (*message != '\0')
     {
-       // << Wed Jul 16 10:58:40 2003 mdd >> _STRLEN_MAX_PID_TID is not used
-       // in this format string
        msgHeader = new char [strlen(message) +
-           strlen(TRACE_COMPONENT_LIST[traceComponent]) +
-           strlen(timeStamp) + _STRLEN_MAX_PID_TID + 5];
+           strlen(TRACE_COMPONENT_LIST[traceComponent]) + 30];
 
-        sprintf(msgHeader, "%s: %s %s", (const char*)timeStamp,
+        msgLen = sprintf(msgHeader, "%us-%uus: %s %s", sec, usec,
             TRACE_COMPONENT_LIST[traceComponent], message);
     }
     else
     {
-        //
-        // Since the message is blank, form a string using the pid and tid
-        //
-        char* tmpBuffer;
-
         //
         // Allocate messageHeader.
         // Needs to be updated if additional info is added
         //
-        tmpBuffer = new char[2 * _STRLEN_MAX_PID_TID + 6];
-        sprintf(tmpBuffer, "[%u:%s]: ",
-            System::getPID(), Threads::id().buffer);
-        msgHeader = new char[strlen(timeStamp) +
-            strlen(TRACE_COMPONENT_LIST[traceComponent]) +
-            strlen(tmpBuffer) + 1  + 5];
+        // Format string length calculation:
+        //        11(sec)+2('s-')+11(usec)+4('us: ')+
+        //        +2(' [')+1(':')+3(']: ')+1(\0) = 35
+        msgHeader = new char[2 * _STRLEN_MAX_PID_TID +
+            strlen(TRACE_COMPONENT_LIST[traceComponent]) + 35];
 
-        sprintf(msgHeader, "%s: %s %s ", (const char*)timeStamp,
-            TRACE_COMPONENT_LIST[traceComponent], tmpBuffer);
-        delete [] tmpBuffer;
+        msgLen = sprintf(msgHeader, "%us-%uus: %s [%u:%s]: ", sec, usec,
+            TRACE_COMPONENT_LIST[traceComponent],
+            System::getPID(), Threads::id().buffer);
     }
 
     // Call trace file handler to write message
-    _getInstance()->_traceHandler->handleMessage(msgHeader,fmt,argList);
+    _getInstance()->_traceHandler->handleMessage(msgHeader,msgLen,fmt,argList);
 
     delete [] msgHeader;
 }
@@ -312,15 +442,17 @@ void Tracer::_trace(
 //to log message to trace file
 ////////////////////////////////////////////////////////////////////////////////
 void Tracer::_traceCString(
-    const Uint32 traceComponent,
+    const TraceComponentId traceComponent,
     const char* message,
     const char* cstring)
 {
     char* completeMessage;
+    Uint32 msgLen;
+    Uint32 usec,sec;
 
     // Get the current system time and prepend to message
-    String currentTime = System::getCurrentASCIITime();
-    CString timeStamp = currentTime.getCString();
+    System::getCurrentTimeUsec(sec,usec);
+
     //
     // Allocate completeMessage.
     // Needs to be updated if additional info is added
@@ -329,16 +461,16 @@ void Tracer::_traceCString(
     // Construct the message header
     // The message header is in the following format
     // timestamp: <component name> [file name:line number]
+    //
+    // Format string length calculation:
+    //        11(sec)+ 2('s-')+11(usec)+4('us: ')+1(' ')+1(\0) = 30
     if (*message != '\0')
     {
-       // << Wed Jul 16 10:58:40 2003 mdd >> _STRLEN_MAX_PID_TID is not used
-       // in this format string
        completeMessage = new char [strlen(message) +
            strlen(TRACE_COMPONENT_LIST[traceComponent]) +
-           strlen(timeStamp) + _STRLEN_MAX_PID_TID + 5 +
-           strlen(cstring) ];
+           strlen(cstring) + 30];
 
-        sprintf(completeMessage, "%s: %s %s%s", (const char*)timeStamp,
+        msgLen = sprintf(completeMessage, "%us-%uus: %s %s%s", sec, usec,
             TRACE_COMPONENT_LIST[traceComponent], message, cstring);
     }
     else
@@ -352,22 +484,21 @@ void Tracer::_traceCString(
         // Allocate messageHeader.
         // Needs to be updated if additional info is added
         //
-        tmpBuffer = new char[2 * _STRLEN_MAX_PID_TID + 6];
-        sprintf(tmpBuffer, "[%u:%s]: ",
-            System::getPID(), Threads::id().buffer);
-
-        completeMessage = new char[strlen(timeStamp) +
+        // Format string length calculation:
+        //        11(sec)+2('s-')+11(usec)+4('us: ')+
+        //        +2(' [')+1(':')+3(']: ')+1(\0) = 35
+        completeMessage = new char[2 * _STRLEN_MAX_PID_TID +
             strlen(TRACE_COMPONENT_LIST[traceComponent]) +
-            strlen(tmpBuffer) + 1  + 5 +
-            strlen(cstring)];
+            strlen(cstring) +35];
 
-        sprintf(completeMessage, "%s: %s %s %s", (const char*)timeStamp,
-            TRACE_COMPONENT_LIST[traceComponent], tmpBuffer, cstring);
-        delete [] tmpBuffer;
+        msgLen = sprintf(completeMessage, "%us-%uus: %s [%u:%s] %s", sec, usec,
+            TRACE_COMPONENT_LIST[traceComponent],
+            System::getPID(), Threads::id().buffer,
+            cstring);
     }
 
     // Call trace file handler to write message
-    _getInstance()->_traceHandler->handleMessage(completeMessage);
+    _getInstance()->_traceHandler->handleMessage(completeMessage,msgLen);
 
     delete [] completeMessage;
 }
@@ -378,17 +509,16 @@ void Tracer::_traceCString(
 ////////////////////////////////////////////////////////////////////////////////
 Boolean Tracer::isValidFileName(const char* filePath)
 {
-    String moduleName = _getInstance()->_moduleName;
-    if (moduleName == String::EMPTY)
+    Tracer* instance = _getInstance();
+    String testTraceFile(filePath);
+
+    if (instance->_runningOOP)
     {
-        return _getInstance()->_traceHandler->isValidFilePath(filePath);
-    }
-    else
-    {
-        String extendedFilePath = String(filePath) + "." + moduleName;
-        return _getInstance()->_traceHandler->isValidFilePath(
-            extendedFilePath.getCString());
+        testTraceFile.append(".");
+        testTraceFile.append(instance->_oopTraceFileExtension);
     }
+
+    return _isValidTraceFile(testTraceFile);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -422,7 +552,7 @@ Boolean Tracer::isValidComponents(
         // Check if ALL is specified
         if (String::equalNoCase(componentStr,"ALL"))
         {
-            return _SUCCESS;
+            return true;
         }
 
         // Append _COMPONENT_SEPARATOR to the end of the traceComponents
@@ -469,7 +599,7 @@ Boolean Tracer::isValidComponents(
     else
     {
         // trace components is empty, it is a valid value so return true
-        return _SUCCESS;
+        return true;
     }
 
     if (invalidComponents != String::EMPTY)
@@ -485,11 +615,40 @@ Boolean Tracer::isValidComponents(
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-//Set the name of the module being traced
+//Validate the trace facility
 ////////////////////////////////////////////////////////////////////////////////
-void Tracer::setModuleName(const String& moduleName)
+Boolean Tracer::isValidTraceFacility(const String& traceFacility)
 {
-    _getInstance()->_moduleName = moduleName;
+    Boolean retCode = false;
+
+    if (traceFacility.size() != 0)
+    {
+        Uint32 index = 0;
+        while (TRACE_FACILITY_LIST[index] != 0 )
+        {
+            if (String::equalNoCase(traceFacility,TRACE_FACILITY_LIST[index]))
+            {
+                retCode = true;
+                break;
+            }
+            index++;
+        }
+    }
+
+    return retCode;
+}
+
+////////////////////////////////////////////////////////////////////////////////
+// Notify the trare running out of process and provide the trace file extension
+// for the out of process trace file.
+////////////////////////////////////////////////////////////////////////////////
+void Tracer::setOOPTraceFileExtension(const String& oopTraceFileExtension)
+{
+    Tracer* instance = _getInstance();
+    instance->_oopTraceFileExtension = oopTraceFileExtension;
+    instance->_runningOOP=true;
+    instance->_traceMemoryBufferSize /= PEGASUS_TRC_BUFFER_OOP_SIZE_DEVISOR;
+
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -521,17 +680,28 @@ Uint32 Tracer::setTraceFile(const char* traceFile)
         return 1;
     }
 
-    String moduleName = _getInstance()->_moduleName;
-    if (moduleName == String::EMPTY)
+    Tracer* instance = _getInstance();
+    String newTraceFile(traceFile);
+
+    if (instance->_runningOOP)
     {
-        return _getInstance()->_traceHandler->setFileName(traceFile);
+        newTraceFile.append(".");
+        newTraceFile.append(instance->_oopTraceFileExtension);
+    }
+
+    if (_isValidTraceFile(newTraceFile))
+    {
+        instance->_traceFile = newTraceFile;
+        instance->_traceHandler->configurationUpdated();
     }
     else
     {
-        String extendedTraceFile = String(traceFile) + "." + moduleName;
-        return _getInstance()->_traceHandler->setFileName(
-            extendedTraceFile.getCString());
+        return 1;
     }
+
+
+    return 0;
+
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -543,26 +713,39 @@ Uint32 Tracer::setTraceLevel(const Uint32 traceLevel)
 
     switch (traceLevel)
     {
+        case LEVEL0:
+            _traceLevelMask = 0x00;
+            break;
+
         case LEVEL1:
-            _getInstance()->_traceLevelMask = 0x01;
+            _traceLevelMask = 0x01;
             break;
 
         case LEVEL2:
-            _getInstance()->_traceLevelMask = 0x03;
+            _traceLevelMask = 0x03;
             break;
 
         case LEVEL3:
-            _getInstance()->_traceLevelMask = 0x07;
+            _traceLevelMask = 0x07;
             break;
 
         case LEVEL4:
-            _getInstance()->_traceLevelMask = 0x0F;
+            _traceLevelMask = 0x0F;
+            break;
+
+        case LEVEL5:
+            _traceLevelMask = 0x1F;
             break;
 
         default:
-            _getInstance()->_traceLevelMask = 0;
+            _traceLevelMask = 0x00;
             retCode = 1;
     }
+
+    // If one of the components was set for tracing and the traceLevel
+    // is not zero, then turn on tracing.
+    _traceOn=((_traceComponentMask!=(Uint64)0)&&(_traceLevelMask!=LEVEL0));
+
     return retCode;
 }
 
@@ -571,31 +754,30 @@ Uint32 Tracer::setTraceLevel(const Uint32 traceLevel)
 ////////////////////////////////////////////////////////////////////////////////
 void Tracer::setTraceComponents(const String& traceComponents)
 {
-    Uint32 position          = 0;
-    Uint32 index             = 0;
-    String componentName;
-    String componentStr      = traceComponents;
-    String invalidComponents;
-
-    if (componentStr != String::EMPTY)
+    // Check if ALL is specified
+    if (String::equalNoCase(traceComponents,"ALL"))
     {
-        // Check if ALL is specified
-        if (String::equalNoCase(componentStr,"ALL"))
-        {
-            for (index = 0; index < _NUM_COMPONENTS; index++)
-            {
-                (_getInstance()->_traceComponentMask.get())[index] = true;
-            }
-            _traceOn = true;
-            return;
-        }
+        // initialize ComponentMask bit array to true
+        _traceComponentMask = (Uint64)-1;
+
+        // If tracing isn't turned off by a traceLevel of zero, let's
+        // turn on the flag that activates tracing.
+        _traceOn = (_traceLevelMask != LEVEL0);
+
+        return;
+    }
+
+    // initialize ComponentMask bit array to false
+    _traceComponentMask = (Uint64)0;
+    _traceOn = false;
+
+    if (traceComponents != String::EMPTY)
+    {
+        Uint32 index = 0;
+        Uint32 position = 0;
+        String componentName;
+        String componentStr = traceComponents;
 
-        // initialize ComponentMask array to False
-        for (index = 0; index < _NUM_COMPONENTS; index++)
-        {
-            (_getInstance()->_traceComponentMask.get())[index] = false;
-        }
-        _traceOn = false;
 
         // Append _COMPONENT_SEPARATOR to the end of the traceComponents
         componentStr.append(_COMPONENT_SEPARATOR);
@@ -614,9 +796,7 @@ void Tracer::setTraceComponents(const String& traceComponents)
                 if (String::equalNoCase(
                     componentName,TRACE_COMPONENT_LIST[index]))
                 {
-                    (_getInstance()->_traceComponentMask.get())[index] = true;
-                    _traceOn = true;
-
+                    _traceComponentMask=_traceComponentMask|((Uint64)1<<index);
                     // Found component, break from the loop
                     break;
                 }
@@ -625,37 +805,102 @@ void Tracer::setTraceComponents(const String& traceComponents)
                     index++;
                 }
             }
-
             // Remove the searched componentname from the traceComponents
             componentStr.remove(0,position+1);
         }
+        // If one of the components was set for tracing and the traceLevel
+        // is not zero, then turn on tracing.
+        _traceOn=((_traceComponentMask!=(Uint64)0)&&(_traceLevelMask!=LEVEL0));
+    }
+
+    return ;
+}
+
+////////////////////////////////////////////////////////////////////////////////
+// Set the trace facility to be used
+////////////////////////////////////////////////////////////////////////////////
+Uint32 Tracer::setTraceFacility(const String& traceFacility)
+{
+    Uint32 retCode = 0;
+    Tracer* instance = _getInstance();
+
+    if (traceFacility.size() != 0)
+    {
+        Uint32 index = 0;
+        while (TRACE_FACILITY_LIST[index] != 0 )
+        {
+            if (String::equalNoCase( traceFacility,TRACE_FACILITY_LIST[index]))
+            {
+                if (index != instance->_traceFacility)
+                {
+                    instance->_setTraceHandler(index);
+                }
+                retCode = 1;
+                break;
+            }
+            index++;
+        }
+    }
+
+    return retCode;
+}
+
+////////////////////////////////////////////////////////////////////////////////
+// Get the trace facility in use
+////////////////////////////////////////////////////////////////////////////////
+Uint32 Tracer::getTraceFacility()
+{
+    return _getInstance()->_traceFacility;
+}
+
+////////////////////////////////////////////////////////////////////////////////
+// Set the size of the memory trace buffer
+////////////////////////////////////////////////////////////////////////////////
+Boolean Tracer::setTraceMemoryBufferSize(Uint32 bufferSize)
+{
+    Tracer* instance = _getInstance();
+    if (instance->_runningOOP)
+    {
+        // in OOP we reduce the trace memory buffer by factor
+        // PEGASUS_TRC_BUFFER_OOP_SIZE_DEVISOR
+        instance->_traceMemoryBufferSize =
+            bufferSize / PEGASUS_TRC_BUFFER_OOP_SIZE_DEVISOR;
     }
     else
     {
-        // initialise ComponentMask array to False
-        for (Uint32 index = 0;index < _NUM_COMPONENTS; index++)
-        {
-            (_getInstance()->_traceComponentMask.get())[index] = false;
-        }
-        _traceOn = 0;
+        instance->_traceMemoryBufferSize = bufferSize;
     }
-    return ;
+
+    // If we decide to dynamically change the trace buffer size,
+    // this is where it needs to be implemented.
+    return true;
 }
 
+////////////////////////////////////////////////////////////////////////////////
+// Flushes the trace buffer to traceFilePath. This method will only
+// have an effect when traceFacility=Memory.
+////////////////////////////////////////////////////////////////////////////////
+void Tracer::flushTrace()
+{
+    _getInstance()->_traceHandler->flushTrace();
+    return;
+}
+
+
 void Tracer::traceEnter(
     TracerToken& token,
     const char* file,
     size_t line,
-    Uint32 traceComponent,
+    TraceComponentId traceComponent,
     const char* method)
 {
     token.component = traceComponent;
     token.method = method;
-    
-    if (isTraceEnabled(traceComponent, LEVEL1))
+
+    if (isTraceEnabled(traceComponent, LEVEL5))
     {
         _traceMethod(
-            file, (Uint32)line, traceComponent, 
+            file, (Uint32)line, traceComponent,
             _METHOD_ENTER_MSG, method);
     }
 }
@@ -665,7 +910,7 @@ void Tracer::traceExit(
     const char* file,
     size_t line)
 {
-    if (isTraceEnabled(token.component, LEVEL1) && token.method)
+    if (isTraceEnabled(token.component, LEVEL5) && token.method)
         _traceMethod(
             file, (Uint32)line, token.component,
             _METHOD_EXIT_MSG, token.method);
@@ -678,35 +923,47 @@ void Tracer::traceExit(
 void Tracer::traceCString(
     const char* fileName,
     const Uint32 lineNum,
-    const Uint32 traceComponent,
+    const TraceComponentId traceComponent,
     const char* cstring)
 {
     char* message;
 
+    Uint32 msgLen;
+    Uint32 usec,sec;
+
+    // Get the current system time
+    System::getCurrentTimeUsec(sec,usec);
+
     //
     // Allocate memory for the message string
     // Needs to be updated if additional info is added
     //
-    message = new char[strlen(fileName) +
-        _STRLEN_MAX_UNSIGNED_INT + (_STRLEN_MAX_PID_TID * 2) + 8];
-    sprintf(
-       message,
-       "[%d:%s:%s:%u]: ",
-       System::getPID(),
-       Threads::id().buffer,
-       fileName,
-       lineNum);
+    message = new char [strlen(fileName) +
+        _STRLEN_MAX_UNSIGNED_INT + (_STRLEN_MAX_PID_TID * 2) + 8 +
+        strlen(TRACE_COMPONENT_LIST[traceComponent]) +
+        strlen(cstring) + 30];
+
+    msgLen = sprintf(message, "%us-%uus: %s [%u:%s:%s:%u]: %s",
+        sec,
+        usec,
+        TRACE_COMPONENT_LIST[traceComponent],
+        System::getPID(),
+        Threads::id().buffer,
+        fileName,
+        lineNum,
+        cstring);
+
+    // Call trace file handler to write message
+    _getInstance()->_traceHandler->handleMessage(message,msgLen);
 
-    _traceCString(traceComponent, message, cstring);
     delete [] message;
 }
 
 void Tracer::traceCIMException(
-    const Uint32 traceComponent,
+    const TraceComponentId traceComponent,
     const Uint32 traceLevel,
     const CIMException& cimException)
 {
-    PEGASUS_ASSERT(traceLevel != LEVEL1);
     if (isTraceEnabled(traceComponent, traceLevel))
     {
         _traceCIMException(traceComponent, cimException);
