@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -39,18 +37,66 @@
 #include <Pegasus/Common/System.h>
 #include <Pegasus/Common/Logger.h>
 #include <Pegasus/Common/InternalException.h>
-#include <Pegasus/Common/TraceComponents.h>
-#include <Pegasus/Common/TraceFileHandler.h>
+#include <Pegasus/Common/TraceHandler.h>
 #include <Pegasus/Common/Linkage.h>
 #include <Pegasus/Common/SharedPtr.h>
 
 PEGASUS_NAMESPACE_BEGIN
 
+/**
+    Trace component identifiers.  This list must be kept in sync with the
+    TRACE_COMPONENT_LIST in Tracer.cpp.
+    The tracer uses the _traceComponentMask 64bit field to mask
+    the user configured components.
+
+    Please ensure that no more than 64 Trace Component ID's are specified.
+*/
+enum TraceComponentId
+{
+    TRC_XML,
+    TRC_XML_IO,
+    TRC_HTTP,
+    TRC_REPOSITORY,
+    TRC_DISPATCHER,
+    TRC_OS_ABSTRACTION,
+    TRC_CONFIG,
+    TRC_IND_HANDLER,
+    TRC_AUTHENTICATION,
+    TRC_AUTHORIZATION,
+    TRC_USER_MANAGER,
+    TRC_SHUTDOWN,
+    TRC_SERVER,
+    TRC_INDICATION_SERVICE,
+    TRC_MESSAGEQUEUESERVICE,
+    TRC_PROVIDERMANAGER,
+    TRC_OBJECTRESOLUTION,
+    TRC_WQL,
+    TRC_CQL,
+    TRC_THREAD,
+    TRC_EXP_REQUEST_DISP,
+    TRC_SSL,
+    TRC_CONTROLPROVIDER,
+    TRC_CIMOM_HANDLE,
+    TRC_L10N,
+    TRC_EXPORT_CLIENT,
+    TRC_LISTENER,
+    TRC_DISCARDED_DATA,
+    TRC_PROVIDERAGENT,
+    TRC_IND_FORMATTER,
+    TRC_STATISTICAL_DATA,
+    TRC_CMPIPROVIDER,
+    TRC_INDICATION_GENERATION,
+    TRC_INDICATION_RECEIPT,
+    TRC_CMPIPROVIDERINTERFACE,
+    TRC_WSMSERVER,
+    TRC_LOGMSG
+};
+
 /** Token used for tracing functions.
 */
 struct TracerToken
 {
-    Uint32 component;
+    TraceComponentId component;
     const char* method;
 };
 
@@ -60,10 +106,26 @@ class PEGASUS_COMMON_LINKAGE Tracer
 {
 public:
 
+    /** Trace facilities
+        File - tracing occurs to the trace file
+        Log  - tracing occurs through the Pegasus Logger class
+        Keep the TRACE_FACILITY_LIST in sync with the TRACE_FACILITY_INDEX,
+        so that the index matches the according string in the list.
+     */
+    static char const* TRACE_FACILITY_LIST[];
+
+    enum TRACE_FACILITY_INDEX
+    {
+        TRACE_FACILITY_FILE = 0,
+        TRACE_FACILITY_LOG  = 1,
+        TRACE_FACILITY_MEMORY = 2
+    };
+
+
     /** Levels of trace
         Trace messages are written to the trace file only if they are at or
         above a given trace level
-        LEVEL1 - Function Entry/Exit
+        LEVEL1 - Severe and log messages
         LEVEL2 - Basic flow trace messages, low data detail
         LEVEL3 - Inter-function logic flow, medium data detail
         LEVEL4 - High data detail
@@ -84,7 +146,7 @@ public:
     static void traceCString(
         const char* fileName,
         const Uint32 lineNum,
-        const Uint32 traceComponent,
+        const TraceComponentId traceComponent,
         const char* cstring);
 
     /** Traces the message in the given CIMException object.  The message
@@ -92,25 +154,25 @@ public:
         line number of the CIMException originator.
         @param traceComponent  component being traced
         @param level           trace level of the trace message
-        @param CIMException    the CIMException to be traced.
+        @param cimException    the CIMException to be traced.
      */
     static void traceCIMException(
-        const Uint32 traceComponent,
+        const TraceComponentId traceComponent,
         const Uint32 level,
         const CIMException& cimException);
 
     /** Gets an HTTP request message.
-        
+
         Given an HTTP request message, this method checks if the
-        message contains a "Basic" authorization header. 
-   
+        message contains a "Basic" authorization header.
+
         If true, the username/passwd is suppressed and returned.
         Otherwise the request message is returned without any changes.
 
         @param requestMessage  requestMessage to be checked
- 
+
         @return request message
- 
+
     */
     static SharedArrayPtr<char> getHTTPRequestMessage(
         const Buffer& requestMessage);
@@ -138,6 +200,32 @@ public:
     static void setTraceComponents(
        const String& traceComponents);
 
+    /** Set trace facility to be used
+        @param traceFacility facility to be used for tracing,
+               for example Log or File.
+        @return 0      if trace facility is valid
+                1      if trace facility is invalid
+    */
+    static Uint32 setTraceFacility(const String& traceFacility);
+
+    /** Get trace facility currently in use
+        @return TRACE_FACILITY_FILE - if trace facility is file
+                TRACE_FACILITY_LOG - if trace facility is the log
+                TRACE_FACILITY_MEMORY - if trace facility is memory tracing
+    */
+    static Uint32 getTraceFacility();
+
+    /** Set buffer size to be used for the memory tracing facility
+        @param bufferSize buffer size in Kbyte to be used for memory tracing
+        @return true   if function was successfully.
+    */
+    static Boolean setTraceMemoryBufferSize(Uint32 bufferSize);
+
+    /** Flushes the trace buffer to traceFilePath. This method will only
+        have an effect when traceFacility=Memory.
+    */
+    static void flushTrace();
+
     /** Traces method entry.
         @param token           TracerToken
         @param fileName        filename of the trace originator
@@ -149,7 +237,7 @@ public:
         TracerToken& token,
         const char* file,
         size_t line,
-        Uint32 component,
+        TraceComponentId traceComponent,
         const char* method);
 
     /** Traces method exit.
@@ -186,11 +274,19 @@ public:
         const String& traceComponents,
         String& invalidComponents);
 
-    /** Specify the name of the module being traced.  If non-empty, this
-        value is used as an extension to the name of the trace file.
-        @param  moduleName Name of the module being traced.
+    /** Validates the trace facility string value
+        @param  traceFacility   The trace facility as string
+        @return 1        if the trace facility is valid
+                0        if the trace facility is invalid
      */
-    static void setModuleName(const String& moduleName);
+    static Boolean isValidTraceFacility( const String& traceFacility );
+
+    /** Signals the trace to be running OOP and provides the file name
+        extension of  the trace file.  If non-empty, this
+        value is used as an extension to the name of the trace file.
+        @param  oopTraceFileExtension Trace file extension.
+     */
+    static void setOOPTraceFileExtension(const String& oopTraceFileExtension);
 
     /**
     */
@@ -202,8 +298,12 @@ public:
     // @return   0               if the component and level are not enabled
     //           1               if the component and level are enabled
     static Boolean isTraceEnabled(
-        const Uint32 traceComponent,
-        const Uint32 level);
+        const TraceComponentId traceComponent,
+        const Uint32 traceLevel)
+    {
+        return ((traceLevel & _traceLevelMask) &&
+                (_traceComponentMask & ((Uint64)1 << traceComponent)));
+    }
 
 private:
 
@@ -214,24 +314,43 @@ private:
      */
     static Boolean _traceOn;
 
+    /** Internal only Levels of trace
+        These cannot be used in any of the trace calls directly, but are set
+        by methods of the Tracer class for specific purposes, such as trace
+        Enter and traceExit.
+        LEVEL0 - Trace is switched off
+        LEVEL5 - used for method enter & exit
+     */
+    static const Uint32 LEVEL0;
+    static const Uint32 LEVEL5;
+
     static const char   _COMPONENT_SEPARATOR;
     static const Uint32 _NUM_COMPONENTS;
     static const Uint32 _STRLEN_MAX_UNSIGNED_INT;
     static const Uint32 _STRLEN_MAX_PID_TID;
-    static const Boolean _SUCCESS;
-    static const Boolean _FAILURE;
-    AutoArrayPtr<Boolean> _traceComponentMask;
-    Uint32              _traceLevelMask;
-    AutoPtr<TraceFileHandler> _traceHandler;
-    String              _moduleName;
-    static Tracer*      _tracerInstance;
+    static Uint64                _traceComponentMask;
+    static Uint32                _traceLevelMask;
+    static Tracer*               _tracerInstance;
+    Uint32                _traceMemoryBufferSize;
+    Uint32                _traceFacility;
+    Boolean               _runningOOP;
+    TraceHandler*         _traceHandler;
+    String                _traceFile;
+    String                _oopTraceFileExtension;
+
 
     // Message Strings for function Entry and Exit
     static const char _METHOD_ENTER_MSG[];
     static const char _METHOD_EXIT_MSG[];
 
-    // Message Strings for Logger
-    static const char _LOG_MSG[];
+    // Factory function to create an instance of the matching trace handler
+    // for the given type of traceFacility.
+    // @param    traceFacility  type of trace handler to create
+    void _setTraceHandler( Uint32 traceFacility );
+
+    // Validates if the given file path if it is eligible for writing traces.
+    // @param    fileName      a file intended to be used to write traces
+    static Boolean _isValidTraceFile(String fileName);
 
     // Traces the given message. Overloaded to include the file name and the
     // line number as one of the parameters.
@@ -242,7 +361,7 @@ private:
     static void _trace(
         const char* fileName,
         const Uint32 lineNum,
-        const Uint32 traceComponent,
+        const TraceComponentId traceComponent,
         const char* fmt,
         va_list argList);
 
@@ -253,25 +372,25 @@ private:
     //  @param    CIMException    the CIMException to be traced.
     //
     static void _traceCIMException(
-        const Uint32 traceComponent,
+        const TraceComponentId traceComponent,
         const CIMException& cimException);
 
     // Called by all the trace interfaces to log message
     // consisting of a single character string to the trace file
-    // @param    traceComponent  component being traced    
+    // @param    traceComponent  component being traced
     // @param    cstring         the string to be traced
     static void _traceCString(
-        const Uint32 traceComponent,
+        const TraceComponentId traceComponent,
         const char* message,
         const char* cstring);
-    
+
     // Called by all the trace interfaces to log message
     // with variable number of arguments to the trace file
     // @param    traceComponent  component being traced
     // @param    *fmt            printf style format string
     // @param    argList         variable argument list
     static void _trace(
-        const Uint32 traceComponent,
+        const TraceComponentId traceComponent,
         const char* message,
         const char* fmt,
         va_list argList);
@@ -284,7 +403,7 @@ private:
     static void _traceMethod(
         const char* fileName,
         const Uint32 lineNum,
-        const Uint32 traceComponent,
+        const TraceComponentId traceComponent,
         const char* methodEntryExit,
         const char* method);
 
@@ -301,6 +420,9 @@ private:
     static Tracer* _getInstance();
 
     friend class TraceCallFrame;
+    friend class TracePropertyOwner;
+    friend class TraceMemoryHandler;
+    friend class TraceFileHandler;
 };
 
 //==============================================================================
@@ -315,14 +437,14 @@ private:
 inline void Tracer::traceCString(
     const char* fileName,
     const Uint32 lineNum,
-    const Uint32 traceComponent,
+    const TraceComponentId traceComponent,
     const char* cstring)
 {
     // empty function
 }
 
 inline void Tracer::traceCIMException(
-    const Uint32 traceComponent,
+    const TraceComponentId traceComponent,
     const Uint32 level,
     const CIMException& cimException)
 {
@@ -353,6 +475,30 @@ inline void Tracer::setTraceComponents(const String& traceComponents)
     // empty function
 }
 
+inline Uint32 Tracer::setTraceFacility(const String& traceFacility)
+{
+    // empty function
+    return 0;
+}
+
+inline Uint32 Tracer::getTraceFacility()
+{
+    // empty function
+    return 0;
+}
+
+inline Boolean Tracer::setTraceMemoryBufferSize(Uint32 bufferSize)
+{
+    // empty function
+    return true;
+}
+
+inline void Tracer::flushTrace()
+{
+    // empty function
+    return;
+}
+
 #endif /* PEGASUS_REMOVE_TRACE */
 
 //==============================================================================
@@ -375,13 +521,17 @@ inline void Tracer::setTraceComponents(const String& traceComponents)
 
 # define PEG_METHOD_ENTER(comp,meth)
 # define PEG_METHOD_EXIT()
-# define PEG_TRACE_STRING(comp,level,string)
 # define PEG_TRACE(VAR_ARGS)
 # define PEG_TRACE_CSTRING(comp,level,chars)
 
 #else /* PEGASUS_REMOVE_TRACE */
 
-# define PEG_METHOD_ENTER(comp, meth) \
+// remover trace code for method enter/exit
+# ifdef  PEGASUS_REMOVE_METHODTRACE
+#  define PEG_METHOD_ENTER(comp,meth)
+#  define PEG_METHOD_EXIT()
+# else
+#  define PEG_METHOD_ENTER(comp, meth) \
     TracerToken __tracerToken; \
     __tracerToken.method = 0; \
     do \
@@ -399,24 +549,7 @@ inline void Tracer::setTraceComponents(const String& traceComponents)
             Tracer::traceExit(__tracerToken PEGASUS_COMMA_FILE_LINE); \
     } \
     while (0)
-
-// Macro for Trace String.  the do construct allows this to appear
-// as a single statement.
-# define PEG_TRACE_STRING(comp, level, string) \
-    do \
-    { \
-        if (Tracer::isTraceOn()) \
-        { \
-            PEGASUS_ASSERT(level != Tracer::LEVEL1); \
-            if (Tracer::isTraceEnabled(comp, level)) \
-            { \
-                Tracer::traceCString(PEGASUS_FILE_LINE_COMMA \
-                                     comp, \
-                                     (const char*) (string).getCString()); \
-            } \
-        } \
-    } \
-    while (0)
+# endif
 
 // Macro to trace character lists.  the do construct allows this to appear
 // as a single statement.
@@ -425,7 +558,6 @@ inline void Tracer::setTraceComponents(const String& traceComponents)
     { \
         if (Tracer::isTraceOn()) \
         { \
-            PEGASUS_ASSERT(level != Tracer::LEVEL1); \
             if (Tracer::isTraceEnabled(comp, level)) \
             { \
                 Tracer::traceCString(PEGASUS_FILE_LINE_COMMA comp, chars); \
@@ -448,17 +580,17 @@ public:
 
     const char* file;
     Uint32 line;
-    
+
     TraceCallFrame(const char* file_, Uint32 line_) : file(file_), line(line_)
     {
     }
-    
+
     PEGASUS_FORMAT(4, 5)
     inline void invoke(
-        const Uint32 component,
+        const TraceComponentId component,
         const Uint32 level,
         const char* format,
-        ...) 
+        ...)
     {
         if (Tracer::isTraceEnabled(component, level))
         {
@@ -474,8 +606,8 @@ public:
     }
 };
 //
-// This macro is a wrapper for calling the printf-style form of the 
-// Tracer::trace() function. Since macros cannot have a varying number of 
+// This macro is a wrapper for calling the printf-style form of the
+// Tracer::trace() function. Since macros cannot have a varying number of
 // arguments, PEG_TRACE() must be invoked with double parentheses. For
 // example:
 //
