@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -39,7 +37,6 @@
 #include <Pegasus/Common/InternalException.h>
 #include <Pegasus/Common/ArrayInternal.h>
 #include <Pegasus/Common/String.h>
-#include <Pegasus/Common/Indentor.h>
 #include <Pegasus/Common/CIMObject.h>
 #include <Pegasus/Common/CIMClass.h>
 #include <Pegasus/Common/CIMInstance.h>
@@ -58,53 +55,14 @@
 #include <Pegasus/Common/AcceptLanguageList.h>
 #include <Pegasus/Common/Buffer.h>
 #include <Pegasus/Common/StrLit.h>
+#include <Pegasus/Common/XmlGenerator.h>
 
 PEGASUS_NAMESPACE_BEGIN
 
-// l10n - added accept language and content language support below
-
-class PEGASUS_COMMON_LINKAGE XmlWriter
+class PEGASUS_COMMON_LINKAGE XmlWriter : public XmlGenerator
 {
 public:
 
-    static void append(Buffer& out, const Char16& x);
-
-    static void append(Buffer& out, char x)
-    {
-      out.append(x);
-    }
-
-    static void append(Buffer& out, Boolean x);
-
-    static void append(Buffer& out, Uint32 x);
-
-    static void append(Buffer& out, Sint32 x);
-
-    static void append(Buffer& out, Uint64 x);
-
-    static void append(Buffer& out, Sint64 x);
-
-    static void append(Buffer& out, Real32 x);
-
-    static void append(Buffer& out, Real64 x);
-
-    static void append(Buffer& out, const char* str);
-
-    static void append(Buffer& out, const String& str);
-
-    static void append(Buffer& out, const Indentor& x);
-
-    static void appendSpecial(Buffer& out, const Char16& x);
-
-    static void appendSpecial(Buffer& out, char x);
-
-    static void appendSpecial(Buffer& out, const char* str);
-
-    static void appendSpecial(Buffer& out, const String& str);
-
-    static String encodeURICharacters(const Buffer& uriString);
-    static String encodeURICharacters(const String& uriString);
-
     static void appendLocalNameSpacePathElement(
         Buffer& out,
         const CIMNamespaceName& nameSpace);
@@ -252,15 +210,17 @@ public:
         HttpMethod httpMethod,
         const AcceptLanguageList& acceptLanguages,
         const ContentLanguageList& contentLanguages,
-        Uint32 contentLength);
+        Uint32 contentLength,
+        bool binaryRequest = false,
+        bool binaryResponse = false);
 
-    // added to accommodate sending WBEMServerResponseTime PEP #128
     static void appendMethodResponseHeader(
         Buffer& out,
         HttpMethod httpMethod,
         const ContentLanguageList& contentLanguages,
         Uint32 contentLength,
-        Uint64 serverResponseTime = 0);
+        Uint64 serverResponseTime = 0,
+        bool binaryResponse = false);
 
     static void appendHttpErrorResponseHeader(
         Buffer& out,
@@ -277,6 +237,7 @@ public:
         Buffer& out,
         const String& content);
 #endif
+
     static void appendParamTypeAndEmbeddedObjAttrib(
         Buffer& out,
         const CIMType& type);
@@ -358,10 +319,9 @@ public:
         HttpMethod httpMethod,
         const String& authenticationHeader,
         const AcceptLanguageList& httpAcceptLanguages,
-        const ContentLanguageList& httpContentLanguages);
+        const ContentLanguageList& httpContentLanguages,
+        bool binaryResponse);
 
-    // PEP 128 - sending serverResponseTime (WBEMServerResponseTime) in
-    // response header
     static Buffer formatSimpleMethodRspMessage(
         const CIMName& methodName,
         const String& messageId,
@@ -387,10 +347,9 @@ public:
         const String& authenticationHeader,
         const AcceptLanguageList& httpAcceptLanguages,
         const ContentLanguageList& httpContentLanguages,
-        const Buffer& body);
+        const Buffer& body,
+        bool binaryResponse);
 
-    // PEP 128 - sending serverResponseTime (WBEMServerResponseTime) in
-    // response header
     static Buffer formatSimpleIMethodRspMessage(
         const CIMName& iMethodName,
         const String& messageId,
@@ -401,6 +360,7 @@ public:
         Boolean isFirst = true,
         Boolean isLast = true);
 
+
     static Buffer formatSimpleIMethodErrorRspMessage(
         const CIMName& iMethodName,
         const String& messageId,
@@ -453,17 +413,12 @@ public:
         HttpMethod httpMethod,
         const CIMException& cimException);
 
-    static void indentedPrint(
-        PEGASUS_STD(ostream)& os,
-        const char* text,
-        Uint32 indentChars = 2);
-
     static String getNextMessageId();
 
     /** Converts the given CIMKeyBinding type to one of the following:
         "boolean", "string", or "numeric"
     */
-    static const char* keyBindingTypeToString (CIMKeyBinding::Type type);
+    static const StrLit keyBindingTypeToString (CIMKeyBinding::Type type);
 
 private:
 
@@ -543,58 +498,9 @@ private:
     static void _appendEMethodResponseElementEnd(
         Buffer& out);
 
-    XmlWriter() { }
+    XmlWriter();
 };
 
-PEGASUS_COMMON_LINKAGE Buffer& operator<<(
-    Buffer& out,
-    const char* x);
-
-inline Buffer& operator<<(Buffer& out, char x)
-{
-    out.append(x);
-    return out;
-}
-
-inline Buffer& operator<<(Buffer& out, const char* s)
-{
-    out.append(s, (Uint32)strlen(s));
-    return out;
-}
-
-PEGASUS_COMMON_LINKAGE Buffer& operator<<(Buffer& out, const Char16& x);
-
-PEGASUS_COMMON_LINKAGE Buffer& operator<<(
-    Buffer& out,
-    const String& x);
-
-PEGASUS_COMMON_LINKAGE Buffer& operator<<(
-    Buffer& out,
-    const Indentor& x);
-
-PEGASUS_COMMON_LINKAGE Buffer& operator<<(
-    Buffer& out,
-    const Buffer& x);
-
-PEGASUS_COMMON_LINKAGE Buffer& operator<<(
-    Buffer& out,
-    Uint32 x);
-
-PEGASUS_COMMON_LINKAGE Buffer& operator<<(
-    Buffer& out,
-    const CIMName& name);
-
-PEGASUS_COMMON_LINKAGE PEGASUS_STD(ostream)& operator<<(
-    PEGASUS_STD(ostream)& os,
-    const CIMDateTime& x);
-
-PEGASUS_COMMON_LINKAGE PEGASUS_STD(ostream)& operator<<(
-    PEGASUS_STD(ostream)& os,
-    const CIMName& name);
-
-PEGASUS_COMMON_LINKAGE PEGASUS_STD(ostream)& operator<<(
-    PEGASUS_STD(ostream)& os,
-    const CIMNamespaceName& name);
 
 PEGASUS_NAMESPACE_END
 
