@@ -1,48 +1,37 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
 //
-// Author: Mike Brasher (mbrasher@bmc.com)
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 //
-// Modified By: Sushma Fernandes, Hewlett-Packard Company
-//              (sushma_fernandes@hp.com)
-//              Carol Ann Krug Graves, Hewlett-Packard Company
-//                (carolann_graves@hp.com)
-//              Willis White (PEP 192)
-//              Roger Kumpf, Hewlett-Packard Company (roger_kumpf@hp.com)
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
 #include <Pegasus/Common/PegasusAssert.h>
 #include <Pegasus/Common/CIMDateTime.h>
-#include <Pegasus/Common/XmlWriter.h>
+#include <Pegasus/Common/CIMValue.h>
 #include <Pegasus/Common/Exception.h>
 
 PEGASUS_USING_PEGASUS;
@@ -57,7 +46,6 @@ void put(const char *msg, const CIMDateTime & x)
 
 int main(int argc, char **argv)
 {
-    Boolean bad = false;
     try
     {
         // ATTN-P2-KS 20 Mar 2002 - Needs expansion of tests.
@@ -71,7 +59,7 @@ int main(int argc, char **argv)
         PEGASUS_TEST_ASSERT(dt.equal(CIMDateTime("00000000000000.000000:000")));
 
         {
-            bad = false;
+            Boolean bad = false;
 
             try
             {
@@ -101,10 +89,10 @@ int main(int argc, char **argv)
             PEGASUS_TEST_ASSERT(bad);
         }
         if (verbose)
-            cout << dt << endl;
+            cout << dt.toString() << endl;
 
-        CIMDateTime dt1;
-        dt1 = dt;
+        CIMDateTime dtcopy;
+        dtcopy = dt;
 
 
     /****************************************************************
@@ -356,8 +344,8 @@ int main(int argc, char **argv)
 
         // Test overflow on timestamp construction from microseconds
         {
-            CIMDateTime dt("99991231235959.999999-000");
-            Uint64 microseconds = dt.toMicroSeconds();
+            CIMDateTime dto("99991231235959.999999-000");
+            Uint64 microseconds = dto.toMicroSeconds();
             Boolean gotException = false;
             try
             {
@@ -375,8 +363,8 @@ int main(int argc, char **argv)
             Boolean gotException = false;
             try
             {
-                CIMDateTime dt("99991231235959.999999-001");
-                CIMDateTime x(dt.toMicroSeconds(), false);
+                CIMDateTime dto("99991231235959.999999-001");
+                CIMDateTime x(dto.toMicroSeconds(), false);
             }
             catch(const DateTimeOutOfRangeException &)
             {
@@ -387,8 +375,8 @@ int main(int argc, char **argv)
 
         // Test overflow on interval construction from microseconds
         {
-            CIMDateTime dt("99999999235959.999999:000");
-            Uint64 microseconds = dt.toMicroSeconds();
+            CIMDateTime dto("99999999235959.999999:000");
+            Uint64 microseconds = dto.toMicroSeconds();
             Boolean gotException = false;
             try
             {
@@ -403,8 +391,8 @@ int main(int argc, char **argv)
 
         // Test overflow on timestamp construction from large, valid interval
         {
-            CIMDateTime dt("99999999235959.999999:000");
-            Uint64 microseconds = dt.toMicroSeconds();
+            CIMDateTime dto("99999999235959.999999:000");
+            Uint64 microseconds = dto.toMicroSeconds();
             Boolean gotException = false;
             try
             {
@@ -525,9 +513,9 @@ int main(int argc, char **argv)
         }
 
 
-        // 
+        //
         // Tests for getDifference.
-        // 
+        //
 
         // One second difference
         {
@@ -715,9 +703,9 @@ int main(int argc, char **argv)
         }
 
 
-        // 
+        //
         // Tests for getCurrentDateTime
-        // 
+        //
         {
             CIMDateTime currentTime1;
             CIMDateTime currentTime2;
@@ -880,7 +868,7 @@ int main(int argc, char **argv)
 
 /*************************************************************************/
 
-        // "testing the operator- 
+        // "testing the operator-
 
 
         Uint64 tfo_m = PEGASUS_UINT64_LITERAL(123456732445);
@@ -937,7 +925,7 @@ int main(int argc, char **argv)
 
 /*************************************************************************/
 
-        // testing operator-= 
+        // testing operator-=
 
 
         CIMDateTime top_tko4("00040520041412.123435-000");
@@ -983,7 +971,7 @@ int main(int argc, char **argv)
 
 /*************************************************************************/
 
-//test operator* 
+//test operator*
 
 
         CIMDateTime mul1("00000020041452.123456:000");
@@ -1022,7 +1010,7 @@ int main(int argc, char **argv)
 
 /*************************************************************************/
 
-        // test operator*= 
+        // test operator*=
 
 
         CIMDateTime ul1("00000020041452.123456:000");
@@ -1077,7 +1065,7 @@ int main(int argc, char **argv)
 
 /*************************************************************************/
 
-        // testing operator/= 
+        // testing operator/=
 
         d_num1 = 50;
 
