@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//=============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%////////////////////////////////////////////////////////////////////////////
 
@@ -48,7 +46,7 @@ CIMInstance _createSubscriptionInstance()
     CIMInstance subscriptionInstance (
             PEGASUS_CLASSNAME_FORMATTEDINDSUBSCRIPTION);
 
-    subscriptionInstance.addProperty (CIMProperty (CIMName ("Filter"), 
+    subscriptionInstance.addProperty (CIMProperty (CIMName ("Filter"),
     CIMValue((String) "filter1")));
     subscriptionInstance.addProperty (CIMProperty (CIMName ("Handler"),
     CIMValue((String) "handler1")));
@@ -62,7 +60,7 @@ CIMInstance _createSubscriptionInstance
     CIMInstance subscriptionInstance (
             PEGASUS_CLASSNAME_FORMATTEDINDSUBSCRIPTION);
 
-    subscriptionInstance.addProperty (CIMProperty (CIMName ("Filter"), 
+    subscriptionInstance.addProperty (CIMProperty (CIMName ("Filter"),
     CIMValue((String) "filter1")));
     subscriptionInstance.addProperty (CIMProperty (CIMName ("Handler"),
     CIMValue((String) "handler1")));
@@ -72,7 +70,7 @@ CIMInstance _createSubscriptionInstance
     (CIMName ("TextFormatParameters"), textFormatParams));
 
     return (subscriptionInstance);
-   
+
 }
 
 CIMInstance _createIndicationInstance1()
@@ -253,13 +251,11 @@ CIMInstance _createIndicationInstance2(CIMType type)
     case CIMTYPE_DATETIME:
     case CIMTYPE_REFERENCE:
     case CIMTYPE_OBJECT:
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
     case CIMTYPE_INSTANCE:
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
         {
             break;
         }
-        
+
     }
     return (indicationInstance);
 }
@@ -476,9 +472,7 @@ void _testDefaultFormat()
     IndicationFormatter::getFormattedIndText(subscriptionInstance,
     indicationInstance, contentLangs);
 
-    PEGASUS_TEST_ASSERT(String::compare(formattedIndText, 
-    expectedIndicationText) == 0);
-
+    PEGASUS_TEST_ASSERT(formattedIndText == expectedIndicationText);
 }
 
 // Tests a formatted indication text message.
@@ -503,12 +497,12 @@ void _testFormat()
     textFormatParams.append("MethodName");
     textFormatParams.append("TestBoolean");
 
-    String expectedIndicationText = 
+    String expectedIndicationText =
     "The prediction is true. A indication which is generated by " \
         "testIndicationFormat occurred at 20050510143211.000000-420" \
         " with Indication ID 1";
 
-    CIMInstance subscriptionInstance = 
+    CIMInstance subscriptionInstance =
     _createSubscriptionInstance(textFormat, textFormatParams);
 
     CIMInstance indicationInstance = _createIndicationInstance1();
@@ -517,20 +511,18 @@ void _testFormat()
     formattedIndText = IndicationFormatter::getFormattedIndText(
     subscriptionInstance, indicationInstance, contentLangs);
 
-    PEGASUS_TEST_ASSERT(String::compare(formattedIndText, 
-    expectedIndicationText) == 0);
-
+    PEGASUS_TEST_ASSERT(formattedIndText == expectedIndicationText);
 }
 
 // checks whether the formatted indication text is same as expected
 void _checkIndicationText(
-    const String & textFormat, 
-    const Array<String> & textFormatParams, 
-    const String expectedIndicationText, 
+    const String & textFormat,
+    const Array<String> & textFormatParams,
+    const String expectedIndicationText,
     const CIMType type,
     const ContentLanguageList contentLangs)
 {
-    CIMInstance subscriptionInstance = 
+    CIMInstance subscriptionInstance =
     _createSubscriptionInstance(textFormat, textFormatParams);
 
     CIMInstance indicationInstance = _createIndicationInstance2(type);
@@ -538,12 +530,10 @@ void _checkIndicationText(
     String formattedIndText = IndicationFormatter::getFormattedIndText(
         subscriptionInstance, indicationInstance, contentLangs);
 
-    PEGASUS_TEST_ASSERT(String::compare(formattedIndText, 
-        expectedIndicationText) == 0);
-
+    PEGASUS_TEST_ASSERT(formattedIndText == expectedIndicationText);
 }
 
-// Tests a formatted indication text message and one of the indication 
+// Tests a formatted indication text message and one of the indication
 // properties is an array property.
 void _testArrayFormat()
 {
@@ -562,10 +552,10 @@ void _testArrayFormat()
     textFormatParams.append("IndicationTime");
     textFormatParams.append("Action");
 
-    String expectedText = 
+    String expectedText =
     "A UPS Alert occurred at 20050510143211.000000-420. " \
         "The Following actions are recommended to resolve the alert: ";
-    
+
     // test case 1: {1[], string}
     String textFormat =
         "A UPS Alert occurred at {0, datetime}. The Following actions are"
@@ -577,7 +567,7 @@ void _testArrayFormat()
     expectedIndicationText.append(
         "[string_action1,string_action2,string_action3,string_action4]");
 
-    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText, 
+    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText,
                          CIMTYPE_STRING, contentLangs);
 
     // test case 2: {1[1], string}
@@ -589,7 +579,7 @@ void _testArrayFormat()
     expectedIndicationText.append(expectedText);
     expectedIndicationText.append("string_action2");
 
-    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText, 
+    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText,
                          CIMTYPE_STRING, contentLangs);
 
     // test case 3: {1[], uint8}
@@ -601,7 +591,7 @@ void _testArrayFormat()
     expectedIndicationText.append(expectedText);
     expectedIndicationText.append("[1,2,3,4]");
 
-    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText, 
+    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText,
                          CIMTYPE_UINT8, contentLangs);
 
     // test case 4: {1[1], uint8}
@@ -613,7 +603,7 @@ void _testArrayFormat()
     expectedIndicationText.append(expectedText);
     expectedIndicationText.append("2");
 
-    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText, 
+    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText,
                          CIMTYPE_UINT8, contentLangs);
 
     // test case 5: {1[], uint16}
@@ -625,7 +615,7 @@ void _testArrayFormat()
     expectedIndicationText.append(expectedText);
     expectedIndicationText.append("[16,26,36,46]");
 
-    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText, 
+    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText,
                          CIMTYPE_UINT16, contentLangs);
 
     // test case 6: {1[1], uint16}
@@ -637,7 +627,7 @@ void _testArrayFormat()
     expectedIndicationText.append(expectedText);
     expectedIndicationText.append("26");
 
-    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText, 
+    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText,
                          CIMTYPE_UINT16, contentLangs);
 
     // test case 7: {1[], uint32}
@@ -649,7 +639,7 @@ void _testArrayFormat()
     expectedIndicationText.append(expectedText);
     expectedIndicationText.append("[32,42,52,62]");
 
-    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText, 
+    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText,
                          CIMTYPE_UINT32, contentLangs);
 
     // test case 8: {1[1], uint32}
@@ -661,7 +651,7 @@ void _testArrayFormat()
     expectedIndicationText.append(expectedText);
     expectedIndicationText.append("42");
 
-    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText, 
+    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText,
                          CIMTYPE_UINT32, contentLangs);
 
     // test case 9: {1[], uint64}
@@ -673,7 +663,7 @@ void _testArrayFormat()
     expectedIndicationText.append(expectedText);
     expectedIndicationText.append("[64,74,84,94]");
 
-    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText, 
+    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText,
                          CIMTYPE_UINT64, contentLangs);
 
     // test case 10: {1[1], uint64}
@@ -685,7 +675,7 @@ void _testArrayFormat()
     expectedIndicationText.append(expectedText);
     expectedIndicationText.append("74");
 
-    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText, 
+    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText,
                          CIMTYPE_UINT64, contentLangs);
 
     // test case 11: {1[], sint8}
@@ -697,7 +687,7 @@ void _testArrayFormat()
     expectedIndicationText.append(expectedText);
     expectedIndicationText.append("[-1,-2,-3,-4]");
 
-    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText, 
+    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText,
                          CIMTYPE_SINT8, contentLangs);
 
     // test case 12: {1[1], sint8}
@@ -709,7 +699,7 @@ void _testArrayFormat()
     expectedIndicationText.append(expectedText);
     expectedIndicationText.append("-2");
 
-    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText, 
+    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText,
                          CIMTYPE_SINT8, contentLangs);
 
     // test case 13: {1[], sint16}
@@ -721,7 +711,7 @@ void _testArrayFormat()
     expectedIndicationText.append(expectedText);
     expectedIndicationText.append("[-16,-26,-36,-46]");
 
-    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText, 
+    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText,
                          CIMTYPE_SINT16, contentLangs);
 
     // test case 14: {1[1], sint16}
@@ -733,7 +723,7 @@ void _testArrayFormat()
     expectedIndicationText.append(expectedText);
     expectedIndicationText.append("-26");
 
-    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText, 
+    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText,
                          CIMTYPE_SINT16, contentLangs);
 
     // test case 15: {1[], sint32}
@@ -745,7 +735,7 @@ void _testArrayFormat()
     expectedIndicationText.append(expectedText);
     expectedIndicationText.append("[-32,-42,-52,-62]");
 
-    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText, 
+    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText,
                          CIMTYPE_SINT32, contentLangs);
 
     // test case 16: {1[1], sint32}
@@ -757,7 +747,7 @@ void _testArrayFormat()
     expectedIndicationText.append(expectedText);
     expectedIndicationText.append("-42");
 
-    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText, 
+    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText,
                          CIMTYPE_SINT32, contentLangs);
 
     // test case 17: {1[], sint64}
@@ -769,7 +759,7 @@ void _testArrayFormat()
     expectedIndicationText.append(expectedText);
     expectedIndicationText.append("[-64,-74,-84,-94]");
 
-    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText, 
+    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText,
                          CIMTYPE_SINT64, contentLangs);
 
     // test case 18: {1[1], sint64}
@@ -781,7 +771,7 @@ void _testArrayFormat()
     expectedIndicationText.append(expectedText);
     expectedIndicationText.append("-74");
 
-    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText, 
+    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText,
                          CIMTYPE_SINT64, contentLangs);
 
     // test case 19: {1[], boolean}
@@ -793,7 +783,7 @@ void _testArrayFormat()
     expectedIndicationText.append(expectedText);
     expectedIndicationText.append("[true,false,true,false]");
 
-    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText, 
+    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText,
                          CIMTYPE_BOOLEAN, contentLangs);
 
     // test case 20: {1[1], boolean}
@@ -805,7 +795,7 @@ void _testArrayFormat()
     expectedIndicationText.append(expectedText);
     expectedIndicationText.append("false");
 
-    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText, 
+    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText,
                          CIMTYPE_BOOLEAN, contentLangs);
 
     // test case 21: {1[], char16}
@@ -817,7 +807,7 @@ void _testArrayFormat()
     expectedIndicationText.append(expectedText);
     expectedIndicationText.append("[a,b,c,d]");
 
-    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText, 
+    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText,
                          CIMTYPE_CHAR16, contentLangs);
 
     // test case 22: {1[1], char16}
@@ -829,7 +819,7 @@ void _testArrayFormat()
     expectedIndicationText.append(expectedText);
     expectedIndicationText.append("b");
 
-    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText, 
+    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText,
                          CIMTYPE_CHAR16, contentLangs);
 
     // test case 20: {1[1], boolean}
@@ -841,9 +831,9 @@ void _testArrayFormat()
     expectedIndicationText.append(expectedText);
     expectedIndicationText.append("false");
 
-    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText, 
+    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText,
                          CIMTYPE_BOOLEAN, contentLangs);
-    // test case 21: array index out of bounds {1[-1], string} 
+    // test case 21: array index out of bounds {1[-1], string}
     textFormat.clear();
     expectedIndicationText.clear();
     textFormat =
@@ -852,10 +842,10 @@ void _testArrayFormat()
     expectedIndicationText.append(expectedText);
     expectedIndicationText.append("UNKNOWN");
 
-    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText, 
+    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText,
                          CIMTYPE_STRING, contentLangs);
 
-    // test case 22: array index out of bounds {1[4], string} 
+    // test case 22: array index out of bounds {1[4], string}
     textFormat.clear();
     expectedIndicationText.clear();
     textFormat =
@@ -864,9 +854,20 @@ void _testArrayFormat()
     expectedIndicationText.append(expectedText);
     expectedIndicationText.append("UNKNOWN");
 
-    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText, 
+    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText,
                          CIMTYPE_STRING, contentLangs);
 
+    // test case 23: array index with whitespace {1[ \t \n 0 \r   \n], string}
+    textFormat.clear();
+    expectedIndicationText.clear();
+    textFormat =
+        "A UPS Alert occurred at {0, datetime}. The Following actions are"
+        " recommended to resolve the alert: {1[ \t \n 0 \r   \n], string}";
+    expectedIndicationText.append(expectedText);
+    expectedIndicationText.append("string_action1");
+
+    _checkIndicationText(textFormat, textFormatParams, expectedIndicationText,
+                         CIMTYPE_STRING, contentLangs);
 }
 
 int main(int argc, char** argv)
