@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -36,8 +34,14 @@
 #include <Pegasus/Common/PegasusAssert.h>
 #include <Pegasus/Common/System.h>
 #include <Pegasus/Common/OperationContextInternal.h>
-#include <Pegasus/Common/CIMMessageSerializer.h>
-#include <Pegasus/Common/CIMMessageDeserializer.h>
+
+#if defined(PEGASUS_ENABLE_PROTOCOL_INTERNAL_BINARY)
+# include <Pegasus/Common/CIMBinMsgSerializer.h>
+# include <Pegasus/Common/CIMBinMsgDeserializer.h>
+#else
+# include <Pegasus/Common/CIMMessageSerializer.h>
+# include <Pegasus/Common/CIMMessageDeserializer.h>
+#endif
 
 PEGASUS_USING_PEGASUS;
 PEGASUS_USING_STD;
@@ -498,6 +502,20 @@ void validateCIMResponseMessageAttributes(
     a Message object.
 */
 CIMMessage* serializeDeserializeMessage(CIMMessage* inMessage)
+#if defined(PEGASUS_ENABLE_PROTOCOL_INTERNAL_BINARY)
+{
+    CIMBuffer buf(64*1024);
+    CIMBinMsgSerializer::serialize(buf, inMessage);
+
+    size_t size = buf.size();
+    buf.rewind();
+
+    CIMMessage* outMessage;
+    outMessage = CIMBinMsgDeserializer::deserialize(buf, size);
+
+    return outMessage;
+}
+#else
 {
     Buffer outBuffer;
     CIMMessageSerializer::serialize(outBuffer, inMessage);
@@ -512,17 +530,31 @@ CIMMessage* serializeDeserializeMessage(CIMMessage* inMessage)
     }
 
     CIMMessage* outMessage;
+
     outMessage = CIMMessageDeserializer::deserialize(inBuffer);
 
     delete [] inBuffer;
-
     return outMessage;
 }
+#endif
 
 //
 // testEmptyRequestMessage
 //
 void testEmptyMessage()
+#if defined(PEGASUS_ENABLE_PROTOCOL_INTERNAL_BINARY)
+{
+    CIMBuffer buf(64*1024);
+    CIMBinMsgSerializer::serialize(buf, 0);
+    PEGASUS_TEST_ASSERT(buf.size() == 0);
+
+    size_t size = buf.size();
+    buf.rewind();
+
+    CIMMessage* outMessage = CIMBinMsgDeserializer::deserialize(buf, size);
+    PEGASUS_TEST_ASSERT(outMessage == 0);
+}
+#else
 {
     Buffer outBuffer;
     CIMMessageSerializer::serialize(outBuffer, 0);
@@ -532,6 +564,7 @@ void testEmptyMessage()
     CIMMessage* outMessage = CIMMessageDeserializer::deserialize(inBuffer);
     PEGASUS_TEST_ASSERT(outMessage == 0);
 }
+#endif
 
 //
 // testCIMGetInstanceRequestMessage
@@ -1223,24 +1256,6 @@ void testCIMStopAllProvidersRequestMessage(
     validateCIMRequestMessageAttributes(&inMessage, outMessage.get());
 }
 
-//
-// testCIMInitializeProviderRequestMessage
-//
-void testCIMInitializeProviderRequestMessage(
-    const OperationContext& oc,
-    const String& mid,
-    const QueueIdStack& qids)
-{
-    CIMInitializeProviderRequestMessage inMessage(mid, qids);
-    inMessage.operationContext = oc;
-    AutoPtr<CIMInitializeProviderRequestMessage> outMessage(
-        dynamic_cast<CIMInitializeProviderRequestMessage*>(
-            serializeDeserializeMessage(&inMessage)));
-    PEGASUS_TEST_ASSERT(outMessage.get() != 0);
-
-    validateCIMRequestMessageAttributes(&inMessage, outMessage.get());
-}
-
 //
 // testCIMInitializeProviderAgentRequestMessage
 //
@@ -1332,7 +1347,8 @@ void testCIMGetInstanceResponseMessage(
     const QueueIdStack& qids,
     const CIMInstance& inst)
 {
-    CIMGetInstanceResponseMessage inMessage(mid, ex, qids, inst);
+    CIMGetInstanceResponseMessage inMessage(mid, ex, qids);
+    inMessage.setCimInstance(inst);
     inMessage.operationContext = oc;
     AutoPtr<CIMGetInstanceResponseMessage> outMessage(
         dynamic_cast<CIMGetInstanceResponseMessage*>(
@@ -1340,7 +1356,8 @@ void testCIMGetInstanceResponseMessage(
     PEGASUS_TEST_ASSERT(outMessage.get() != 0);
 
     validateCIMResponseMessageAttributes(&inMessage, outMessage.get());
-    validateCIMInstance(inMessage.cimInstance, outMessage->cimInstance);
+    validateCIMInstance(
+        inMessage.getCimInstance(), outMessage->getCimInstance());
 }
 
 //
@@ -1412,16 +1429,19 @@ void testCIMEnumerateInstancesResponseMessage(
     const QueueIdStack& qids,
     const Array<CIMInstance>& instances)
 {
-    CIMEnumerateInstancesResponseMessage inMessage(mid, ex, qids, instances);
+    CIMEnumerateInstancesResponseMessage inMessage(mid, ex, qids);
+    inMessage.setNamedInstances(instances);
     inMessage.operationContext = oc;
     AutoPtr<CIMEnumerateInstancesResponseMessage> outMessage(
         dynamic_cast<CIMEnumerateInstancesResponseMessage*>(
             serializeDeserializeMessage(&inMessage)));
     PEGASUS_TEST_ASSERT(outMessage.get() != 0);
 
+
     validateCIMResponseMessageAttributes(&inMessage, outMessage.get());
+
     validateCIMInstanceArray(
-        inMessage.cimNamedInstances, outMessage->cimNamedInstances);
+        inMessage.getNamedInstances(), outMessage->getNamedInstances());
 }
 
 //
@@ -1787,25 +1807,6 @@ void testCIMStopAllProvidersResponseMessage(
     validateCIMResponseMessageAttributes(&inMessage, outMessage.get());
 }
 
-//
-// testCIMInitializeProviderResponseMessage
-//
-void testCIMInitializeProviderResponseMessage(
-    const OperationContext& oc,
-    const String& mid,
-    const CIMException& ex,
-    const QueueIdStack& qids)
-{
-    CIMInitializeProviderResponseMessage inMessage(mid, ex, qids);
-    inMessage.operationContext = oc;
-    AutoPtr<CIMInitializeProviderResponseMessage> outMessage(
-        dynamic_cast<CIMInitializeProviderResponseMessage*>(
-            serializeDeserializeMessage(&inMessage)));
-    PEGASUS_TEST_ASSERT(outMessage.get() != 0);
-
-    validateCIMResponseMessageAttributes(&inMessage, outMessage.get());
-}
-
 //
 // testCIMInitializeProviderAgentResponseMessage
 //
@@ -2357,11 +2358,6 @@ void testMessageSerialization()
     testCIMStopAllProvidersRequestMessage(oc4, mid3, qids1);
     testCIMStopAllProvidersRequestMessage(oc1, mid4, qids2);
 
-    testCIMInitializeProviderRequestMessage(oc1, mid1, qids2);
-    testCIMInitializeProviderRequestMessage(oc2, mid2, qids3);
-    testCIMInitializeProviderRequestMessage(oc3, mid3, qids4);
-    testCIMInitializeProviderRequestMessage(oc4, mid4, qids1);
-
     testCIMInitializeProviderAgentRequestMessage(
         oc2, mid1, mid4, spa3, false,  true, qids2);
     testCIMInitializeProviderAgentRequestMessage(
@@ -2523,11 +2519,6 @@ void testMessageSerialization()
     testCIMStopAllProvidersResponseMessage(oc3, mid4, ex4, qids3);
     testCIMStopAllProvidersResponseMessage(oc4, mid1, ex1, qids4);
 
-    testCIMInitializeProviderResponseMessage(oc1, mid1, ex4, qids3);
-    testCIMInitializeProviderResponseMessage(oc2, mid2, ex1, qids4);
-    testCIMInitializeProviderResponseMessage(oc3, mid3, ex2, qids1);
-    testCIMInitializeProviderResponseMessage(oc4, mid4, ex3, qids2);
-
     testCIMInitializeProviderAgentResponseMessage(oc1, mid4, ex3, qids1);
     testCIMInitializeProviderAgentResponseMessage(oc2, mid1, ex4, qids2);
     testCIMInitializeProviderAgentResponseMessage(oc3, mid2, ex1, qids3);
