@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -59,7 +57,7 @@ void test01()
     // Test clone
     CIMProperty p1clone = p1.clone();
     CIMProperty p2clone = p2.clone();
-   
+
     // Test print
 
     if(verbose)
@@ -158,21 +156,21 @@ void test01()
 
     // Tests for value insertion.
     {
-           CIMProperty p1(CIMName ("p1"), String("Hi There"));
-           // test for CIMValue and type
-           CIMProperty p2(CIMName ("p2"), Uint32(999));
-           // test for CIMValue and type
+        CIMProperty px(CIMName ("p1"), String("Hi There"));
+        // test for CIMValue and type
+        CIMProperty py(CIMName ("p2"), Uint32(999));
+        // test for CIMValue and type
 
-       //Test getName and setName
-       PEGASUS_TEST_ASSERT(p1.getName() == CIMName ("p1"));
-       p1.setName(CIMName ("px"));
-       PEGASUS_TEST_ASSERT(p1.getName() == CIMName ("px"));
+        //Test getName and setName
+        PEGASUS_TEST_ASSERT(px.getName() == CIMName ("p1"));
+        px.setName(CIMName ("px"));
+        PEGASUS_TEST_ASSERT(px.getName() == CIMName ("px"));
 
-       PEGASUS_TEST_ASSERT(p2.getName() == CIMName ("p2"));
-       p2.setName(CIMName ("py"));
-       PEGASUS_TEST_ASSERT(p2.getName() == CIMName ("py"));
+        PEGASUS_TEST_ASSERT(py.getName() == CIMName ("p2"));
+        py.setName(CIMName ("py"));
+        PEGASUS_TEST_ASSERT(py.getName() == CIMName ("py"));
 
-       // Test setValue and getValue
+        // ATTN: Test setValue and getValue
     }
 }
 
@@ -226,15 +224,15 @@ void test02()
     PEGASUS_TEST_ASSERT(cp1.findQualifier(
         CIMName ("stuf")) == PEG_NOT_FOUND);
     PEGASUS_TEST_ASSERT(cp1.getQualifierCount() == 4);
- 
-        try 
+
+        try
         {
             p1.getQualifier(0);
         }
         catch(IndexOutOfBoundsException& e)
         {
             if(verbose)
-                cout << "Exception: " << e.getMessage() << endl;    
+                cout << "Exception: " << e.getMessage() << endl;
         }
 }
 //
@@ -281,7 +279,7 @@ void test04()
     String p =  "//localhost/root/SampleProvider:"
                 "TST_PersonDynamic.Name=\"Father\"";
     CIMObjectPath path = p;
-        
+
     String referenceClassName = "TST_Person";
     CIMProperty p1(CIMName ("message"), path, 0,
                    CIMName(referenceClassName));
@@ -289,7 +287,7 @@ void test04()
     PEGASUS_TEST_ASSERT(p1.getReferenceClassName()==
                         CIMName(referenceClassName));
     PEGASUS_TEST_ASSERT(p1.getType() == CIMTYPE_REFERENCE);
-    
+
     CIMValue v1;
     v1 = p1.getValue();
     PEGASUS_TEST_ASSERT(v1.getType() ==  CIMTYPE_REFERENCE);
@@ -323,7 +321,7 @@ void test04()
     v1.get(pathout2);
     // Now compare the paths
 
-    
+
     if(verbose)
         XmlWriter::printPropertyElement(p2, cout);
 }
