@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -107,8 +105,8 @@ void test01()
             {
                 if (verbose)
                 {
-                    cout << "keyName= " <<  kbArray[i].getName() << " Value= "
-                         << kbArray[i].getValue() << endl;
+                    cout << "keyName= " <<  kbArray[i].getName().getString()
+                         << " Value= " << kbArray[i].getValue() << endl;
                 }
                 if ( kbArray[i].getName() == CIMName ("B") )
                 {
@@ -206,7 +204,7 @@ void test01()
         "TennisPlayer.first=\"Chris\",last=\"Evert\"");
     CIMObjectPath h17("//u812/root/cimv25:"
         "TennisPlayer.first=\"Chris\",last=\"Evert\"");
-     
+
     // Hostname with '_' character support checks, see bug#2556.
     CIMObjectPath h18("//_atp:9999/_root/_cimv25:_TennisPlayer");
     CIMObjectPath h19("//a_tp/_root/_cimv25:_TennisPlayer");
@@ -273,7 +271,7 @@ void test01()
     catch (const Exception&)
     {
        errorDetected = true;
-    } 
+    }
     PEGASUS_TEST_ASSERT(errorDetected);
 
     errorDetected = false;
@@ -286,7 +284,7 @@ void test01()
     catch (const Exception&)
     {
        errorDetected = true;
-    } 
+    }
     PEGASUS_TEST_ASSERT(errorDetected);
 
     errorDetected = false;
@@ -299,7 +297,7 @@ void test01()
     catch (const Exception&)
     {
        errorDetected = true;
-    } 
+    }
     PEGASUS_TEST_ASSERT(errorDetected);
 
     errorDetected = false;
@@ -319,9 +317,9 @@ void test01()
     try
     {
         // Octet out of range
-        CIMObjectPath h5("//192.168.256.80:77/root/cimv25:"
+        CIMObjectPath op("//192.168.256.80:77/root/cimv25:"
             "TennisPlayer.first=\"Chris\",last=\"Evert\"");
-    } 
+    }
     catch (const Exception&)
     {
         errorDetected = true;
@@ -332,7 +330,7 @@ void test01()
     try
     {
         // Missing port
-        CIMObjectPath h5("//192.168.1.80:/root/cimv25:"
+        CIMObjectPath op("//192.168.1.80:/root/cimv25:"
             "TennisPlayer.first=\"Chris\",last=\"Evert\"");
     }
     catch (const Exception&)
@@ -345,9 +343,9 @@ void test01()
     try
     {
         // Too many octets
-        CIMObjectPath h5("//192.168.1.80.12/root/cimv25:"
+        CIMObjectPath op("//192.168.1.80.12/root/cimv25:"
             "TennisPlayer.first=\"Chris\",last=\"Evert\"");
-    } 
+    }
     catch (const Exception&)
     {
         errorDetected = true;
@@ -358,7 +356,7 @@ void test01()
     try
     {
         // Too few octets
-        CIMObjectPath h5("//192.168.80:77/root/cimv25:"
+        CIMObjectPath op("//192.168.80:77/root/cimv25:"
             "TennisPlayer.first=\"Chris\",last=\"Evert\"");
     }
     catch (const Exception&)
@@ -371,7 +369,7 @@ void test01()
     try
     {
         // Missing port
-        CIMObjectPath h1("//usopen-9.usta-1-a.org:/root/cimv25:"
+        CIMObjectPath op("//usopen-9.usta-1-a.org:/root/cimv25:"
             "TennisPlayer.first=\"Chris\",last=\"Evert\"");
     }
     catch (Exception&)
@@ -384,7 +382,7 @@ void test01()
     try
     {
         // Hostname (IP) without trailing '/' (with port)
-        CIMObjectPath h5("//192.168.256.80:77");
+        CIMObjectPath op("//192.168.256.80:77");
     }
     catch (const Exception&)
     {
@@ -396,7 +394,7 @@ void test01()
     try
     {
         // Hostname (IP) without trailing '/' (without port)
-        CIMObjectPath h5("//192.168.256.80");
+        CIMObjectPath op("//192.168.256.80");
     }
     catch (const Exception&)
     {
@@ -408,7 +406,7 @@ void test01()
     try
     {
         // Hostname without trailing '/' (with port)
-        CIMObjectPath h5("//usopen-9.usta-1-a.org:77");
+        CIMObjectPath op("//usopen-9.usta-1-a.org:77");
     }
     catch (const Exception&)
     {
@@ -420,7 +418,7 @@ void test01()
     try
     {
         // Hostname without trailing '/' (without port)
-        CIMObjectPath h5("//usopen-9.usta-1-a.org");
+        CIMObjectPath op("//usopen-9.usta-1-a.org");
     }
     catch (const Exception&)
     {
@@ -432,7 +430,7 @@ void test01()
     try
     {
         // Invalid first character
-        CIMObjectPath h1("//+usopen-9.usta-1-a.1org:77/root/cimv25:"
+        CIMObjectPath op("//+usopen-9.usta-1-a.1org:77/root/cimv25:"
             "TennisPlayer.first=\"Chris\",last=\"Evert\"");
     }
     catch (Exception&)
@@ -445,7 +443,7 @@ void test01()
     try
     {
         // Non-alphanum char (?)
-        CIMObjectPath h1("//usopen-9.usta?-1-a.org:77/root/cimv25:"
+        CIMObjectPath op("//usopen-9.usta?-1-a.org:77/root/cimv25:"
             "TennisPlayer.first=\"Chris\",last=\"Evert\"");
     }
     catch (Exception&)
@@ -458,7 +456,7 @@ void test01()
     try
     {
         // Leading dot
-        CIMObjectPath h2("//.usopen-9.usta-1-a.org:77/root/cimv25:"
+        CIMObjectPath op("//.usopen-9.usta-1-a.org:77/root/cimv25:"
             "TennisPlayer.first=\"Chris\",last=\"Evert\"");
     }
     catch (Exception&)
@@ -471,7 +469,7 @@ void test01()
     try
     {
         // Dot in the wrong spot (before a -)
-        CIMObjectPath h3("//usopen.-9.usta-1-a.org:77/root/cimv25:"
+        CIMObjectPath op("//usopen.-9.usta-1-a.org:77/root/cimv25:"
             "TennisPlayer.first=\"Chris\",last=\"Evert\"");
     }
     catch (Exception&)
@@ -484,7 +482,7 @@ void test01()
     try
     {
         // Two dots in a row
-        CIMObjectPath h4("//usopen-9.usta-1-a..org:77/root/cimv25:"
+        CIMObjectPath op("//usopen-9.usta-1-a..org:77/root/cimv25:"
             "TennisPlayer.first=\"Chris\",last=\"Evert\"");
     }
     catch (Exception&)
@@ -497,7 +495,7 @@ void test01()
     try
     {
         // Trailing dot
-        CIMObjectPath h5("//usopen-9.usta-1-a.org.:77/root/cimv25:"
+        CIMObjectPath op("//usopen-9.usta-1-a.org.:77/root/cimv25:"
             "TennisPlayer.first=\"Chris\",last=\"Evert\"");
     }
     catch (Exception&)
@@ -673,7 +671,7 @@ void test03()
 
     CIMKeyBinding kb11("test11", String("+100"), CIMKeyBinding::NUMERIC);
     // Unsigned ints may not start with "+"
-    PEGASUS_TEST_ASSERT(!kb11.equal(Uint64(100)));  
+    PEGASUS_TEST_ASSERT(!kb11.equal(Uint64(100)));
     PEGASUS_TEST_ASSERT(!kb11.equal(Uint32(100)));
     PEGASUS_TEST_ASSERT(!kb11.equal(Uint16(100)));
     PEGASUS_TEST_ASSERT(!kb11.equal(Uint8(100)));
@@ -734,7 +732,7 @@ void test04()
     PEGASUS_TEST_ASSERT (aPath.identical (aPath2));
 
     CIMInstance instanceB (CIMName ("B"));
-    instanceB.addProperty (CIMProperty (CIMName ("q"), 
+    instanceB.addProperty (CIMProperty (CIMName ("q"),
         String ("pelargonium")));
     instanceB.addProperty (CIMProperty (CIMName ("r"), String ("thyme")));
     instanceB.addProperty (CIMProperty (CIMName ("s"), String ("sage")));
@@ -776,12 +774,14 @@ void test04()
 // Test handling of escape characters
 void test05()
 {
-    // Test '\' and '"' characters in a key value
-    // This represents MyClass.key1="\\\"\"\\",key2="\"\"\"\"\\\\\\\\"
-    String s1 = "MyClass.key1=\"\\\\\\\"\\\"\\\\\","
+    {
+        // Test '\' and '"' characters in a key value
+        // This represents MyClass.key1="\\\"\"\\",key2="\"\"\"\"\\\\\\\\"
+        String s1 = "MyClass.key1=\"\\\\\\\"\\\"\\\\\","
                 "key2=\"\\\"\\\"\\\"\\\"\\\\\\\\\\\\\\\\\"";
-    CIMObjectPath r1 = s1;
-    PEGASUS_TEST_ASSERT(r1.toString() == s1);
+        CIMObjectPath r1 = s1;
+        PEGASUS_TEST_ASSERT(r1.toString() == s1);
+    }
 
     // Catch invalid escape sequences in a key value
     Boolean errorDetected;
