@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//=============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%////////////////////////////////////////////////////////////////////////////
 
@@ -76,36 +74,12 @@ test_async_queue::test_async_queue (ROLE role):Base (
 
 }
 
-
-
-
-Boolean test_async_queue::messageOK (const Message * msg)
-{
-  if (msg->getMask () & MessageMask::ha_async)
-    {
-      if (_role == CLIENT)
-        {
-          if (msg->getType () == ASYNC_ASYNC_OP_RESULT)
-            return true;
-        }
-      else
-        {
-          if (msg->getType () == ASYNC_ASYNC_OP_START)
-            return true;
-          if (msg->getType () == ASYNC_CIMSERVICE_STOP)
-            return true;
-        }
-    }
-  return true;
-}
-
-
 void
 test_async_queue::_handle_async_request (AsyncRequest * rq)
 {
   if ((rq->getType () == ASYNC_ASYNC_OP_START) ||
       (rq->getType () == ASYNC_ASYNC_LEGACY_OP_START))
-    {  
+    {
      try {
       PEGASUS_TEST_ASSERT (_role == SERVER);
       Message *response_data =
@@ -114,7 +88,7 @@ test_async_queue::_handle_async_request (AsyncRequest * rq)
         new async_complete (static_cast < async_start & >(*rq),
                             async_results::OK,
                             response_data);
-      _complete_op_node (rq->op, 0, 0, async_results::ASYNC_COMPLETE);
+      _complete_op_node (rq->op);
     } catch (const PEGASUS_STD(bad_alloc) &)
     {
         cerr <<" Out of memory!" << endl;
@@ -145,7 +119,7 @@ test_async_queue::async_handleEnqueue (AsyncOpNode * op,
                                        MessageQueue * q, void *parm)
 {
 
-  // I am static, get a pointer to my object 
+  // I am static, get a pointer to my object
   test_async_queue *myself = static_cast < test_async_queue * >(q);
 
   async_start *rq = static_cast < async_start * >(op->removeRequest());
@@ -186,14 +160,14 @@ test_async_queue::async_handleSafeEnqueue (Message * msg,
 void
 test_async_queue::_handle_stop (CimServiceStop * stop)
 {
-  try { 
+  try {
   AsyncReply *resp = new AsyncReply (ASYNC_REPLY,
                                      0,
                                      stop->op,
                                      async_results::CIM_SERVICE_STOPPED,
                                      stop->resp,
                                      stop->block);
-  _completeAsyncResponse (stop, resp, ASYNC_OPSTATE_COMPLETE, 0);
+  _completeAsyncResponse (stop, resp);
   _die_now = 1;
   } catch (const PEGASUS_STD(bad_alloc) &) {
     cerr << "Out of memory in _handle_stop. Continuing tests .. " << endl;
@@ -246,11 +220,11 @@ client_func (void *parm)
 
     test_async_queue *client = new test_async_queue (test_async_queue::CLIENT);
 
-    // find the server 
-    Array < Uint32 > services;
-    while (services.size () == 0)
+    // find the server
+    MessageQueue *serverQueue = 0;
+    while (serverQueue == 0)
     {
-        client->find_services (String ("server"), 0, 0, &services);
+        serverQueue = MessageQueue::lookup("server");
         // It is a good idea to yield to other threads. You should do this,
         // but this test-case stresses situations in which does not happen.
         //Threads::yield ();
@@ -277,13 +251,13 @@ client_func (void *parm)
             AsyncOperationStart *async_rq =
                 new AsyncOperationStart(
                     op,
-                    services[0],
+                    serverQueue->getQueueId(),
                     client->getQueueId(),
                     false,
                     cim_rq);
             client->SendAsync(
                 op,
-                services[0],
+                serverQueue->getQueueId(),
                 test_async_queue::async_handleEnqueue,
                 client,
                 (void *) 0);
@@ -297,7 +271,7 @@ client_func (void *parm)
 
         // You really ought to allow other threads to their job (like picking
         // up all of these messages, but we want to stress test unfair
-        // circumstances. 
+        // circumstances.
         //Threads::yield ();
     }
 
@@ -318,40 +292,6 @@ client_func (void *parm)
         Threads::yield();
     }
 
-    if (verbose)
-    {
-        cout << "testing fast safe async send" << endl;
-    }
-
-    test_async_queue::msg_count = 0;
-    requestCount = 0; 
-    while (requestCount < 10000)
-    {
-        // The problem on multi-processor machines is that if we make it
-        // continue on sending the messages, and the MessageQueueService
-        // does not get to pick up the messages, the machine can crawl to
-        // halt with about 300-400 threads and ever-continuing number of
-        // them created.
-        try 
-        {
-            Message *cim_rq = new Message(CIM_GET_INSTANCE_REQUEST_MESSAGE);
-
-            client->SendAsync(
-                cim_rq,
-                services[0],
-                test_async_queue::async_handleSafeEnqueue,
-                client,
-                (void *) NULL);
-        }
-        catch (const PEGASUS_STD(bad_alloc) &)
-        {
-            cerr <<" Out of memory! Continuing tests." << endl;
-            continue;
-        }
-        requestCount++;
-        //Threads::yield ();
-    }
-
     if (verbose)
     {
         cout << "Waiting until all messages are flushed. " << endl;
@@ -377,7 +317,7 @@ client_func (void *parm)
     {
         CimServiceStop *stop = new CimServiceStop(
             0,
-            services[0],
+            serverQueue->getQueueId(),
             client->getQueueId (),
             true);
 
@@ -390,10 +330,10 @@ client_func (void *parm)
         cerr <<" Out of memory! Continuing tests." << endl;
     }
 
-    // wait for the server to shut down 
-    while (services.size () > 0)
+    // wait for the server to shut down
+    while (serverQueue)
     {
-        client->find_services (String ("server"), 0, 0, &services);
+        serverQueue = MessageQueue::lookup("server");
         Threads::yield ();
     }
 
@@ -402,11 +342,8 @@ client_func (void *parm)
         cout << "shutting down client" << endl;
     }
 
-    client->deregister_service();
-
     delete client;
-    myself->exit_self((ThreadReturnType) 1);
-    return (0);
+    return ThreadReturnType(0);
 }
 
 
@@ -424,10 +361,7 @@ server_func (void *parm)
   if (verbose)
     cout << "server shutting down" << endl;
 
-  server->deregister_service ();
-
   delete server;
 
-  myself->exit_self ((ThreadReturnType) 1);
-  return (0);
+  return ThreadReturnType(0);
 }
