@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
 //
-//==============================================================================
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -93,7 +91,7 @@ extern void *create_cimmof_buffer_wrapper(const FILE *f, int size);
 
 const char LexerError::MSG[] = "";
 
-cimmofParser *cimmofParser::_instance = 0;
+cimmofParser* cimmofParser::_instance = 0;
 
 cimmofParser::cimmofParser():
   parser(),  _cmdline(0),
@@ -114,6 +112,11 @@ cimmofParser * cimmofParser::Instance()
     return _instance;
 }
 
+void cimmofParser::destroy()
+{
+    delete _instance;
+    _instance = 0;
+}
 
   //------------------------------------------------------------------
   // Methods for manipulating the members added in this specialization
@@ -149,6 +152,11 @@ Boolean cimmofParser::setRepository(void)
         if (rep != "")
         {
             cimmofRepositoryInterface::_repositoryType rt;
+#ifdef PEGASUS_ENABLE_MRR_GENERATION
+            if (_cmdline->mrr())
+                rt = cimmofRepositoryInterface::REPOSITORY_INTERFACE_MRR;
+            else
+#endif
             if (_cmdline->is_local())
                 rt = cimmofRepositoryInterface::REPOSITORY_INTERFACE_LOCAL;
             else
@@ -165,7 +173,13 @@ Boolean cimmofParser::setRepository(void)
                 {
                     mode = CIMRepository::MODE_BIN;
                 }
-                _repository.init(rt, combined, mode, _ot);
+                _repository.init(rt, combined, mode, _ot, !_cmdline->discard());
+
+                _repository.start();
+            }
+            catch (const CannotConnectException &)
+            {
+                throw;
             }
             catch(Exception &e)
             {
@@ -305,7 +319,7 @@ int cimmofParser::setInputBuffer(const FILE *f, Boolean closeCurrent)
 int cimmofParser::setInputBuffer(void *buffstate, Boolean closeCurrent)
 {
     return switch_to_buffer_wrapper(buffstate, closeCurrent);
-};
+}
 
 //--------------------------------------------------------------------
 // Handle include files from either the file name or an open handle
@@ -432,6 +446,9 @@ int cimmofParser::parse()
         }
     }
     ret =  cimmof_parse();
+
+    _repository.finish();
+
     if (_cmdline)
     {
 
@@ -454,7 +471,7 @@ void cimmofParser::log_parse_error(char *token, const char *errmsg) const
 {
     String message;
     char buf[40];  // itoa can't overflow
-    sprintf(buf, "%d", get_lineno());
+    sprintf(buf, "%u", get_lineno());
     cimmofMessages::arglist arglist;
     arglist.append(get_current_filename());
     arglist.append(buf);
@@ -1193,13 +1210,19 @@ CIMProperty * cimmofParser::PropertyFromInstance(CIMInstance &instance,
     // OK, we got the className.  Use it to find the class object.
     try
     {
-        Array<String> propertyList;
-        propertyList.append(propertyName.getString());
         CIMClass c = _repository.getClass(getNamespacePath(), className);
         Uint32 pos = c.findProperty(propertyName);
-        if (pos != (Uint32)-1)
+        if (pos != PEG_NOT_FOUND)
         {
-            return new CIMProperty(c.getProperty(pos));
+            // Return a copy of the property without qualifiers.
+            CIMProperty p = c.getProperty(pos);
+            return new CIMProperty(
+                p.getName(),
+                p.getValue(),
+                p.getArraySize(),
+                p.getReferenceClassName(),
+                p.getClassOrigin(),
+                p.getPropagated());
         }
     }
     catch (Exception &e)
