@@ -1,3 +1,6 @@
+/* To be inserted in other files to bypass the chksrc tests */
+/* NOCHKSRC */
+
 /* A Bison parser, made by GNU Bison 2.3.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
@@ -43,8 +46,6 @@
    define necessary library symbols; they are noted "INFRINGES ON
    USER NAME SPACE" below.  */
 
-/* NOCHKSRC */
-
 /* Identify Bison output.  */
 #define YYBISON 1
 
@@ -214,7 +215,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 31 "cimmof.y"
+#line 29 "cimmof.y"
 
   /* Flex grammar created from CIM Specification Version 2.2 Appendix A */
 
@@ -255,7 +256,7 @@
 #define YYSTACKSIZE 2000
 
 #include <cstdlib>
-#if !defined(PEGASUS_PLATFORM_ZOS_ZSERIES_IBM) && !defined(PEGASUS_OS_VMS)
+#if !defined(PEGASUS_OS_ZOS) && !defined(PEGASUS_OS_VMS)
 #if defined(PEGASUS_OS_DARWIN)
 #include <sys/malloc.h>
 #else
@@ -270,7 +271,8 @@
 #include "cimmofParser.h"
 #include "valueFactory.h"
 #include "memobjs.h"
-#include "qualifierList.h"
+#include <Pegasus/Common/CIMQualifierList.h>
+#include <Pegasus/Common/AutoPtr.h>
 
 //include any useful debugging stuff here
 
@@ -310,7 +312,7 @@ extern int   cimmof_leng;
   CIMFlavor g_flavor = CIMFlavor (CIMFlavor::NONE);
   CIMScope g_scope = CIMScope ();
   //ATTN: BB 2001 BB P1 - Fixed size qualifier list max 20. Make larger or var
-  qualifierList g_qualifierList(20);
+  CIMQualifierList g_qualifierList;
   CIMMethod *g_currentMethod = 0;
   CIMClass *g_currentClass = 0;
   CIMInstance *g_currentInstance = 0;
@@ -374,7 +376,7 @@ static void MOF_trace2(const char * str, const char * S);
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 170 "cimmof.y"
+#line 169 "cimmof.y"
 {
   //char                     *strval;
   CIMClass                 *mofclass;
@@ -397,8 +399,8 @@ typedef union YYSTYPE
   struct pragma            *pragma;
   TYPED_INITIALIZER_VALUE  *typedinitializer;
 }
-/* Line 193 of yacc.c.  */
-#line 400 "cimmoftemp"
+/* Line 187 of yacc.c.  */
+#line 401 "cimmoftemp"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -411,7 +413,7 @@ typedef union YYSTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 413 "cimmoftemp"
+#line 414 "cimmoftemp"
 
 #ifdef short
 # undef short
@@ -756,23 +758,23 @@ static const yytype_int16 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   306,   306,   309,   310,   314,   315,   320,   324,   336,
-     344,   364,   367,   368,   371,   372,   375,   376,   379,   385,
-     390,   410,   421,   440,   443,   446,   452,   453,   454,   457,
-     485,   486,   497,   511,   530,   541,   558,   561,   564,   565,
-     568,   572,   575,   578,   584,   587,   590,   592,   599,   601,
-     603,   610,   616,   622,   628,   638,   641,   654,   656,   660,
-     661,   663,   665,   667,   673,   674,   675,   676,   677,   680,
-     682,   686,   687,   693,   725,   727,   731,   732,   735,   753,
-     782,   784,   787,   790,   800,   802,   806,   825,   828,   837,
-     842,   853,   876,   894,   899,   900,   907,   965,   969,   975,
-     982,   985,  1004,  1014,  1023,  1026,  1032,  1033,  1038,  1040,
-    1041,  1042,  1044,  1045,  1046,  1047,  1048,  1052,  1055,  1061,
-    1065,  1066,  1080,  1082,  1083,  1084,  1085,  1088,  1090,  1093,
-    1094,  1098,  1099,  1100,  1101,  1102,  1105,  1106,  1107,  1108,
-    1109,  1110,  1111,  1112,  1113,  1116,  1118,  1128,  1130,  1134,
-    1139,  1141,  1144,  1158,  1160,  1166,  1172,  1178,  1184,  1191,
-    1194
+       0,   305,   305,   308,   309,   313,   314,   319,   323,   335,
+     343,   363,   366,   372,   377,   378,   381,   382,   385,   391,
+     396,   416,   427,   446,   449,   452,   462,   463,   464,   467,
+     495,   496,   507,   521,   540,   551,   568,   571,   574,   575,
+     578,   585,   592,   599,   605,   608,   611,   613,   620,   622,
+     624,   631,   637,   643,   649,   659,   662,   675,   677,   681,
+     682,   684,   686,   688,   694,   695,   696,   697,   698,   701,
+     703,   707,   708,   714,   746,   748,   752,   753,   756,   774,
+     803,   805,   808,   811,   821,   823,   827,   846,   849,   858,
+     863,   874,   897,   915,   920,   921,   928,   986,   990,   996,
+    1003,  1006,  1025,  1035,  1044,  1047,  1053,  1054,  1062,  1064,
+    1065,  1066,  1068,  1069,  1070,  1071,  1072,  1076,  1079,  1088,
+    1092,  1093,  1107,  1109,  1110,  1111,  1112,  1115,  1117,  1123,
+    1124,  1128,  1129,  1130,  1131,  1132,  1135,  1136,  1137,  1138,
+    1139,  1140,  1141,  1142,  1143,  1146,  1148,  1158,  1160,  1164,
+    1169,  1171,  1174,  1189,  1191,  1198,  1204,  1210,  1216,  1223,
+    1226
 };
 #endif
 
@@ -1643,7 +1645,7 @@ yyparse ()
 #endif
 #endif
 {
-  
+
   int yystate;
   int yyn;
   int yyresult;
@@ -1888,34 +1890,34 @@ yyreduce:
   switch (yyn)
     {
         case 5:
-#line 314 "cimmof.y"
+#line 313 "cimmof.y"
     { /* FIXME: Where do we put directives? */ ;}
     break;
 
   case 6:
-#line 316 "cimmof.y"
-    { 
+#line 315 "cimmof.y"
+    {
             cimmofParser::Instance()->addQualifier((yyvsp[(1) - (1)].mofqualifier));
             delete (yyvsp[(1) - (1)].mofqualifier);
         ;}
     break;
 
   case 7:
-#line 321 "cimmof.y"
-    { 
+#line 320 "cimmof.y"
+    {
             cimmofParser::Instance()->addClass((yyvsp[(1) - (1)].mofclass));
         ;}
     break;
 
   case 8:
-#line 325 "cimmof.y"
+#line 324 "cimmof.y"
     {
         cimmofParser::Instance()->addInstance((yyvsp[(1) - (1)].instance));
         ;}
     break;
 
   case 9:
-#line 337 "cimmof.y"
+#line 336 "cimmof.y"
     {
     YACCTRACE("classDeclaration");
     if (g_currentAliasDecl != String::EMPTY)
@@ -1924,7 +1926,7 @@ yyreduce:
     break;
 
   case 10:
-#line 345 "cimmof.y"
+#line 344 "cimmof.y"
     {
     // create new instance of class with className and superclassName
     // put returned class object on stack
@@ -1932,7 +1934,7 @@ yyreduce:
     (yyval.mofclass) = cimmofParser::Instance()->newClassDecl(*(yyvsp[(3) - (5)].cimnameval), *(yyvsp[(5) - (5)].cimnameval));
 
     // put list of qualifiers into class
-    applyQualifierList(&g_qualifierList, (yyval.mofclass));
+    applyQualifierList(g_qualifierList, *(yyval.mofclass));
 
     g_currentAliasRef = *(yyvsp[(4) - (5)].strval);
     if (g_currentClass)
@@ -1945,48 +1947,53 @@ yyreduce:
     break;
 
   case 11:
-#line 364 "cimmof.y"
+#line 363 "cimmof.y"
     {;}
     break;
 
   case 12:
 #line 367 "cimmof.y"
-    { (yyval.cimnameval) = new CIMName(*(yyvsp[(2) - (2)].cimnameval)); ;}
+    {
+    (yyval.cimnameval) = new CIMName(*(yyvsp[(2) - (2)].cimnameval));
+    delete (yyvsp[(2) - (2)].cimnameval);
+;}
     break;
 
   case 13:
-#line 368 "cimmof.y"
-    { (yyval.cimnameval) = new CIMName(); ;}
+#line 372 "cimmof.y"
+    {
+    (yyval.cimnameval) = new CIMName();
+;}
     break;
 
   case 18:
-#line 380 "cimmof.y"
+#line 386 "cimmof.y"
     {
         YACCTRACE("classFeature:applyProperty");
         cimmofParser::Instance()->applyProperty(*g_currentClass, *(yyvsp[(1) - (1)].property));
-        delete (yyvsp[(1) - (1)].property); 
+        delete (yyvsp[(1) - (1)].property);
     ;}
     break;
 
   case 19:
-#line 386 "cimmof.y"
+#line 392 "cimmof.y"
     {
         YACCTRACE("classFeature:applyMethod");
-        cimmofParser::Instance()->applyMethod(*g_currentClass, *(yyvsp[(1) - (1)].method)); 
+        cimmofParser::Instance()->applyMethod(*g_currentClass, *(yyvsp[(1) - (1)].method));
     ;}
     break;
 
   case 20:
-#line 391 "cimmof.y"
+#line 397 "cimmof.y"
     {
         YACCTRACE("classFeature:applyProperty");
         cimmofParser::Instance()->applyProperty(*g_currentClass, *(yyvsp[(1) - (1)].property));
-        delete (yyvsp[(1) - (1)].property); 
+        delete (yyvsp[(1) - (1)].property);
     ;}
     break;
 
   case 21:
-#line 411 "cimmof.y"
+#line 417 "cimmof.y"
     {
     YACCTRACE("methodDeclaration");
     (yyval.method) = (yyvsp[(2) - (4)].method);
@@ -1994,7 +2001,7 @@ yyreduce:
     break;
 
   case 22:
-#line 422 "cimmof.y"
+#line 428 "cimmof.y"
     {
     YACCTRACE("methodHead");
     if (g_currentMethod)
@@ -2007,19 +2014,22 @@ yyreduce:
     (yyval.method) = g_currentMethod;
 
     // apply the method qualifier list.
-    applyQualifierList(&g_qualifierList, (yyval.method));
+    applyQualifierList(g_qualifierList, *(yyval.method));
 
     delete (yyvsp[(2) - (2)].cimnameval);
 ;}
     break;
 
   case 25:
-#line 446 "cimmof.y"
-    { (yyval.cimnameval) = new CIMName(*(yyvsp[(1) - (1)].strval)); ;}
+#line 453 "cimmof.y"
+    {
+    (yyval.cimnameval) = new CIMName(*(yyvsp[(1) - (1)].strval));
+    delete (yyvsp[(1) - (1)].strval);
+;}
     break;
 
   case 29:
-#line 458 "cimmof.y"
+#line 468 "cimmof.y"
     {
     // ATTN: P2 2002 Question Need to create default value including type?
 
@@ -2039,7 +2049,7 @@ yyreduce:
     g_referenceClassName = CIMName();
 
     YACCTRACE("parameter:applyQualifierList");
-    applyQualifierList(&g_qualifierList, p);
+    applyQualifierList(g_qualifierList, *p);
 
     cp->applyParameter(*g_currentMethod, *p);
     delete p;
@@ -2048,17 +2058,17 @@ yyreduce:
     break;
 
   case 30:
-#line 485 "cimmof.y"
+#line 495 "cimmof.y"
     { (yyval.datatype) = (yyvsp[(1) - (1)].datatype); ;}
     break;
 
   case 31:
-#line 486 "cimmof.y"
+#line 496 "cimmof.y"
     { (yyval.datatype) = CIMTYPE_REFERENCE; ;}
     break;
 
   case 32:
-#line 498 "cimmof.y"
+#line 508 "cimmof.y"
     {
     // set body to stack and apply qualifier list
     // ATTN: the apply qualifer only works here because
@@ -2068,20 +2078,20 @@ yyreduce:
     // applied.
     YACCTRACE("propertyDeclaration:");
     (yyval.property) = (yyvsp[(2) - (3)].property);
-    applyQualifierList(&g_qualifierList, (yyval.property));
+    applyQualifierList(g_qualifierList, *(yyval.property));
 ;}
     break;
 
   case 33:
-#line 512 "cimmof.y"
+#line 522 "cimmof.y"
     {
     CIMValue *v = valueFactory::createValue((yyvsp[(1) - (4)].datatype), (yyvsp[(3) - (4)].ival),
             ((yyvsp[(4) - (4)].typedinitializer)->type == CIMMOF_NULL_VALUE), (yyvsp[(4) - (4)].typedinitializer)->value);
-    if ((yyvsp[(3) - (4)].ival) == -1) 
+    if ((yyvsp[(3) - (4)].ival) == -1)
     {
         (yyval.property) = cimmofParser::Instance()->newProperty(*(yyvsp[(2) - (4)].cimnameval), *v, false, 0);
-    } 
-    else 
+    }
+    else
     {
         (yyval.property) = cimmofParser::Instance()->newProperty(*(yyvsp[(2) - (4)].cimnameval), *v, true, (yyvsp[(3) - (4)].ival));
     }
@@ -2093,7 +2103,7 @@ yyreduce:
     break;
 
   case 35:
-#line 543 "cimmof.y"
+#line 553 "cimmof.y"
     {
     String s(*(yyvsp[(2) - (6)].strval));
     if (!String::equal(*(yyvsp[(5) - (6)].strval), String::EMPTY))
@@ -2101,7 +2111,7 @@ yyreduce:
     CIMValue *v = valueFactory::createValue(CIMTYPE_REFERENCE, -1, true, &s);
     //KS add the isArray and arraysize parameters. 8 mar 2002
     (yyval.property) = cimmofParser::Instance()->newProperty(*(yyvsp[(4) - (6)].strval), *v, false,0, *(yyvsp[(2) - (6)].strval));
-    applyQualifierList(&g_qualifierList, (yyval.property));
+    applyQualifierList(g_qualifierList, *(yyval.property));
     delete (yyvsp[(2) - (6)].strval);
     delete (yyvsp[(4) - (6)].strval);
     delete (yyvsp[(5) - (6)].strval);
@@ -2110,43 +2120,51 @@ yyreduce:
     break;
 
   case 36:
-#line 558 "cimmof.y"
+#line 568 "cimmof.y"
     { (yyval.strval) = (yyvsp[(1) - (1)].strval); ;}
     break;
 
   case 37:
-#line 561 "cimmof.y"
+#line 571 "cimmof.y"
     { (yyval.strval) = (yyvsp[(1) - (1)].strval); ;}
     break;
 
   case 38:
-#line 564 "cimmof.y"
+#line 574 "cimmof.y"
     { (yyval.strval) = (yyvsp[(2) - (2)].strval); ;}
     break;
 
   case 39:
-#line 565 "cimmof.y"
+#line 575 "cimmof.y"
     { (yyval.strval) = new String(String::EMPTY); ;}
     break;
 
   case 40:
-#line 568 "cimmof.y"
+#line 579 "cimmof.y"
     {
-    g_referenceClassName = *(yyvsp[(1) - (2)].cimnameval); ;}
+    g_referenceClassName = *(yyvsp[(1) - (2)].cimnameval);
+    delete (yyvsp[(1) - (2)].cimnameval);
+;}
     break;
 
   case 41:
-#line 572 "cimmof.y"
-    { (yyval.cimnameval) = new CIMName(*(yyvsp[(1) - (1)].strval)); ;}
+#line 586 "cimmof.y"
+    {
+    (yyval.cimnameval) = new CIMName(*(yyvsp[(1) - (1)].strval));
+    delete (yyvsp[(1) - (1)].strval);
+;}
     break;
 
   case 42:
-#line 575 "cimmof.y"
-    { (yyval.cimnameval) = new CIMName(*(yyvsp[(1) - (1)].strval)); ;}
+#line 593 "cimmof.y"
+    {
+    (yyval.cimnameval) = new CIMName(*(yyvsp[(1) - (1)].strval));
+    delete (yyvsp[(1) - (1)].strval);
+;}
     break;
 
   case 43:
-#line 580 "cimmof.y"
+#line 601 "cimmof.y"
     {
             (yyval.ival) = (Uint32) valueFactory::stringToUint(*(yyvsp[(2) - (3)].strval), CIMTYPE_UINT32);
             delete (yyvsp[(2) - (3)].strval);
@@ -2154,22 +2172,22 @@ yyreduce:
     break;
 
   case 44:
-#line 585 "cimmof.y"
+#line 606 "cimmof.y"
     { (yyval.ival) = 0; ;}
     break;
 
   case 45:
-#line 587 "cimmof.y"
+#line 608 "cimmof.y"
     { (yyval.ival) = -1; ;}
     break;
 
   case 46:
-#line 590 "cimmof.y"
+#line 611 "cimmof.y"
     { (yyval.typedinitializer) = (yyvsp[(2) - (2)].typedinitializer); ;}
     break;
 
   case 47:
-#line 592 "cimmof.y"
+#line 613 "cimmof.y"
     {   /* empty */
         g_typedInitializerValue.type = CIMMOF_NULL_VALUE;
         g_typedInitializerValue.value = new String(String::EMPTY);
@@ -2178,22 +2196,22 @@ yyreduce:
     break;
 
   case 48:
-#line 600 "cimmof.y"
+#line 621 "cimmof.y"
     { (yyval.strval) = (yyvsp[(1) - (1)].strval); ;}
     break;
 
   case 49:
-#line 602 "cimmof.y"
+#line 623 "cimmof.y"
     { (yyval.strval) = (yyvsp[(1) - (1)].strval); ;}
     break;
 
   case 50:
-#line 604 "cimmof.y"
+#line 625 "cimmof.y"
     { (yyval.strval) = (yyvsp[(1) - (1)].strval); ;}
     break;
 
   case 51:
-#line 611 "cimmof.y"
+#line 632 "cimmof.y"
     {
             g_typedInitializerValue.type = CIMMOF_CONSTANT_VALUE;
             g_typedInitializerValue.value =  (yyvsp[(1) - (1)].strval);
@@ -2202,7 +2220,7 @@ yyreduce:
     break;
 
   case 52:
-#line 617 "cimmof.y"
+#line 638 "cimmof.y"
     {
             g_typedInitializerValue.type = CIMMOF_NULL_VALUE;
             g_typedInitializerValue.value = new String(String::EMPTY);
@@ -2211,7 +2229,7 @@ yyreduce:
     break;
 
   case 53:
-#line 623 "cimmof.y"
+#line 644 "cimmof.y"
     {
             g_typedInitializerValue.type = CIMMOF_ARRAY_VALUE;
             g_typedInitializerValue.value =  (yyvsp[(1) - (1)].strval);
@@ -2220,7 +2238,7 @@ yyreduce:
     break;
 
   case 54:
-#line 629 "cimmof.y"
+#line 650 "cimmof.y"
     {
             g_typedInitializerValue.type = CIMMOF_REFERENCE_VALUE;
             g_typedInitializerValue.value =  (yyvsp[(1) - (1)].strval);
@@ -2229,13 +2247,13 @@ yyreduce:
     break;
 
   case 55:
-#line 639 "cimmof.y"
+#line 660 "cimmof.y"
     {
         *(yyval.strval) = valueFactory::stringWComma(String(*(yyvsp[(1) - (1)].strval))); ;}
     break;
 
   case 56:
-#line 642 "cimmof.y"
+#line 663 "cimmof.y"
     {
             YACCTRACE("constantValues:1, Value= " << *(yyvsp[(3) - (3)].strval));
             (*(yyval.strval)).append(",");
@@ -2246,66 +2264,66 @@ yyreduce:
     break;
 
   case 57:
-#line 655 "cimmof.y"
+#line 676 "cimmof.y"
     {(yyval.strval) = (yyvsp[(1) - (1)].strval);;}
     break;
 
   case 58:
-#line 657 "cimmof.y"
+#line 678 "cimmof.y"
     { (yyval.strval) = new String(String::EMPTY); ;}
     break;
 
   case 59:
-#line 660 "cimmof.y"
+#line 681 "cimmof.y"
     { (yyval.strval) = (yyvsp[(1) - (1)].strval); ;}
     break;
 
   case 60:
-#line 662 "cimmof.y"
+#line 683 "cimmof.y"
     { (yyval.strval) = (yyvsp[(1) - (1)].strval); ;}
     break;
 
   case 61:
-#line 664 "cimmof.y"
+#line 685 "cimmof.y"
     { (yyval.strval) =  (yyvsp[(1) - (1)].strval); ;}
     break;
 
   case 62:
-#line 666 "cimmof.y"
+#line 687 "cimmof.y"
     { ;}
     break;
 
   case 63:
-#line 668 "cimmof.y"
+#line 689 "cimmof.y"
     {
             (yyval.strval) = new String((yyvsp[(1) - (1)].ival) ? "T" : "F");
     ;}
     break;
 
   case 69:
-#line 681 "cimmof.y"
+#line 702 "cimmof.y"
     { (yyval.ival) = 0; ;}
     break;
 
   case 70:
-#line 683 "cimmof.y"
+#line 704 "cimmof.y"
     { (yyval.ival) = 1; ;}
     break;
 
   case 71:
-#line 686 "cimmof.y"
+#line 707 "cimmof.y"
     { (yyval.strval) = (yyvsp[(1) - (1)].strval); ;}
     break;
 
   case 72:
-#line 688 "cimmof.y"
+#line 709 "cimmof.y"
     {
         (*(yyval.strval)).append(*(yyvsp[(2) - (2)].strval));  delete (yyvsp[(2) - (2)].strval);
     ;}
     break;
 
   case 73:
-#line 694 "cimmof.y"
+#line 715 "cimmof.y"
     {
    //String oldrep = *$1;
    //String s(oldrep), s1(String::EMPTY);
@@ -2337,27 +2355,27 @@ yyreduce:
     break;
 
   case 74:
-#line 726 "cimmof.y"
+#line 747 "cimmof.y"
     { (yyval.strval) = (yyvsp[(2) - (3)].strval); ;}
     break;
 
   case 75:
-#line 728 "cimmof.y"
+#line 749 "cimmof.y"
     { (yyval.strval) = new String(String::EMPTY); ;}
     break;
 
   case 76:
-#line 731 "cimmof.y"
+#line 752 "cimmof.y"
     {;}
     break;
 
   case 77:
-#line 732 "cimmof.y"
+#line 753 "cimmof.y"
     {  ;}
     break;
 
   case 78:
-#line 736 "cimmof.y"
+#line 757 "cimmof.y"
     {
     // The objectName string is decomposed for syntactical validation purposes
     // and reassembled here for later parsing in creation of an CIMObjectPath
@@ -2376,7 +2394,7 @@ yyreduce:
     break;
 
   case 79:
-#line 754 "cimmof.y"
+#line 775 "cimmof.y"
     {
 
     CIMObjectPath AOP;
@@ -2406,22 +2424,22 @@ yyreduce:
     break;
 
   case 80:
-#line 783 "cimmof.y"
+#line 804 "cimmof.y"
     { ;}
     break;
 
   case 81:
-#line 784 "cimmof.y"
+#line 805 "cimmof.y"
     { (yyval.strval) = new String(String::EMPTY); ;}
     break;
 
   case 82:
-#line 787 "cimmof.y"
+#line 808 "cimmof.y"
     {;}
     break;
 
   case 83:
-#line 790 "cimmof.y"
+#line 811 "cimmof.y"
     {
     CIMObjectPath *m = new CIMObjectPath(
         String::EMPTY,
@@ -2433,17 +2451,17 @@ yyreduce:
     break;
 
   case 84:
-#line 801 "cimmof.y"
+#line 822 "cimmof.y"
     { (yyval.ival) = 0; ;}
     break;
 
   case 85:
-#line 803 "cimmof.y"
+#line 824 "cimmof.y"
     { (yyval.ival) = 0; ;}
     break;
 
   case 86:
-#line 807 "cimmof.y"
+#line 828 "cimmof.y"
     {
         CIMKeyBinding::Type keyBindingType;
         Char16 firstChar = (*(yyvsp[(3) - (3)].strval))[0];
@@ -2458,12 +2476,12 @@ yyreduce:
         g_KeyBindingArray.append(*kb);
         delete kb;
         delete (yyvsp[(1) - (3)].strval);
-        delete (yyvsp[(3) - (3)].strval); 
+        delete (yyvsp[(3) - (3)].strval);
     ;}
     break;
 
   case 88:
-#line 829 "cimmof.y"
+#line 850 "cimmof.y"
     {
         (yyval.strval) = (yyvsp[(2) - (2)].strval);
         g_currentAliasDecl = *(yyvsp[(2) - (2)].strval);
@@ -2475,14 +2493,14 @@ yyreduce:
     break;
 
   case 89:
-#line 837 "cimmof.y"
+#line 858 "cimmof.y"
     {
         (yyval.strval) = new String(String::EMPTY);
         g_currentAliasDecl = String::EMPTY;}
     break;
 
   case 91:
-#line 854 "cimmof.y"
+#line 875 "cimmof.y"
     {
     (yyval.instance) = g_currentInstance;
     if (g_currentAliasDecl != String::EMPTY)
@@ -2505,7 +2523,7 @@ yyreduce:
     break;
 
   case 92:
-#line 877 "cimmof.y"
+#line 898 "cimmof.y"
     {
     if (g_currentInstance)
         delete g_currentInstance;
@@ -2513,7 +2531,7 @@ yyreduce:
     g_currentInstance = cimmofParser::Instance()->newInstance(*(yyvsp[(4) - (5)].cimnameval));
     // apply the qualifierlist to the current instance
     (yyval.instance) = g_currentInstance;
-    applyQualifierList(&g_qualifierList, (yyval.instance));
+    applyQualifierList(g_qualifierList, *(yyval.instance));
     delete (yyvsp[(4) - (5)].cimnameval);
     delete (yyvsp[(5) - (5)].strval);
     if (g_currentAliasDecl != String::EMPTY)
@@ -2523,8 +2541,9 @@ yyreduce:
     break;
 
   case 96:
-#line 909 "cimmof.y"
+#line 930 "cimmof.y"
     {
+    AutoPtr<String> identifier((yyvsp[(2) - (5)].strval));
     cimmofParser *cp = cimmofParser::Instance();
     // ATTN: P1 InstanceUpdate function 2001 BB  Instance update needs
     // work here and CIMOM
@@ -2534,8 +2553,8 @@ yyreduce:
     // to the class whose name is in g_currentInstance->getClassName().
     // The steps are
     //   2. Get  property declaration's value object
-    CIMProperty *oldprop = cp->PropertyFromInstance(*g_currentInstance,
-            *(yyvsp[(2) - (5)].strval));
+    CIMProperty *oldprop =
+        cp->PropertyFromInstance(*g_currentInstance, *identifier);
     CIMValue *oldv = cp->ValueFromProperty(*oldprop);
 
     //   3. create the new Value object of the same type
@@ -2546,8 +2565,8 @@ yyreduce:
     // validation.
 
     CIMValue *v = valueFactory::createValue(oldv->getType(),
-            (((yyvsp[(4) - (5)].typedinitializer)->type == CIMMOF_ARRAY_VALUE) |
-             (((yyvsp[(4) - (5)].typedinitializer)->type == CIMMOF_NULL_VALUE) & oldprop->isArray()))?0:-1,
+            (((yyvsp[(4) - (5)].typedinitializer)->type == CIMMOF_ARRAY_VALUE) ||
+             (((yyvsp[(4) - (5)].typedinitializer)->type == CIMMOF_NULL_VALUE) && oldprop->isArray()))?0:-1,
             ((yyvsp[(4) - (5)].typedinitializer)->type == CIMMOF_NULL_VALUE),
             (yyvsp[(4) - (5)].typedinitializer)->value);
 
@@ -2556,11 +2575,10 @@ yyreduce:
     CIMProperty *newprop = cp->copyPropertyWithNewValue(*oldprop, *v);
 
     //   5. apply the qualifiers;
-    applyQualifierList(&g_qualifierList, newprop);
+    applyQualifierList(g_qualifierList, *newprop);
 
     //   6. and apply the CIMProperty to g_currentInstance.
     cp->applyProperty(*g_currentInstance, *newprop);
-    delete (yyvsp[(2) - (5)].strval);
     delete (yyvsp[(4) - (5)].typedinitializer)->value;
     delete oldprop;
     delete oldv;
@@ -2570,33 +2588,33 @@ yyreduce:
     break;
 
   case 97:
-#line 966 "cimmof.y"
+#line 987 "cimmof.y"
     {
         //printf("compilerDirectiveInclude ");
     ;}
     break;
 
   case 98:
-#line 970 "cimmof.y"
+#line 991 "cimmof.y"
     {
         //printf("compilerDirectivePragma ");
     ;}
     break;
 
   case 99:
-#line 977 "cimmof.y"
+#line 998 "cimmof.y"
     {
       cimmofParser::Instance()->enterInlineInclude(*(yyvsp[(4) - (5)].strval)); delete (yyvsp[(4) - (5)].strval);
     ;}
     break;
 
   case 100:
-#line 982 "cimmof.y"
+#line 1003 "cimmof.y"
     { (yyval.strval) = (yyvsp[(1) - (1)].strval); ;}
     break;
 
   case 101:
-#line 987 "cimmof.y"
+#line 1008 "cimmof.y"
     {
         cimmofParser::Instance()->processPragma(*(yyvsp[(2) - (5)].strval), *(yyvsp[(4) - (5)].strval));
         delete (yyvsp[(2) - (5)].strval);
@@ -2605,17 +2623,17 @@ yyreduce:
     break;
 
   case 102:
-#line 1006 "cimmof.y"
+#line 1027 "cimmof.y"
     {
-//    CIMQualifierDecl *qd = new CIMQualifierDecl($2, $3, $4, $5);
     (yyval.mofqualifier) = cimmofParser::Instance()->newQualifierDecl(*(yyvsp[(2) - (6)].strval), (yyvsp[(3) - (6)].value), *(yyvsp[(4) - (6)].scope), *(yyvsp[(5) - (6)].flavor));
-        delete (yyvsp[(2) - (6)].strval);
+    delete (yyvsp[(2) - (6)].strval);
     delete (yyvsp[(3) - (6)].value);  // CIMValue object created in qualifierValue production
+    delete (yyvsp[(4) - (6)].scope);  // CIMScope object created in scope/metaElements production
 ;}
     break;
 
   case 103:
-#line 1015 "cimmof.y"
+#line 1036 "cimmof.y"
     {
     (yyval.value) = valueFactory::createValue((yyvsp[(2) - (4)].datatype), (yyvsp[(3) - (4)].ival),
                                    ((yyvsp[(4) - (4)].typedinitializer)->type == CIMMOF_NULL_VALUE),
@@ -2625,229 +2643,238 @@ yyreduce:
     break;
 
   case 104:
-#line 1023 "cimmof.y"
+#line 1044 "cimmof.y"
     { (yyval.scope) = (yyvsp[(2) - (3)].scope); ;}
     break;
 
   case 105:
-#line 1027 "cimmof.y"
+#line 1048 "cimmof.y"
     {
     g_scope = CIMScope (CIMScope::NONE);
     ;}
     break;
 
   case 106:
-#line 1032 "cimmof.y"
+#line 1053 "cimmof.y"
     { (yyval.scope) = (yyvsp[(1) - (1)].scope); ;}
     break;
 
   case 107:
-#line 1034 "cimmof.y"
-    { (yyval.scope)->addScope(*(yyvsp[(3) - (3)].scope)); ;}
+#line 1055 "cimmof.y"
+    {
+            (yyval.scope)->addScope(*(yyvsp[(3) - (3)].scope));
+            delete (yyvsp[(3) - (3)].scope);
+        ;}
     break;
 
   case 108:
-#line 1038 "cimmof.y"
+#line 1062 "cimmof.y"
     { (yyval.scope) = new CIMScope(CIMScope::CLASS);        ;}
     break;
 
   case 109:
-#line 1040 "cimmof.y"
+#line 1064 "cimmof.y"
     { (yyval.scope) = new CIMScope(CIMScope::CLASS); ;}
     break;
 
   case 110:
-#line 1041 "cimmof.y"
+#line 1065 "cimmof.y"
     { (yyval.scope) = new CIMScope(CIMScope::ASSOCIATION);  ;}
     break;
 
   case 111:
-#line 1042 "cimmof.y"
+#line 1066 "cimmof.y"
     { (yyval.scope) = new CIMScope(CIMScope::INDICATION);   ;}
     break;
 
   case 112:
-#line 1044 "cimmof.y"
+#line 1068 "cimmof.y"
     { (yyval.scope) = new CIMScope(CIMScope::PROPERTY);     ;}
     break;
 
   case 113:
-#line 1045 "cimmof.y"
+#line 1069 "cimmof.y"
     { (yyval.scope) = new CIMScope(CIMScope::REFERENCE);    ;}
     break;
 
   case 114:
-#line 1046 "cimmof.y"
+#line 1070 "cimmof.y"
     { (yyval.scope) = new CIMScope(CIMScope::METHOD);       ;}
     break;
 
   case 115:
-#line 1047 "cimmof.y"
+#line 1071 "cimmof.y"
     { (yyval.scope) = new CIMScope(CIMScope::PARAMETER);    ;}
     break;
 
   case 116:
-#line 1048 "cimmof.y"
+#line 1072 "cimmof.y"
     { (yyval.scope) = new CIMScope(CIMScope::ANY);          ;}
     break;
 
   case 117:
-#line 1053 "cimmof.y"
+#line 1077 "cimmof.y"
     { (yyval.flavor) = &g_flavor; ;}
     break;
 
   case 118:
-#line 1055 "cimmof.y"
-    { (yyval.flavor) = new CIMFlavor (CIMFlavor::NONE); ;}
+#line 1079 "cimmof.y"
+    {
+        g_flavor = CIMFlavor (CIMFlavor::NONE);
+        (yyval.flavor) = &g_flavor;
+    ;}
     break;
 
   case 119:
-#line 1062 "cimmof.y"
+#line 1089 "cimmof.y"
     {g_flavor = CIMFlavor (CIMFlavor::NONE);;}
     break;
 
   case 122:
-#line 1081 "cimmof.y"
+#line 1108 "cimmof.y"
     { g_flavor.addFlavor (CIMFlavor::ENABLEOVERRIDE); ;}
     break;
 
   case 123:
-#line 1082 "cimmof.y"
+#line 1109 "cimmof.y"
     { g_flavor.addFlavor (CIMFlavor::DISABLEOVERRIDE); ;}
     break;
 
   case 124:
-#line 1083 "cimmof.y"
+#line 1110 "cimmof.y"
     { g_flavor.addFlavor (CIMFlavor::RESTRICTED); ;}
     break;
 
   case 125:
-#line 1084 "cimmof.y"
+#line 1111 "cimmof.y"
     { g_flavor.addFlavor (CIMFlavor::TOSUBELEMENTS); ;}
     break;
 
   case 126:
-#line 1085 "cimmof.y"
+#line 1112 "cimmof.y"
     { g_flavor.addFlavor (CIMFlavor::TRANSLATABLE); ;}
     break;
 
   case 127:
-#line 1088 "cimmof.y"
+#line 1115 "cimmof.y"
     { (yyval.flavor) = &g_flavor; ;}
     break;
 
   case 128:
-#line 1090 "cimmof.y"
-    { (yyval.flavor) = new CIMFlavor (CIMFlavor::NONE); ;}
+#line 1117 "cimmof.y"
+    {
+        g_flavor = CIMFlavor (CIMFlavor::NONE);
+        (yyval.flavor) = &g_flavor;
+    ;}
     break;
 
   case 131:
-#line 1098 "cimmof.y"
+#line 1128 "cimmof.y"
     { (yyval.datatype) = (yyvsp[(1) - (1)].datatype); ;}
     break;
 
   case 132:
-#line 1099 "cimmof.y"
+#line 1129 "cimmof.y"
     { (yyval.datatype) = (yyvsp[(1) - (1)].datatype); ;}
     break;
 
   case 133:
-#line 1100 "cimmof.y"
+#line 1130 "cimmof.y"
     { (yyval.datatype) = CIMTYPE_STRING;   ;}
     break;
 
   case 134:
-#line 1101 "cimmof.y"
+#line 1131 "cimmof.y"
     { (yyval.datatype) = CIMTYPE_BOOLEAN;  ;}
     break;
 
   case 135:
-#line 1102 "cimmof.y"
+#line 1132 "cimmof.y"
     { (yyval.datatype) = CIMTYPE_DATETIME; ;}
     break;
 
   case 136:
-#line 1105 "cimmof.y"
+#line 1135 "cimmof.y"
     { (yyval.datatype) = CIMTYPE_UINT8;  ;}
     break;
 
   case 137:
-#line 1106 "cimmof.y"
+#line 1136 "cimmof.y"
     { (yyval.datatype) = CIMTYPE_SINT8;  ;}
     break;
 
   case 138:
-#line 1107 "cimmof.y"
+#line 1137 "cimmof.y"
     { (yyval.datatype) = CIMTYPE_UINT16; ;}
     break;
 
   case 139:
-#line 1108 "cimmof.y"
+#line 1138 "cimmof.y"
     { (yyval.datatype) = CIMTYPE_SINT16; ;}
     break;
 
   case 140:
-#line 1109 "cimmof.y"
+#line 1139 "cimmof.y"
     { (yyval.datatype) = CIMTYPE_UINT32; ;}
     break;
 
   case 141:
-#line 1110 "cimmof.y"
+#line 1140 "cimmof.y"
     { (yyval.datatype) = CIMTYPE_SINT32; ;}
     break;
 
   case 142:
-#line 1111 "cimmof.y"
+#line 1141 "cimmof.y"
     { (yyval.datatype) = CIMTYPE_UINT64; ;}
     break;
 
   case 143:
-#line 1112 "cimmof.y"
+#line 1142 "cimmof.y"
     { (yyval.datatype) = CIMTYPE_SINT64; ;}
     break;
 
   case 144:
-#line 1113 "cimmof.y"
+#line 1143 "cimmof.y"
     { (yyval.datatype) = CIMTYPE_CHAR16; ;}
     break;
 
   case 145:
-#line 1117 "cimmof.y"
+#line 1147 "cimmof.y"
     { (yyval.datatype) =CIMTYPE_REAL32; ;}
     break;
 
   case 146:
-#line 1119 "cimmof.y"
+#line 1149 "cimmof.y"
     { (yyval.datatype) =CIMTYPE_REAL64; ;}
     break;
 
   case 148:
-#line 1130 "cimmof.y"
+#line 1160 "cimmof.y"
     {
             //yydebug = 1; stderr = stdout;
         ;}
     break;
 
   case 149:
-#line 1134 "cimmof.y"
+#line 1164 "cimmof.y"
     {
     //yydebug = 1; stderr = stdout;
     YACCTRACE("qualifierListbegin");
-    g_qualifierList.init(); ;}
+    g_qualifierList.clear(); ;}
     break;
 
   case 150:
-#line 1140 "cimmof.y"
+#line 1170 "cimmof.y"
     { ;}
     break;
 
   case 151:
-#line 1142 "cimmof.y"
+#line 1172 "cimmof.y"
     { ;}
     break;
 
   case 152:
-#line 1145 "cimmof.y"
+#line 1175 "cimmof.y"
     {
     cimmofParser *p = cimmofParser::Instance();
     // The qualifier value can't be set until we know the contents of the
@@ -2855,7 +2882,8 @@ yyreduce:
     CIMValue *v = p->QualifierValue(*(yyvsp[(1) - (3)].strval),
                   ((yyvsp[(2) - (3)].typedinitializer)->type == CIMMOF_NULL_VALUE), *(yyvsp[(2) - (3)].typedinitializer)->value);
     (yyval.qualifier) = p->newQualifier(*(yyvsp[(1) - (3)].strval), *v, g_flavor);
-    g_qualifierList.add((yyval.qualifier));
+    g_qualifierList.add(*(yyval.qualifier));
+    delete (yyval.qualifier);
     delete (yyvsp[(1) - (3)].strval);
     delete (yyvsp[(2) - (3)].typedinitializer)->value;
     delete v;
@@ -2863,20 +2891,21 @@ yyreduce:
     break;
 
   case 153:
-#line 1158 "cimmof.y"
+#line 1189 "cimmof.y"
     {
         g_flavor = CIMFlavor (CIMFlavor::NONE); ;}
     break;
 
   case 154:
-#line 1160 "cimmof.y"
+#line 1191 "cimmof.y"
     {
         (yyval.strval) = new String((*(yyvsp[(1) - (1)].scope)).toString ());
-        g_flavor = CIMFlavor (CIMFlavor::NONE); ;}
+        g_flavor = CIMFlavor (CIMFlavor::NONE);
+        delete (yyvsp[(1) - (1)].scope); ;}
     break;
 
   case 155:
-#line 1167 "cimmof.y"
+#line 1199 "cimmof.y"
     {
             g_typedInitializerValue.type = CIMMOF_CONSTANT_VALUE;
             g_typedInitializerValue.value =  (yyvsp[(2) - (3)].strval);
@@ -2885,7 +2914,7 @@ yyreduce:
     break;
 
   case 156:
-#line 1173 "cimmof.y"
+#line 1205 "cimmof.y"
     {
             g_typedInitializerValue.type = CIMMOF_NULL_VALUE;
             g_typedInitializerValue.value = new String(String::EMPTY);
@@ -2894,7 +2923,7 @@ yyreduce:
     break;
 
   case 157:
-#line 1179 "cimmof.y"
+#line 1211 "cimmof.y"
     {
             g_typedInitializerValue.type = CIMMOF_ARRAY_VALUE;
             g_typedInitializerValue.value =  (yyvsp[(1) - (1)].strval);
@@ -2903,7 +2932,7 @@ yyreduce:
     break;
 
   case 158:
-#line 1184 "cimmof.y"
+#line 1216 "cimmof.y"
     {   /* empty */
             g_typedInitializerValue.type = CIMMOF_NULL_VALUE;
             g_typedInitializerValue.value = new String(String::EMPTY);
@@ -2912,18 +2941,18 @@ yyreduce:
     break;
 
   case 159:
-#line 1191 "cimmof.y"
+#line 1223 "cimmof.y"
     { (yyval.strval) = (yyvsp[(1) - (1)].strval); ;}
     break;
 
   case 160:
-#line 1194 "cimmof.y"
+#line 1226 "cimmof.y"
     { (yyval.strval) = (yyvsp[(1) - (1)].strval); ;}
     break;
 
 
 /* Line 1267 of yacc.c.  */
-#line 2925 "cimmoftemp"
+#line 2953 "cimmoftemp"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -3137,7 +3166,7 @@ yyreturn:
 }
 
 
-#line 1196 "cimmof.y"
+#line 1228 "cimmof.y"
 
 
 /*
