@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
 //
-//==============================================================================
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -189,7 +187,7 @@ ostream & help(ostream &os, int progtype)
     help.append( "               [ -n namespace | --namespace namespace ]"
                                 " [ --xml ]\n");
     help.append( "               [ --trace ]");
-#ifdef PEGASUS_OS_PASE 
+#ifdef PEGASUS_OS_PASE
   if(progtype == 1)
       help.append("  [ -q ]");
 #endif
@@ -218,7 +216,7 @@ ostream & help(ostream &os, int progtype)
                                                 " Schema changes\n");
     help.append( "    -aEV                - Allow both Experimental and"
                                                 " Version Schema changes\n");
-#ifdef PEGASUS_OS_PASE 
+#ifdef PEGASUS_OS_PASE
     help.append( "    -q                  - Suppress all messages except"
                                             " command line usage errors\n");
 #endif
@@ -246,7 +244,23 @@ ostream & help(ostream &os, int progtype)
         "                          under very controlled situations. cimmof\n"
         "                          is the recommended OpenPegasus MOF\n"
         "                          compiler.)\n");
-}
+    }
+
+#ifdef PEGASUS_ENABLE_MRR_GENERATION
+    if (progtype == 1)
+    {
+        help.append(
+        "    -m                  - Create an MRR (memory-resident repository)\n"
+        "                          rather than a disk-resident repository.\n"
+        "                          Classes and qualifier declarations are\n"
+        "                          placed into source files and instances are\n"
+        "                          placed into a flat binary file.\n");
+        help.append(
+        "    -d                  - Discard description qualifiers when\n"
+        "                          creating an MRR (memory-resident\n"
+        "                          repository).\n");
+    }
+#endif
 
     if(progtype == 1)
     {
@@ -308,6 +322,10 @@ static struct optspec optspecs[] =
 #ifdef PEGASUS_OS_PASE
     //PASE env ship q option
     {(char*)"q", QUIETFLAG, false, getoopt::NOARG},
+#endif
+#ifdef PEGASUS_ENABLE_MRR_GENERATION
+    {(char*)"m", MRRFLAG, false, getoopt::NOARG},
+    {(char*)"d", DISCARDFLAG, false, getoopt::NOARG},
 #endif
     {(char*)"", OPTEND_CIMMOF, false, getoopt::NOARG},
     {(char*)"R", REPOSITORYDIR, false, getoopt::MUSTHAVEARG},
@@ -369,7 +387,7 @@ static void applyDefaults(mofCompilerOptions &cmdlinedata)
     if (cmdlinedata.is_local())
     {
 #if defined(PEGASUS_USE_RELEASE_DIRS) && \
-        defined(PEGASUS_PLATFORM_ZOS_ZSERIES_IBM)
+        defined(PEGASUS_OS_ZOS)
         cmdlinedata.set_repository_name(ZOS_DEFAULT_PEGASUS_REPOSITORY);
 #elif defined(PEGASUS_OS_PASE)
         cmdlinedata.set_repository(PASE_DEFAULT_PEGASUS_HOME);
@@ -382,7 +400,7 @@ static void applyDefaults(mofCompilerOptions &cmdlinedata)
         {
         }
 #endif // end of #if defined(PEGASUS_USE_RELEASE_DIRS) &&
-       // defined(PEGASUS_PLATFORM_ZOS_ZSERIES_IBM)
+       // defined(PEGASUS_OS_ZOS)
     }
     else
     {
@@ -428,20 +446,23 @@ Boolean isCimmoflCommandName(const char *name)
         pos = name;
     else
         pos++;
-    if (*pos != 'c' && *pos != 'C') return -1;
+    // returns true in case of cimmofl
+    // returns false in case first 6 letter are "cimmof" and no "l" follows
+    // returns true in case anything else but "cimmof" or "cimmofl"
+    if (*pos != 'c' && *pos != 'C') return true;
     pos++;
-    if (*pos != 'i' && *pos != 'I') return -1;
+    if (*pos != 'i' && *pos != 'I') return true;
     pos++;
-    if (*pos != 'm' && *pos != 'M') return -1;
+    if (*pos != 'm' && *pos != 'M') return true;
     pos++;
-    if (*pos != 'm' && *pos != 'M') return -1;
+    if (*pos != 'm' && *pos != 'M') return true;
     pos++;
-    if (*pos != 'o' && *pos != 'O') return -1;
+    if (*pos != 'o' && *pos != 'O') return true;
     pos++;
-    if (*pos != 'f' && *pos != 'F') return -1;
+    if (*pos != 'f' && *pos != 'F') return true;
     pos++;
-    if (*pos != 'l' && *pos != 'L') return 0;
-    return 1;
+    if (*pos != 'l' && *pos != 'L') return false;
+    return true;
 }
 
 extern "C++" int processCmdline(int, char **, mofCompilerOptions &, ostream&);
@@ -474,6 +495,7 @@ int processCmdLine(int argc, char **argv, mofCompilerOptions &cmdlinedata,
                         &ptr) == 0)
                 &&
                     (ptr != 0))
+
         {
             setgid(ptr->pw_gid);
             setuid(ptr->pw_uid);
@@ -492,10 +514,9 @@ int processCmdLine(int argc, char **argv, mofCompilerOptions &cmdlinedata,
     if (cmdline.hasErrors())
     {
 
-        //  throw an exception and hande it in the caller
-        //l10n
-        //String msg = "Command line errors:\n";
-        MessageLoaderParms parms("Compiler.cmdline.cimmof.CMDLINE_ERRORS",
+        // Throw an exception and handle it in the caller
+        MessageLoaderParms parms(
+            "Compiler.cmdline.cimmof.cmdline.CMDLINE_ERRORS",
             "Command line errors:\n");
         String msg = MessageLoader::getMessage(parms);
         cmdline.printErrors(msg);
@@ -503,7 +524,8 @@ int processCmdLine(int argc, char **argv, mofCompilerOptions &cmdlinedata,
         throw ArgumentErrorsException(msg);
     }
 
-    MessageLoaderParms parms("Compiler.cmdline.cimmof.CMDLINE_ERRORS",
+    MessageLoaderParms tooManyOptionsMsgParms(
+        "Compiler.cmdline.cimmof.cmdline.CMDLINE_ERRORS",
         "Too many options specified.\n");
 
     for (unsigned int i = cmdline.first(); i < cmdline.last(); i++)
@@ -511,16 +533,16 @@ int processCmdLine(int argc, char **argv, mofCompilerOptions &cmdlinedata,
         const Optarg &arg = cmdline[i];
         opttypes c = catagorize(arg, isCimmoflCommand);
         if(type == HELPFLAG || type == VERSIONFLAG)
-            throw ArgumentErrorsException(parms);
+            throw ArgumentErrorsException(tooManyOptionsMsgParms);
         switch (c)
         {
             case VERSIONFLAG:
                 if(type != -1)
-                    throw ArgumentErrorsException(parms);
+                    throw ArgumentErrorsException(tooManyOptionsMsgParms);
                 break;
             case HELPFLAG:
                 if(type != -1)
-                    throw ArgumentErrorsException(parms);
+                    throw ArgumentErrorsException(tooManyOptionsMsgParms);
                 break;
             case INCLUDEPATH:
                 cmdlinedata.add_include_path(arg.optarg());
@@ -540,21 +562,12 @@ int processCmdLine(int argc, char **argv, mofCompilerOptions &cmdlinedata,
             case REPOSITORYMODE:
                 {
                     cmdlinedata.set_repository_mode(arg.optarg());
-                    // prevent using binary repository since we do not support
-                    // that in 2.5
-#ifdef PEGASUS_OS_PASE
-                    if (String::equalNoCase(arg.optarg(), "BIN"))
-                    {
-                        throw ArgumentErrorsException("ERROR: THE VALUE BIN IS"
-                            "NOT SUPPORTED FOR THE REPOSITORY MODE."); 
-                    }
-#endif
-                   if(String::equalNoCase(arg.optarg(), "XML") ||
-                       String::equalNoCase(arg.optarg(), "BIN")) {}
-                   else
+                   if (!String::equalNoCase(arg.optarg(), "XML") &&
+                       !String::equalNoCase(arg.optarg(), "BIN"))
                    {
                       MessageLoaderParms parms(
-                          "Compiler.cmdline.cimmof.UNKNOWN_VALUE_OPTION_A",
+                          "Compiler.cmdline.cimmof.cmdline."
+                              "UNKNOWN_VALUE_OPTION_M",
                           "Unknown value specified for option -M.");
                       throw ArgumentErrorsException(parms);
                    }
@@ -565,14 +578,14 @@ int processCmdLine(int argc, char **argv, mofCompilerOptions &cmdlinedata,
                 {
                   if (arg.optarg().size() == 1)
                   {
-                      for (unsigned int i = 0; i < arg.optarg().size(); i++)
+                      for (unsigned int j = 0; j < arg.optarg().size(); j++)
                       {
-                          if (arg.optarg()[i] == 'c')
+                          if (arg.optarg()[j] == 'c')
                               cmdlinedata.set_update_class();
                           else
                           {
                               MessageLoaderParms parms(
-                                  "Compiler.cmdline.cimmof."
+                                  "Compiler.cmdline.cimmof.cmdline."
                                         "UNKNOWN_VALUE_OPTION_U",
                                   "Unknown value specified for option -u.");
                               throw ArgumentErrorsException(parms);
@@ -582,7 +595,8 @@ int processCmdLine(int argc, char **argv, mofCompilerOptions &cmdlinedata,
                   else
                   {
                       MessageLoaderParms parms(
-                          "Compiler.cmdline.cimmof.TOO_MANY_VALUES_OPTION_U",
+                          "Compiler.cmdline.cimmof.cmdline."
+                              "TOO_MANY_VALUES_OPTION_U",
                           "Too many values specified for option -u.");
                       throw ArgumentErrorsException(parms);
                   }
@@ -592,29 +606,30 @@ int processCmdLine(int argc, char **argv, mofCompilerOptions &cmdlinedata,
                 {
                   if ((arg.optarg().size() <= 2) && (arg.optarg().size() != 0))
                   {
-                      for (unsigned int i = 0; i < arg.optarg().size(); i++)
+                      for (unsigned int j = 0; j < arg.optarg().size(); j++)
                       {
-                          if (arg.optarg()[i] == 'E')
+                          if (arg.optarg()[j] == 'E')
                               cmdlinedata.set_allow_experimental();
                           else
-                              if (arg.optarg()[i] == 'V')
+                              if (arg.optarg()[j] == 'V')
                                   cmdlinedata.set_allow_version();
                               else
                               {
                                   MessageLoaderParms parms(
-                                      "Compiler.cmdline.cimmof."
+                                      "Compiler.cmdline.cimmof.cmdline."
                                             "UNKNOWN_VALUE_OPTION_A",
                                       "Unknown value specified for option -a.");
                                   throw ArgumentErrorsException(parms);
-                          }
+                              }
                       }
                   }
                   else
                   {
-                  MessageLoaderParms parms(
-                      "Compiler.cmdline.cimmof.TOO_MANY_VALUES_OPTION_A",
-                      "Too many values specified for option -a.");
-                  throw ArgumentErrorsException(parms);
+                      MessageLoaderParms parms(
+                          "Compiler.cmdline.cimmof.cmdline."
+                              "TOO_MANY_VALUES_OPTION_A",
+                          "Too many values specified for option -a.");
+                      throw ArgumentErrorsException(parms);
                   }
                 }
                 break;
@@ -642,7 +657,7 @@ int processCmdLine(int argc, char **argv, mofCompilerOptions &cmdlinedata,
             case XMLFLAG: cmdlinedata.set_xmloutput();
                 break;
 #endif
-#ifdef PEGASUS_OS_PASE 
+#ifdef PEGASUS_OS_PASE
             // If quiet mode is chosen then shut down stdout and stderr.
             // This is used during product installation and PTF application.
             // We must be absolutely quiet to avoid a terminal being
@@ -666,6 +681,14 @@ int processCmdLine(int argc, char **argv, mofCompilerOptions &cmdlinedata,
 
             case NO_USAGE_WARNING:
                cmdlinedata.set_no_usage_warning();
+#ifdef PEGASUS_ENABLE_MRR_GENERATION
+            case MRRFLAG:
+                cmdlinedata.set_mrr();
+                break;
+            case DISCARDFLAG:
+                cmdlinedata.set_discard();
+                break;
+#endif
         }
         type = c;
     }
@@ -684,8 +707,8 @@ int processCmdLine(int argc, char **argv, mofCompilerOptions &cmdlinedata,
     if (String::equal(cmdlinedata.get_repository(), String::EMPTY)) {
 
         MessageLoaderParms parms(
-            "Compiler.cmdline.cimmof.MUST_SPECIFY_R_OR_HOME",
-            "You must specify -R or set PEGASUS_HOME environment variable");
+            "Compiler.cmdline.cimmof.cmdline.MUST_SPECIFY_R_OR_HOME",
+            "Specify -R or set the PEGASUS_HOME environment variable.");
         throw CmdlineNoRepository(parms);
     }
 
