@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%////////////////////////////////////////////////////////////////////////////
 
@@ -54,24 +52,16 @@ PEGASUS_NAMESPACE_BEGIN
 //
 /////////////////////////////////////////////////////////////////////////////
 
-TracePropertyOwner* ConfigManager::traceOwner =
-    new TracePropertyOwner;
-LogPropertyOwner* ConfigManager::logOwner =
-    new LogPropertyOwner;
-DefaultPropertyOwner* ConfigManager::defaultOwner =
-    new DefaultPropertyOwner;
-SecurityPropertyOwner* ConfigManager::securityOwner =
-    new SecurityPropertyOwner;
-RepositoryPropertyOwner* ConfigManager::repositoryOwner =
-    new RepositoryPropertyOwner;
-ShutdownPropertyOwner* ConfigManager::shutdownOwner =
-    new ShutdownPropertyOwner;
-FileSystemPropertyOwner* ConfigManager::fileSystemOwner =
-    new FileSystemPropertyOwner;
-ProviderDirPropertyOwner* ConfigManager::providerDirOwner =
-    new ProviderDirPropertyOwner;
-NormalizationPropertyOwner* ConfigManager::normalizationOwner =
-    new NormalizationPropertyOwner;
+TracePropertyOwner ConfigManager::traceOwner;
+LogPropertyOwner ConfigManager::logOwner;
+DefaultPropertyOwner ConfigManager::defaultOwner;
+SecurityPropertyOwner ConfigManager::securityOwner;
+RepositoryPropertyOwner ConfigManager::repositoryOwner;
+ShutdownPropertyOwner ConfigManager::shutdownOwner;
+FileSystemPropertyOwner ConfigManager::fileSystemOwner;
+ProviderDirPropertyOwner ConfigManager::providerDirOwner;
+NormalizationPropertyOwner ConfigManager::normalizationOwner;
+
 
 /////////////////////////////////////////////////////////////////////////////
 //
@@ -89,103 +79,111 @@ struct OwnerEntry
 static struct OwnerEntry _properties[] =
 {
     {"traceLevel",
-         (ConfigPropertyOwner*)ConfigManager::traceOwner},
+         (ConfigPropertyOwner*)&ConfigManager::traceOwner},
     {"traceComponents",
-         (ConfigPropertyOwner*)ConfigManager::traceOwner},
+         (ConfigPropertyOwner*)&ConfigManager::traceOwner},
     {"traceFilePath",
-         (ConfigPropertyOwner*)ConfigManager::traceOwner},
+         (ConfigPropertyOwner*)&ConfigManager::traceOwner},
+    {"traceFacility",
+         (ConfigPropertyOwner*)&ConfigManager::traceOwner},
+    {"traceMemoryBufferKbytes",
+         (ConfigPropertyOwner*)&ConfigManager::traceOwner},
 #if !defined(PEGASUS_USE_SYSLOGS)
     {"logdir",
-         (ConfigPropertyOwner*)ConfigManager::logOwner},
+         (ConfigPropertyOwner*)&ConfigManager::logOwner},
+    {"maxLogFileSizeKBytes",
+         (ConfigPropertyOwner*)&ConfigManager::logOwner},
 #endif
     {"logLevel",
-         (ConfigPropertyOwner*)ConfigManager::logOwner},
+         (ConfigPropertyOwner*)&ConfigManager::logOwner},
     {"enableHttpConnection",
-         (ConfigPropertyOwner*)ConfigManager::defaultOwner},
+         (ConfigPropertyOwner*)&ConfigManager::defaultOwner},
     {"enableHttpsConnection",
-         (ConfigPropertyOwner*)ConfigManager::defaultOwner},
+         (ConfigPropertyOwner*)&ConfigManager::defaultOwner},
     {"httpPort",
-         (ConfigPropertyOwner*)ConfigManager::defaultOwner},
+         (ConfigPropertyOwner*)&ConfigManager::defaultOwner},
     {"httpsPort",
-         (ConfigPropertyOwner*)ConfigManager::defaultOwner},
-    {"home",
-         (ConfigPropertyOwner*)ConfigManager::defaultOwner},
+         (ConfigPropertyOwner*)&ConfigManager::defaultOwner},
     {"daemon",
-         (ConfigPropertyOwner*)ConfigManager::defaultOwner},
+         (ConfigPropertyOwner*)&ConfigManager::defaultOwner},
+#ifdef PEGASUS_ENABLE_SLP
     {"slp",
-         (ConfigPropertyOwner*)ConfigManager::defaultOwner},
+         (ConfigPropertyOwner*)&ConfigManager::defaultOwner},
+#endif
     {"enableAssociationTraversal",
-         (ConfigPropertyOwner*)ConfigManager::defaultOwner},
+         (ConfigPropertyOwner*)&ConfigManager::defaultOwner},
     {"enableIndicationService",
-         (ConfigPropertyOwner*)ConfigManager::defaultOwner},
+         (ConfigPropertyOwner*)&ConfigManager::defaultOwner},
     {"enableAuthentication",
-         (ConfigPropertyOwner*)ConfigManager::securityOwner},
+         (ConfigPropertyOwner*)&ConfigManager::securityOwner},
     {"enableNamespaceAuthorization",
-         (ConfigPropertyOwner*)ConfigManager::securityOwner},
+         (ConfigPropertyOwner*)&ConfigManager::securityOwner},
     {"httpAuthType",
-         (ConfigPropertyOwner*)ConfigManager::securityOwner},
+         (ConfigPropertyOwner*)&ConfigManager::securityOwner},
     {"passwordFilePath",
-         (ConfigPropertyOwner*)ConfigManager::securityOwner},
+         (ConfigPropertyOwner*)&ConfigManager::securityOwner},
     {"sslCertificateFilePath",
-         (ConfigPropertyOwner*)ConfigManager::securityOwner},
+         (ConfigPropertyOwner*)&ConfigManager::securityOwner},
     {"sslKeyFilePath",
-         (ConfigPropertyOwner*)ConfigManager::securityOwner},
+         (ConfigPropertyOwner*)&ConfigManager::securityOwner},
     {"sslTrustStore",
-         (ConfigPropertyOwner*)ConfigManager::securityOwner},
+         (ConfigPropertyOwner*)&ConfigManager::securityOwner},
 #ifdef PEGASUS_ENABLE_SSL_CRL_VERIFICATION
     {"crlStore",
-         (ConfigPropertyOwner*)ConfigManager::securityOwner},
+         (ConfigPropertyOwner*)&ConfigManager::securityOwner},
 #endif
     {"sslClientVerificationMode",
-         (ConfigPropertyOwner*)ConfigManager::securityOwner},
+         (ConfigPropertyOwner*)&ConfigManager::securityOwner},
     {"sslTrustStoreUserName",
-         (ConfigPropertyOwner*)ConfigManager::securityOwner},
+         (ConfigPropertyOwner*)&ConfigManager::securityOwner},
 #ifdef PEGASUS_KERBEROS_AUTHENTICATION
     {"kerberosServiceName",
-         (ConfigPropertyOwner*)ConfigManager::securityOwner},
+         (ConfigPropertyOwner*)&ConfigManager::securityOwner},
 #endif
 #ifdef PEGASUS_OS_ZOS
     {"enableCFZAPPLID",
-         (ConfigPropertyOwner*)ConfigManager::securityOwner},
+         (ConfigPropertyOwner*)&ConfigManager::securityOwner},
 #endif
     {"repositoryIsDefaultInstanceProvider",
-         (ConfigPropertyOwner*)ConfigManager::repositoryOwner},
+         (ConfigPropertyOwner*)&ConfigManager::repositoryOwner},
     {"enableBinaryRepository",
-         (ConfigPropertyOwner*)ConfigManager::repositoryOwner},
+         (ConfigPropertyOwner*)&ConfigManager::repositoryOwner},
     {"shutdownTimeout",
-         (ConfigPropertyOwner*)ConfigManager::shutdownOwner},
+         (ConfigPropertyOwner*)&ConfigManager::shutdownOwner},
     {"repositoryDir",
-         (ConfigPropertyOwner*)ConfigManager::fileSystemOwner},
+         (ConfigPropertyOwner*)&ConfigManager::fileSystemOwner},
+    {"providerManagerDir",
+         (ConfigPropertyOwner*)&ConfigManager::fileSystemOwner},
     {"providerDir",
-         (ConfigPropertyOwner*)ConfigManager::providerDirOwner},
+         (ConfigPropertyOwner*)&ConfigManager::providerDirOwner},
     {"enableRemotePrivilegedUserAccess",
-         (ConfigPropertyOwner*)ConfigManager::securityOwner},
+         (ConfigPropertyOwner*)&ConfigManager::securityOwner},
     {"enableSubscriptionsForNonprivilegedUsers",
-         (ConfigPropertyOwner*)ConfigManager::securityOwner},
+         (ConfigPropertyOwner*)&ConfigManager::securityOwner},
 #ifdef PEGASUS_ENABLE_USERGROUP_AUTHORIZATION
     {"authorizedUserGroups",
-         (ConfigPropertyOwner*)ConfigManager::securityOwner},
+         (ConfigPropertyOwner*)&ConfigManager::securityOwner},
 #endif
     {"messageDir",
-         (ConfigPropertyOwner*)ConfigManager::fileSystemOwner},
+         (ConfigPropertyOwner*)&ConfigManager::fileSystemOwner},
 #ifdef PEGASUS_ENABLE_OBJECT_NORMALIZATION
     {"enableNormalization",
-         (ConfigPropertyOwner*)ConfigManager::normalizationOwner},
+         (ConfigPropertyOwner*)&ConfigManager::normalizationOwner},
     {"excludeModulesFromNormalization",
-         (ConfigPropertyOwner*)ConfigManager::normalizationOwner},
+         (ConfigPropertyOwner*)&ConfigManager::normalizationOwner},
 #endif
     {"forceProviderProcesses",
-         (ConfigPropertyOwner*)ConfigManager::defaultOwner},
+         (ConfigPropertyOwner*)&ConfigManager::defaultOwner},
     {"maxProviderProcesses",
-         (ConfigPropertyOwner*)ConfigManager::defaultOwner},
+         (ConfigPropertyOwner*)&ConfigManager::defaultOwner},
 #ifdef PEGASUS_ENABLE_AUDIT_LOGGER
     {"enableAuditLog",
-         (ConfigPropertyOwner*)ConfigManager::defaultOwner},
+         (ConfigPropertyOwner*)&ConfigManager::defaultOwner},
 #endif
     {"socketWriteTimeout",
-         (ConfigPropertyOwner*)ConfigManager::defaultOwner},
+         (ConfigPropertyOwner*)&ConfigManager::defaultOwner},
     {"idleConnectionTimeout",
-         (ConfigPropertyOwner*)ConfigManager::defaultOwner}
+         (ConfigPropertyOwner*)&ConfigManager::defaultOwner}
 };
 
 const Uint32 NUM_PROPERTIES = sizeof(_properties) / sizeof(struct OwnerEntry);
@@ -229,9 +227,9 @@ const String ConfigManager::PEGASUS_HOME_DEFAULT = ".";
 String ConfigManager::_pegasusHome = PEGASUS_HOME_DEFAULT;
 
 //
-// Initialize ConfigManager instance
+// The singleton ConfigManager instance
 //
-ConfigManager* ConfigManager::_instance = 0;
+AutoPtr<ConfigManager> ConfigManager::_instance;
 
 
 /** Constructor. */
@@ -249,39 +247,17 @@ ConfigManager::ConfigManager()
     _initPropertyTable();
 }
 
-/**
- Terminate the ConfigManager
-*/
-void
-ConfigManager::destroy()
-{
-   if (_instance)
-   {
-       delete _instance->traceOwner;
-       delete _instance->logOwner;
-       delete _instance->defaultOwner;
-       delete _instance->securityOwner;
-       delete _instance->repositoryOwner;
-       delete _instance->shutdownOwner;
-       delete _instance->fileSystemOwner;
-       delete _instance->providerDirOwner;
-       delete _instance->normalizationOwner;
-       delete _instance;
-       _instance = 0;
-   }
-}
-
 /**
     Get a reference to the singleton ConfigManager instance.  If no
     ConfigManager instance exists, construct one.
 */
 ConfigManager* ConfigManager::getInstance()
 {
-    if (!_instance)
+    if (!_instance.get())
     {
-        _instance = new ConfigManager();
+        _instance.reset(new ConfigManager());
     }
-    return _instance;
+    return _instance.get();
 }
 
 
@@ -764,10 +740,11 @@ void ConfigManager::_loadConfigProperties()
                 {
                     Logger::put_l(Logger::STANDARD_LOG, System::CIMSERVER,
                         Logger::WARNING,
-                        "Config.ConfigManager.NOTSUPPORTED_CONFIG_PROPERTY",
-                        "Configuration property $0 is not supported. "
-                            "Setting ignored.",
-                        propertyName);
+                        MessageLoaderParms(
+                            "Config.ConfigManager.NOTSUPPORTED_CONFIG_PROPERTY",
+                            "Configuration property $0 is not supported. "
+                                "Setting ignored.",
+                            propertyName));
                 }
                 else
                 {
@@ -777,12 +754,14 @@ void ConfigManager::_loadConfigProperties()
         }
         catch (UnrecognizedConfigProperty& ucp)
         {
-            PEG_TRACE_STRING(TRC_CONFIG, Tracer::LEVEL2, ucp.getMessage());
+            PEG_TRACE_CSTRING(TRC_CONFIG, Tracer::LEVEL1,
+                (const char*)ucp.getMessage().getCString());
             throw;
         }
         catch (InvalidPropertyValue& ipv)
         {
-            PEG_TRACE_STRING(TRC_CONFIG, Tracer::LEVEL2, ipv.getMessage());
+            PEG_TRACE_CSTRING(TRC_CONFIG, Tracer::LEVEL1,
+                (const char*)ipv.getMessage().getCString());
             throw;
         }
     }
