@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -42,6 +40,8 @@
 #include "ConfigManager.h"
 #include <Pegasus/Common/AuditLogger.h>
 #include <Pegasus/Common/StringConversion.h>
+#include <Pegasus/Common/HTTPAcceptor.h>
+#include <Pegasus/Common/HTTPConnection.h>
 
 PEGASUS_USING_STD;
 
@@ -162,7 +162,15 @@ String DefaultPropertyOwner::getCurrentValue(const String& name) const
     {
         if (String::equalNoCase(_configProperties.get()[i].propertyName, name))
         {
-            return _configProperties.get()[i].currentValue;
+            if (String::equalNoCase(name, "maxProviderProcesses"))
+            {
+                AutoMutex lock(_maxProviderProcessesMutex);
+                return _configProperties.get()[i].currentValue;
+            }
+            else
+            {
+                return _configProperties.get()[i].currentValue;
+            }
         }
     }
 
@@ -198,19 +206,46 @@ void DefaultPropertyOwner::initCurrentValue(
     const String& name,
     const String& value)
 {
-    for (Uint32 i = 0; i < NUM_PROPERTIES; i++)
+    Uint32 index;
+    for (index = 0; index < NUM_PROPERTIES; index++)
     {
-        if (String::equalNoCase(_configProperties.get()[i].propertyName, name))
+        if (String::equalNoCase(
+            _configProperties.get()[index].propertyName,
+            name))
         {
-            _configProperties.get()[i].currentValue = value;
-            return;
+            if (String::equalNoCase(name, "maxProviderProcesses"))
+            {
+                AutoMutex lock(_maxProviderProcessesMutex);
+                _configProperties.get()[index].currentValue = value;
+            }
+            else
+            {
+               _configProperties.get()[index].currentValue = value;
+            }
+            break;
         }
     }
 
-    //
-    // Specified property name could not be found
-    //
-    throw UnrecognizedConfigProperty(name);
+    if (index >= NUM_PROPERTIES)
+    {
+        //
+        // Specified property name could not be found
+        //
+        throw UnrecognizedConfigProperty(name);
+    }
+    else if (String::equal(name, "idleConnectionTimeout"))
+    {
+        Uint64 v;
+        StringConversion::decimalStringToUint64(value.getCString(), v);
+        HTTPConnection::setIdleConnectionTimeout((Uint32)v);
+    }
+    else if (String::equal(name, "socketWriteTimeout"))
+    {
+        Uint64 v;
+        StringConversion::decimalStringToUint64(value.getCString(), v);
+        HTTPAcceptor::setSocketWriteTimeout((Uint32)v);
+    }
+    return;
 }
 
 /**
@@ -297,8 +332,7 @@ Boolean DefaultPropertyOwner::isValid(
     // By default, no validation is done. It can optionally be added here
     // per property.
     //
-    if (String::equalNoCase(name, "socketWriteTimeout") ||
-        String::equalNoCase(name, "idleConnectionTimeout"))
+    if (String::equalNoCase(name, "socketWriteTimeout"))
     {
         Uint64 v;
         return
@@ -306,7 +340,8 @@ Boolean DefaultPropertyOwner::isValid(
             StringConversion::checkUintBounds(v, CIMTYPE_UINT32) &&
             (v != 0);
     }
-    if (String::equalNoCase(name, "maxProviderProcesses"))
+    if (String::equalNoCase(name, "maxProviderProcesses") ||
+        String::equalNoCase(name, "idleConnectionTimeout"))
     {
         Uint64 v;
         return
