@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -76,21 +74,21 @@ static struct ConfigPropertyRow properties[] =
     {"enableAuthentication", "true", IS_STATIC, 0, 0, IS_VISIBLE},
     {"httpAuthType", "Basic", IS_STATIC, 0, 0, IS_VISIBLE},
     {"passwordFilePath", "cimserver.passwd", IS_STATIC, 0, 0, IS_VISIBLE},
-    {"sslCertificateFilePath", "ssl/keystore/servercert.pem", IS_STATIC, 
+    {"sslCertificateFilePath", "ssl/keystore/servercert.pem", IS_STATIC,
         0, 0, IS_VISIBLE},
-    {"sslKeyFilePath", "ssl/keystore/serverkey.pem", IS_STATIC, 
+    {"sslKeyFilePath", "ssl/keystore/serverkey.pem", IS_STATIC,
         0, 0, IS_VISIBLE},
     {"sslTrustStore", "ssl/truststore/", IS_STATIC, 0, 0, IS_VISIBLE},
 # ifdef PEGASUS_ENABLE_SSL_CRL_VERIFICATION
     {"crlStore", "ssl/crlstore/", IS_STATIC, 0, 0, IS_VISIBLE},
-# endif    
+# endif
     {"sslClientVerificationMode", "optional", IS_STATIC, 0, 0, IS_VISIBLE},
-    {"sslTrustStoreUserName", "", IS_STATIC, 0, 0, IS_VISIBLE},
+    {"sslTrustStoreUserName", "QYCMCIMOM", IS_STATIC, 0, 0, IS_VISIBLE},
     {"enableNamespaceAuthorization", "true", IS_STATIC, 0, 0, IS_VISIBLE},
 # ifdef PEGASUS_KERBEROS_AUTHENTICATION
     {"kerberosServiceName", "cimom", IS_STATIC, 0, 0, IS_VISIBLE},
-# endif    
-    {"enableSubscriptionsForNonprivilegedUsers", "false", IS_STATIC, 
+# endif
+    {"enableSubscriptionsForNonprivilegedUsers", "false", IS_STATIC,
         0, 0, IS_VISIBLE},
     {"enableRemotePrivilegedUserAccess", "true", IS_STATIC, 0, 0, IS_VISIBLE},
     {"authorizedUserGroups", "", IS_STATIC, 0, 0, IS_VISIBLE},
@@ -865,7 +863,7 @@ Boolean SecurityPropertyOwner::isValid(
 #ifdef PEGASUS_OS_ZOS
     else if (String::equalNoCase(_enableCFZAPPLID->propertyName, name))
     {
-        if (String::equalNoCase(value, "true") 
+        if (String::equalNoCase(value, "true")
            || String::equalNoCase(value, "false"))
         {
             retVal = true;
