@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -39,8 +37,10 @@
 ///////////////////////////////////////////////////////////////////////////////
 
 #include <Pegasus/Common/Tracer.h>
+#include <Pegasus/Common/Logger.h>
 #include <Pegasus/Common/FileSystem.h>
 #include <Pegasus/Common/MessageLoader.h>
+#include <Pegasus/Common/StringConversion.h>
 #include "ConfigManager.h"
 #include "TracePropertyOwner.h"
 
@@ -59,21 +59,34 @@ PEGASUS_NAMESPACE_BEGIN
 static struct ConfigPropertyRow properties[] =
 {
 #ifdef PEGASUS_OS_HPUX
-    {"traceLevel", "1", IS_DYNAMIC, 0, 0, IS_HIDDEN},
+    {"traceLevel", "0", IS_DYNAMIC, 0, 0, IS_HIDDEN},
     {"traceComponents", "", IS_DYNAMIC, 0, 0, IS_HIDDEN},
+    {"traceMemoryBufferKbytes", "10240", IS_STATIC, 0, 0, IS_HIDDEN},
+    {"traceFacility", "File", IS_DYNAMIC, 0, 0, IS_HIDDEN},
 #elif defined(PEGASUS_OS_PASE)
-    {"traceLevel", "1", IS_DYNAMIC, 0, 0, IS_VISIBLE},
+    {"traceLevel", "0", IS_DYNAMIC, 0, 0, IS_VISIBLE},
     {"traceComponents", "", IS_DYNAMIC, 0, 0, IS_VISIBLE},
+    {"traceMemoryBufferKbytes", "10240", IS_STATIC, 0, 0, IS_VISIBLE},
+    {"traceFacility", "File", IS_DYNAMIC, 0, 0, IS_VISIBLE},
+#elif defined(PEGASUS_OS_ZOS)
+    {"traceLevel", "2", IS_DYNAMIC, 0, 0, IS_VISIBLE},
+    {"traceComponents", "All", IS_DYNAMIC, 0, 0, IS_VISIBLE},
+    {"traceMemoryBufferKbytes", "10240", IS_STATIC, 0, 0, IS_VISIBLE},
+    {"traceFacility", "Memory", IS_DYNAMIC, 0, 0, IS_VISIBLE},
 #else
-#if defined (PEGASUS_USE_RELEASE_CONFIG_OPTIONS)
-    {"traceLevel", "1", IS_DYNAMIC, 0, 0, IS_HIDDEN},
+# if defined (PEGASUS_USE_RELEASE_CONFIG_OPTIONS)
+    {"traceLevel", "0", IS_DYNAMIC, 0, 0, IS_HIDDEN},
     {"traceComponents", "", IS_DYNAMIC, 0, 0, IS_HIDDEN},
-#else
-    {"traceLevel", "1", IS_DYNAMIC, 0, 0, IS_VISIBLE},
+    {"traceMemoryBufferKbytes", "10240", IS_STATIC, 0, 0, IS_HIDDEN},
+    {"traceFacility", "File", IS_DYNAMIC, 0, 0, IS_HIDDEN},
+# else
+    {"traceLevel", "0", IS_DYNAMIC, 0, 0, IS_VISIBLE},
     {"traceComponents", "", IS_DYNAMIC, 0, 0, IS_VISIBLE},
+    {"traceMemoryBufferKbytes", "10240", IS_STATIC, 0, 0, IS_VISIBLE},
+    {"traceFacility", "File", IS_DYNAMIC, 0, 0, IS_VISIBLE},
+# endif
 #endif
-#endif
-#if defined(PEGASUS_PLATFORM_ZOS_ZSERIES_IBM)
+#if defined(PEGASUS_OS_ZOS)
 # if defined(PEGASUS_USE_RELEASE_DIRS)
     {"traceFilePath", "/tmp/cimserver.trc", IS_DYNAMIC, 0, 0, IS_VISIBLE},
 # else
@@ -92,28 +105,58 @@ const Uint32 NUM_PROPERTIES = sizeof(properties) / sizeof(properties[0]);
 //
 // Checks if the trace level is valid
 //
-Boolean isLevelValid(const String& traceLevel)
+Boolean TracePropertyOwner::isLevelValid(const String& traceLevel) const
 {
     //
     // Check if the level is valid
     //
-    if (traceLevel == "1" || traceLevel == "2" ||
-        traceLevel == "3" || traceLevel == "4")
+    return (traceLevel == "0" || traceLevel == "1" ||
+            traceLevel == "2" || traceLevel == "3" ||
+            traceLevel == "4" || traceLevel == "5");
+}
+
+
+//
+// Converts the trace memory buffer size string into a Uint32 value.
+// It returns false and the bufferSize is set to 0 if the string was not valid.
+//
+Boolean TracePropertyOwner::toUint32TraceMemoryBufferSize(
+    const String& traceBufferSize, Uint32& bufferSize ) const
+{
+    Boolean retCode = false;
+    Uint64 uInt64BufferSize;
+
+    bufferSize = 0;
+    CString stringBufferSize = traceBufferSize.getCString();
+
+
+    retCode = StringConversion::decimalStringToUint64(stringBufferSize,
+                                                      uInt64BufferSize);
+
+    if (retCode )
     {
-        return 1;
+        retCode = StringConversion::checkUintBounds(uInt64BufferSize,
+                                                    CIMTYPE_UINT32);
     }
-    else
+
+    if (retCode )
     {
-        return 0;
+        bufferSize = (Uint32)uInt64BufferSize;
     }
+
+    return retCode;
 }
 
 //
 // Get the appropriate trace level
 //
-Uint32 getTraceLevel(const String& traceLevel)
+Uint32 TracePropertyOwner::getTraceLevel(const String& traceLevel)
 {
-    if ( traceLevel == "1" )
+    if ( traceLevel == "0")
+    {
+        return Tracer::LEVEL0;
+    }
+    else if ( traceLevel == "1" )
     {
         return Tracer::LEVEL1;
     }
@@ -125,18 +168,29 @@ Uint32 getTraceLevel(const String& traceLevel)
     {
         return Tracer::LEVEL3;
     }
-    else
+    else if ( traceLevel == "4" )
     {
         return Tracer::LEVEL4;
     }
+    else if ( traceLevel == "5" )
+    {
+        return Tracer::LEVEL5;
+    }
+    else
+    {
+        return Tracer::LEVEL0;
+    }
 }
 
 /** Constructors  */
-TracePropertyOwner::TracePropertyOwner()
+TracePropertyOwner::TracePropertyOwner():
+   _initialized(false)
 {
     _traceLevel.reset(new ConfigProperty);
     _traceFilePath.reset(new ConfigProperty);
     _traceComponents.reset(new ConfigProperty);
+    _traceFacility.reset(new ConfigProperty);
+    _traceMemoryBufferKbytes.reset(new ConfigProperty);
 }
 
 /**
@@ -144,11 +198,16 @@ TracePropertyOwner::TracePropertyOwner()
 */
 void TracePropertyOwner::initialize()
 {
+    //
+    // Initialize the properties with default values only once !
+    //
+    if (_initialized)
+    {
+        return;
+    }
+
     for (Uint32 i = 0; i < NUM_PROPERTIES; i++)
     {
-        //
-        // Initialize the properties with default values
-        //
         if (String::equalNoCase(properties[i].propertyName, "traceComponents"))
         {
             _traceComponents->propertyName = properties[i].propertyName;
@@ -160,6 +219,8 @@ void TracePropertyOwner::initialize()
             _traceComponents->domainSize = properties[i].domainSize;
             _traceComponents->externallyVisible =
                 properties[i].externallyVisible;
+
+            Tracer::setTraceComponents(_traceComponents->defaultValue);
         }
         else if (String::equalNoCase(properties[i].propertyName, "traceLevel"))
         {
@@ -172,6 +233,11 @@ void TracePropertyOwner::initialize()
             _traceLevel->domainSize = properties[i].domainSize;
             _traceLevel->externallyVisible =
                 properties[i].externallyVisible;
+
+            PEGASUS_ASSERT(_traceLevel->defaultValue.size()!= 0);
+
+            Tracer::setTraceLevel(getTraceLevel(_traceLevel->defaultValue));
+
         }
         else if (String::equalNoCase(
                      properties[i].propertyName, "traceFilePath"))
@@ -185,28 +251,62 @@ void TracePropertyOwner::initialize()
             _traceFilePath->domainSize = properties[i].domainSize;
             _traceFilePath->externallyVisible =
                 properties[i].externallyVisible;
-        }
-    }
 
-    if (_traceLevel->defaultValue != String::EMPTY)
-    {
-        if (_traceLevel->defaultValue == "1")
-        {
-            Tracer::setTraceLevel(Tracer::LEVEL1);
+            // set the default value in the Trace
+            Uint32 retCode = Tracer::setTraceFile(ConfigManager::getHomedPath(
+                _traceFilePath->defaultValue).getCString());
+            if ( retCode == 1 )
+            {
+                Logger::put_l(
+                    Logger::ERROR_LOG,System::CIMSERVER,Logger::WARNING,
+                    MessageLoaderParms(
+                    "Config.TracePropertyOwner.UNABLE_TO_WRITE_TRACE_FILE",
+                    "Unable to write to trace file $0",
+                    _traceFilePath->defaultValue));
+                _traceFilePath->currentValue.clear();
+            }
+
         }
-        else if (_traceLevel->defaultValue == "2")
+        else if (String::equalNoCase(
+                     properties[i].propertyName, "traceMemoryBufferKbytes"))
         {
-            Tracer::setTraceLevel(Tracer::LEVEL2);
+            _traceMemoryBufferKbytes->propertyName = properties[i].propertyName;
+            _traceMemoryBufferKbytes->defaultValue = properties[i].defaultValue;
+            _traceMemoryBufferKbytes->currentValue = properties[i].defaultValue;
+            _traceMemoryBufferKbytes->plannedValue = properties[i].defaultValue;
+            _traceMemoryBufferKbytes->dynamic = properties[i].dynamic;
+            _traceMemoryBufferKbytes->domain = properties[i].domain;
+            _traceMemoryBufferKbytes->domainSize = properties[i].domainSize;
+            _traceMemoryBufferKbytes->externallyVisible =
+                properties[i].externallyVisible;
+
+            PEGASUS_ASSERT(_traceMemoryBufferKbytes->defaultValue.size()!= 0);
+
+            Uint32 bufferSize;
+            toUint32TraceMemoryBufferSize(
+                _traceMemoryBufferKbytes->defaultValue, bufferSize );
+            Tracer::setTraceMemoryBufferSize(bufferSize);
+
         }
-        else if (_traceLevel->defaultValue == "3")
+        else if (String::equalNoCase(
+                     properties[i].propertyName, "traceFacility"))
         {
-            Tracer::setTraceLevel(Tracer::LEVEL3);
-        }
-        else if (_traceLevel->defaultValue == "4")
-        {
-            Tracer::setTraceLevel(Tracer::LEVEL4);
+            _traceFacility->propertyName = properties[i].propertyName;
+            _traceFacility->defaultValue = properties[i].defaultValue;
+            _traceFacility->currentValue = properties[i].defaultValue;
+            _traceFacility->plannedValue = properties[i].defaultValue;
+            _traceFacility->dynamic = properties[i].dynamic;
+            _traceFacility->domain = properties[i].domain;
+            _traceFacility->domainSize = properties[i].domainSize;
+            _traceFacility->externallyVisible =
+                properties[i].externallyVisible;
+
+            PEGASUS_ASSERT(_traceFacility->defaultValue.size()!= 0);
+
+            Tracer::setTraceFacility(_traceFacility->defaultValue);
         }
     }
+    _initialized = true;
 }
 
 struct ConfigProperty* TracePropertyOwner::_lookupConfigProperty(
@@ -224,6 +324,14 @@ struct ConfigProperty* TracePropertyOwner::_lookupConfigProperty(
     {
         return _traceFilePath.get();
     }
+    else if (String::equalNoCase(_traceFacility->propertyName, name))
+    {
+        return _traceFacility.get();
+    }
+    else if (String::equalNoCase(_traceMemoryBufferKbytes->propertyName, name))
+    {
+        return _traceMemoryBufferKbytes.get();
+    }
     else
     {
         throw UnrecognizedConfigProperty(name);
@@ -299,26 +407,6 @@ void TracePropertyOwner::initCurrentValue(
 {
     if (String::equalNoCase(_traceComponents->propertyName, name))
     {
-        if (_traceFilePath->currentValue != String::EMPTY &&
-            value != String::EMPTY)
-        {
-            CString fileName = ConfigManager::getHomedPath(
-                _traceFilePath->currentValue).getCString();
-            if (Tracer::isValidFileName(fileName))
-            {
-                Uint32 retCode = Tracer::setTraceFile(fileName);
-                // Check whether the filepath was set
-                if ( retCode == 1 )
-                {
-                    Logger::put_l(Logger::DEBUG_LOG,System::CIMSERVER,
-                        Logger::WARNING,
-                        "Config.TracePropertyOwner.UNABLE_TO_WRITE_TRACE_FILE",
-                        "Unable to write to trace file $0",
-                        (const char*)fileName);
-                    _traceFilePath->currentValue = "";
-                }
-            }
-        }
         _traceComponents->currentValue = value;
         Tracer::setTraceComponents(_traceComponents->currentValue);
     }
@@ -331,28 +419,33 @@ void TracePropertyOwner::initCurrentValue(
     else if (String::equalNoCase(_traceFilePath->propertyName, name))
     {
         _traceFilePath->currentValue = value;
-        if (_traceFilePath->currentValue != String::EMPTY &&
-            _traceComponents->currentValue != String::EMPTY)
+        Uint32 retCode = Tracer::setTraceFile(ConfigManager::getHomedPath(
+            _traceFilePath->currentValue).getCString());
+        if ( retCode == 1 )
         {
-            CString fileName = ConfigManager::getHomedPath(
-                _traceFilePath->currentValue).getCString();
-            if (Tracer::isValidFileName(fileName))
-            {
-                Uint32 retCode = Tracer::setTraceFile(fileName);
-
-                // Check whether the filepath was set
-                if ( retCode == 1 )
-                {
-                     Logger::put_l(Logger::DEBUG_LOG,System::CIMSERVER,
-                        Logger::WARNING,
-                        "Config.TracePropertyOwner.UNABLE_TO_WRITE_TRACE_FILE",
-                        "Unable to write to trace file $0",
-                        (const char*)fileName);
-                    _traceFilePath->currentValue = "";
-                }
-            }
+            Logger::put_l(
+                Logger::ERROR_LOG,System::CIMSERVER,Logger::WARNING,
+                MessageLoaderParms(
+                "Config.TracePropertyOwner.UNABLE_TO_WRITE_TRACE_FILE",
+                "Unable to write to trace file $0",
+                _traceFilePath->currentValue));
+            _traceFilePath->currentValue.clear();
         }
     }
+    else if (String::equalNoCase(_traceFacility->propertyName, name))
+    {
+        _traceFacility->currentValue = value;
+        Tracer::setTraceFacility(value);
+    }
+    else if (String::equalNoCase(_traceMemoryBufferKbytes->propertyName, name))
+    {
+        Uint32 bufferSize;
+
+        _traceMemoryBufferKbytes->currentValue = value;
+
+        toUint32TraceMemoryBufferSize( value, bufferSize );
+        Tracer::setTraceMemoryBufferSize(bufferSize);
+    }
     else
     {
         throw UnrecognizedConfigProperty(name);
@@ -448,7 +541,34 @@ Boolean TracePropertyOwner::isValid(
         // string when a trace file cannot be opened successfully.
         //
         if ((value != String::EMPTY) &&
-            !Tracer::isValidFileName(value.getCString()))
+            !Tracer::isValidFileName((const char*)value.getCString()))
+        {
+            throw InvalidPropertyValue(name, value);
+        }
+        return true;
+    }
+    else if (String::equalNoCase(_traceFacility->propertyName, name))
+    {
+        //
+        // Check if the trace facility is valid
+        //
+        if (!Tracer::isValidTraceFacility(value))
+        {
+            throw InvalidPropertyValue(name, value);
+        }
+        return true;
+    }
+    else if (String::equalNoCase(_traceMemoryBufferKbytes->propertyName, name))
+    {
+        Boolean retCode = false;
+        Uint32 size = 0;
+
+        //
+        // Ckeck if the trace memeory buffer size is valid
+        //
+        retCode = toUint32TraceMemoryBufferSize(value ,size);
+        if (!retCode || (size > PEGASUS_TRC_BUFFER_MAX_SIZE_KB) ||
+                        (size < PEGASUS_TRC_BUFFER_MIN_SIZE_KB))
         {
             throw InvalidPropertyValue(name, value);
         }
