@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%////////////////////////////////////////////////////////////////////////////
 
@@ -44,6 +42,7 @@
 
 #include "ConfigSettingProvider.h"
 #include <Pegasus/Common/String.h>
+#include <Pegasus/Common/CIMNameCast.h>
 #include <Pegasus/Common/System.h>
 #include <Pegasus/Common/ArrayInternal.h>
 #include <Pegasus/Common/CIMType.h>
@@ -71,20 +70,20 @@ PEGASUS_NAMESPACE_BEGIN
 /**
     The constants representing the string literals.
 */
-static const CIMName PROPERTY_NAME       = CIMName ("PropertyName");
+static const CIMName PROPERTY_NAME    = CIMNameCast("PropertyName");
 
-static const CIMName DEFAULT_VALUE       = CIMName ("DefaultValue");
+static const CIMName DEFAULT_VALUE    = CIMNameCast("DefaultValue");
 
-static const CIMName CURRENT_VALUE       = CIMName ("CurrentValue");
+static const CIMName CURRENT_VALUE    = CIMNameCast("CurrentValue");
 
-static const CIMName PLANNED_VALUE       = CIMName ("PlannedValue");
+static const CIMName PLANNED_VALUE    = CIMNameCast("PlannedValue");
 
-static const CIMName DYNAMIC_PROPERTY    = CIMName ("DynamicProperty");
+static const CIMName DYNAMIC_PROPERTY = CIMNameCast("DynamicProperty");
 
 /**
     The constant representing the config setting class name
 */
-static const CIMName PG_CONFIG_SETTING  = CIMName ("PG_ConfigSetting");
+static const CIMName PG_CONFIG_SETTING  = CIMNameCast("PG_ConfigSetting");
 
 void ConfigSettingProvider::getInstance(
     const OperationContext & context,
@@ -149,7 +148,7 @@ void ConfigSettingProvider::getInstance(
                     "ControlProviders.ConfigSettingProvider."
                         "ConfigSettingProvider."
                         "CONFIG_PROPERTY_NOT_FOUND",
-                    "Configuration property \"$0\"", 
+                    "Configuration property \"$0\"",
                     keyValue));
         }
 
@@ -239,7 +238,7 @@ void ConfigSettingProvider::modifyInstance(
                         "ConfigSettingProvider."
                         "INVALID_INSTANCE_NAME",
                     "Invalid instance name"));
-                
+
         }
 
         String configPropertyName = kbArray[0].getValue();
@@ -282,7 +281,7 @@ void ConfigSettingProvider::modifyInstance(
                         "ControlProviders.ConfigSettingProvider."
                             "ConfigSettingProvider."
                             "MODIFICATION_NOT_SUPPORTED",
-                        "Modification of property \"$0\"", 
+                        "Modification of property \"$0\"",
                         propertyName.getString()));
             }
         }
@@ -363,7 +362,7 @@ void ConfigSettingProvider::modifyInstance(
                                 "UPDATE_CURRENT_VALUE_FAILED",
                             "Failed to update the current value."));
                 }
-                
+
                 // It is unset, get current value which is default
                 if (currentValueIsNull)
                 {
@@ -372,7 +371,7 @@ void ConfigSettingProvider::modifyInstance(
                 }
 
                 // send notify config change message to ProviderManager Service
-                _sendNotifyConfigChangeMessage(configPropertyName, 
+                _sendNotifyConfigChangeMessage(configPropertyName,
                                                currentValue,
                                                true);
 
@@ -410,7 +409,7 @@ void ConfigSettingProvider::modifyInstance(
                 }
 
                 // send notify config change message to ProviderManager Service
-                _sendNotifyConfigChangeMessage(configPropertyName, 
+                _sendNotifyConfigChangeMessage(configPropertyName,
                                                plannedValue,
                                                false);
 
@@ -439,7 +438,7 @@ void ConfigSettingProvider::modifyInstance(
                     "ControlProviders.ConfigSettingProvider."
                         "ConfigSettingProvider."
                         "CONFIG_PROPERTY_NOT_FOUND",
-                    "Configuration property \"$0\"", 
+                    "Configuration property \"$0\"",
                     configPropertyName));
         }
 
@@ -492,20 +491,20 @@ void ConfigSettingProvider::enumerateInstances(
                  propertyNames[i], propertyInfo);
 
                  Array<CIMKeyBinding> keyBindings;
-                 keyBindings.append(CIMKeyBinding(PROPERTY_NAME, 
+                 keyBindings.append(CIMKeyBinding(PROPERTY_NAME,
                  propertyInfo[0], CIMKeyBinding::STRING));
-                 CIMObjectPath instanceName(ref.getHost(), 
+                 CIMObjectPath instanceName(ref.getHost(),
                  ref.getNameSpace(),
                  PG_CONFIG_SETTING, keyBindings);
 
                  // construct the instance
-                 instance.addProperty(CIMProperty(PROPERTY_NAME, 
+                 instance.addProperty(CIMProperty(PROPERTY_NAME,
                                          propertyInfo[0]));
-                 instance.addProperty(CIMProperty(DEFAULT_VALUE, 
+                 instance.addProperty(CIMProperty(DEFAULT_VALUE,
                                          propertyInfo[1]));
-                 instance.addProperty(CIMProperty(CURRENT_VALUE, 
+                 instance.addProperty(CIMProperty(CURRENT_VALUE,
                                          propertyInfo[2]));
-                 instance.addProperty(CIMProperty(PLANNED_VALUE, 
+                 instance.addProperty(CIMProperty(PLANNED_VALUE,
                                          propertyInfo[3]));
                  instance.addProperty(CIMProperty(DYNAMIC_PROPERTY,
                  Boolean(propertyInfo[4]=="true"?true:false)));
@@ -550,7 +549,7 @@ void ConfigSettingProvider::enumerateInstanceNames(
         if (!className.equal (PG_CONFIG_SETTING))
         {
             PEG_METHOD_EXIT();
-            throw PEGASUS_CIM_EXCEPTION( CIM_ERR_NOT_SUPPORTED, 
+            throw PEGASUS_CIM_EXCEPTION( CIM_ERR_NOT_SUPPORTED,
                 className.getString());
         }
 
@@ -572,7 +571,7 @@ void ConfigSettingProvider::enumerateInstanceNames(
                  //
                  // Convert instance names to References
                  //
-                 CIMObjectPath ref(hostName, nameSpace, className, 
+                 CIMObjectPath ref(hostName, nameSpace, className,
                                     keyBindings);
 
                  instanceRefs.append(ref);
@@ -649,10 +648,9 @@ void ConfigSettingProvider::_sendNotifyConfigChangeMessage(
         AsyncLegacyOperationStart asyncRequest(
             NULL,
             service->getQueueId(),
-            notify_req,
-            service->getQueueId());
+            notify_req);
 
-        AutoPtr<AsyncReply> asyncReply( 
+        AutoPtr<AsyncReply> asyncReply(
             controller->ClientSendWait(service->getQueueId(), &asyncRequest));
 
         AutoPtr<CIMNotifyConfigChangeResponseMessage> response(
