@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//=============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%////////////////////////////////////////////////////////////////////////////
 
@@ -111,22 +109,22 @@ void InteropProvider::associators(
     for (Uint32 i = 0; i < numIterations; ++i)
     {
         Array<CIMInstance> refs = localReferences(
-            context, 
+            context,
             objectName,
             associationClass,
-            originRole, 
-            targetRole, 
+            originRole,
+            targetRole,
             CIMPropertyList(),
             resultClass);
-        for (Uint32 i = 0, n = refs.size(); i < n; ++i)
+        for (Uint32 j = 0, n = refs.size(); j < n; ++j)
         {
-            CIMInstance & currentRef = refs[i];
+            CIMInstance & currentRef = refs[j];
             // Retrieve the "other side" of the association
             CIMObjectPath currentTarget = getRequiredValue<CIMObjectPath>(
-                currentRef, 
+                currentRef,
                 targetRole);
             CIMInstance tmpInstance = localGetInstance(
-                context, 
+                context,
                 currentTarget,
                 propertyList);
             tmpInstance.setPath(currentTarget);
@@ -191,16 +189,16 @@ void InteropProvider::associatorNames(
     for (Uint32 i = 0; i < numIterations; ++i)
     {
         Array<CIMInstance> refs = localReferences(
-            context,  
+            context,
             objectName,
-            associationClass, 
-            originRole, 
-            targetRole, 
+            associationClass,
+            originRole,
+            targetRole,
             CIMPropertyList(),
             resultClass);
-        for (Uint32 i = 0, n = refs.size(); i < n; ++i)
+        for (Uint32 j = 0, n = refs.size(); j < n; ++j)
         {
-            CIMInstance & currentRef = refs[i];
+            CIMInstance & currentRef = refs[j];
             CIMObjectPath currentTarget = getRequiredValue<CIMObjectPath>(
                 currentRef,
                 targetRole);
@@ -266,14 +264,14 @@ void InteropProvider::references(
     for (Uint32 i = 0; i < numIterations; ++i)
     {
         Array<CIMInstance> refs = localReferences(
-            context, 
-            objectName, 
-            resultClass, 
-            tmpRole, 
+            context,
+            objectName,
+            resultClass,
+            tmpRole,
             tmpTarget);
-        for (Uint32 i = 0, n = refs.size(); i < n; ++i)
+        for (Uint32 j = 0, n = refs.size(); j < n; ++j)
         {
-            handler.deliver((CIMObject)refs[i]);
+            handler.deliver((CIMObject)refs[j]);
         }
         if (numIterations == 2)
         {
@@ -321,14 +319,14 @@ void InteropProvider::referenceNames(
     for (Uint32 i = 0; i < numIterations; ++i)
     {
         Array<CIMInstance> refs = localReferences(
-            context, 
+            context,
             objectName,
             resultClass,
-            tmpRole, 
+            tmpRole,
             tmpTarget);
-        for (Uint32 i = 0, n = refs.size(); i < n; ++i)
+        for (Uint32 j = 0, n = refs.size(); j < n; ++j)
         {
-            handler.deliver(refs[i].getPath());
+            handler.deliver(refs[j].getPath());
         }
         if (numIterations == 2)
         {
