@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//=============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%////////////////////////////////////////////////////////////////////////////
 
@@ -59,6 +57,7 @@
 #include "InteropConstants.h"
 
 #include <Pegasus/Common/StatisticalData.h>
+#include <Pegasus/Common/StringConversion.h>
 
 PEGASUS_USING_STD;
 PEGASUS_NAMESPACE_BEGIN
@@ -78,17 +77,49 @@ PEGASUS_NAMESPACE_BEGIN
 //
 InteropProvider::InteropProvider(CIMRepository * rep) : repository(rep),
     hostName(System::getHostName()), providerInitialized(false),
+    updateProfileCache(0),
     profileIds(Array<String>()), conformingElements(Array<CIMNameArray>()),
     elementNamespaces(Array<CIMNamespaceArray>())
 {
     PEG_METHOD_ENTER(TRC_CONTROLPROVIDER,"InteropProvider::InteropProvider");
 
+    ConfigManager *configManager = ConfigManager::getInstance();
+#ifdef PEGASUS_ENABLE_SLP
+    enableSLP = ConfigManager::parseBooleanValue(
+        configManager->getCurrentValue("slp"));
+#else
+    enableSLP = false;
+#endif
+
+    httpPort = configManager->getCurrentValue("httpPort");
+    if (httpPort.size() == 0)
+    {
+        Uint32 portNumberHttp = System::lookupPort(
+            WBEM_HTTP_SERVICE_NAME, WBEM_DEFAULT_HTTP_PORT);
+        char buffer[32];
+        Uint32 n;
+        const char *output = Uint32ToString(buffer, portNumberHttp, n);
+        httpPort.assign(output, n);
+    }
+
+    httpsPort = configManager->getCurrentValue("httpsPort");
+    if (httpsPort.size() == 0)
+    {
+        Uint32 portNumberHttps = System::lookupPort(
+            WBEM_HTTPS_SERVICE_NAME, WBEM_DEFAULT_HTTPS_PORT);
+        char buffer[32];
+        Uint32 n;
+        const char *output = Uint32ToString(buffer, portNumberHttps, n);
+        httpsPort.assign(output, n);
+    }
+
+
 #ifndef PEGASUS_DISABLE_PERFINST
     try
     {
         initProvider();
     }
-    catch(const Exception & e)
+    catch(const Exception &)
     {
         // Provider initialization may fail if the repository is not
         // populated
@@ -122,16 +153,21 @@ CIMInstance InteropProvider::localGetInstance(
     CIMNamespaceName opNamespace = instanceName.getNameSpace();
     CIMName opClass = instanceName.getClassName();
     if(opNamespace != PEGASUS_NAMESPACENAME_INTEROP &&
-        opClass != PEGASUS_CLASSNAME_PG_ELEMENTCONFORMSTOPROFILE)
+        opClass != PEGASUS_CLASSNAME_PG_ELEMENTCONFORMSTOPROFILE
+        // Get CIM_IndicationService instance from IndicationService.
+#ifdef PEGASUS_ENABLE_DMTF_INDICATION_PROFILE_SUPPORT
+        || opClass == PEGASUS_CLASSNAME_CIM_INDICATIONSERVICE
+#endif
+        )
     {
         AutoMutex mut(interopMut);
         CIMInstance gotInstance = cimomHandle.getInstance(
                                          context,
                                          opNamespace,
-                                         instanceName, 
-                                         false, 
-                                         false, 
-                                         false, 
+                                         instanceName,
+                                         false,
+                                         false,
+                                         false,
                                          propertyList);
         PEG_METHOD_EXIT();
         return gotInstance;
@@ -294,6 +330,35 @@ Array<CIMInstance> InteropProvider::localEnumerateInstances(
             instances = enumHostedAccessPointInstances();
             break;
         }
+        //We don't support enumerate CIM_Namespace instances. PG_Namespace is
+        //supported.
+        case CIM_NAMESPACE:
+        {
+            break;
+        }
+        case PG_PROVIDERPROFILECAPABILITIES:
+        {
+            instances = enumProviderProfileCapabilityInstances(false, false);
+            break;
+        }
+
+#ifdef PEGASUS_ENABLE_DMTF_INDICATION_PROFILE_SUPPORT
+        case PG_ELEMENTCAPABILITIES:
+        {
+            instances = enumElementCapabilityInstances(context);
+            break;
+        }
+        case PG_HOSTEDINDICATIONSERVICE:
+        {
+            instances = enumHostedIndicationServiceInstances(context);
+            break;
+        }
+        case PG_SERVICEAFFECTSELEMENT:
+        {
+            instances = enumServiceAffectsElementInstances(context);
+            break;
+        }
+#endif
         default:
             PEG_METHOD_EXIT();
             throw CIMNotSupportedException(className.getString() +
@@ -319,10 +384,10 @@ Array<CIMInstance> InteropProvider::localEnumerateInstances(
 //
 bool InteropProvider::validAssocClassForObject(
     const OperationContext & context,
-    const CIMName & assocClass, 
+    const CIMName & assocClass,
     const CIMObjectPath & objectName,
     const CIMNamespaceName & opNamespace,
-    String & originProperty, 
+    String & originProperty,
     String & targetProperty)
 {
     PEG_METHOD_ENTER(TRC_CONTROLPROVIDER,
@@ -392,7 +457,7 @@ bool InteropProvider::validAssocClassForObject(
     CIMInstance tmpInstance;
     Uint32 index;
     propNames.clear();
-    
+
     //
     // Set the target and origin role values. Note that if these values are
     // not set following the switch block, that implies that the origin class
@@ -444,17 +509,20 @@ bool InteropProvider::validAssocClassForObject(
           propNames.append(CIMName("RegisteredName"));
           propertyList = CIMPropertyList(propNames);
           tmpInstance = localGetInstance(
-              context, 
+              context,
               objectName,
               propertyList);
-          index = tmpInstance.findProperty("RegisteredName");
-          if (index != PEG_NOT_FOUND)
+          if (!tmpInstance.isUninitialized())
           {
-              const CIMValue &tmpVal = 
-                  tmpInstance.getProperty(index).getValue();
-              if (!tmpVal.isNull())
+              index = tmpInstance.findProperty("RegisteredName");
+              if (index != PEG_NOT_FOUND)
               {
-                  tmpVal.get(profileName);
+                  const CIMValue &tmpVal =
+                      tmpInstance.getProperty(index).getValue();
+                  if (!tmpVal.isNull())
+                  {
+                      tmpVal.get(profileName);
+                  }
               }
           }
           if (String::compareNoCase(profileName, String("SMI-S")) == 0)
@@ -587,6 +655,15 @@ bool InteropProvider::validAssocClassForObject(
               expectedOriginRole = PROPERTY_DEPENDENT;
           }
           break;
+#ifdef PEGASUS_ENABLE_DMTF_INDICATION_PROFILE_SUPPORT
+      case PG_HOSTEDINDICATIONSERVICE:
+          if(originClassEnum == PG_COMPUTERSYSTEM)
+          {
+              expectedTargetRole = PROPERTY_DEPENDENT;
+              expectedOriginRole = PROPERTY_ANTECEDENT;
+          }
+          break;
+#endif
       default:
           break;
     }
@@ -658,11 +735,11 @@ Array<CIMInstance> InteropProvider::localReferences(
 
     // Check that the association traversal request is valid
     if (validAssocClassForObject(
-        context, 
-        assocClass, 
+        context,
+        assocClass,
         objectName,
-        originNamespace, 
-        originProperty, 
+        originNamespace,
+        originProperty,
         targetProperty))
     {
         // retrieve all of the association class instances
@@ -757,6 +834,7 @@ Array<CIMInstance> InteropProvider::localReferences(
 CIMInstance InteropProvider::buildInstanceSkeleton(
       const CIMNamespaceName & nameSpace,
       const CIMName& className,
+      Boolean includeQualifiers,
       CIMClass& returnedClass)
 {
     PEG_METHOD_ENTER(TRC_CONTROLPROVIDER,
@@ -764,8 +842,8 @@ CIMInstance InteropProvider::buildInstanceSkeleton(
     // get class with lo = false, qualifier = true classorig = true
     returnedClass = repository->getClass(nameSpace,
         className, false, true, true);
-    CIMInstance skeleton = returnedClass.buildInstance(true,true,
-        CIMPropertyList());
+    CIMInstance skeleton = returnedClass.buildInstance(
+        includeQualifiers, true, CIMPropertyList());
 
     PEG_METHOD_EXIT();
     return skeleton;
@@ -845,104 +923,119 @@ void InteropProvider::initProvider()
         profileCapabilitiesClass = repository->getClass(
             PEGASUS_NAMESPACENAME_INTEROP,
             PEGASUS_CLASSNAME_PG_PROVIDERPROFILECAPABILITIES,
-            false, true, false);
+            false,
+            true,
+            false);
 
         providerClassifications.append(Uint16(5)); // "Instrumentation"
 
-        //
-        // Initialize the namespaces so that all namespaces with the
-        // CIM_ElementConformsToProfile class also have the
-        // PG_ElementConformsToProfile class. Needed in order to implement
-        // the cross-namespace ElementConformsToProfile association in both
-        // directions.
-        //
-        Array<CIMNamespaceName> namespaceNames =
-            repository->enumerateNameSpaces();
-        // get the PG_ElementConformstoProfile class without the qualifiers
-        // and then add just the required ASSOCIATION qualifier, so that
-        // resolveclass doesn't fail for the test/EmbeddedInstance/Dynamic
-        // namespace, which uses the CIM25 schema that doesn't include any
-        // of the new qualifiers added to this class in later versions of
-        // the CIMSchema.
-        CIMClass conformsClass = repository->getClass(
-            PEGASUS_NAMESPACENAME_INTEROP,
-            PEGASUS_CLASSNAME_PG_ELEMENTCONFORMSTOPROFILE, true, false);
-        conformsClass.addQualifier(CIMQualifier(CIMName("ASSOCIATION"),
-                              CIMValue(true)));
-        CIMClass profileClass = repository->getClass(
-            PEGASUS_NAMESPACENAME_INTEROP,
-            PEGASUS_CLASSNAME_PG_REGISTEREDPROFILE, true, false);
-        for(Uint32 i = 0, n = namespaceNames.size(); i < n; ++i)
-        {
-            // Check if the PG_ElementConformsToProfile class is present
-            CIMNamespaceName & currentNamespace = namespaceNames[i];
-            CIMClass tmpCimClass;
-            CIMClass tmpPgClass;
-            CIMClass tmpPgProfileClass;
-            try
-            {
-                // Look for these classes in the same try-block since the
-                // second depends on the first
-                tmpCimClass = repository->getClass(currentNamespace,
-                    PEGASUS_CLASSNAME_CIM_ELEMENTCONFORMSTOPROFILE);
-                tmpPgClass = repository->getClass(currentNamespace,
-                    PEGASUS_CLASSNAME_PG_ELEMENTCONFORMSTOPROFILE);
-            }
-            catch(const Exception &)
-            {
-            }
-            try
-            {
-                tmpPgProfileClass = repository->getClass(currentNamespace,
-                    PEGASUS_CLASSNAME_PG_REGISTEREDPROFILE);
-            }
-            catch(const Exception &)
-            {
-                // Note: if any of the above three classes aren't found,
-                // an exception will be thrown, which we can ignore since it's
-                // an expected case
-                // TBD: Log trace message?
-            }
-
-            // If the CIM_ElementConformsToProfile class is present, but
-            // the PG_ElementConformsToProfile or PG_RegisteredProfile
-            // class is not, then add it to that namespace.
-            //
-            // Note that we don't have to check for the
-            // CIM_RegisteredProfile class because if the
-            // CIM_ElementConformsToProfile class is present, the
-            // CIM_RegisteredProfile class must also be present.
-            if(!tmpCimClass.isUninitialized())
-            {
-                if(tmpPgClass.isUninitialized())
-                {
-                    CIMClass newclass = conformsClass.clone();
-                    CIMObjectPath newPath = conformsClass.getPath();
-                    newPath.setNameSpace(currentNamespace);
-                    newclass.setPath(newPath);
-                    repository->createClass(currentNamespace,
-                        newclass);
-                }
-                if(tmpPgProfileClass.isUninitialized())
-                {
-                    CIMClass newclass = profileClass.clone();
-                    CIMObjectPath newPath = profileClass.getPath();
-                    newPath.setNameSpace(currentNamespace);
-                    newclass.setPath(newPath);
-                    repository->createClass(currentNamespace,
-                        newclass);
-                }
-            }
-        }
+        // initialize namespaces.
+        initializeNamespaces();
 
         // Now cache the Registration info used for ElementConformsToProfile
         cacheProfileRegistrationInfo();
 
         providerInitialized = true;
     }
-
     PEG_METHOD_EXIT();
 }
 
+//
+// Initialize the namespaces so that all namespaces with the
+// CIM_ElementConformsToProfile class also have the
+// PG_ElementConformsToProfile class. Needed in order to implement
+// the cross-namespace ElementConformsToProfile association in both
+// directions.
+//
+void InteropProvider::initializeNamespaces()
+{
+    Array<CIMNamespaceName> namespaceNames =  repository->enumerateNameSpaces();
+    // get the PG_ElementConformstoProfile class without the qualifiers
+    // and then add just the required ASSOCIATION qualifier, so that
+    // resolveclass doesn't fail for the test/EmbeddedInstance/Dynamic
+    // namespace, which uses the CIM25 schema that doesn't include any
+    // of the new qualifiers added to this class in later versions of
+    // the CIMSchema.
+    CIMClass conformsClass = repository->getClass(
+        PEGASUS_NAMESPACENAME_INTEROP,
+        PEGASUS_CLASSNAME_PG_ELEMENTCONFORMSTOPROFILE,
+        true,
+        false);
+    conformsClass.addQualifier(
+        CIMQualifier(CIMName("ASSOCIATION"), CIMValue(true)));
+    CIMClass profileClass = repository->getClass(
+        PEGASUS_NAMESPACENAME_INTEROP,
+        PEGASUS_CLASSNAME_PG_REGISTEREDPROFILE,
+        true,
+        false);
+    for(Uint32 i = 0, n = namespaceNames.size(); i < n; ++i)
+    {
+        // Check if the PG_ElementConformsToProfile class is present
+        CIMNamespaceName & currentNamespace = namespaceNames[i];
+        CIMClass tmpCimClass;
+        CIMClass tmpPgClass;
+        CIMClass tmpPgProfileClass;
+        try
+        {
+            // Look for these classes in the same try-block since the
+            // second depends on the first
+            tmpCimClass = repository->getClass(
+                currentNamespace,
+                PEGASUS_CLASSNAME_CIM_ELEMENTCONFORMSTOPROFILE);
+            tmpPgClass = repository->getClass(
+                currentNamespace,
+                PEGASUS_CLASSNAME_PG_ELEMENTCONFORMSTOPROFILE);
+        }
+        catch(const Exception &)
+        {
+        }
+        try
+        {
+            tmpPgProfileClass = repository->getClass(
+                currentNamespace,
+                PEGASUS_CLASSNAME_PG_REGISTEREDPROFILE);
+        }
+        catch(const Exception &)
+        {
+            // Note: if any of the above three classes aren't found,
+            // an exception will be thrown, which we can ignore since it's
+            // an expected case
+            // TBD: Log trace message?
+        }
+
+        // If the CIM_ElementConformsToProfile class is present, but
+        // the PG_ElementConformsToProfile or PG_RegisteredProfile
+        // class is not, then add it to that namespace.
+        //
+        // Note that we don't have to check for the
+        // CIM_RegisteredProfile class because if the
+        // CIM_ElementConformsToProfile class is present, the
+        // CIM_RegisteredProfile class must also be present.
+        if(!tmpCimClass.isUninitialized())
+        {
+            if(tmpPgClass.isUninitialized())
+            {
+                CIMClass newclass = conformsClass.clone();
+                CIMObjectPath newPath = conformsClass.getPath();
+                newPath.setNameSpace(currentNamespace);
+                newclass.setPath(newPath);
+                repository->createClass(
+                    currentNamespace,
+                    newclass);
+            }
+            if(tmpPgProfileClass.isUninitialized())
+            {
+                CIMClass newclass = profileClass.clone();
+                CIMObjectPath newPath = profileClass.getPath();
+                newPath.setNameSpace(currentNamespace);
+                newclass.setPath(newPath);
+                repository->createClass(
+                    currentNamespace,
+                    newclass);
+            }
+        }
+    }
+}
+
 PEGASUS_NAMESPACE_END
 // END OF FILE
