@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//=============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 
 
 #ifndef InteropProvider_h
@@ -54,6 +52,7 @@
 #include <Pegasus/Repository/CIMRepository.h>
 #include <Pegasus/Provider/CIMInstanceProvider.h>
 #include <Pegasus/Provider/CIMAssociationProvider.h>
+#include <Pegasus/Provider/CIMMethodProvider.h>
 
 PEGASUS_NAMESPACE_BEGIN
 
@@ -91,7 +90,9 @@ typedef Array<CIMName> CIMNameArray;
 typedef Array<CIMNamespaceName> CIMNamespaceArray;
 
 class PEGASUS_INTEROPPROVIDER_LINKAGE InteropProvider :
-        public CIMInstanceProvider, public CIMAssociationProvider
+        public CIMInstanceProvider,
+        public CIMAssociationProvider,
+        public CIMMethodProvider
 {
 public:
 
@@ -188,6 +189,14 @@ public:
         const String & role,
         ObjectPathResponseHandler & handler);
 
+    // CIMMethodProvider interface
+    virtual void invokeMethod(
+        const OperationContext & context,
+        const CIMObjectPath & objectReference,
+        const CIMName & methodName,
+        const Array<CIMParamValue> & inParameters,
+        MethodResultResponseHandler & handler);
+
 private:
 
     void initProvider();
@@ -195,6 +204,7 @@ private:
     CIMInstance buildInstanceSkeleton(
         const CIMNamespaceName & nameSpace,
         const CIMName& className,
+        Boolean includeQualifiers,
         CIMClass& returnedClass);
 
     CIMInstance buildCIMXMLCommunicationMechanismInstance(
@@ -220,6 +230,14 @@ private:
     CIMObjectPath createNamespace(const CIMInstance & namespaceInstance);
     void deleteNamespace(const CIMObjectPath & instanceName);
 
+    CIMObjectPath createProviderProfileCapabilityInstance(
+        const CIMInstance & profileInstance,
+        const OperationContext & context);
+
+    void deleteProviderProfileCapabilityInstance(
+        const CIMObjectPath & instanceName,
+        const OperationContext & context);
+
     Array<CIMInstance> enumNamespaceInManagerInstances();
 
     Array<CIMInstance> enumCommMechanismForManagerInstances();
@@ -249,19 +267,41 @@ private:
     Array<CIMInstance> enumRegisteredSubProfileInstances();
     Array<CIMInstance> enumReferencedProfileInstances();
     Array<CIMInstance> getProfilesForVersion(
-        Array<CIMInstance>& subprofs, 
+        Array<CIMInstance>& subprofs,
         const String version);
     Array<CIMInstance> enumElementConformsToProfileInstances(
         const OperationContext & opContext,
         const CIMNamespaceName & opNamespace);
     Array<CIMInstance> enumElementConformsToProfileRPRPInstances(
-        const OperationContext & opContext, 
+        const OperationContext & opContext,
         const CIMNamespaceName & opNamespace);
     Array<CIMInstance> enumSubProfileRequiresProfileInstances();
     Array<CIMInstance> enumSoftwareIdentityInstances();
     Array<CIMInstance> enumElementSoftwareIdentityInstances();
     Array<CIMInstance> enumInstalledSoftwareIdentityInstances();
 
+    Array<CIMInstance> enumProviderProfileCapabilityInstances(
+        Boolean checkProviders = true,
+        Boolean localOnly = true,
+        Boolean includeQualifiers = false,
+        Boolean includeClassOrigin = false,
+        const CIMPropertyList &propertyList = CIMPropertyList());
+
+#ifdef PEGASUS_ENABLE_DMTF_INDICATION_PROFILE_SUPPORT
+    Array<CIMInstance> enumElementCapabilityInstances(
+        const OperationContext & opContext);
+    Array<CIMInstance> enumHostedIndicationServiceInstances(
+        const OperationContext & opContext);
+    Array<CIMInstance> enumServiceAffectsElementInstances(
+        const OperationContext & opContext);
+    CIMInstance buildAssociationInstance(
+        const CIMName &className,
+        const CIMName &propName1,
+        const CIMObjectPath &objPath1,
+        const CIMName &propName2,
+        const CIMObjectPath &objPath2);
+#endif
+
     CIMInstance buildRegisteredProfile(
         const String & instanceId,
         const String & profileName,
@@ -295,6 +335,9 @@ private:
         const CIMName & profileType,
         const Array<String> & defaultSniaProfiles);
 
+    Array<CIMInstance> getDMTFProfileInstances(
+        const CIMName & profileType);
+
     // The following are internal equivalents of the operations
     // allowing the operations to call one another internally within
     // the provider.
@@ -319,6 +362,7 @@ private:
 
     void cacheProfileRegistrationInfo();
     void verifyCachedInfo();
+    void initializeNamespaces();
 
     bool validAssocClassForObject(
         const OperationContext & context,
@@ -326,6 +370,11 @@ private:
         const CIMNamespaceName & opNamespace,
         String & originProperty, String & targetProperty);
 
+#ifdef PEGASUS_ENABLE_SLP
+    void sendUpdateRegMessageToSLPProvider(
+        const OperationContext & context);
+#endif
+
     // Repository Instance variable
     CIMOMHandle cimomHandle;
     CIMRepository * repository;
@@ -336,11 +385,16 @@ private:
     Array<Uint16> providerClassifications;
     Mutex interopMut;
     bool providerInitialized;
+    AtomicInt updateProfileCache;
 
     // Registration info to cache
     Array<String> profileIds;
     Array<CIMNameArray> conformingElements;
     Array<CIMNamespaceArray> elementNamespaces;
+
+    Boolean enableSLP;
+    String httpPort;
+    String httpsPort;
 };
 
 PEGASUS_NAMESPACE_END
