@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//=============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -39,8 +37,8 @@
 //  $(PEGASUS_ROOT)/Schemas/Pegasus/InterOp/VER20 for retails regarding the
 //  classes supported by this control provider.
 //
-//  Interop forces all creates to the PEGASUS_NAMESPACENAME_INTEROP 
-//  namespace. There is a test on each operation that returns 
+//  Interop forces all creates to the PEGASUS_NAMESPACENAME_INTEROP
+//  namespace. There is a test on each operation that returns
 //  the Invalid Class CIMDError
 //  This is a control provider and as such uses the Tracer functions
 //  for data and function traces.  Since we do not expect high volume
@@ -157,7 +155,7 @@ bool namespaceSupported(const CIMObjectPath & path)
 
     throw CIMNotSupportedException(path.getClassName().getString() +
       " in namespace " + path.getNameSpace().getString());
-    
+
     return false;
 }
 */
@@ -291,7 +289,7 @@ String getHostAddress(
   {
       ipAddress = "[" + ipAddress + "]";
   }
-#endif     
+#endif
   ipAddress.append(":");
   ipAddress.append(port);
 
@@ -421,8 +419,6 @@ Boolean validateRequiredProperty(
 //
 TARGET_CLASS translateClassInput(const CIMName& className)
 {
-    PEG_METHOD_ENTER(TRC_CONTROLPROVIDER,
-        "InteropProvider::translateClassInput");
     if(className.equal(PEGASUS_CLASSNAME_PG_OBJECTMANAGER))
         return PG_OBJECTMANAGER;
 
@@ -472,13 +468,32 @@ TARGET_CLASS translateClassInput(const CIMName& className)
     else if(className.equal(PEGASUS_CLASSNAME_PG_HOSTEDACCESSPOINT))
         return PG_HOSTEDACCESSPOINT;
 
+    else if(className.equal(PEGASUS_CLASSNAME_CIMNAMESPACE))
+        return CIM_NAMESPACE;
+
+    else if(className.equal(PEGASUS_CLASSNAME_PG_PROVIDERPROFILECAPABILITIES))
+        return PG_PROVIDERPROFILECAPABILITIES;
+
+    else if(className.equal(PEGASUS_CLASSNAME_PG_PROVIDERREFERENCEDPROFILES))
+        return PG_PROVIDERREFERENCEDPROFILES;
+
+#ifdef PEGASUS_ENABLE_DMTF_INDICATION_PROFILE_SUPPORT
+    else if(className.equal(PEGASUS_CLASSNAME_PG_ELEMENTCAPABILITIES))
+        return PG_ELEMENTCAPABILITIES;
+
+    else if(className.equal(PEGASUS_CLASSNAME_PG_HOSTEDINDICATIONSERVICE))
+        return PG_HOSTEDINDICATIONSERVICE;
+
+    else if(className.equal(PEGASUS_CLASSNAME_PG_SERVICEAFFECTSELEMENT))
+        return PG_SERVICEAFFECTSELEMENT;
+#endif
+
     // Last entry, reverse test and throw exception if not PG_Namespace
     // Note: Changed to PG_Namespace for CIM 2.4
     else if(!className.equal(PEGASUS_CLASSNAME_PGNAMESPACE))
         throw CIMNotSupportedException
             (className.getString() + " not supported by Interop Provider");
 
-    PEG_METHOD_EXIT();
     return PG_NAMESPACE;
 }
 
@@ -487,9 +502,6 @@ TARGET_CLASS translateClassInput(const CIMName& className)
 //
 TARGET_CLASS translateAssocClassInput(const CIMName & className)
 {
-    PEG_METHOD_ENTER(TRC_CONTROLPROVIDER,
-            "InteropProvider::translateAssocClassInput");
-
     if(className.equal(PEGASUS_CLASSNAME_PG_NAMESPACEINMANAGER))
         return PG_NAMESPACEINMANAGER;
 
@@ -517,7 +529,6 @@ TARGET_CLASS translateAssocClassInput(const CIMName & className)
           " not supported by association operations in the Interop Provider");
     }
 
-    PEG_METHOD_EXIT();
     return PG_SUBPROFILEREQUIRESPROFILE;
 }
 
