@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//=============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 
 #ifndef InteropProviderUtils_h
 #define InteropProviderUtils_h
@@ -42,24 +40,33 @@
 PEGASUS_NAMESPACE_BEGIN
 
 // Enum for class selection for instance operations.
-enum TARGET_CLASS {
-        PG_NAMESPACE,
-        PG_OBJECTMANAGER,
-        PG_CIMXMLCOMMUNICATIONMECHANISM,
-        PG_NAMESPACEINMANAGER,
-        PG_COMMMECHANISMFORMANAGER,
-        PG_REGISTEREDPROFILE,
-        PG_REGISTEREDSUBPROFILE,
-        PG_REFERENCEDPROFILE,
-        PG_ELEMENTCONFORMSTOPROFILE,
-        PG_SUBPROFILEREQUIRESPROFILE,
-        PG_SOFTWAREIDENTITY,
-        PG_ELEMENTSOFTWAREIDENTITY,
-        PG_INSTALLEDSOFTWAREIDENTITY,
-        PG_COMPUTERSYSTEM,
-        PG_HOSTEDOBJECTMANAGER,
-        PG_HOSTEDACCESSPOINT,
-        PG_ELEMENTCONFORMSTOPROFILE_RP_RP
+enum TARGET_CLASS
+{
+    PG_NAMESPACE,
+    PG_OBJECTMANAGER,
+    PG_CIMXMLCOMMUNICATIONMECHANISM,
+    PG_NAMESPACEINMANAGER,
+    PG_COMMMECHANISMFORMANAGER,
+    PG_REGISTEREDPROFILE,
+    PG_REGISTEREDSUBPROFILE,
+    PG_REFERENCEDPROFILE,
+    PG_ELEMENTCONFORMSTOPROFILE,
+    PG_SUBPROFILEREQUIRESPROFILE,
+    PG_SOFTWAREIDENTITY,
+    PG_ELEMENTSOFTWAREIDENTITY,
+    PG_INSTALLEDSOFTWAREIDENTITY,
+    PG_COMPUTERSYSTEM,
+    PG_HOSTEDOBJECTMANAGER,
+    PG_HOSTEDACCESSPOINT,
+    PG_ELEMENTCONFORMSTOPROFILE_RP_RP,
+    CIM_NAMESPACE,
+    PG_PROVIDERPROFILECAPABILITIES,
+    PG_PROVIDERREFERENCEDPROFILES
+#ifdef PEGASUS_ENABLE_DMTF_INDICATION_PROFILE_SUPPORT
+    ,PG_ELEMENTCAPABILITIES,
+    PG_HOSTEDINDICATIONSERVICE,
+    PG_SERVICEAFFECTSELEMENT
+#endif
 };
 
 /***************************************************************
@@ -334,6 +341,8 @@ String extractProfileInfo(
     Array<String> & subprofileVersions,
     Array<Uint16> & subprofileOrganizations,
     Array<String> & subprofileOrganizationNames,
+    Array<String> & subProfileProviderModuleNames,
+    Array<String> & subProfileProviderNames,
     bool noSubProfileInfo = true);
 
 PEGASUS_NAMESPACE_END
