@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -92,7 +90,7 @@ static const CIMName PG_NAMESPACE_PROPERTY_PARENTNAMESPACE(
 Array<CIMInstance> InteropProvider::enumNamespaceInstances()
 {
     PEG_METHOD_ENTER(TRC_CONTROLPROVIDER,
-        "InteropProvider::_getInstancesCIMNamespace()");
+        "InteropProvider::enumNamespaceInstances()");
 
     Array<CIMNamespaceName> namespaceNames = repository->enumerateNameSpaces();
     Array<CIMInstance> instanceArray;
@@ -116,7 +114,7 @@ Array<CIMInstance> InteropProvider::enumNamespaceInstances()
 Array<CIMInstance> InteropProvider::enumNamespaceInManagerInstances()
 {
     PEG_METHOD_ENTER(TRC_CONTROLPROVIDER,
-        "InteropProvider::buildInstancesNamespaceInManager");
+        "InteropProvider::enumNamespaceInManagerInstances()");
 
     Array<CIMInstance> namespaceInstances = enumNamespaceInstances();
 
@@ -127,7 +125,7 @@ Array<CIMInstance> InteropProvider::enumNamespaceInManagerInstances()
 
     CIMInstance instanceskel = buildInstanceSkeleton(
         PEGASUS_NAMESPACENAME_INTEROP,
-        PEGASUS_CLASSNAME_PG_NAMESPACEINMANAGER, targetClass);
+        PEGASUS_CLASSNAME_PG_NAMESPACEINMANAGER, true, targetClass);
     // Build and instance for each namespace instance.
     for (Uint32 i = 0 ; i < namespaceInstances.size() ; i++)
     {
@@ -155,12 +153,12 @@ CIMInstance InteropProvider::buildNamespaceInstance(
     const String & nameSpace)
 {
     PEG_METHOD_ENTER(TRC_CONTROLPROVIDER,
-        "InteropProvider::buildInstancePGNamespace");
+        "InteropProvider::buildNamespaceInstance()");
 
     CIMClass targetClass;
     CIMInstance instance = buildInstanceSkeleton(
         PEGASUS_NAMESPACENAME_INTEROP, PEGASUS_CLASSNAME_PGNAMESPACE,
-        targetClass);
+        true, targetClass);
 
     setCommonKeys(instance);
 
@@ -239,6 +237,13 @@ CIMInstance InteropProvider::buildNamespaceInstance(
         {
             parent=value;
         }
+#ifdef PEGASUS_ENABLE_REMOTE_CMPI
+        else if (String::equalNoCase(key,"remoteInfo"))
+        {
+            //ATTN: remoteInfo property is not part of PG_Namespace class,
+            // add the property to PG_Namespace instance once avilable.
+        }
+#endif
         else
         {
             PEG_METHOD_EXIT();
@@ -279,7 +284,7 @@ String buildNamespacePath(
     const String & objectManagerName)
 {
     PEG_METHOD_ENTER(TRC_CONTROLPROVIDER,
-        "InteropProvider::buildNamespacePath");
+        "buildNamespacePath()");
 
     unsigned int propIndex = PEG_NOT_FOUND;
     CIMName propertyName;
@@ -320,8 +325,9 @@ String buildNamespacePath(
 
     if(propIndex == PEG_NOT_FOUND)
     {
-        PEG_TRACE_STRING(TRC_CONTROLPROVIDER, Tracer::LEVEL4,
-            "Invalid CIM_Namespace Key Property " +  propertyName.getString());
+        PEG_TRACE((TRC_CONTROLPROVIDER, Tracer::LEVEL1,
+            "Invalid CIM_Namespace Key Property %s",
+            (const char*)propertyName.getString().getCString()));
         PEG_METHOD_EXIT();
         throw CIMInvalidParameterException(
             "Invalid CIM_Namespace key property: " + propertyName.getString());
@@ -375,7 +381,7 @@ CIMNamespaceName validateNamespaceKeys(
     const String & objectManagerName)
 {
     PEG_METHOD_ENTER(TRC_CONTROLPROVIDER,
-        "InteropProvider::validatePGNamespaceKeys");
+        "validateNamespaceKeys()");
 
     CIMName propertyName;
     if(!validateRequiredProperty(
@@ -450,13 +456,10 @@ void InteropProvider::deleteNamespace(
 
     repository->deleteNameSpace(deleteNamespaceName);
 
-    PEG_TRACE_STRING(TRC_CONTROLPROVIDER, Tracer::LEVEL4,
-        "Namespace = " + deleteNamespaceName.getString() +
-            " successfully deleted.");
+    PEG_TRACE((TRC_CONTROLPROVIDER, Tracer::LEVEL4,
+        "Namespace = %s successfully deleted.",
+        (const char*)deleteNamespaceName.getString().getCString()));
 
-    Logger::put(Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
-        "Interop Provider Delete Namespace: $0",
-        deleteNamespaceName.getString());
     PEG_METHOD_EXIT();
 }
 
@@ -475,9 +478,9 @@ CIMObjectPath InteropProvider::createNamespace(
 
     // Create the new namespace
 
-    PEG_TRACE_STRING(TRC_CONTROLPROVIDER, Tracer::LEVEL4,
-        "Namespace = " + newNamespaceName.getString() +
-            " to be created.");
+    PEG_TRACE((TRC_CONTROLPROVIDER, Tracer::LEVEL4,
+        "Namespace = %s to be created.",
+        (const char*)newNamespaceName.getString().getCString()));
 
     CIMRepository::NameSpaceAttributes attributes;
 
@@ -517,16 +520,15 @@ CIMObjectPath InteropProvider::createNamespace(
     //
     repository->createNameSpace(newNamespaceName, attributes);
 
-    PEG_TRACE_STRING(TRC_CONTROLPROVIDER, Tracer::LEVEL4,
-        "Namespace = " + newNamespaceName.getString() +
-            " successfully created.");
-    Logger::put(Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
-        "Create Namespace $0: Shareable = $1, Updates allowed: $2, "
-            "Parent: $3",
-        newNamespaceName.getString(),
+    PEG_TRACE((
+        TRC_CONTROLPROVIDER,
+        Tracer::LEVEL4,
+        "Namespace %s: Shareable = %s, Updates allowed: %s, Parent: %s"
+            "  successfully created.",
+        (const char*) newNamespaceName.getString().getCString(),
         shareable? "true" : "false",
         updatesAllowed? "true" : "false",
-        parent);
+        (const char*) parent.getCString()));
 
     return newInstanceReference;
 }
