@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//=============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -39,8 +37,8 @@
 //  $(PEGASUS_ROOT)/Schemas/Pegasus/InterOp/VER20 for retails regarding the
 //  classes supported by this control provider.
 //
-//  Interop forces all creates to the PEGASUS_NAMESPACENAME_INTEROP 
-//  namespace. There is a test on each operation that returns 
+//  Interop forces all creates to the PEGASUS_NAMESPACENAME_INTEROP
+//  namespace. There is a test on each operation that returns
 //  the Invalid Class CIMDError
 //  This is a control provider and as such uses the Tracer functions
 //  for data and function traces.  Since we do not expect high volume
@@ -103,7 +101,7 @@ const CIMName CIMXMLCOMMMECH_PROPERTY_AUTHENTICATIONMECHANISMDESCRIPTIONS(
 const CIMName CIMXMLCOMMMECH_PROPERTY_MULTIPLEOPERATIONSSUPPORTED(
         "MultipleOperationsSupported");
 const CIMName CIMXMLCOMMMECH_PROPERTY_VERSION("Version");
-const CIMName 
+const CIMName
    CIMXMLCOMMMECH_PROPERTY_CIMXMLPROTOVERSION("CIMXMLProtocolVersion");
 const CIMName CIMXMLCOMMMECH_PROPERTY_NAMESPACETYPE("namespaceType");
 const CIMName CIMXMLCOMMMECH_PROPERTY_NAMESPACEACCESSPROTOCOL(
@@ -118,7 +116,7 @@ const CIMName CIMXMLCOMMMECH_PROPERTY_ADVERTISETYPES("AdvertiseTypes");
 //
 // Fills in the CIMOperation functional profiles and corresponding description
 // array.  This function is closely linked to compile and configuration
-// features in the CIM Server to determine if certain features are 
+// features in the CIM Server to determine if certain features are
 // enabled and/or compiled.  Definitions correspond to the DMTF SLP template
 // version 1.0.
 // @param Array<Uint16> profiles provides an array for the profiles
@@ -268,8 +266,7 @@ CIMInstance InteropProvider::buildCIMXMLCommunicationMechanismInstance(
 
     // AdvertiseTypes property
     Array<Uint16> advertiseTypes;
-    ConfigManager* configManager = ConfigManager::getInstance();
-    if (String::equal(configManager->getCurrentValue("slp"), "true"))
+    if (enableSLP)
     {
         advertiseTypes.append(3); // Advertised via SLP
     }
@@ -313,24 +310,16 @@ Array<CIMInstance> InteropProvider::enumCIMXMLCommunicationMechanismInstances()
         PEGASUS_NAMESPACENAME_INTEROP,
         PEGASUS_CLASSNAME_PG_CIMXMLCOMMUNICATIONMECHANISM, false, true, false);
 
+    Array<String> ips;
+#ifdef PEGASUS_ENABLE_IPV6
+    ips = System::getInterfaceAddrs();
+#endif
     if (enableHttpConnection)
     {
         // Build the CommunicationMechanism instance for the HTTP protocol
         namespaceAccessProtocol = 2;
         namespaceType = "http";
-        String httpPort = configManager->getCurrentValue("httpPort");
-        if (httpPort == String::EMPTY)
-        {
-            Uint32 portNumberHttp = System::lookupPort(
-                WBEM_HTTP_SERVICE_NAME, WBEM_DEFAULT_HTTP_PORT);
-            char buffer[32];
-            sprintf(buffer, "%u", portNumberHttp);
-            httpPort.assign(buffer);
-        }
         CIMInstance instance;
-        Array<String> ips;
-#ifdef PEGASUS_ENABLE_IPV6
-        ips = System::getInterfaceAddrs();
         for (Uint32 i = 0; i < ips.size() ; ++i)
         {
             String addr = ips[i];
@@ -340,7 +329,7 @@ Array<CIMInstance> InteropProvider::enumCIMXMLCommunicationMechanismInstances()
             }
             addr.append(":");
             addr.append(httpPort);
-            
+
             instance  =
                 buildCIMXMLCommunicationMechanismInstance(
                     namespaceType,
@@ -349,7 +338,6 @@ Array<CIMInstance> InteropProvider::enumCIMXMLCommunicationMechanismInstances()
                     commMechClass);
             instances.append(instance);
         }
-#endif
         // If System::getInterfaceAddrs() fails add ip4 addr here.
         if (!ips.size())
         {
@@ -367,19 +355,7 @@ Array<CIMInstance> InteropProvider::enumCIMXMLCommunicationMechanismInstances()
         // Build the CommunicationMechanism instance for the HTTPS protocol
         namespaceAccessProtocol = 3;
         namespaceType = "https";
-        String httpsPort = configManager->getCurrentValue("httpsPort");
-        if (httpsPort == String::EMPTY)
-        {
-            Uint32 portNumberHttps = System::lookupPort(
-                WBEM_HTTPS_SERVICE_NAME, WBEM_DEFAULT_HTTPS_PORT);
-            char buffer[32];
-            sprintf(buffer, "%u", portNumberHttps);
-            httpsPort.assign(buffer);
-        }
         CIMInstance instance;
-        Array<String> ips;
-#ifdef PEGASUS_ENABLE_IPV6
-        ips = System::getInterfaceAddrs();
         for (Uint32 i = 0; i < ips.size() ; ++i)
         {
             String addr = ips[i];
@@ -387,8 +363,8 @@ Array<CIMInstance> InteropProvider::enumCIMXMLCommunicationMechanismInstances()
             {
                 addr = "[" + addr + "]";
             }
-            addr.append(":");  
-            addr.append(httpsPort);  
+            addr.append(":");
+            addr.append(httpsPort);
             instance  =
                 buildCIMXMLCommunicationMechanismInstance(
                     namespaceType,
@@ -397,7 +373,6 @@ Array<CIMInstance> InteropProvider::enumCIMXMLCommunicationMechanismInstances()
                     commMechClass);
             instances.append(instance);
         }
-#endif
         // If System::getInterfaceAddrs() fails add ip4 addr here.
         if (!ips.size())
         {
@@ -454,7 +429,7 @@ CIMInstance InteropProvider::getObjectManagerInstance()
         //
         CIMClass omClass;
         instance = buildInstanceSkeleton(PEGASUS_NAMESPACENAME_INTEROP,
-            PEGASUS_CLASSNAME_PG_OBJECTMANAGER, omClass);
+            PEGASUS_CLASSNAME_PG_OBJECTMANAGER, false, omClass);
 
         // Set the common key properties
         setCommonKeys(instance);
@@ -507,6 +482,9 @@ CIMInstance InteropProvider::getObjectManagerInstance()
         // write instance to the repository
         CIMObjectPath instancePath = repository->createInstance(
             PEGASUS_NAMESPACENAME_INTEROP, instance);
+        // Get an updated copy of the instance that was saved
+        instance = repository->getInstance(
+            PEGASUS_NAMESPACENAME_INTEROP, instancePath, false);
         instance.setPath(instancePath);
     }
 
@@ -576,9 +554,11 @@ void InteropProvider::modifyObjectManagerInstance(
     // Modify the instance on disk
     repository->modifyInstance(instanceReference.getNameSpace(),
         omInstance, false,  propertyList);
-    Logger::put(Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
-        "Interop Provider Set Statistics gathering in CIM_ObjectManager: $0",
-        (statisticsFlag? "true" : "false"));
+    PEG_TRACE((
+        TRC_CONTROLPROVIDER,
+        Tracer::LEVEL3,
+        "Interop Provider Set Statistics gathering in CIM_ObjectManager: %s",
+        (statisticsFlag? "true" : "false")));
     StatisticalData* sd = StatisticalData::current();
     sd->setCopyGSD(statisticsFlag);
     PEG_METHOD_EXIT();
@@ -587,7 +567,7 @@ void InteropProvider::modifyObjectManagerInstance(
 #else
     PEG_METHOD_EXIT();
     throw CIMNotSupportedException
-        (OM_PROPERTY_GATHERSTATISTICALDATA.getString() + 
+        (OM_PROPERTY_GATHERSTATISTICALDATA.getString() +
                 " modify operation not supported by Interop Provider");
 #endif
 }
@@ -728,8 +708,8 @@ Array<CIMInstance> InteropProvider::enumCommMechanismForManagerInstances()
     Array<CIMInstance> assocInstances;
     CIMClass targetClass;
     CIMInstance instanceskel = buildInstanceSkeleton(
-        PEGASUS_NAMESPACENAME_INTEROP, 
-        PEGASUS_CLASSNAME_PG_COMMMECHANISMFORMANAGER, targetClass);
+        PEGASUS_NAMESPACENAME_INTEROP,
+        PEGASUS_CLASSNAME_PG_COMMMECHANISMFORMANAGER, true, targetClass);
     for (Uint32 i = 0, n = commInstances.size(); i < n; ++i)
     {
         CIMInstance instance = instanceskel.clone();
@@ -747,6 +727,227 @@ Array<CIMInstance> InteropProvider::enumCommMechanismForManagerInstances()
     return assocInstances;
 }
 
+#ifdef PEGASUS_ENABLE_DMTF_INDICATION_PROFILE_SUPPORT
+
+CIMInstance InteropProvider::buildAssociationInstance(
+    const CIMName &className,
+    const CIMName &propName1,
+    const CIMObjectPath &objPath1,
+    const CIMName &propName2,
+    const CIMObjectPath &objPath2)
+{
+    CIMClass cimClass = repository->getClass(
+        PEGASUS_NAMESPACENAME_INTEROP,
+        className,
+        false,
+        true,
+        true);
+
+    CIMInstance instance = cimClass.buildInstance(
+        true,
+        true,
+        CIMPropertyList());
+
+    instance.getProperty(instance.findProperty(propName1)).setValue(objPath1);
+    instance.getProperty(instance.findProperty(propName2)).setValue(objPath2);
+    instance.setPath(instance.buildPath(cimClass));
+
+    return instance;
+}
+
+Array<CIMInstance> InteropProvider::enumElementCapabilityInstances(
+    const OperationContext &opContext)
+{
+    // Get CIM_IndicationServiceCapabilities instance
+    Array<CIMObjectPath> capPaths = cimomHandle.enumerateInstanceNames(
+        opContext,
+        PEGASUS_NAMESPACENAME_INTEROP,
+        PEGASUS_CLASSNAME_CIM_INDICATIONSERVICECAPABILITIES);
+    PEGASUS_ASSERT(capPaths.size() == 1);
+
+    // Get CIM_IndicationService instance
+    Array<CIMObjectPath> servicePaths = cimomHandle.enumerateInstanceNames(
+        opContext,
+        PEGASUS_NAMESPACENAME_INTEROP,
+        PEGASUS_CLASSNAME_CIM_INDICATIONSERVICE);
+    PEGASUS_ASSERT(servicePaths.size() == 1);
+
+    Array<CIMInstance> instances;
+
+    instances.append(
+        buildAssociationInstance(
+            PEGASUS_CLASSNAME_PG_ELEMENTCAPABILITIES,
+            PROPERTY_CAPABILITIES,
+            capPaths[0],
+            PROPERTY_MANAGEDELEMENT,
+            servicePaths[0]));
+
+    return instances;
+}
+
+Array<CIMInstance> InteropProvider::enumHostedIndicationServiceInstances(
+    const OperationContext &opContext)
+{
+    Array<CIMInstance> instances;
+    CIMInstance cInst = getComputerSystemInstance();
+
+    // Get CIM_IndicationService instance
+    Array<CIMObjectPath> servicePaths = cimomHandle.enumerateInstanceNames(
+        opContext,
+        PEGASUS_NAMESPACENAME_INTEROP,
+        PEGASUS_CLASSNAME_CIM_INDICATIONSERVICE);
+
+    PEGASUS_ASSERT(servicePaths.size() == 1);
+
+    instances.append(
+        buildAssociationInstance(
+            PEGASUS_CLASSNAME_PG_HOSTEDINDICATIONSERVICE,
+            PROPERTY_ANTECEDENT,
+            cInst.getPath(),
+            PROPERTY_DEPENDENT,
+            servicePaths[0]));
+
+    return instances;
+}
+
+Array<CIMInstance> InteropProvider::enumServiceAffectsElementInstances(
+    const OperationContext &opContext)
+{
+    Array<CIMInstance> instances;
+
+    // Get CIM_IndicationService instance
+    Array<CIMObjectPath> servicePaths = cimomHandle.enumerateInstanceNames(
+        opContext,
+        PEGASUS_NAMESPACENAME_INTEROP,
+        PEGASUS_CLASSNAME_CIM_INDICATIONSERVICE);
+    PEGASUS_ASSERT(servicePaths.size() == 1);
+
+    Array<CIMNamespaceName> namespaceNames = repository->enumerateNameSpaces();
+    // Get CIM_IndicationFilter and CIM_ListenerDestination instances in all
+    // namespaces and associate them with CIM_IndicationService instance using
+    // PG_ServiceAffectsElement instance.
+    for (Uint32 i = 0, n = namespaceNames.size() ; i < n ; ++i)
+    {
+        Array<CIMObjectPath> filterPaths;
+        try
+        {
+            // Get CIM_IndicationFilter instance names
+            filterPaths = cimomHandle.enumerateInstanceNames(
+                opContext,
+                namespaceNames[i],
+                PEGASUS_CLASSNAME_INDFILTER);
+        }
+        catch(CIMException &e)
+        {
+            // Ignore exception with CIM_ERR_INVALID_CLASS code. This will
+            // happen when the class CIM_IndicationFilter can not be found
+            // in this namespace.
+            if (e.getCode() != CIM_ERR_INVALID_CLASS)
+            {
+                PEG_TRACE((
+                    TRC_CONTROLPROVIDER,
+                    Tracer::LEVEL2,
+                    "CIMException while enumerating the "
+                        "CIM_IndicationFilter instances"
+                            " in the namespace %s: %s.",
+                     (const char*)namespaceNames[i].getString().getCString(),
+                     (const char*)e.getMessage().getCString()));
+            }
+        }
+        catch(Exception &e)
+        {
+            PEG_TRACE((
+                TRC_CONTROLPROVIDER,
+                Tracer::LEVEL1,
+                "Exception while enumerating the "
+                    "CIM_IndicationFilter instances"
+                        " in the namespace %s: %s.",
+                (const char*)namespaceNames[i].getString().getCString(),
+                (const char*)e.getMessage().getCString()));
+        }
+        catch(...)
+        {
+            PEG_TRACE((
+                TRC_CONTROLPROVIDER,
+                Tracer::LEVEL1,
+                "Unknown error occurred while enumerating the "
+                    "CIM_IndicationFilter instances in the namespace %s.",
+                (const char*)namespaceNames[i].getString().getCString()));
+        }
+        for (Uint32 f = 0, fn = filterPaths.size(); f < fn ; ++f)
+        {
+            filterPaths[f].setNameSpace(namespaceNames[i]);
+            instances.append(
+                buildAssociationInstance(
+                    PEGASUS_CLASSNAME_PG_SERVICEAFFECTSELEMENT,
+                    PROPERTY_AFFECTEDELEMENT,
+                    filterPaths[f],
+                    PROPERTY_AFFECTINGELEMENT,
+                    servicePaths[0]));
+        }
+
+        Array<CIMObjectPath> handlerPaths;
+        try
+        {
+            // Get CIM_ListenerDestination instance names
+            handlerPaths = cimomHandle.enumerateInstanceNames(
+                opContext,
+                namespaceNames[i],
+                PEGASUS_CLASSNAME_LSTNRDST);
+        }
+        catch(CIMException &e)
+        {
+            // Ignore exception with CIM_ERR_INVALID_CLASS code. This will
+            // happen when the class CIM_ListenerDestination can not be found
+            // in this namespace.
+            if (e.getCode() != CIM_ERR_INVALID_CLASS)
+            {
+                PEG_TRACE((
+                    TRC_CONTROLPROVIDER,
+                    Tracer::LEVEL2,
+                    "CIMException while enumerating the "
+                        "CIM_ListenerDestination instances"
+                            " in the namespace %s: %s.",
+                     (const char*)namespaceNames[i].getString().getCString(),
+                     (const char*)e.getMessage().getCString()));
+            }
+        }
+        catch(Exception &e)
+        {
+            PEG_TRACE((
+                TRC_CONTROLPROVIDER,
+                Tracer::LEVEL1,
+                "Exception while enumerating the "
+                    "CIM_ListenerDestination instances"
+                        " in the namespace %s: %s.",
+                (const char*)namespaceNames[i].getString().getCString(),
+                (const char*)e.getMessage().getCString()));
+        }
+        catch(...)
+        {
+            PEG_TRACE((
+                TRC_CONTROLPROVIDER,
+                Tracer::LEVEL1,
+                "Unknown error occurred while enumerating the "
+                    "CIM_ListenerDestination instances in the namespace %s.",
+                (const char*)namespaceNames[i].getString().getCString()));
+        }
+        for (Uint32 h = 0, hn = handlerPaths.size(); h < hn ; ++h)
+        {
+            handlerPaths[h].setNameSpace(namespaceNames[i]);
+            instances.append(
+                buildAssociationInstance(
+                    PEGASUS_CLASSNAME_PG_SERVICEAFFECTSELEMENT,
+                    PROPERTY_AFFECTEDELEMENT,
+                    handlerPaths[h],
+                    PROPERTY_AFFECTINGELEMENT,
+                    servicePaths[0]));
+        }
+    }
+    return instances;
+}
+#endif
+
 PEGASUS_NAMESPACE_END
 
 // END OF FILE
