@@ -1,39 +1,39 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//=============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 
 #include <Pegasus/Common/Config.h>
 #include <Pegasus/Common/CIMName.h>
 #include <Pegasus/Common/CIMObjectPath.h>
 #include <Pegasus/Common/CIMInstance.h>
 #include <Pegasus/Common/String.h>
+#include <Pegasus/Common/Constants.h>
+#include <Pegasus/Common/PegasusAssert.h>
 
 #include <Pegasus/Client/CIMClient.h>
 
@@ -418,6 +418,200 @@ void testAssociationClass(CIMClient & client, const CIMName & className)
     cout << "Test Complete" << endl;
 }
 
+void testDMTFProfileInstances(CIMClient &client)
+{
+    cout << "Testing DMTF Profiles instances...";
+
+    // Get All Registered profile names
+    Array<CIMObjectPath> regInstanceNames = client.enumerateInstanceNames(
+        interopNamespace,
+        CIMName("CIM_RegisteredProfile"));
+
+    // Find out DMTF autonomous and component profiles.
+    for(Uint32 i = 0, n = regInstanceNames.size() ; i < n ; ++i)
+    {
+        // Filter SNIA sub profile names.
+        if (regInstanceNames[i].getClassName().equal("PG_RegisteredSubProfile"))
+        {
+            continue;
+        }
+
+        Array<CIMObjectPath> result = client.associatorNames(
+            interopNamespace,
+            regInstanceNames[i],
+            CIMName("CIM_ReferencedProfile"));
+
+        Uint32 dmtfProfiles = 0;
+        for (Uint32 j = 0, k = result.size(); j < k ; ++j)
+        {
+            // Get only DMTF component profiles.
+            if (result[j].getClassName().equal("PG_RegisteredProfile"))
+            {
+                Array<CIMKeyBinding> keys = result[j].getKeyBindings();
+                String value = keys[0].getValue();
+                Uint32 index = value.find("DMTF");
+                if (index != PEG_NOT_FOUND)
+                {
+                    dmtfProfiles++;
+                }
+            }
+        }
+        if (dmtfProfiles && dmtfProfiles != result.size())
+        {
+            exitFailure(
+                String("Invalid component profiles for ")
+                    + regInstanceNames[i].toString());
+        }
+    }
+
+    cout << "Test Complete" << endl;
+}
+
+//
+// ATTN: The following indications profile tests will be removed once the
+// association opertaions are implemented for these classes. At present these
+// tests are pegasus specific.
+//
+#ifdef PEGASUS_ENABLE_DMTF_INDICATION_PROFILE_SUPPORT
+void _testHostedIndicationServiceInstance(CIMClient &client)
+{
+    cout << "Testing Association Class "
+        << (const char *)PEGASUS_CLASSNAME_PG_HOSTEDINDICATIONSERVICE.
+             getString().getCString()
+        << "...";
+    // Get PG_HostedIndicationService Instances
+    Array<CIMInstance> hostedInstances = client.enumerateInstances(
+        PEGASUS_NAMESPACENAME_INTEROP,
+        PEGASUS_CLASSNAME_PG_HOSTEDINDICATIONSERVICE);
+    PEGASUS_TEST_ASSERT(hostedInstances.size() == 1);
+
+    // Get PG_HostedIndicationService Instance names
+    Array<CIMObjectPath> hostedPaths = client.enumerateInstanceNames(
+        PEGASUS_NAMESPACENAME_INTEROP,
+        PEGASUS_CLASSNAME_PG_HOSTEDINDICATIONSERVICE);
+    PEGASUS_TEST_ASSERT(hostedPaths.size() == 1);
+
+    // Get CIM_IndicationService instance names
+    Array<CIMObjectPath> servicePaths = client.enumerateInstanceNames(
+        PEGASUS_NAMESPACENAME_INTEROP,
+        PEGASUS_CLASSNAME_CIM_INDICATIONSERVICE);
+    PEGASUS_TEST_ASSERT(servicePaths.size() == 1);
+
+    // Test the CIM_IndicationService value.
+    CIMValue capValue = hostedInstances[0].getProperty(
+        hostedInstances[0].findProperty("Dependent")).getValue();
+    CIMObjectPath testPath;
+    capValue.get(testPath);
+    testPath.setNameSpace(CIMNamespaceName());
+    PEGASUS_TEST_ASSERT(testPath.identical(servicePaths[0]));
+
+    cout << "Test Complete" << endl;
+}
+
+void _testElementCapabilityInstance(CIMClient &client)
+{
+    cout << "Testing Association Class "
+        << (const char *)PEGASUS_CLASSNAME_CIM_INDICATIONSERVICECAPABILITIES.
+             getString().getCString()
+        << "...";
+
+    // Get CIM_IndicationServiceCapabilities instance names
+    Array<CIMObjectPath> capPaths = client.enumerateInstanceNames(
+        PEGASUS_NAMESPACENAME_INTEROP,
+        PEGASUS_CLASSNAME_CIM_INDICATIONSERVICECAPABILITIES);
+    PEGASUS_TEST_ASSERT(capPaths.size() == 1);
+
+    // Get CIM_IndicationService instance names
+    Array<CIMObjectPath> servicePaths = client.enumerateInstanceNames(
+        PEGASUS_NAMESPACENAME_INTEROP,
+        PEGASUS_CLASSNAME_CIM_INDICATIONSERVICE);
+    PEGASUS_TEST_ASSERT(servicePaths.size() == 1);
+
+
+    // Get PG_ElementCapabilities instances
+    Array<CIMInstance> eleInstances = client.enumerateInstances(
+        PEGASUS_NAMESPACENAME_INTEROP,
+        PEGASUS_CLASSNAME_PG_ELEMENTCAPABILITIES);
+    PEGASUS_TEST_ASSERT(eleInstances.size() == 1);
+
+    // Test PG_ElementCapabilities instance.
+    CIMValue capValue = eleInstances[0].getProperty(
+        eleInstances[0].findProperty("Capabilities")).getValue();
+
+    CIMValue meValue = eleInstances[0].getProperty(
+        eleInstances[0].findProperty("ManagedElement")).getValue();
+
+    // Now test the instance names of CIM_IndicationService instance and
+    // CIM_IndicationServiceCapabilities instance.
+    CIMObjectPath testPath;
+    capValue.get(testPath);
+    testPath.setNameSpace(CIMNamespaceName());
+    PEGASUS_TEST_ASSERT(testPath.identical(capPaths[0]));
+
+    meValue.get(testPath);
+    testPath.setNameSpace(CIMNamespaceName());
+    PEGASUS_TEST_ASSERT(testPath.identical(servicePaths[0]));
+
+    cout << "Test Complete" << endl;
+}
+
+void _testServiceAffectsElementInstances(CIMClient &client)
+{
+    cout << "Testing Association Class "
+        << (const char *)PEGASUS_CLASSNAME_PG_SERVICEAFFECTSELEMENT.
+             getString().getCString()
+        << "...";
+
+    // Get PG_ServiceAffectsElement instances.
+    Array<CIMInstance> sfInstances = client.enumerateInstances(
+        PEGASUS_NAMESPACENAME_INTEROP,
+        PEGASUS_CLASSNAME_PG_SERVICEAFFECTSELEMENT);
+
+    // Get PG_ServiceAffectsElement instance names
+    Array<CIMObjectPath> sfPaths = client.enumerateInstanceNames(
+        PEGASUS_NAMESPACENAME_INTEROP,
+        PEGASUS_CLASSNAME_PG_SERVICEAFFECTSELEMENT);
+
+    PEGASUS_TEST_ASSERT(sfInstances.size() == sfPaths.size());
+
+    // Get CIM_IndicationFilter instance names
+    Array<CIMObjectPath> filterPaths = client.enumerateInstanceNames(
+        PEGASUS_NAMESPACENAME_INTEROP,
+        PEGASUS_CLASSNAME_INDFILTER);
+
+    // Get CIM_ListenerDestination instance names
+    Array<CIMObjectPath> handlerPaths = client.enumerateInstanceNames(
+        PEGASUS_NAMESPACENAME_INTEROP,
+        PEGASUS_CLASSNAME_LSTNRDST);
+
+    // Count only handlers and filters from interop namespace
+    Uint32 elements = 0;
+    for (Uint32 i = 0; i < sfInstances.size() ; ++i)
+    {
+        CIMValue value = sfInstances[i].getProperty(
+            sfInstances[i].findProperty("AffectedElement")).getValue();
+        CIMObjectPath path;
+        value.get(path);
+        PEGASUS_TEST_ASSERT(path.getNameSpace() != CIMNamespaceName());
+        if (path.getNameSpace() == PEGASUS_NAMESPACENAME_INTEROP)
+        {
+             elements++;
+        }
+    }
+    PEGASUS_TEST_ASSERT(
+        elements == (filterPaths.size() + handlerPaths.size()));
+
+    cout << "Test Complete" << endl;
+}
+
+void testIndicationProfileInstances(CIMClient &client)
+{
+    _testHostedIndicationServiceInstance(client);
+    _testElementCapabilityInstance(client);
+    _testServiceAffectsElementInstances(client);
+}
+#endif
+
 ///////////////////////////////////////////////////////////////
 //    MAIN
 ///////////////////////////////////////////////////////////////
@@ -480,6 +674,10 @@ int main(int argc, char** argv)
             currentClass.getString());
     }
 
+    testDMTFProfileInstances(client);
+#ifdef PEGASUS_ENABLE_DMTF_INDICATION_PROFILE_SUPPORT
+    testIndicationProfileInstances(client);
+#endif
     //testAssociationTraversal(client);
 
     cout << endl << "Server Profile Tests complete" << endl;
