@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//=============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%////////////////////////////////////////////////////////////////////////////
 
@@ -339,6 +337,27 @@ Array<CIMInstance> InteropProvider::enumSoftwareIdentityInstances()
         PEGASUS_PRODUCT_VERSION,
         0, 0, 0, 0, false, // no extended revision info
         PEGASUS_INTERNAL_PROVIDER_TYPE, String::EMPTY, String::EMPTY));
+
+    // Pegasus Indication Service acts as Provider for CIM Event classes.
+    // If DMTF Indications Profile support is enabled create SoftwareIdentity
+    // instance with Pegasus Indication Service.
+#ifdef PEGASUS_ENABLE_DMTF_INDICATION_PROFILE_SUPPORT
+    instances.append(
+        buildSoftwareIdentity(
+            PEGASUS_MODULE_NAME,
+            INDICATION_SERVICE_NAME,
+            PEGASUS_CIMOM_GENERIC_NAME,
+            PEGASUS_PRODUCT_VERSION,
+            0,
+            0,
+            0,
+            0,
+            false, // no extended revision info
+            PEGASUS_INTERNAL_SERVICE_TYPE,
+            String::EMPTY,
+            String::EMPTY));
+#endif
+
     return instances;
 }
 
@@ -352,10 +371,7 @@ Array<CIMInstance> InteropProvider::enumElementSoftwareIdentityInstances()
     Array<CIMInstance> instances;
 
     Array<CIMInstance> profileCapabilities =
-        repository->enumerateInstancesForClass(
-            PEGASUS_NAMESPACENAME_INTEROP,
-            PEGASUS_CLASSNAME_PG_PROVIDERPROFILECAPABILITIES,
-            false);
+        enumProviderProfileCapabilityInstances(true, false);
 
     CIMClass elementSoftwareIdentityClass = repository->getClass(
         PEGASUS_NAMESPACENAME_INTEROP,
@@ -371,23 +387,28 @@ Array<CIMInstance> InteropProvider::enumElementSoftwareIdentityInstances()
         String organizationName;
         Array<String> subprofiles;
         String profileName;
-        Uint16 dummyInt = 0;
+        Uint16 profileOrg = 0;
         Array<Uint16> dummyIntArray;
         Array<String> subprofileVersions;
         Array<String> subprofileOrgs;
+        Array<String> subprofileProviderModuleNames;
+        Array<String> subprofileProviderNames;
 
         String profileId = extractProfileInfo(currentCapabilities,
             profileCapabilitiesClass,
             registeredProfileClass,
             profileName,
             version,
-            dummyInt, // Throw away organization enum
+            profileOrg,
             organizationName,
             subprofiles,
             subprofileVersions,
             dummyIntArray, // Throw away subprofile organization enums
             subprofileOrgs,
+            subprofileProviderModuleNames,
+            subprofileProviderNames,
             false); // Get subprofile information
+
         if (!(String::equalNoCase(profileName,"SMI-S")))
         {
             String moduleName = getRequiredValue<String>(currentCapabilities,
@@ -418,13 +439,23 @@ Array<CIMInstance> InteropProvider::enumElementSoftwareIdentityInstances()
                 {
                     subprofileVersion = subprofileVersions[j];
                 }
+                // Check if subprofile is implemented in a different provider
+                // module or provider.
+                if (subprofileProviderModuleNames.size())
+                {
+                    softwareInstanceId = subprofileProviderModuleNames[j];
+                    softwareInstanceId.append("+");
+                    softwareInstanceId.append(subprofileProviderNames[j]);
+                }
 
                 instances.append(buildDependencyInstance(
                     softwareInstanceId,
                     PEGASUS_CLASSNAME_PG_SOFTWAREIDENTITY,
                     buildProfileInstanceId(subprofileOrgs[j], subprofiles[j],
                         subprofileVersion),
-                    PEGASUS_CLASSNAME_PG_REGISTEREDSUBPROFILE,
+                    profileOrg == DMTF_NUM ?
+                        PEGASUS_CLASSNAME_PG_REGISTEREDPROFILE :
+                        PEGASUS_CLASSNAME_PG_REGISTEREDSUBPROFILE,
                     elementSoftwareIdentityClass));
             }
         }
@@ -434,25 +465,25 @@ Array<CIMInstance> InteropProvider::enumElementSoftwareIdentityInstances()
     // subprofile, and the Pegasus Interoperability provider software identity
     String interopSoftwareIdentity = PEGASUS_MODULE_NAME + "+" +
         INTEROP_PROVIDER_NAME;
-    String serverProfileId, indicationProfileId, softwareProfileId;  
+    String serverProfileId, indicationProfileId, softwareProfileId;
 
     //add instances for smi-s version 1.1.0
     serverProfileId = buildProfileInstanceId(
-        SNIA_NAME, 
+        SNIA_NAME,
         "Server",
         SNIA_VER_110);
     indicationProfileId = buildProfileInstanceId(
         SNIA_NAME,
-        "Indication", 
+        "Indication",
         SNIA_VER_110);
     softwareProfileId = buildProfileInstanceId(
         SNIA_NAME,
-        "Software", 
+        "Software",
         SNIA_VER_110);
 
     instances.append(buildDependencyInstance(
         interopSoftwareIdentity,
-        PEGASUS_CLASSNAME_PG_SOFTWAREIDENTITY, 
+        PEGASUS_CLASSNAME_PG_SOFTWAREIDENTITY,
         serverProfileId,
         PEGASUS_CLASSNAME_PG_REGISTEREDPROFILE,
         elementSoftwareIdentityClass));
@@ -466,7 +497,7 @@ Array<CIMInstance> InteropProvider::enumElementSoftwareIdentityInstances()
 
     instances.append(buildDependencyInstance(
         interopSoftwareIdentity,
-        PEGASUS_CLASSNAME_PG_SOFTWAREIDENTITY, 
+        PEGASUS_CLASSNAME_PG_SOFTWAREIDENTITY,
         softwareProfileId,
         PEGASUS_CLASSNAME_PG_REGISTEREDSUBPROFILE,
         elementSoftwareIdentityClass));
@@ -475,32 +506,32 @@ Array<CIMInstance> InteropProvider::enumElementSoftwareIdentityInstances()
 
     String profileRegistrationProfileId;
     serverProfileId = buildProfileInstanceId(
-        SNIA_NAME, 
+        SNIA_NAME,
         "Server",
         SNIA_VER_120);
     profileRegistrationProfileId = buildProfileInstanceId(
-        SNIA_NAME, 
+        SNIA_NAME,
         "Profile Registration",
         SNIA_VER_100);
     indicationProfileId = buildProfileInstanceId(
         SNIA_NAME,
-        "Indication", 
+        "Indication",
         SNIA_VER_120);
     softwareProfileId = buildProfileInstanceId(
         SNIA_NAME,
-        "Software", 
+        "Software",
         SNIA_VER_120);
 
     instances.append(buildDependencyInstance(
         interopSoftwareIdentity,
-        PEGASUS_CLASSNAME_PG_SOFTWAREIDENTITY, 
+        PEGASUS_CLASSNAME_PG_SOFTWAREIDENTITY,
         serverProfileId,
         PEGASUS_CLASSNAME_PG_REGISTEREDPROFILE,
         elementSoftwareIdentityClass));
 
     instances.append(buildDependencyInstance(
         interopSoftwareIdentity,
-        PEGASUS_CLASSNAME_PG_SOFTWAREIDENTITY, 
+        PEGASUS_CLASSNAME_PG_SOFTWAREIDENTITY,
         profileRegistrationProfileId,
         PEGASUS_CLASSNAME_PG_REGISTEREDPROFILE,
         elementSoftwareIdentityClass));
@@ -519,6 +550,25 @@ Array<CIMInstance> InteropProvider::enumElementSoftwareIdentityInstances()
         PEGASUS_CLASSNAME_PG_REGISTEREDSUBPROFILE,
         elementSoftwareIdentityClass));
 
+#ifdef PEGASUS_ENABLE_DMTF_INDICATION_PROFILE_SUPPORT
+    String indProfileId = buildProfileInstanceId(
+        DMTF_NAME,
+        "Indication",
+        DMTF_VER_100);
+
+    String indicationServiceSoftwareIdentity(PEGASUS_MODULE_NAME);
+    indicationServiceSoftwareIdentity.append("+");
+    indicationServiceSoftwareIdentity.append(INDICATION_SERVICE_NAME);
+
+    instances.append(
+        buildDependencyInstance(
+            indicationServiceSoftwareIdentity,
+            PEGASUS_CLASSNAME_PG_SOFTWAREIDENTITY,
+            indProfileId,
+            PEGASUS_CLASSNAME_PG_REGISTEREDPROFILE,
+            elementSoftwareIdentityClass));
+#endif
+
     return instances;
 }
 
@@ -536,7 +586,8 @@ Array<CIMInstance> InteropProvider::enumInstalledSoftwareIdentityInstances()
     CIMClass installedSoftwareClass;
     CIMInstance skeletonInst =  buildInstanceSkeleton(
         PEGASUS_NAMESPACENAME_INTEROP,
-        PEGASUS_CLASSNAME_PG_INSTALLEDSOFTWAREIDENTITY, 
+        PEGASUS_CLASSNAME_PG_INSTALLEDSOFTWAREIDENTITY,
+        true,
         installedSoftwareClass);
     for (Uint32 i = 0, n = softwareInstances.size(); i < n; ++i)
     {
