@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%////////////////////////////////////////////////////////////////////////////
 
@@ -42,6 +40,7 @@
 #include <iostream>
 
 #include <Pegasus/Common/String.h>
+#include <Pegasus/Common/CIMNameCast.h>
 #include <Pegasus/Common/System.h>
 #include <Pegasus/Common/ArrayInternal.h>
 #include <Pegasus/Common/CIMType.h>
@@ -70,33 +69,38 @@ PEGASUS_NAMESPACE_BEGIN
     The constants representing the Username and Password properties in the
     schema.
 */
-static const CIMName PROPERTY_NAME_USERNAME       = CIMName ("Username");
+static const CIMName PROPERTY_NAME_USERNAME = CIMNameCast("Username");
 
-static const CIMName PROPERTY_NAME_PASSWORD       = CIMName ("Password");
+static const CIMName PROPERTY_NAME_PASSWORD = CIMNameCast("Password");
 
-static const char OLD_PASSWORD []                 = "OldPassword";
+static const char OLD_PASSWORD[] = "OldPassword";
 
-static const char NEW_PASSWORD []                 = "NewPassword";
+static const char NEW_PASSWORD[] = "NewPassword";
 
 /**
     The constants representing the namespace and authorization
     in the schema.
 */
-static const CIMName PROPERTY_NAME_NAMESPACE       = CIMName ("Namespace");
+static const CIMName PROPERTY_NAME_NAMESPACE       =
+    CIMNameCast("Namespace");
 
-static const CIMName PROPERTY_NAME_AUTHORIZATION   = CIMName ("Authorization");
+static const CIMName PROPERTY_NAME_AUTHORIZATION   =
+    CIMNameCast("Authorization");
 
 /**
     The constant representing the User class name.
 */
-static const CIMName CLASS_NAME_PG_USER            = CIMName ("PG_User");
+static const CIMName CLASS_NAME_PG_USER            =
+    CIMNameCast("PG_User");
 
-static const CIMName METHOD_NAME_MODIFY_PASSWORD   = CIMName ("modifyPassword");
+static const CIMName METHOD_NAME_MODIFY_PASSWORD   =
+    CIMNameCast("modifyPassword");
 
 /**
     The constant representing the authorization class name
 */
-static const CIMName CLASS_NAME_PG_AUTHORIZATION = CIMName ("PG_Authorization");
+static const CIMName CLASS_NAME_PG_AUTHORIZATION =
+    CIMNameCast("PG_Authorization");
 
 //
 // Verify user authorization
