@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -401,9 +399,6 @@ setlocale(LC_ALL, "");
                     }
                     else
                     {
-                        //l10n
-                        //cout << "Missing argument for option -" 
-                        //     << option << endl;
                         String opt(option);
                         MessageLoaderParms parms(
                                 "src.Server.cimserver.MISSING_ARGUMENT",
@@ -450,9 +445,6 @@ setlocale(LC_ALL, "");
                     //
                     if (shutdownOption)
                     {
-                        //l10n
-                        //cout << "Duplicate shutdown option specified."
-                        //     << endl;
                         MessageLoaderParms parms(
                            "DynListener.cimlistener.DUPLICATE_SHUTDOWN_OPTION",
                            "Duplicate shutdown option specified.");
@@ -550,13 +542,12 @@ int CIMListenerProcess::cimserver_run(
     }
     catch (Exception& e)
     {
-        Logger::put_l(Logger::ERROR_LOG, System::CIMLISTENER, Logger::SEVERE,
-            "src.Server.cimserver.SERVER_NOT_STARTED",
-            "cimserver not started:  $0", e.getMessage());
-
         MessageLoaderParms parms("DynListener.cimlistener.LISTENER_NOT_STARTED",
                 "CIM Listener not started: $0", e.getMessage());
 
+        Logger::put_l(Logger::ERROR_LOG, System::CIMLISTENER, Logger::SEVERE,
+            parms);
+
         PEGASUS_STD(cerr) << argv[0] << ": " << MessageLoader::getMessage(parms)
             << PEGASUS_STD(endl);
 
@@ -616,12 +607,12 @@ int CIMListenerProcess::cimserver_run(
         //cimserver_kill(1);
 #else
 #if defined(PEGASUS_OS_HPUX) || defined(PEGASUS_OS_LINUX) \
-        || defined(PEGASUS_PLATFORM_ZOS_ZSERIES_IBM) \
+        || defined(PEGASUS_OS_ZOS) \
         || defined(PEGASUS_OS_AIX) || defined(PEGASUS_OS_PASE) \
         || defined(PEGASUS_OS_SOLARIS) \
         || defined(PEGASUS_OS_VMS)
 
-        // Check to see if the CIM Listener is running. 
+        // Check to see if the CIM Listener is running.
         // No need to stop if not running.
         if (_serverRunStatus.isServerRunning())
         {
@@ -645,7 +636,7 @@ int CIMListenerProcess::cimserver_run(
         return(0);
     }
 
-    //get config options.  
+    //get config options.
     //note that the paths will be converted to homedPaths in the lookup calls.
     Uint32 listenerPort;
     Boolean httpsConnection;
@@ -679,12 +670,10 @@ int CIMListenerProcess::cimserver_run(
     configManager->lookupIntegerValue("traceLevel", traceLevel);
     configManager->lookupValue("traceComponents", traceComponents);
 
-    } catch (Exception& ex)
+    }
+    catch (Exception& ex)
     {
-        MessageLoaderParms parms("src.Server.cimserver.INVALID_CONFIG_OPTION",
-                                 "Invalid configuration option: $0",
-                                 ex.getMessage());
-        cout << MessageLoader::getMessage(parms) << endl;
+        cout << ex.getMessage() << endl;
         exit(0);
     }
 
@@ -717,17 +706,17 @@ int CIMListenerProcess::cimserver_run(
         Tracer::setTraceComponents(traceComponents);
         Tracer::setTraceLevel(traceLevelArg);
     }
+
 #if defined(PEGASUS_DEBUG)
-    // Put out startup up message.
-    cout << _cimListenerProcess->getProductName() << " " 
-         << _cimListenerProcess->getVersion() << endl;
-    //l10n
-    //cout << "Built " << __DATE__ << " " << __TIME__ << endl;
-    //cout <<"Starting..."
-    MessageLoaderParms parms("DynListener.cimlistener.STARTUP_MESSAGE",
+    {
+        // Put out startup up message.
+        cout << _cimListenerProcess->getProductName() << " "
+             << _cimListenerProcess->getVersion() << endl;
+        MessageLoaderParms parms("DynListener.cimlistener.STARTUP_MESSAGE",
             "CIM Listener built $0 $1\nCIM Listener starting...",
             __DATE__,
             __TIME__);
+    }
 #endif
 
 //l10n
@@ -757,21 +746,23 @@ MessageLoader::_useProcessLocale = false;
     // The run function for the dummy Thread should never be called,
     Thread *dummyInitialThread = new Thread(dummyThreadFunc, NULL, false);
     Thread::setCurrent(dummyInitialThread);
-    AcceptLanguageList default_al;
-    try{
-         default_al = LanguageParser::getDefaultAcceptLanguages();
-         Thread::setLanguages(new AcceptLanguageList(default_al));
-    }catch(InvalidAcceptLanguageHeader& e){
+    try
+    {
+         Thread::setLanguages(LanguageParser::getDefaultAcceptLanguages());
+    }
+    catch(InvalidAcceptLanguageHeader& e)
+    {
           Logger::put_l(Logger::ERROR_LOG, System::CIMLISTENER, Logger::SEVERE,
+              MessageLoaderParms(
                   "src.Server.cimserver.FAILED_TO_SET_PROCESS_LOCALE",
                   "Could not convert the system process"
-                  "locale into a valid AcceptLanguage format.");
+                  "locale into a valid AcceptLanguage format."));
           Logger::put(Logger::ERROR_LOG, System::CIMLISTENER, Logger::SEVERE,
                              e.getMessage());
     }
 
 #if defined(PEGASUS_OS_HPUX) || defined(PEGASUS_PLATFORM_LINUX_GENERIC_GNU) \
-|| defined(PEGASUS_PLATFORM_ZOS_ZSERIES_IBM) || defined(PEGASUS_OS_AIX) \
+|| defined(PEGASUS_OS_ZOS) || defined(PEGASUS_OS_AIX) \
 || defined(PEGASUS_OS_PASE) \
 || defined(PEGASUS_OS_SOLARIS) || defined (PEGASUS_OS_VMS)
     umask(S_IWGRP|S_IWOTH);
@@ -817,17 +808,18 @@ MessageLoader::_useProcessLocale = false;
 
         _cimListener->start();
 
-        Logger::put_l(Logger::STANDARD_LOG, 
-                System::CIMLISTENER, Logger::INFORMATION,
-                "src.Server.cimserver.LISTENING_ON_PORT",
-                "Listening on port $0.", listenerPort);
-
+        Logger::put_l(Logger::STANDARD_LOG,
+            System::CIMLISTENER, Logger::INFORMATION,
+            MessageLoaderParms(
+                "DynListener.cimlistener.LISTENING_ON_PORT",
+                "The CIM listener is listening on port $0.",
+                listenerPort));
 
 
 #if defined(PEGASUS_DEBUG)
         //Log startup options
         printf("Starting CIMListener with the following options\n");
-        printf("\tlistenerPort %d\n", listenerPort);
+        printf("\tlistenerPort %u\n", listenerPort);
         printf("\thttpsConnection %d\n", httpsConnection);
         printf("\tsslKeyFilePath %s\n",
                 (const char*)sslKeyFilePath.getCString());
@@ -837,10 +829,10 @@ MessageLoader::_useProcessLocale = false;
         printf("\tconsumerConfigDir %s\n",
                 (const char*)consumerConfigDir.getCString());
         printf("\tenableConsumerUnload %d\n", enableConsumerUnload);
-        printf("\tconsumerIdleTimeout %d\n", consumerIdleTimeout);
-        printf("\tshutdownTimeout %d\n", shutdownTimeout);
+        printf("\tconsumerIdleTimeout %u\n", consumerIdleTimeout);
+        printf("\tshutdownTimeout %u\n", shutdownTimeout);
         printf("\ttraceFilePath %s\n", (const char*)traceFile.getCString());
-        printf("\ttraceLevel %d\n", traceLevel);
+        printf("\ttraceLevel %u\n", traceLevel);
         printf("\ttraceComponents %s\n",
                 (const char*)traceComponents.getCString());
         printf("\tMessage home is %s\n", (const char*)msgHome.getCString());
@@ -854,7 +846,7 @@ MessageLoader::_useProcessLocale = false;
     time_t last = 0;
 
 #if defined(PEGASUS_OS_HPUX) || defined(PEGASUS_OS_LINUX) || \
-    defined(PEGASUS_PLATFORM_ZOS_ZSERIES_IBM) || defined(PEGASUS_OS_AIX) || \
+    defined(PEGASUS_OS_ZOS) || defined(PEGASUS_OS_AIX) || \
     defined(PEGASUS_OS_PASE) || \
     defined(PEGASUS_OS_SOLARIS) || defined(PEGASUS_OS_VMS)
         //
@@ -871,10 +863,11 @@ MessageLoader::_useProcessLocale = false;
         // Put server started message to the logger
         Logger::put_l(Logger::STANDARD_LOG, System::CIMLISTENER,
             Logger::INFORMATION,
-            "src.Server.cimserver.STARTED_VERSION",
-            "Started $0 version $1.",
-            _cimListenerProcess->getProductName(),
-            _cimListenerProcess->getVersion());
+            MessageLoaderParms(
+                "src.Server.cimserver.STARTED_VERSION",
+                "Started $0 version $1.",
+                _cimListenerProcess->getProductName(),
+                _cimListenerProcess->getVersion()));
 
 #if defined(PEGASUS_OS_TYPE_UNIX)
         if (daemonOption && !debugOutputOption)
@@ -924,7 +917,7 @@ MessageLoader::_useProcessLocale = false;
         {
 #if defined(PEGASUS_DEBUG)
             printf("Graceful shutdown\n");
-#endif            
+#endif
             _cimListener->stop();
         }
 #endif
@@ -954,15 +947,18 @@ MessageLoader::_useProcessLocale = false;
 
         // Put server shutdown message to the logger
         Logger::put_l(Logger::STANDARD_LOG, System::CIMLISTENER,
-            Logger::INFORMATION, "src.Server.cimserver.STOPPED",
-            "$0 stopped.", _cimListenerProcess->getProductName());
+            Logger::INFORMATION,
+            MessageLoaderParms(
+                "src.Server.cimserver.STOPPED",
+                "$0 stopped.", _cimListenerProcess->getProductName()));
     }
     catch (Exception& e)
     {
         Logger::put_l(
             Logger::STANDARD_LOG, System::CIMLISTENER, Logger::WARNING,
-            "src.Server.cimserver.ERROR",
-            "Error: $0", e.getMessage());
+            MessageLoaderParms(
+                "src.Server.cimserver.ERROR",
+                "Error: $0", e.getMessage()));
 
         MessageLoaderParms parms("DynListener.cimlistener.ERROR",
             "CIM Listener error: $0");
