@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -290,7 +288,7 @@ void CIMExportClient::exportIndication(
         request->operationContext.set
             (ContentLanguageListContainer(contentLanguages));
 
-        PEG_TRACE ((TRC_INDICATION_GENERATION, Tracer::LEVEL3,
+        PEG_TRACE ((TRC_INDICATION_GENERATION, Tracer::LEVEL4,
             "Exporting %s Indication for destination %s:%d%s",
             (const char*)(instanceName.getClassName().getString().
             getCString()),
@@ -300,7 +298,7 @@ void CIMExportClient::exportIndication(
         Message* message = _doRequest(request,
             CIM_EXPORT_INDICATION_RESPONSE_MESSAGE);
 
-        PEG_TRACE ((TRC_INDICATION_GENERATION, Tracer::LEVEL3,
+        PEG_TRACE ((TRC_INDICATION_GENERATION, Tracer::LEVEL4,
             "%s Indication for destination %s:%d%s exported successfully",
             (const char*)(instanceName.getClassName().getString().
             getCString()),
@@ -314,13 +312,14 @@ void CIMExportClient::exportIndication(
     }
     catch (const Exception& e)
     {
-        PEG_TRACE_STRING (TRC_DISCARDED_DATA, Tracer::LEVEL4,
-            "Failed to export indication: " + e.getMessage ());
+        PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL1,
+            "Failed to export indication: %s",
+            (const char*)e.getMessage().getCString()));
         throw;
     }
     catch (...)
     {
-        PEG_TRACE_CSTRING (TRC_DISCARDED_DATA, Tracer::LEVEL4,
+        PEG_TRACE_CSTRING (TRC_DISCARDED_DATA, Tracer::LEVEL1,
             "Failed to export indication");
         throw;
     }
@@ -350,14 +349,15 @@ Message* CIMExportClient::_doRequest(
         }
         catch (const Exception& e)
         {
-            PEG_TRACE_STRING(TRC_EXPORT_CLIENT, Tracer::LEVEL2,
-                "Failed to connect to indication listener: " + e.getMessage());
+            PEG_TRACE((TRC_EXPORT_CLIENT, Tracer::LEVEL1,
+                "Failed to connect to indication listener: %s",
+                (const char*)e.getMessage().getCString()));
             PEG_METHOD_EXIT();
             throw;
         }
         catch (...)
         {
-            PEG_TRACE_CSTRING(TRC_EXPORT_CLIENT, Tracer::LEVEL2,
+            PEG_TRACE_CSTRING(TRC_EXPORT_CLIENT, Tracer::LEVEL1,
                 "Failed to connect to indication listener.");
             PEG_METHOD_EXIT();
             throw;
@@ -423,7 +423,7 @@ Message* CIMExportClient::_doRequest(
                 Exception* clientException =
                     ((ClientExceptionMessage*)response.get())->clientException;
 
-                PEG_TRACE_CSTRING(TRC_EXPORT_CLIENT, Tracer::LEVEL4,
+                PEG_TRACE_CSTRING(TRC_EXPORT_CLIENT, Tracer::LEVEL2,
                     "Client Exception Message received.");
 
                 AutoPtr<Exception> d(clientException);
@@ -491,7 +491,7 @@ Message* CIMExportClient::_doRequest(
                 }
                 if (cimResponse->cimException.getCode() != CIM_ERR_SUCCESS)
                 {
-                    PEG_TRACE_CSTRING(TRC_EXPORT_CLIENT, Tracer::LEVEL4,
+                    PEG_TRACE_CSTRING(TRC_EXPORT_CLIENT, Tracer::LEVEL1,
                         "Received indication failure message.");
                     CIMException cimException(
                         cimResponse->cimException.getCode(),
@@ -528,7 +528,8 @@ Message* CIMExportClient::_doRequest(
 
                 CIMClientResponseException responseException(mlString);
 
-                PEG_TRACE_STRING(TRC_EXPORT_CLIENT, Tracer::LEVEL4, mlString);
+                PEG_TRACE((TRC_EXPORT_CLIENT, Tracer::LEVEL1,
+                           (const char*)mlString.getCString()));
 
                 PEG_METHOD_EXIT();
                 throw responseException;
@@ -542,7 +543,7 @@ Message* CIMExportClient::_doRequest(
     // Reconnect to reset the connection (disregard late response)
     //
 
-    PEG_TRACE_CSTRING(TRC_EXPORT_CLIENT, Tracer::LEVEL4,
+    PEG_TRACE_CSTRING(TRC_EXPORT_CLIENT, Tracer::LEVEL2,
         "Connection to the listener timed out.");
 
     _disconnect();
