@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
 //
-//==============================================================================
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -173,7 +171,7 @@ void CIMExportRequestDecoder::handleHTTPMessage(HTTPMessage* httpMessage)
     Boolean closeConnect = httpMessage->getCloseConnect();
     PEG_TRACE((
         TRC_HTTP,
-        Tracer::LEVEL3,
+        Tracer::LEVEL4,
         "CIMOperationRequestDecoder::handleHTTPMessage() -"
              " httpMessage->getCloseConnect() returned %d",
         httpMessage->getCloseConnect()));
@@ -241,12 +239,6 @@ void CIMExportRequestDecoder::handleHTTPMessage(HTTPMessage* httpMessage)
     //</bug>
 
     // Process M-POST and POST messages:
-    String cimContentType;
-    String cimExport;
-    String cimExportBatch;
-    Boolean cimExportBatchFlag;
-    String cimProtocolVersion;
-    String cimExportMethod;
 
     if (httpVersion == "HTTP/1.1")
     {
@@ -259,7 +251,7 @@ void CIMExportRequestDecoder::handleHTTPMessage(HTTPMessage* httpMessage)
         //
         // Note:  The Host header value is not validated.
 
-        String hostHeader;
+        const char* hostHeader;
         Boolean hostHeaderFound = HTTPMessage::lookupHeader(
             headers, "Host", hostHeader, false);
 
@@ -281,6 +273,7 @@ void CIMExportRequestDecoder::handleHTTPMessage(HTTPMessage* httpMessage)
 
     // Validate the "CIMExport" header:
 
+    const char* cimExport;
     Boolean exportHeaderFound = HTTPMessage::lookupHeader(
         headers, "CIMExport", cimExport, true);
     // If the CIMExport header was missing, the HTTPAuthenticatorDelegator
@@ -300,7 +293,7 @@ void CIMExportRequestDecoder::handleHTTPMessage(HTTPMessage* httpMessage)
     }
     // </bug>
 
-    if (!String::equalNoCase(cimExport, "MethodRequest"))
+    if (System::strcasecmp(cimExport, "MethodRequest") != 0)
     {
         // The Specification for CIM Operations over HTTP reads:
         //     3.3.5. CIMExport
@@ -321,9 +314,9 @@ void CIMExportRequestDecoder::handleHTTPMessage(HTTPMessage* httpMessage)
 
     // Validate the "CIMExportBatch" header:
 
-    cimExportBatchFlag = HTTPMessage::lookupHeader(
-        headers, "CIMExportBatch", cimExportBatch, true);
-    if (cimExportBatchFlag)
+    const char* cimExportBatch;
+    if (HTTPMessage::lookupHeader(
+            headers, "CIMExportBatch", cimExportBatch, true))
     {
         // The Specification for CIM Operations over HTTP reads:
         //     3.3.10. CIMExportBatch
@@ -342,27 +335,27 @@ void CIMExportRequestDecoder::handleHTTPMessage(HTTPMessage* httpMessage)
 
     // Save these headers for later checking
 
+    const char* cimProtocolVersion;
     if (!HTTPMessage::lookupHeader(
             headers, "CIMProtocolVersion", cimProtocolVersion, true))
     {
         // Mandated by the Specification for CIM Operations over HTTP
-        cimProtocolVersion.assign("1.0");
+        cimProtocolVersion = "1.0";
     }
 
-    if (HTTPMessage::lookupHeader(
+    const char* cimExportMethod;
+    if (!HTTPMessage::lookupHeader(
             headers, "CIMExportMethod", cimExportMethod, true))
     {
-        if (cimExportMethod == String::EMPTY)
-        {
-            // This is not a valid value, and we use EMPTY to mean "absent"
-            sendHttpError(
-                queueId,
-                HTTP_STATUS_BADREQUEST,
-                "header-mismatch",
-                String::EMPTY,
-                closeConnect);
-            return;
-        }
+        // The CIMExportMethod header is not present and we already know the
+        // Export Request Message is a Simple Export Request.
+        sendHttpError(
+            queueId,
+            HTTP_STATUS_BADREQUEST,
+            "header-mismatch",
+            String::EMPTY,
+            closeConnect);
+        return;
     }
 
     AcceptLanguageList acceptLanguages;
@@ -431,11 +424,17 @@ void CIMExportRequestDecoder::handleHTTPMessage(HTTPMessage* httpMessage)
 
     // Validate the "Content-Type" header:
 
+    const char* cimContentType;
     Boolean contentTypeHeaderFound = HTTPMessage::lookupHeader(
         headers, "Content-Type", cimContentType, true);
+    String type;
+    String charset;
 
     if (!contentTypeHeaderFound ||
-        !HTTPMessage::isSupportedContentType (cimContentType))
+        !HTTPMessage::parseContentTypeHeader(cimContentType, type, charset) ||
+        (!String::equalNoCase(type, "application/xml") &&
+         !String::equalNoCase(type, "text/xml")) ||
+        !String::equalNoCase(charset, "utf-8"))
     {
         sendHttpError(
             queueId,
@@ -487,8 +486,8 @@ void CIMExportRequestDecoder::handleMethodRequest(
     HttpMethod httpMethod,
     char* content,
     const String& requestUri,
-    const String& cimProtocolVersionInHeader,
-    const String& cimExportMethodInHeader,
+    const char* cimProtocolVersionInHeader,
+    const char* cimExportMethodInHeader,
     const String& userName,
     const String& ipAddress,
     const AcceptLanguageList& httpAcceptLanguages,
@@ -498,7 +497,7 @@ void CIMExportRequestDecoder::handleMethodRequest(
     // Set the Accept-Language into the thread for this service.
     // This will allow all code in this thread to get
     // the languages for the messages returned to the client.
-    Thread::setLanguages(new AcceptLanguageList(httpAcceptLanguages));
+    Thread::setLanguages(httpAcceptLanguages);
 
     //
     // If CIM Listener is shutting down, return error response
@@ -589,30 +588,7 @@ void CIMExportRequestDecoder::handleMethodRequest(
             return;
         }
 
-        // We accept protocol version 1.x (see Bugzilla 1556)
-
-        Boolean protocolVersionAccepted = false;
-
-        if ((protocolVersion.size() >= 3) &&
-            (protocolVersion[0] == '1') &&
-            (protocolVersion[1] == '.'))
-        {
-            // Verify that all characters after the '.' are digits
-            Uint32 index = 2;
-            while ((index < protocolVersion.size()) &&
-                   (protocolVersion[index] >= '0') &&
-                   (protocolVersion[index] <= '9'))
-            {
-                index++;
-            }
-
-            if (index == protocolVersion.size())
-            {
-                protocolVersionAccepted = true;
-            }
-        }
-
-        if (!protocolVersionAccepted)
+        if (!XmlReader::isSupportedProtocolVersion(protocolVersion))
         {
             // See Specification for CIM Operations over HTTP section 4.3
             sendHttpError(
@@ -689,7 +665,8 @@ void CIMExportRequestDecoder::handleMethodRequest(
         //     "400 Bad Request" (and MUST include a CIMError header in the
         //     response with a value of header-mismatch), subject to the
         //     considerations specified in Errors.
-        if (!String::equalNoCase(cimExportMethodName, cimExportMethodInHeader))
+        if (System::strcasecmp(
+                cimExportMethodName, cimExportMethodInHeader) != 0)
         {
             // ATTN-RK-P3-20020404: How to decode cimExportMethodInHeader?
             sendHttpError(
@@ -755,10 +732,10 @@ void CIMExportRequestDecoder::handleMethodRequest(
     }
     catch (XmlValidationError& e)
     {
-        Logger::put(Logger::ERROR_LOG, System::CIMSERVER, Logger::TRACE,
+        PEG_TRACE((TRC_XML,Tracer::LEVEL1,
             "CIMExportRequestDecoder::handleMethodRequest - "
-            "XmlValidationError exception has occurred. Message: $0",
-            e.getMessage());
+            "XmlValidationError exception has occurred. Message: %s",
+            (const char*) e.getMessage().getCString()));
 
         sendHttpError(
             queueId,
@@ -770,10 +747,10 @@ void CIMExportRequestDecoder::handleMethodRequest(
     }
     catch (XmlSemanticError& e)
     {
-        Logger::put(Logger::ERROR_LOG, System::CIMSERVER, Logger::TRACE,
+        PEG_TRACE((TRC_XML,Tracer::LEVEL1,
             "CIMExportRequestDecoder::handleMethodRequest - "
-            "XmlSemanticError exception has occurred. Message: $0",
-            e.getMessage());
+            "XmlSemanticError exception has occurred. Message: %s",
+            (const char*) e.getMessage().getCString()));
         // ATTN-RK-P2-20020404: Is this the correct response for these errors?
         sendHttpError(
             queueId,
@@ -785,9 +762,10 @@ void CIMExportRequestDecoder::handleMethodRequest(
     }
     catch (XmlException& e)
     {
-        Logger::put(Logger::ERROR_LOG, System::CIMSERVER, Logger::TRACE,
+        PEG_TRACE((TRC_XML,Tracer::LEVEL1,
             "CIMExportRequestDecoder::handleMethodRequest - "
-            "XmlException has occurred. Message: $0",e.getMessage());
+            "XmlException has occurred. Message: %s",
+            (const char*) e.getMessage().getCString()));
 
         sendHttpError(
             queueId,
