@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -85,7 +83,7 @@ void EmailListenerDestination::handleIndication(
 
     try
     {
-        PEG_TRACE ((TRC_INDICATION_GENERATION, Tracer::LEVEL3,
+        PEG_TRACE ((TRC_INDICATION_GENERATION, Tracer::LEVEL4,
             "EmailListenerDestination %s:%s.%s processing %s Indication",
            (const char*)(nameSpace.getCString()),
            (const char*)(handler.getClassName().getString().getCString()),
@@ -136,19 +134,21 @@ void EmailListenerDestination::handleIndication(
     }
     catch (CIMException& c)
     {
-        PEG_TRACE_STRING(TRC_IND_HANDLER, Tracer::LEVEL4, c.getMessage());
+        PEG_TRACE((TRC_IND_HANDLER, Tracer::LEVEL1, "CIMException: %s",
+            (const char*)c.getMessage().getCString()));
         PEG_METHOD_EXIT();
         throw PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED, c.getMessage());
     }
     catch (Exception& e)
     {
-        PEG_TRACE_STRING(TRC_IND_HANDLER, Tracer::LEVEL4, e.getMessage());
+        PEG_TRACE((TRC_IND_HANDLER, Tracer::LEVEL1, "Exception: %s",
+            (const char*)e.getMessage().getCString()));
         PEG_METHOD_EXIT();
         throw PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED, e.getMessage());
     }
     catch (...)
     {
-        PEG_TRACE_CSTRING(TRC_IND_HANDLER, Tracer::LEVEL4,
+        PEG_TRACE_CSTRING(TRC_IND_HANDLER, Tracer::LEVEL1,
             "Failed to deliver indication via e-mail.");
         PEG_METHOD_EXIT();
         throw PEGASUS_CIM_EXCEPTION_L(CIM_ERR_FAILED, MessageLoaderParms(
@@ -173,7 +173,6 @@ void EmailListenerDestination::_sendViaEmail(
     defined(PEGASUS_OS_VMS)
 
     String exceptionStr;
-    FILE* mailFilePtr;
     FILE* filePtr;
     char mailFile[TEMP_NAME_LEN];
 
@@ -181,23 +180,15 @@ void EmailListenerDestination::_sendViaEmail(
     // Check for proper execute permissions for sendmail
     if (access(SENDMAIL_CMD, X_OK) < 0)
     {
-        PEG_TRACE((TRC_IND_HANDLER, Tracer::LEVEL4,
-            "Cannot execute %s: %s.", SENDMAIL_CMD, strerror(errno)));
-
-        MessageLoaderParms parms(
-            "Handler.EmailListenerDestination.EmailListenerDestination."
-                "_MSG_EXECUTE_ACCESS_FAILED",
-            "Cannot execute $0: $1",
-            SENDMAIL_CMD,
-            strerror(errno));
-
         Logger::put_l(Logger::STANDARD_LOG, System::CIMSERVER, Logger::WARNING,
-            "Handler.EmailListenerDestination.EmailListenerDestination."
-                "_MSG_EXECUTE_ACCESS_FAILED",
-            MessageLoader::getMessage(parms));
+            MessageLoaderParms(
+                "Handler.EmailListenerDestination.EmailListenerDestination."
+                    "_MSG_EXECUTE_ACCESS_FAILED",
+                "Cannot execute $0: $1",
+                SENDMAIL_CMD,
+                strerror(errno)));
 
         PEG_METHOD_EXIT();
-
         return;
     }
 #endif
@@ -214,7 +205,7 @@ void EmailListenerDestination::_sendViaEmail(
 
         fclose(filePtr);
     }
-    catch (CIMException& c)
+    catch (CIMException&)
     {
         fclose(filePtr);
         unlink(mailFile);
@@ -232,7 +223,7 @@ void EmailListenerDestination::_sendViaEmail(
         status = mail$send_begin(&send_context, &nulllist, &nulllist);
         if (status != SS$_NORMAL)
         {
-            PEG_TRACE_CSTRING(TRC_IND_HANDLER, Tracer::LEVEL4,
+            PEG_TRACE_CSTRING(TRC_IND_HANDLER, Tracer::LEVEL1,
                 "Routine mail$send_begin failed.");
             PEG_METHOD_EXIT();
 
@@ -245,7 +236,7 @@ void EmailListenerDestination::_sendViaEmail(
         // send the message
         _sendMsg(mailFile);
     }
-    catch (CIMException& c)
+    catch (CIMException&)
     {
         unlink(mailFile);
 
@@ -259,7 +250,7 @@ void EmailListenerDestination::_sendViaEmail(
 
 #else
 
-    PEG_TRACE_CSTRING(TRC_IND_HANDLER, Tracer::LEVEL4,
+    PEG_TRACE_CSTRING(TRC_IND_HANDLER, Tracer::LEVEL1,
                          "sendmail is not supported.");
     PEG_METHOD_EXIT();
 
@@ -322,7 +313,7 @@ void EmailListenerDestination::_buildMailHeader(
         &nulllist);
     if (status != SS$_NORMAL)
     {
-        PEG_TRACE_CSTRING(TRC_IND_HANDLER, Tracer::LEVEL4,
+        PEG_TRACE_CSTRING(TRC_IND_HANDLER, Tracer::LEVEL1,
             "Routine mail$send_add_attribute failed.");
         PEG_METHOD_EXIT();
 
@@ -342,7 +333,7 @@ void EmailListenerDestination::_buildMailHeader(
     status = mail$send_add_bodypart(&send_context, bodypart_itmlst, 0);
     if (status != SS$_NORMAL)
     {
-        PEG_TRACE_CSTRING(TRC_IND_HANDLER, Tracer::LEVEL4,
+        PEG_TRACE_CSTRING(TRC_IND_HANDLER, Tracer::LEVEL1,
             "Routine mail$send_add_bodypart failed..");
         PEG_METHOD_EXIT();
 
@@ -416,7 +407,7 @@ String EmailListenerDestination::_buildMailAddrStr(
             &nulllist);
         if (status != SS$_NORMAL)
         {
-            PEG_TRACE_CSTRING(TRC_IND_HANDLER, Tracer::LEVEL4,
+            PEG_TRACE_CSTRING(TRC_IND_HANDLER, Tracer::LEVEL1,
                 "Routine mail$send_add_address failed.");
             PEG_METHOD_EXIT();
 
@@ -465,7 +456,7 @@ String EmailListenerDestination::_buildMailAddrCcStr(
             &nulllist);
         if (status != SS$_NORMAL)
         {
-            PEG_TRACE_CSTRING(TRC_IND_HANDLER, Tracer::LEVEL4,
+            PEG_TRACE_CSTRING(TRC_IND_HANDLER, Tracer::LEVEL1,
                 "Routine mail$send_add_address failed (cc).");
             PEG_METHOD_EXIT();
 
@@ -493,7 +484,7 @@ void EmailListenerDestination::_writeStrToFile(
 
     if (fprintf(filePtr, "%s\n", (const char *) mailHdrStr.getCString()) < 0)
     {
-        PEG_TRACE((TRC_IND_HANDLER, Tracer::LEVEL4,
+        PEG_TRACE((TRC_IND_HANDLER, Tracer::LEVEL1,
             "Failed to write the %s to the file: %s.",
             (const char *) mailHdrStr.getCString(),
             strerror(errno)));
@@ -528,7 +519,7 @@ void EmailListenerDestination::_sendMsg(
     // Checks the existence of the temp mail file
     if (!System::exists(mailFile))
     {
-        PEG_TRACE((TRC_IND_HANDLER, Tracer::LEVEL4,
+        PEG_TRACE((TRC_IND_HANDLER, Tracer::LEVEL1,
             "File %s does not exist: %s.",
             mailFile,
             strerror(errno)));
@@ -551,7 +542,7 @@ void EmailListenerDestination::_sendMsg(
     // problems for sendmail()
     if (stat(mailFile, &statBuf) != 0)
     {
-        PEG_TRACE((TRC_IND_HANDLER, Tracer::LEVEL4,
+        PEG_TRACE((TRC_IND_HANDLER, Tracer::LEVEL1,
             "Can not get file %s status: %s.",
             mailFile,
             strerror(errno)));
@@ -572,7 +563,7 @@ void EmailListenerDestination::_sendMsg(
 
     if (statBuf.st_size == 0)
     {
-        PEG_TRACE((TRC_IND_HANDLER, Tracer::LEVEL4,
+        PEG_TRACE((TRC_IND_HANDLER, Tracer::LEVEL1,
             "File %s does not contain any data.",
             mailFile));
 
@@ -596,7 +587,7 @@ void EmailListenerDestination::_sendMsg(
     status = mail$send_message(&send_context, nulllist, nulllist);
     if (status != SS$_NORMAL)
     {
-        PEG_TRACE_CSTRING(TRC_IND_HANDLER, Tracer::LEVEL4,
+        PEG_TRACE_CSTRING(TRC_IND_HANDLER, Tracer::LEVEL1,
             "Routine mail$send_message failed.");
         PEG_METHOD_EXIT();
 
@@ -612,7 +603,7 @@ void EmailListenerDestination::_sendMsg(
     status = mail$send_end(&send_context, nulllist, nulllist);
     if (status != SS$_NORMAL)
     {
-        PEG_TRACE_CSTRING(TRC_IND_HANDLER, Tracer::LEVEL4,
+        PEG_TRACE_CSTRING(TRC_IND_HANDLER, Tracer::LEVEL1,
             "Routine mail$send_end failed.");
         PEG_METHOD_EXIT();
 
@@ -628,7 +619,7 @@ void EmailListenerDestination::_sendMsg(
     // Open the pipe to send the message
     if ((sendmailPtr = popen(sendmailCmd, "r")) == NULL)
     {
-        PEG_TRACE_CSTRING(TRC_IND_HANDLER, Tracer::LEVEL4,
+        PEG_TRACE_CSTRING(TRC_IND_HANDLER, Tracer::LEVEL1,
             "popen of sendmail failed.");
 
         MessageLoaderParms parms(
@@ -647,7 +638,7 @@ void EmailListenerDestination::_sendMsg(
     Sint32 retCode = pclose(sendmailPtr);
     if (retCode < 0)
     {
-        PEG_TRACE_CSTRING(TRC_IND_HANDLER, Tracer::LEVEL4,
+        PEG_TRACE_CSTRING(TRC_IND_HANDLER, Tracer::LEVEL1,
             "No associated stream with this popen command.");
 
         MessageLoaderParms parms(
@@ -663,7 +654,7 @@ void EmailListenerDestination::_sendMsg(
     }
     else if (retCode == SH_EXECUTE_FAILED)
     {
-        PEG_TRACE_CSTRING(TRC_IND_HANDLER, Tracer::LEVEL4,
+        PEG_TRACE_CSTRING(TRC_IND_HANDLER, Tracer::LEVEL1,
             "/usr/bin/sh could not be executed.");
 
         MessageLoaderParms parms(
@@ -697,7 +688,7 @@ void EmailListenerDestination::_openFile(
 #endif
     if (*filePtr == NULL)
     {
-        PEG_TRACE((TRC_IND_HANDLER, Tracer::LEVEL4,
+        PEG_TRACE((TRC_IND_HANDLER, Tracer::LEVEL1,
             "fopen of %s failed: %s.", mailFile,
             strerror(errno)));
 
