@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -60,6 +58,12 @@ void snmpDeliverTrap_netsnmp::initialize()
     // Initializes the SNMP library
     init_snmp("snmpIndicationHandler");
 
+    // don't load/save persistent file
+#ifdef NETSNMP_DS_LIB_DONT_PERSIST_STATE
+    netsnmp_ds_set_boolean(NETSNMP_DS_LIBRARY_ID,
+        NETSNMP_DS_LIB_DONT_PERSIST_STATE, 1);
+#endif
+
     // windows32 specific initialization (is a NOOP on unix)
     SOCK_STARTUP;
 
@@ -72,7 +76,7 @@ void snmpDeliverTrap_netsnmp::terminate()
 
     // Shuts down the application, and appropriate clean up
     snmp_shutdown("snmpIndicationHandler");
-   
+
     SOCK_CLEANUP;
 
     PEG_METHOD_EXIT();
@@ -122,13 +126,11 @@ void snmpDeliverTrap_netsnmp::deliverTrap(
     }
     catch (Exception& e)
     {
-        PEG_TRACE_STRING(TRC_DISCARDED_DATA, Tracer::LEVEL2, e.getMessage());
-
-        Logger::put_l(Logger::STANDARD_LOG, System::CIMSERVER,
-                      Logger::WARNING,
-                      _MSG_PACK_CIM_PROPERTY_TO_PDU_FAILED_KEY,
-                      _MSG_PACK_CIM_PROPERTY_TO_PDU_FAILED,
-                      e.getMessage());
+        Logger::put_l(Logger::STANDARD_LOG, System::CIMSERVER, Logger::WARNING,
+            MessageLoaderParms(
+                _MSG_PACK_CIM_PROPERTY_TO_PDU_FAILED_KEY,
+                _MSG_PACK_CIM_PROPERTY_TO_PDU_FAILED,
+                e.getMessage()));
     }
     catch (...)
     {
@@ -152,6 +154,8 @@ void snmpDeliverTrap_netsnmp::deliverTrap(
 
         free(errStr);
 
+        snmp_free_pdu(snmpPdu);
+
         _destroySession(sessionHandle);
 
         PEG_METHOD_EXIT();
@@ -220,6 +224,8 @@ void snmpDeliverTrap_netsnmp::_createSession(
 
         free(errStr);
 
+        free(snmpSession.peername);
+
         PEG_METHOD_EXIT();
 
         throw PEGASUS_CIM_EXCEPTION_L(CIM_ERR_FAILED,
@@ -241,6 +247,8 @@ void snmpDeliverTrap_netsnmp::_createSession(
 
             free(errStr);
 
+            free(snmpSession.peername);
+
             throw PEGASUS_CIM_EXCEPTION_L(CIM_ERR_FAILED, MessageLoaderParms(
                 _MSG_GET_SESSION_POINTER_FAILED_KEY,
                 exceptionStr));
@@ -341,13 +349,12 @@ void snmpDeliverTrap_netsnmp::_createPdu(
             }
             catch (CIMException& e)
             {
-                PEG_TRACE_STRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
-                    e.getMessage());
                 Logger::put_l(
                     Logger::STANDARD_LOG, System::CIMSERVER, Logger::WARNING,
-                    _MSG_PACK_TRAP_INFO_INTO_PDU_FAILED_KEY,
-                    _MSG_PACK_TRAP_INFO_INTO_PDU_FAILED,
-                    e.getMessage());
+                    MessageLoaderParms(
+                        _MSG_PACK_TRAP_INFO_INTO_PDU_FAILED_KEY,
+                        _MSG_PACK_TRAP_INFO_INTO_PDU_FAILED,
+                        e.getMessage()));
             }
 
             break;
@@ -387,13 +394,12 @@ void snmpDeliverTrap_netsnmp::_createPdu(
             {
                 String errMsg = snmp_api_errstring(retCode);
 
-                PEG_TRACE_STRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
-                    "Failed to add sysUpTime to pdu: " + errMsg);
                 Logger::put_l(
                     Logger::STANDARD_LOG, System::CIMSERVER, Logger::WARNING,
-                    _MSG_ADD_SYSUPTIME_TO_PDU_FAILED_KEY,
-                    _MSG_ADD_SYSUPTIME_TO_PDU_FAILED,
-                    errMsg);
+                    MessageLoaderParms(
+                        _MSG_ADD_SYSUPTIME_TO_PDU_FAILED_KEY,
+                        _MSG_ADD_SYSUPTIME_TO_PDU_FAILED,
+                        errMsg));
             }
 
             // Add snmp trap to the PDU
@@ -409,13 +415,12 @@ void snmpDeliverTrap_netsnmp::_createPdu(
             {
                 String errMsg = snmp_api_errstring(retCode);
 
-                PEG_TRACE_STRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
-                    "Failed to add snmp trap to pdu: " + errMsg);
                 Logger::put_l(
                     Logger::STANDARD_LOG, System::CIMSERVER, Logger::WARNING,
-                    _MSG_ADD_SNMP_TRAP_TO_PDU_FAILED_KEY,
-                    _MSG_ADD_SNMP_TRAP_TO_PDU_FAILED,
-                    errMsg);
+                    MessageLoaderParms(
+                        _MSG_ADD_SNMP_TRAP_TO_PDU_FAILED_KEY,
+                        _MSG_ADD_SNMP_TRAP_TO_PDU_FAILED,
+                        errMsg));
             }
 
             break;
