@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -123,7 +121,7 @@ void snmpIndicationHandler::handleIndication(
 
     try
     {
-        PEG_TRACE ((TRC_INDICATION_GENERATION, Tracer::LEVEL3,
+        PEG_TRACE ((TRC_INDICATION_GENERATION, Tracer::LEVEL4,
             "snmpIndicationHandler %s:%s.%s processing %s Indication",
            (const char*)(nameSpace.getCString()),
            (const char*)(handler.getClassName().getString().getCString()),
@@ -153,10 +151,10 @@ void snmpIndicationHandler::handleIndication(
                 {
                     //
                     // We are looking for following fields:
-                    // MappingStrings {"OID.IETF | SNMP." oidStr, 
+                    // MappingStrings {"OID.IETF | SNMP." oidStr,
                     //     "DataType.IETF |" dataType}
                     // oidStr is the object identifier (e.g. "1.3.6.1.2.1.5..."
-                    // dataType is either Integer, or OctetString, 
+                    // dataType is either Integer, or OctetString,
                     // or OID
                     // Following is one example:
                     // MappingStrings {"OID.IETF | SNMP.1.3.6.6.3.1.1.5.2",
@@ -165,7 +163,7 @@ void snmpIndicationHandler::handleIndication(
 
                     propDecl.getQualifier(qualifierPos).getValue().get(
                         mapStr);
- 
+
                     String oidStr, dataType;
                     String mapStr1, mapStr2;
                     Boolean isValidAuthority = false;
@@ -174,17 +172,17 @@ void snmpIndicationHandler::handleIndication(
                     for (Uint32 j=0; j < mapStr.size(); j++)
                     {
                         Uint32 barPos = mapStr[j].find("|");
-                            
-                        if (barPos != PEG_NOT_FOUND) 
+
+                        if (barPos != PEG_NOT_FOUND)
                         {
                             mapStr1 = mapStr[j].subString(0, barPos);
                             mapStr2 = mapStr[j].subString(barPos + 1);
 
                             _trimWhitespace(mapStr1);
                             _trimWhitespace(mapStr2);
-                                
+
                             if ((mapStr1 == "OID.IETF") &&
-                                (String::compare(mapStr2, 
+                                (String::compare(mapStr2,
                                  String("SNMP."), 5) == 0))
                             {
                                 isValidAuthority = true;
@@ -196,7 +194,7 @@ void snmpIndicationHandler::handleIndication(
                                 dataType = mapStr2;
                             }
 
-                            if (isValidAuthority && isValidDataType) 
+                            if (isValidAuthority && isValidDataType)
                             {
                                 propOIDs.append(oidStr);
                                 propTYPEs.append(dataType);
@@ -227,7 +225,7 @@ void snmpIndicationHandler::handleIndication(
 
         if (targetHostPos == PEG_NOT_FOUND)
         {
-            PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL3,
+            PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL1,
                 "Target host is not set for IndicationHandlerSNMPMapper %s"
                 " Indication.",
                 (const char*)(indication.getClassName().getString().
@@ -240,7 +238,7 @@ void snmpIndicationHandler::handleIndication(
         }
         if (targetHostFormatPos == PEG_NOT_FOUND)
         {
-            PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL3,
+            PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL1,
                 "Target host format is not set for IndicationHandlerSNMPMapper"
                 " %s Indication.",
                 (const char*)(indication.getClassName().getString().
@@ -253,7 +251,7 @@ void snmpIndicationHandler::handleIndication(
         }
         if (snmpVersionPos == PEG_NOT_FOUND)
         {
-            PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL3,
+            PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL1,
                 "SNMP Version is not set for IndicationHandlerSNMPMapper %s"
                 " Indication.",
                 (const char*)(indication.getClassName().getString().
@@ -277,7 +275,6 @@ void snmpIndicationHandler::handleIndication(
 
             String trapOid;
             Boolean trapOidAvailable = false;
-            String exceptionStr;
             //
             //  Get snmpTrapOid from context
             //
@@ -305,9 +302,9 @@ void snmpIndicationHandler::handleIndication(
                     {
                         Uint32 barPos = classMapStr[i].find("|");
 
-                        if (barPos != PEG_NOT_FOUND) 
+                        if (barPos != PEG_NOT_FOUND)
                         {
-                            String authorityName = 
+                            String authorityName =
                                 classMapStr[i].subString(0, barPos);
                             String oidStr = classMapStr[i].subString(
                                 barPos+1, PEG_NOT_FOUND);
@@ -316,10 +313,10 @@ void snmpIndicationHandler::handleIndication(
                             _trimWhitespace(oidStr);
 
                             if ((authorityName == "OID.IETF") &&
-                                (String::compare(oidStr, 
+                                (String::compare(oidStr,
                                  String("SNMP."), 5) == 0))
                             {
-                                trapOid = oidStr.subString(5); 
+                                trapOid = oidStr.subString(5);
                                 trapOidAvailable = true;
                                 break;
                             }
@@ -328,26 +325,30 @@ void snmpIndicationHandler::handleIndication(
 
                     if (!trapOidAvailable)
                     {
-                        exceptionStr = "No MappingStrings for snmp trap"
-                            "is specified for class: ";
-                      
-                        exceptionStr.append(
-                            indication.getClassName().getString());
+                        PEG_TRACE((
+                            TRC_IND_HANDLER,
+                            Tracer::LEVEL1,
+                            "No MappingStrings for snmp trap is specified "
+                                "for class: %s",
+                            (const char*)
+                              indication.getClassName().getString().getCString()
+                            ));
 
-                        PEG_TRACE_STRING(TRC_IND_HANDLER, Tracer::LEVEL4,
-                            exceptionStr);
                         PEG_METHOD_EXIT();
 
-                        throw PEGASUS_CIM_EXCEPTION_L(CIM_ERR_FAILED,
+                        throw PEGASUS_CIM_EXCEPTION_L(
+                            CIM_ERR_FAILED,
                             MessageLoaderParms(
                                 "Handler.snmpIndicationHandler."
                                 "snmpIndicationHandler.NO_MS_FOR_SNMP_TRAP",
-                                exceptionStr));
+                                "No MappingStrings for snmp trap is specified "
+                                    "for class: $0",
+                                indication.getClassName().getString()));
                     }
                 }
                 else
                 {
-                    PEG_TRACE_CSTRING(TRC_IND_HANDLER, Tracer::LEVEL4,
+                    PEG_TRACE_CSTRING(TRC_IND_HANDLER, Tracer::LEVEL1,
                         "Qualifier MappingStrings can not be found.");
                     PEG_METHOD_EXIT();
                     MessageLoaderParms parms(
@@ -387,7 +388,7 @@ void snmpIndicationHandler::handleIndication(
                 handler.getProperty(engineIDPos).getValue().get(engineID);
             }
 
-            PEG_TRACE ((TRC_INDICATION_GENERATION, Tracer::LEVEL3,
+            PEG_TRACE ((TRC_INDICATION_GENERATION, Tracer::LEVEL4,
                "snmpIndicationHandler sending %s Indication trap %s to target"
                " host %s target port %d",
                (const char*)(indication.getClassName().getString().
@@ -407,7 +408,7 @@ void snmpIndicationHandler::handleIndication(
                 propTYPEs,
                 propVALUEs);
 
-        PEG_TRACE ((TRC_INDICATION_GENERATION, Tracer::LEVEL3,
+        PEG_TRACE ((TRC_INDICATION_GENERATION, Tracer::LEVEL4,
            "%s Indication trap %s sent to target host %s target port %d "
            "successfully",
            (const char*)(indication.getClassName().getString().getCString()),
@@ -417,20 +418,22 @@ void snmpIndicationHandler::handleIndication(
     }
     catch (CIMException& c)
     {
-        PEG_TRACE_STRING(TRC_IND_HANDLER, Tracer::LEVEL4, c.getMessage());
+        PEG_TRACE((TRC_IND_HANDLER, Tracer::LEVEL1, "CIMException %s",
+            (const char*)c.getMessage().getCString()));
         PEG_METHOD_EXIT();
         throw PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED, c.getMessage());
     }
     catch (Exception& e)
     {
-        PEG_TRACE_STRING(TRC_IND_HANDLER, Tracer::LEVEL4, e.getMessage());
+        PEG_TRACE((TRC_IND_HANDLER, Tracer::LEVEL1, "Exception %s",
+            (const char*)e.getMessage().getCString()));
         PEG_METHOD_EXIT();
 
         throw PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED, e.getMessage());
     }
     catch (...)
     {
-        PEG_TRACE_CSTRING(TRC_IND_HANDLER, Tracer::LEVEL4,
+        PEG_TRACE_CSTRING(TRC_IND_HANDLER, Tracer::LEVEL1,
             "Failed to deliver trap.");
         PEG_METHOD_EXIT();
 
