@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -51,7 +49,7 @@ const String INDICATION_CLASS_NAME = "Test_IndicationProviderClass";
 const String SNMPV1_HANDLER_NAME = "SNMPHandler01";
 const String SNMPV2C_HANDLER_NAME = "SNMPHandler02";
 const String SNMPV2C_IPV6_HANDLER_NAME = "SNMPHandler03";
-const String FILTER_NAME = "IPFilter01";
+const String FILTER_NAME = "SNMPIPFilter01";
 
 enum SNMPVersion {_SNMPV1_TRAP = 2, _SNMPV2C_TRAP = 3};
 enum TargetHostFormat {_HOST_NAME = 2, _IPV4_ADDRESS = 3, _IPV6_ADDRESS = 4};
@@ -69,7 +67,7 @@ AtomicInt errorsEncountered(0);
 class T_Parms
 {
 public:
-    AutoPtr<CIMClient> client;
+    CIMClient* client;
     Uint32 indicationSendCount;
     Uint32 uniqueID;
 };
@@ -403,7 +401,7 @@ void _setup (CIMClient & client, const String& qlang)
             "public",
             _IPV6_ADDRESS,
             _SNMPV2C_TRAP);
-    } 
+    }
     catch (CIMException& e)
     {
         if (e.getCode() == CIM_ERR_ALREADY_EXISTS)
@@ -474,7 +472,7 @@ void _cleanup (CIMClient & client)
     }
 
 #if defined(PEGASUS_ENABLE_IPV6)
-    try     
+    try
     {
         _deleteSubscriptionInstance (client, FILTER_NAME,
             SNMPV2C_IPV6_HANDLER_NAME);
@@ -552,13 +550,13 @@ static void _testEnd(const String& uniqueID, const double elapsedTime)
 ThreadReturnType PEGASUS_THREAD_CDECL _executeTests(void *parm)
 {
     Thread *my_thread = (Thread *)parm;
-    T_Parms *parms = (T_Parms *)my_thread->get_parm();
-    CIMClient *client = parms->client.get();
+    AutoPtr<T_Parms> parms((T_Parms *)my_thread->get_parm());
+    CIMClient* client = parms->client;
     Uint32 indicationSendCount = parms->indicationSendCount;
     Uint32 id = parms->uniqueID;
     char id_[4];
     memset(id_,0x00,sizeof(id_));
-    sprintf(id_,"%i",id);
+    sprintf(id_,"%u",id);
     String uniqueID = "_";
     uniqueID.append(id_);
 
@@ -585,8 +583,8 @@ ThreadReturnType PEGASUS_THREAD_CDECL _executeTests(void *parm)
     {
         cout << e.getMessage() << endl;
     }
-    my_thread->exit_self((ThreadReturnType)1);
-    return(0);
+
+    return ThreadReturnType(0);
 }
 
 Thread * _runTestThreads(
@@ -596,7 +594,7 @@ Thread * _runTestThreads(
 {
     // package parameters, create thread and run...
     AutoPtr<T_Parms> parms(new T_Parms());
-    parms->client.reset(client);
+    parms->client = client;
     parms->indicationSendCount = indicationSendCount;
     parms->uniqueID = uniqueID;
     AutoPtr<Thread> t(new Thread(_executeTests, (void*)parms.release(), false));
@@ -604,12 +602,7 @@ Thread * _runTestThreads(
     return t.release();
 }
 
-String _getLogFile()
-{
-    return("trapLogFile");
-}
-
-Uint32 _getReceivedTrapCount(Uint16 snmpVersion)
+Uint32 _getReceivedTrapCount(Uint16 snmpVersion, const String& logFile)
 {
     String trap1 = "Trap Info: TRAP, SNMP v1, community public";
     String trap2 = "Trap Info: TRAP2, SNMP v2c, community public";
@@ -617,7 +610,7 @@ Uint32 _getReceivedTrapCount(Uint16 snmpVersion)
     Uint32 receivedTrap1Count = 0;
     Uint32 receivedTrap2Count = 0;
 
-    ifstream ifs(_getLogFile().getCString());
+    ifstream ifs(logFile.getCString());
     if (!ifs)
     {
         return (0);
@@ -660,13 +653,11 @@ Uint32 _getReceivedTrapCount(Uint16 snmpVersion)
 // Stop snmptrapd process if it is running and remove
 // procIdFile file if it exists
 //
-void _stopSnmptrapd()
+void _stopSnmptrapd(const String& processIdFile)
 {
-    String procIdFileName = "procIdFile";
-
     Uint32 receiverPid;
     FILE *fd;
-    if ((fd = fopen(procIdFileName.getCString(), "r")) != NULL)
+    if ((fd = fopen(processIdFile.getCString(), "r")) != NULL)
     {
         if (fscanf(fd, "%d\n", &receiverPid) != 1)
         {
@@ -678,14 +669,16 @@ void _stopSnmptrapd()
         fclose(fd);
     }
 
-    if (FileSystem::exists(procIdFileName))
+    if (FileSystem::exists(processIdFile))
     {
-        FileSystem::removeFile(procIdFileName);
+        FileSystem::removeFile(processIdFile);
     }
 }
 
 static Boolean _startSnmptrapd(
-    FILE **trapInfo)
+    FILE **trapInfo,
+    const String& processIdFile,
+    const String& logFile)
 {
     String snmptrapdCmd;
 
@@ -700,7 +693,10 @@ static Boolean _startSnmptrapd(
     // Specify logging incoming traps to trapLogFile
     // Save the process ID of the snmptrapd in procIdFile
     snmptrapdCmd.append(
-        "/usr/sbin/snmptrapd -f -Lf trapLogFile -p procIdFile");
+        "/usr/sbin/snmptrapd -f -Lf ");
+    snmptrapdCmd.append(logFile);
+    snmptrapdCmd.append(" -p ");
+    snmptrapdCmd.append(processIdFile);
 
     // Specify incoming trap format
     snmptrapdCmd.append( " -F \"\nTrap Info: %P\nVariable: %v\n\"");
@@ -732,7 +728,7 @@ static Boolean _startSnmptrapd(
     while (iterations < MAX_ITERATIONS)
     {
         iterations++;
-        if (FileSystem::exists("procIdFile"))
+        if (FileSystem::exists(processIdFile))
         {
             return (true);
         }
@@ -747,10 +743,8 @@ static Boolean _startSnmptrapd(
 }
 #endif
 
-void _removeTrapLogFile ()
+void _removeTrapLogFile(const String& logFile)
 {
-    String logFile = _getLogFile();
-
     // if trapLogFile exists, remove it
     if (FileSystem::exists(logFile))
     {
@@ -761,7 +755,8 @@ void _removeTrapLogFile ()
 void _receiveExpectedTraps(
     CIMClient& workClient,
     Uint32 indicationSendCount,
-    Uint32 runClientThreadCount)
+    Uint32 runClientThreadCount,
+    const String& logFile)
 {
     Uint32 indicationTrapV1SendCount = 0;
     Uint32 indicationTrapV2SendCount = 0;
@@ -774,7 +769,7 @@ void _receiveExpectedTraps(
 
     // if IPV6 is enabled, an additional SNMPv2c trap is sent to IPV6 address
 #if defined(PEGASUS_ENABLE_IPV6)
-    indicationTrapV2SendCount = 2 * indicationTrapV1SendCount; 
+    indicationTrapV2SendCount = 2 * indicationTrapV1SendCount;
 #else
     indicationTrapV2SendCount = indicationTrapV1SendCount;
 #endif
@@ -811,6 +806,7 @@ void _receiveExpectedTraps(
     for(Uint32 i=0; i< runClientThreadCount; i++)
     {
         clientThreads[i]->join();
+        delete clientThreads[i];
     }
 
     delete[] clientConnections;
@@ -854,8 +850,10 @@ void _receiveExpectedTraps(
     {
         totalIterations++;
 
-        currentReceivedTrap1Count = _getReceivedTrapCount(_SNMPV1_TRAP);
-        currentReceivedTrap2Count = _getReceivedTrapCount(_SNMPV2C_TRAP);
+        currentReceivedTrap1Count =
+            _getReceivedTrapCount(_SNMPV1_TRAP, logFile);
+        currentReceivedTrap2Count =
+            _getReceivedTrapCount(_SNMPV2C_TRAP, logFile);
 
         if (totalIterations % COUT_TIME_INTERVAL == 1 &&
             !(receivedTrapCountComplete))
@@ -927,22 +925,24 @@ void _receiveExpectedTraps(
 
 int _beginTest(CIMClient& workClient,
     Uint32 indicationSendCount,
-    Uint32 runClientThreadCount)
+    Uint32 runClientThreadCount,
+    const String& processIdFile,
+    const String& logFile)
 {
 
 #ifdef PEGASUS_USE_NET_SNMP
 
     // Stop snmptrapd process if it is running
-    _stopSnmptrapd();
+    _stopSnmptrapd(processIdFile);
 
     // if trapLogFile exists, remove it
-    _removeTrapLogFile();
+    _removeTrapLogFile(logFile);
 
     FILE * trapInfo;
 
     try
     {
-        _startSnmptrapd(&trapInfo);
+        _startSnmptrapd(&trapInfo, processIdFile, logFile);
     }
     catch (Exception & e)
     {
@@ -952,10 +952,10 @@ int _beginTest(CIMClient& workClient,
 
     // Extended for all snmp implementation
     _receiveExpectedTraps(workClient, indicationSendCount,
-        runClientThreadCount);
+        runClientThreadCount, logFile);
 
     // Stop snmptrapd process if it is running and remove procIdFile
-    _stopSnmptrapd();
+    _stopSnmptrapd(processIdFile);
 
     pclose(trapInfo);
 
@@ -986,6 +986,12 @@ int main (int argc, char** argv)
     {
         workClient.connectLocal();
 
+        String processIdFile = TRAP_DIR;
+        processIdFile.append("/procIdFile");
+
+        String logFile = TRAP_DIR;
+        logFile.append("/trapLogFile");
+
         if (argc <= 1 || argc > 4)
         {
             cerr << "Invalid argument count: " << argc << endl;
@@ -1033,7 +1039,7 @@ int main (int argc, char** argv)
             }
 
             int rc = _beginTest(workClient, indicationSendCount,
-                runClientThreadCount);
+                runClientThreadCount, processIdFile, logFile);
             return rc;
         }
         else if (String::equalNoCase(argv[1], "cleanup"))
@@ -1059,7 +1065,7 @@ int main (int argc, char** argv)
                 return -1;
             }
 
-            _removeTrapLogFile ();
+            _removeTrapLogFile(logFile);
             cout << "+++++ removelog completed successfully" << endl;
             return 0;
         }
