@@ -1,41 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
 //
-// Author: Nitin Upasani, Hewlett-Packard Company (Nitin_Upasani@hp.com)
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 //
-// Modified By:  Carol Ann Krug Graves, Hewlett-Packard Company
-//                   (carolann_graves@hp.com)
-//               Ben Heilbronn, Hewlett-Packard Company (ben_heilbronn@hp.com)
-//               Roger Kumpf, Hewlett-Packard Company (roger_kumpf@hp.com)
-//               Yi Zhou, Hewlett-Packard Company (yi.zhou@hp.com)
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -47,14 +37,21 @@
 #include <Pegasus/Common/CIMMessage.h>
 #include <Pegasus/Common/AcceptLanguageList.h>
 #include <Pegasus/Common/ContentLanguageList.h>
-// NOCHKSRC
-#include <Pegasus/Server/ProviderRegistrationManager/ProviderRegistrationManager.h>
-// DOCHKSRC
+#include <Pegasus/Server/ProviderRegistrationManager/\
+ProviderRegistrationManager.h>
 #include <Pegasus/Server/Linkage.h>
 #include <Pegasus/Query/QueryExpression/QueryExpression.h>
 
-#include "ProviderClassList.h"
-#include "IndicationOperationAggregate.h"
+#include <Pegasus/IndicationService/ProviderClassList.h>
+#include <Pegasus/IndicationService/IndicationOperationAggregate.h>
+
+#ifdef PEGASUS_ENABLE_INDICATION_COUNT
+# include <Pegasus/IndicationService/ProviderIndicationCountTable.h>
+#endif
+
+#ifdef PEGASUS_ENABLE_DMTF_INDICATION_PROFILE_SUPPORT
+# include <Pegasus/IndicationService/IndicationServiceConfiguration.h>
+#endif
 
 PEGASUS_NAMESPACE_BEGIN
 
@@ -124,7 +121,7 @@ private:
 
     void _handleDeleteInstanceRequest(const Message * message);
 
-    void _handleProcessIndicationRequest(const Message* message);
+    void _handleProcessIndicationRequest(Message* message);
 
     /**
         Asynchronous callback function for _handleProcessIndicationRequest.
@@ -214,7 +211,9 @@ private:
         @param   instance              instance to be validated
         @param   propertyName          name of property to be validated
         @param   expectedType          expected CIMType of property value
-        @param   message               message to be used in exception
+        @param   isKeyProperty         indicates whether the property is a key
+                                       property (used for selection of error
+                                       message)
         @param   isArray               indicates whether the validated
                                        property is array
 
@@ -225,8 +224,8 @@ private:
         CIMInstance& instance,
         const CIMName& propertyName,
         const CIMType expectedType,
-        const String& message,
-        const Boolean isArray = false);
+        Boolean isKeyProperty,
+        Boolean isArray = false);
 
     /**
         Validates the specified Uint16 (non-array) property and its
@@ -1160,10 +1159,122 @@ private:
      */
     String _getSubscriptionLogString(CIMInstance& subscription);
 
+    /**
+        Retrieves list of enabled subscription instances based on the class
+        name and namespace of the generated indication. If the subscription
+        matches the class name and namespace of the generated indication
+        and the provider who generated this indication accepted this
+        subscription, the subscription is added to the initial subscriptions
+        list.
+        If the indication provider included subscriptions in the
+        SubscriptionInstanceNamesContainer, the subset of subscriptions
+        specified by the indication provider that also appear in the initial
+        subscriptions list is returned.
+        Any subscription included by the provider but not containing in the
+        initial subscriptions list is ignored.
+
+        @param   providedSubscriptionNames   Subscriptions specified by the
+                                             indication provider
+        @param   className                   The generated indication class
+                                             name
+        @param   nameSpace                   The generated indication namespace
+        @param   indicationProvider          The provider which generated
+                                             the indication
+        @param   subscriptions               Output Array of subscription
+                                             instances
+        @param   subscriptionKeys            Output Array of keys associated
+                                             with the subscriptions
+    */
+    void _getRelevantSubscriptions(
+        const Array<CIMObjectPath> & providedSubscriptionNames,
+        const CIMName& className,
+        const CIMNamespaceName& nameSpace,
+        const CIMInstance& indicationProvider,
+        Array<CIMInstance>& subscriptions,
+        Array<String>& subscriptionKeys);
+
+    /**
+        Evaluate if the specified subscription matches the indication based on:
+        1) Whether the properties (in WHERE clause) from filter query are
+           supported by the indication provider;
+        2) Whether the subscripton is expired;
+        3) Whether the filter criteria are met by the generated indication
+
+        @param   subscription              The subscription to be evaluated
+        @param   indication                The generated indication
+        @param   supportedPropertyList     The properties are supported by the
+                                           indication provider
+        @param   queryExpr                 The query expression of the evaluated
+                                           subscription which is used for
+                                           indication evaluation
+        @param   sourceNameSpace           The source namespace of the filter
+                                           instance
+
+        @return  True, if the subscription is met all above conditions;
+                 False otherwise
+    */
+    Boolean _subscriptionMatch(
+        const CIMInstance& subscription,
+        const CIMInstance& indication,
+        const CIMPropertyList& supportedPropertyList,
+        QueryExpression& queryExpr,
+        const CIMNamespaceName sourceNameSpace);
+
+    /**
+        Format the generated indication based on:
+        1) Use QueryExpression::applyProjection to remove properties not
+           listed in the SELECT clause;
+        2) Remove any properties that may be left on the indication
+           that are not in the indication class. These are properties
+           added by the provider incorrectly.
+
+        @param   formattedindication          The generated indication to
+                                              be formatted
+        @param   queryExpr,                   The query expression of the
+                                              matched subscription needs to be
+                                              used for indication projection
+        @param   ProviderSupportedProperties  The properties are supported by
+                                              the indication provider
+        @param   indicationClassProperties    The indication class properties
+
+        @return  True, if the indication is formatted;
+                 False otherwise
+    */
+    Boolean _formatIndication(
+        CIMInstance& formattedIndication,
+        QueryExpression& queryExpr,
+        const Array<CIMName>& providerSupportedProperties,
+        const Array<CIMName>& indicationClassProperties);
+
+    /**
+        Forward the formatted indication to the handler
+
+        @param   matchedSubscription    The matched subscription
+        @param   handlerInstance        The handler instance for the matched
+                                        subscription
+        @param   formattedIndication    The formatted indication
+        @param   namespaceName          The generated indication namespace
+        @param   operationContext       The operation context
+    */
+    void _forwardIndToHandler(
+        const CIMInstance& matchedSubscription,
+        const CIMInstance& handlerInstance,
+        const CIMInstance& formattedIndication,
+        const CIMNamespaceName& namespaceName,
+        const OperationContext& operationContext);
+
     SubscriptionRepository* _subscriptionRepository;
 
     SubscriptionTable * _subscriptionTable;
 
+#ifdef PEGASUS_ENABLE_INDICATION_COUNT
+    ProviderIndicationCountTable _providerIndicationCountTable;
+#endif
+
+#ifdef PEGASUS_ENABLE_DMTF_INDICATION_PROFILE_SUPPORT
+    IndicationServiceConfiguration *_indicationServiceConfiguration;
+#endif
+
     /**
         Handle to Provider Registration Manager
      */
