@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
 //
-//==============================================================================
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -38,7 +36,6 @@
 
 #include "IndicationConstants.h"
 #include "SubscriptionRepository.h"
-#include "IndicationMessageConstants.h"
 
 PEGASUS_USING_STD;
 
@@ -48,7 +45,7 @@ PEGASUS_NAMESPACE_BEGIN
 
 /**
    Handler and Filter cache
-    
+
    Note that a single cache can be used for handler and filter instances,
    since the string representation of the object path is used as the key
    and this is unique anyway.
@@ -56,7 +53,7 @@ PEGASUS_NAMESPACE_BEGIN
 #define PEGASUS_INDICATION_HANDLER_FILTER_CACHE_SIZE 50
 
 
-static ObjectCache<CIMInstance> 
+static ObjectCache<CIMInstance>
     _handlerFilterCache(PEGASUS_INDICATION_HANDLER_FILTER_CACHE_SIZE);
 static Mutex _handlerFilterCacheMutex;
 
@@ -85,8 +82,12 @@ void SubscriptionRepository::beginCreateSubscription(
                 subPath.toString());
         }
         throw PEGASUS_CIM_EXCEPTION_L(CIM_ERR_FAILED,
-                  MessageLoaderParms(_MSG_DUPLICATE_SUBSCRIPTION_REQUEST_KEY,
-                      _MSG_DUPLICATE_SUBSCRIPTION_REQUEST, subPath.toString()));
+            MessageLoaderParms(
+                "IndicationService.IndicationService."
+                    "_MSG_DUPLICATE_SUBSCRIPTION_REQUEST",
+                "Similar create subscription request is being processed. "
+                    "Subscription path : $0",
+                subPath.toString()));
     }
     _normalizedSubscriptionTable->add(subPath, false);
 }
@@ -426,8 +427,7 @@ Boolean SubscriptionRepository::getState (
             (stateIndex).getValue ();
         if (stateValue.isNull ())
         {
-            PEG_TRACE_CSTRING (TRC_INDICATION_SERVICE_INTERNAL,
-                Tracer::LEVEL2,
+            PEG_TRACE_CSTRING (TRC_INDICATION_SERVICE,Tracer::LEVEL1,
                 "Null SubscriptionState property value");
 
             //
@@ -438,16 +438,10 @@ Boolean SubscriptionRepository::getState (
         else if ((stateValue.getType () != CIMTYPE_UINT16) ||
             (stateValue.isArray ()))
         {
-            String traceString;
-            if (stateValue.isArray ())
-            {
-                traceString.append ("array of ");
-            }
-            traceString.append (cimTypeToString (stateValue.getType ()));
-            PEG_TRACE_STRING (TRC_INDICATION_SERVICE_INTERNAL,
-               Tracer::LEVEL2,
-               "SubscriptionState property value of incorrect type: "
-               + traceString);
+            PEG_TRACE((TRC_INDICATION_SERVICE,Tracer::LEVEL1,
+                "SubscriptionState property value of incorrect type:%s %s",
+                (stateValue.isArray()) ? " array of" : " ",
+                cimTypeToString(stateValue.getType())));
 
             //
             //  This is a corrupted/invalid instance
@@ -461,8 +455,7 @@ Boolean SubscriptionRepository::getState (
     }
     else
     {
-        PEG_TRACE_CSTRING (TRC_INDICATION_SERVICE_INTERNAL,
-            Tracer::LEVEL2,
+        PEG_TRACE_CSTRING(TRC_INDICATION_SERVICE,Tracer::LEVEL1,
             "Missing SubscriptionState property");
 
         //
@@ -495,10 +488,10 @@ CIMInstance SubscriptionRepository::deleteSubscription (
     }
     catch (Exception & exception)
     {
-        PEG_TRACE_STRING (TRC_INDICATION_SERVICE_INTERNAL, Tracer::LEVEL2,
-            "Exception caught in retrieving subscription (" +
-            subscriptionInstance.getPath ().toString () + "): " +
-            exception.getMessage ());
+        PEG_TRACE((TRC_INDICATION_SERVICE, Tracer::LEVEL1,
+            "Exception caught in retrieving subscription (%s): %s",
+            (const char*)subscriptionInstance.getPath().toString().getCString(),
+            (const char*)exception.getMessage().getCString()));
 
         //
         //  If the subscription could not be retrieved, it may already have
@@ -517,10 +510,10 @@ CIMInstance SubscriptionRepository::deleteSubscription (
     }
     catch (Exception & exception)
     {
-        PEG_TRACE_STRING (TRC_INDICATION_SERVICE_INTERNAL, Tracer::LEVEL2,
-            "Exception caught in deleting subscription (" +
-            subscriptionInstance.getPath ().toString () + "): " +
-            exception.getMessage ());
+        PEG_TRACE((TRC_INDICATION_SERVICE, Tracer::LEVEL1,
+            "Exception caught in deleting subscription (%s): %s",
+            (const char*)subscriptionInstance.getPath().toString().getCString(),
+            (const char*)exception.getMessage().getCString()));
 
         //
         //  If the subscription could not be deleted, it may already have
@@ -620,11 +613,13 @@ Array <CIMInstance> SubscriptionRepository::deleteReferencingSubscriptions (
                     //
                     //  Deletion of referencing subscription failed
                     //
-                    PEG_TRACE_STRING (TRC_INDICATION_SERVICE_INTERNAL,
-                        Tracer::LEVEL2,
-                        "Exception caught deleting referencing subscription (" +
-                        subscriptions [i].getPath ().toString () + "): " +
-                        exception.getMessage ());
+                    PEG_TRACE((TRC_INDICATION_SERVICE, Tracer::LEVEL1,
+                        "Exception caught deleting referencing "
+                        "subscription (%s): %s",
+                        (const char*)subscriptions [i].getPath().toString()
+                               .getCString(),
+                        (const char*)exception.getMessage().getCString()));
+
                 }
 
                 deletedSubscriptions.append (subscriptions [i]);
@@ -683,10 +678,10 @@ CIMInstance SubscriptionRepository::getHandler (
         }
         catch (const Exception & exception)
         {
-            PEG_TRACE_STRING (TRC_DISCARDED_DATA, Tracer::LEVEL2,
-                "Exception caught trying to get Handler instance (" +
-                handlerRef.toString () + "): " +
-                exception.getMessage ());
+            PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL1,
+                "Exception caught trying to get Handler instance (%s): %s",
+                (const char*)handlerRef.toString().getCString(),
+                (const char*)exception.getMessage().getCString()));
             PEG_METHOD_EXIT ();
             throw;
         }
@@ -791,10 +786,10 @@ void SubscriptionRepository::getFilterProperties (
         }
         catch (const Exception & exception)
         {
-            PEG_TRACE_STRING (TRC_DISCARDED_DATA, Tracer::LEVEL2,
-                "Exception caught trying to get Filter instance (" +
-                filterReference.toString () + "): " +
-                exception.getMessage ());
+            PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL1,
+                "Exception caught trying to get Filter instance (%s): %s",
+                (const char*)filterReference.toString().getCString(),
+                (const char*)exception.getMessage().getCString()));
             PEG_METHOD_EXIT ();
             throw;
         }
@@ -856,10 +851,10 @@ void SubscriptionRepository::getFilterProperties (
     }
     catch (const Exception & exception)
     {
-        PEG_TRACE_STRING (TRC_INDICATION_SERVICE_INTERNAL, Tracer::LEVEL2,
-            "Exception caught in getting filter instance (" +
-            filterReference.toString () + "): " +
-            exception.getMessage ());
+        PEG_TRACE((TRC_INDICATION_SERVICE, Tracer::LEVEL1,
+            "Exception caught in getting filter instance (%s): %s",
+            (const char*)filterReference.toString().getCString(),
+            (const char*)exception.getMessage().getCString()));
         PEG_METHOD_EXIT ();
         throw;
     }
@@ -907,10 +902,10 @@ void SubscriptionRepository::getFilterProperties (
     }
     catch (const Exception & exception)
     {
-        PEG_TRACE_STRING (TRC_INDICATION_SERVICE_INTERNAL, Tracer::LEVEL2,
-            "Exception caught in getting filter instance (" +
-            filterReference.toString () + "): " +
-            exception.getMessage ());
+        PEG_TRACE((TRC_INDICATION_SERVICE, Tracer::LEVEL1,
+            "Exception caught in getting filter instance (%s): %s",
+            (const char*)filterReference.toString().getCString(),
+            (const char*)exception.getMessage().getCString()));
         PEG_METHOD_EXIT ();
         throw;
     }
@@ -942,10 +937,10 @@ Boolean SubscriptionRepository::validateIndicationClassName (
     }
     catch (const Exception & exception)
     {
-        PEG_TRACE_STRING (TRC_DISCARDED_DATA, Tracer::LEVEL2,
-            "Exception caught trying to get indication class (" +
-            indicationClassName.getString () + "): " +
-            exception.getMessage ());
+        PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL1,
+            "Exception caught trying to get indication class (%s): %s",
+            (const char*)indicationClassName.getString().getCString(),
+            (const char*)exception.getMessage().getCString()));
         PEG_METHOD_EXIT ();
         throw;
     }
@@ -1003,7 +998,7 @@ Boolean SubscriptionRepository::reconcileFatalError (
         (_PROPERTY_ONFATALERRORPOLICY)).getValue ();
     errorPolicyValue.get (onFatalErrorPolicy);
 
-    if (errorPolicyValue == _ERRORPOLICY_DISABLE)
+    if (onFatalErrorPolicy == _ERRORPOLICY_DISABLE)
     {
         //
         //  FUTURE: Failure Trigger Time Interval should be allowed to pass
@@ -1014,7 +1009,7 @@ Boolean SubscriptionRepository::reconcileFatalError (
         _disableSubscription (subscription);
         removeOrDisable = true;
     }
-    else if (errorPolicyValue == _ERRORPOLICY_REMOVE)
+    else if (onFatalErrorPolicy == _ERRORPOLICY_REMOVE)
     {
         //
         //  FUTURE: Failure Trigger Time Interval should be allowed to pass
@@ -1045,10 +1040,10 @@ CIMClass SubscriptionRepository::getClass (
     }
     catch (const Exception & exception)
     {
-        PEG_TRACE_STRING (TRC_DISCARDED_DATA, Tracer::LEVEL2,
-            "Exception caught trying to get class (" +
-            className.getString () + "): " +
-            exception.getMessage ());
+        PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL1,
+            "Exception caught trying to get class (%s) %s",
+            (const char*)className.getString().getCString(),
+            (const char*)exception.getMessage().getCString()));
         throw;
     }
 }
@@ -1116,7 +1111,7 @@ void SubscriptionRepository::deleteInstance (
             PEGASUS_CLASSNAME_FORMATTEDINDSUBSCRIPTION))
     {
         _repository->deleteInstance (nameSpace, instanceName);
-        
+
         CIMObjectPath tmpPath = instanceName;
         tmpPath.setNameSpace(nameSpace);
         _normalizedSubscriptionTable->remove(tmpPath);
@@ -1206,7 +1201,7 @@ void SubscriptionRepository::_disableSubscription (
     //
     CIMProperty state = instance.getProperty (instance.findProperty
         (PEGASUS_PROPERTYNAME_SUBSCRIPTION_STATE));
-    state.setValue (CIMValue (STATE_DISABLED));
+    state.setValue(CIMValue(Uint16(STATE_DISABLED)));
 
     //
     //  Modify the instance in the repository
@@ -1219,9 +1214,9 @@ void SubscriptionRepository::_disableSubscription (
     }
     catch (Exception & exception)
     {
-        PEG_TRACE_STRING (TRC_INDICATION_SERVICE_INTERNAL, Tracer::LEVEL2,
-           "Exception caught in attempting to disable a subscription: " +
-            exception.getMessage ());
+        PEG_TRACE((TRC_INDICATION_SERVICE, Tracer::LEVEL1,
+           "Exception caught in attempting to disable a subscription: %s",
+            (const char*)exception.getMessage().getCString()));
     }
 
     PEG_METHOD_EXIT ();
@@ -1244,9 +1239,9 @@ void SubscriptionRepository::_deleteSubscription (
     }
     catch (Exception & exception)
     {
-        PEG_TRACE_STRING (TRC_INDICATION_SERVICE_INTERNAL, Tracer::LEVEL2,
-           "Exception caught in attempting to delete a subscription: " +
-            exception.getMessage ());
+        PEG_TRACE((TRC_INDICATION_SERVICE, Tracer::LEVEL1,
+           "Exception caught in attempting to delete a subscription: %s",
+           (const char*)exception.getMessage().getCString()));
     }
 
     PEG_METHOD_EXIT ();
