@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
 //
-//==============================================================================
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 // Author: Carol Ann Krug Graves, Hewlett-Packard Company
 //             (carolann_graves@hp.com)
@@ -358,6 +356,72 @@ public:
      */
     void clear ();
 
+    /**
+        Retrieves list of enabled subscription instances in the specified
+        namespace, where the subscription indication class matches or is a
+        superclass of the supported class. A subscription is only included
+        in the list returned if the specified provider accepted the
+        subscription.
+
+        @param   supportedClass      The supported class
+        @param   nameSpace           The specified namespace
+        @param   provider            The provider instance which accepts
+                                     subscriptions
+        @param   subscriptions       Output Array of subscription instances
+        @param   subscriptionKeys    Output Array of associated subscription
+                                     keys
+     */
+    void getMatchingClassNamespaceSubscriptions(
+        const CIMName & supportedClass,
+        const CIMNamespaceName&  nameSpace,
+        const CIMInstance & provider,
+        Array<CIMInstance>& matchingSubscriptions,
+        Array<String>& matchingSubscriptionKeys);
+
+#ifdef PEGASUS_ENABLE_INDICATION_COUNT
+    /**
+        Updates entries in the Active Subscriptions table to increase
+        matched indication counts for a specified provider which serves the
+        subscriptions.
+
+        @param provider A PG_Provider instance representing the provider that
+            serves the subscriptions.
+        @param subscriptionsKeys The keys of matched subscriptions which
+            are served by the provider.
+     */
+    void updateMatchedIndicationCounts(
+        const CIMInstance& providerInstance,
+        const Array<String>& subscriptionsKeys);
+
+    /**
+        Enumerates PG_SubscriptionIndicationData instances using the data
+        stored in the Active Subscriptions table.
+
+        @return All the PG_SubscriptionIndicationData instances.
+    */
+    Array<CIMInstance> enumerateSubscriptionIndicationDataInstances();
+
+    /**
+        Enumerates PG_SubscriptionIndicationData instance names using the data
+        stored in the Active Subscriptions table.
+
+        @return All the PG_SubscriptionIndicationData instanceName.
+    */
+    Array<CIMObjectPath> enumerateSubscriptionIndicationDataInstanceNames();
+
+    /**
+        Gets the PG_SubscriptionIndicationData instance for the specified CIM
+        object path.
+
+        @param instanceName CIMObjectpath specifies a CIM instance to be
+            returned
+        @return The specified PG_SubscriptionIndicationData instance.
+                If the specified instance does not exist, throw a
+                CIMObjectNotFoundException
+    */
+    CIMInstance getSubscriptionIndicationDataInstance(
+        const CIMObjectPath& instanceName);
+#endif
 
 private:
 
@@ -476,6 +540,181 @@ private:
         const CIMInstance & subscription,
         const Array <ProviderClassList> & updatedProviderList);
 
+#ifdef PEGASUS_ENABLE_INDICATION_COUNT
+    /**
+        Returns all the Active Subscriptions table entries.
+
+        @return An Array containing the complete list of
+            ActiveSubscriptionsTable entries.
+     */
+    Array<ActiveSubscriptionsTableEntry> _getAllActiveSubscriptionEntries();
+
+    /**
+        Gets filter name and handler name from the specified subscription.
+        The format of filter name is namespace:filtername where the
+        namespace is the namespace of filter instance created, and
+        the filtername is the value of property Name in the filter instance.
+        The format of handler name is namespace:classname.handlername where
+        namespace is the namespace of handler instance created, the classname
+        is the class of the handler instance, and handlername is the value
+        of property Name in the handler instance.
+
+        @param   subscription   Input subscription instance used to get
+                                filterName and handlerName
+        @param   filterName     Output string containing the colon-separated
+                                the namespace of filter instance created and
+                                the value of property Name in the filter
+                                instance
+        @param   handlerName    Output string containing the colon-separated
+                                the namespace of handler instance created and
+                                the class of the handler instance with the
+                                dot-connected the value of property Name in
+                                the Handler instance
+     */
+    void _getFilterAndHandlerNames(
+        const CIMInstance& subscription,
+        String& filterName,
+        String& handlerName);
+
+    /**
+        Gets handler name, filter name, source namespace, provider module name,
+        and provider name from a specified PG_SubscriptionIndicationData
+        instanceName
+
+        @param instanceName Input subscription indication data instance
+            object path used to get filterName, handlerName, sourceNamespace,
+            providerModuleName, and providerName.
+        @param filterName  Output string containing the colon-separated
+            the namespace of filter instance created and the value of property
+            Name in the filter instance.
+        @param handlerName  Output string containing the colon-separated the
+            the namespace of handler instance created and the class of the
+            handler instance with the dot-connected the value of property Name
+            in the handler instance.
+        @param sourceNS Output string containing source namespace of the
+            subscription.
+        @param providerModuleName Output string containing the provider module
+            name.
+        @param providerName Output string containing the provider name.
+     */
+    void _getSubscriptionIndicationDataKeys(
+        const CIMObjectPath& instanceName,
+        String& filterName,
+        String& handlerName,
+        String& sourceNS,
+        String& providerModuleName,
+        String& providerName);
+
+    /**
+        Builds the filter object path by using the specified filterName.
+
+        @param filterName Input string containing the colon-separated
+            the namespace of filter instance created and the value of property
+            Name in the filter instance.
+        @return The created filter object path.
+     */
+    CIMObjectPath _buildFilterPath(const String& filterName);
+
+    /**
+        Builds the handler object path by using the specified handlerName.
+
+        @param handlerName Input string containing the colon-separated the
+            namespace of handler instance created and the class of the handler
+            instance with the dot-connected the value of property Name in
+            the handler instance
+        @return The created handler object path.
+     */
+    CIMObjectPath _buildHandlerPath(const String& handlerName);
+
+    /**
+        Builds the subscription object path by using the specified filterName,
+            handlerName, and sourceNS.
+
+        @param filterName Input string containing the colon-separated
+            the namespace of filter instance created and the value of property
+            Name in the filter instance.
+        @param handlerName Input string containing the colon-separated the
+            namespace of handler instance created and the class of the handler
+            instance with the dot-connected the value of property Name in
+            the handler instance.
+        @param sourceNS Input string containing source namespace of the
+            subscription.
+        @return The created subscription object path.
+     */
+    CIMObjectPath _buildSubscriptionPath(
+        const String& filterName,
+        const String& handlerName,
+        const String& sourceNS);
+
+    /**
+        Creates the subscription indication data instance by using the
+            specified filterName, handlerName, sourceNS, providerModuleName,
+            providerName, and  matchedIndicationCount.
+
+        @param filterName Input string containing the colon-separated
+            the namespace of filter instance created and the value of property
+            Name in the filter instance.
+        @param handlerName Input string containing the colon-separated the
+            namespace of handler instance created and the class of the handler
+            instance with the dot-connected the value of property Name in
+            the handler instance.
+        @param sourceNS Input string containing source namespace of the
+            subscription.
+        @param providerModuleName The provider module name used to build the
+            instance.
+        @param providerName The provider name used to build the instance.
+        @param matchedIndicationCount The matched indication count used to
+            build the instance.
+        @return The created subscription indication data instance.
+     */
+    CIMInstance _buildSubscriptionIndDataInstance(
+        const String& filterName,
+        const String& handlerName,
+        const String& sourceNS,
+        const String& providerModuleName,
+        const String& providerName,
+        Uint32 matchedIndicationCount);
+
+    /**
+        Builds the subscription indication data instance object path by using
+            specified filterName, handlerName, sourceNS, providerModuleName,
+            and providerName.
+
+        @param filterName Input string containing the colon-separated
+            the namespace of filter instance created and the value of property
+            Name in the filter instance.
+        @param handlerName Input string containing the colon-separated the
+            namespace of handler instance created and the class of the handler
+            instance with the dot-connected the value of property Name in
+            the handler instance.
+        @param sourceNS Input string containing source namespace of the
+            subscription.
+            the specified parameters.
+        @param providerModuleName The provider module name used to build the
+            instance path.
+        @param providerName The provider name used to build the instance path.
+        @return The created subscription indication data instance object path.
+     */
+    CIMObjectPath _buildSubscriptionIndDataInstanceName(
+        const String& filterName,
+        const String& handlerName,
+        const String& sourceNS,
+        const String& providerModuleName,
+        const String& providerName);
+
+    /**
+        Builds the PG_Provider instance object path by using specified
+            providerModuleName and providerName.
+        @param providerModuleName The provider module name used to build the
+            instance path.
+        @param providerName The provider name used to build the instance path.
+        @return The created PG_Provider instance object path.
+     */
+    CIMObjectPath _buildProviderPath(
+        const String& providerModuleName,
+        const String& providerName);
+#endif
+
     /**
         Active Subscriptions information table.  Access to this table is
         controlled by the _activeSubscriptionsTableLock.
