@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -360,7 +358,7 @@ void _createDuplicate(CIMClient &client,
     {
         if (e.getCode() != CIM_ERR_ALREADY_EXISTS)
         {
-            PEGASUS_TEST_ASSERT(0); 
+            PEGASUS_TEST_ASSERT(0);
         }
         exceptionCaught =  true;
     }
@@ -392,12 +390,12 @@ void _testDuplicate(CIMClient &client)
     CIMObjectPath filterPath;
     CIMObjectPath handlerPath;
     CIMObjectPath subscriptionPath;
-   
+
     try
     {
         handlerPath = CreateHandler1Instance(client,
             PEGASUS_NAMESPACENAME_INTEROP);
-        filterPath = CreateFilterInstance(client, 
+        filterPath = CreateFilterInstance(client,
             QUERY1, "WQL", "Filter1",
             PEGASUS_NAMESPACENAME_INTEROP);
         subscriptionPath = CreateSbscriptionInstance(client, handlerPath,
@@ -410,7 +408,7 @@ void _testDuplicate(CIMClient &client)
             PEGASUS_NAMESPACENAME_INTEROP, filterPath,
             String::EMPTY,PEGASUS_NAMESPACENAME_INTEROP, handlerPath);
 
-        _createDuplicate(client, "127.0.0.1", 
+        _createDuplicate(client, "127.0.0.1",
             PEGASUS_NAMESPACENAME_INTEROP, filterPath,
             String::EMPTY, CIMNamespaceName(), handlerPath);
 
@@ -431,7 +429,7 @@ void _testDuplicate(CIMClient &client)
         PEGASUS_STD(cerr) << "Exception: " << e.getMessage()
                           << PEGASUS_STD (endl);
         PEGASUS_TEST_ASSERT(0);
-    }        
+    }
 }
 
 ThreadReturnType PEGASUS_THREAD_CDECL createSubscriptionFunc(void *parm)
@@ -457,8 +455,7 @@ ThreadReturnType PEGASUS_THREAD_CDECL createSubscriptionFunc(void *parm)
         cout << e.getMessage() << endl;
     }
 
-    my_handle->exit_self((ThreadReturnType) 1);
-    return 0;
+    return ThreadReturnType(0);
 }
 
 //
@@ -506,7 +503,7 @@ void _testConcurrent(CIMClient &client)
       PEGASUS_STD(cerr) << "Exception: " << e.getMessage()
                         << PEGASUS_STD (endl);
       PEGASUS_TEST_ASSERT(0);
-   } 
+   }
 }
 
 int main(int argc, char** argv)
@@ -545,18 +542,18 @@ int main(int argc, char** argv)
     rc = _test(client, wql, query1, query2wql);
     if (rc != 0)
       return rc;
-    PEGASUS_STD (cout) << "+++++ start dupliacte subscription test" 
+    PEGASUS_STD (cout) << "+++++ start dupliacte subscription test"
                        << PEGASUS_STD (endl);
     _testDuplicate(client);
     PEGASUS_STD (cout) << "+++++ duplicate subscription test completed"
                        << PEGASUS_STD (endl);
 
-    PEGASUS_STD (cout) << "+++++ start concurrent subscription test" 
+    PEGASUS_STD (cout) << "+++++ start concurrent subscription test"
                        << PEGASUS_STD (endl);
     _testConcurrent(client);
     PEGASUS_STD (cout) << "+++++ concurrent subscription test completed"
                        << PEGASUS_STD (endl);
-#ifndef PEGASUS_DISABLE_CQL
+#ifdef PEGASUS_ENABLE_CQL
     PEGASUS_STD (cout) << "+++++ start cql test" << PEGASUS_STD (endl);
     return _test(client, cql, query1, query2cql);
 #else
