@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//=============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%////////////////////////////////////////////////////////////////////////////
 
@@ -84,7 +82,7 @@ CMPIStatus CmpiBaseMI::driveBaseCleanup(
         CmpiBaseMI* cmi = reinterpret_cast<CmpiBaseMI*>(mi->hdl);
         if (cmi->isUnloadable())
         {
-            if (cmi->getProviderBase() && 
+            if (cmi->getProviderBase() &&
                 cmi->getProviderBase()->decUseCount()==0)
             {
                 cmi->getProviderBase()->setBaseMI(0);
@@ -251,7 +249,7 @@ CMPIStatus CmpiInstanceMI::driveSetInstance(
     const CMPIContext* eCtx,
     const CMPIResult* eRslt,
     const CMPIObjectPath* eCop,
-    const CMPIInstance* eInst, 
+    const CMPIInstance* eInst,
     const char* *properties)
 {
     try
@@ -781,23 +779,20 @@ CmpiIndicationMI::CmpiIndicationMI(
 CMPIStatus CmpiIndicationMI::driveAuthorizeFilter(
     CMPIIndicationMI* mi,
     const CMPIContext* eCtx,
-    const CMPIResult* eRslt,
     const CMPISelectExp* eSe,
     const char* ns,
-    const CMPIObjectPath* eCop, 
+    const CMPIObjectPath* eCop,
     const char* user)
 {
     try
     {
         const CmpiContext ctx((CMPIContext*)eCtx);
-        CmpiResult rslt((CMPIResult*)eRslt);
         const CmpiObjectPath cop((CMPIObjectPath*)eCop);
         const CmpiSelectExp se(eSe);
         CmpiBaseMI* cmi = reinterpret_cast<CmpiBaseMI*> (mi->hdl);
         CmpiIndicationMI* nmi = dynamic_cast<CmpiIndicationMI*>(cmi);
         return nmi->authorizeFilter(
             ctx,
-            rslt,
             se,
             ns,
             cop,
@@ -815,7 +810,6 @@ CMPIStatus CmpiIndicationMI::driveAuthorizeFilter(
 CMPIStatus CmpiIndicationMI::driveMustPoll(
     CMPIIndicationMI* mi,
     const CMPIContext* eCtx,
-    const CMPIResult* eRslt,
     const CMPISelectExp* eSe,
     const char* ns,
     const CMPIObjectPath* eCop)
@@ -823,14 +817,12 @@ CMPIStatus CmpiIndicationMI::driveMustPoll(
     try
     {
         const CmpiContext ctx((CMPIContext*)eCtx);
-        CmpiResult rslt((CMPIResult*)eRslt);
         const CmpiObjectPath cop((CMPIObjectPath*)eCop);
         const CmpiSelectExp se(eSe);
         CmpiBaseMI* cmi = reinterpret_cast<CmpiBaseMI*> (mi->hdl);
         CmpiIndicationMI* nmi = dynamic_cast<CmpiIndicationMI*>(cmi);
         return nmi->mustPoll(
             ctx,
-            rslt,
             se,
             ns,
             cop).status();
@@ -847,25 +839,22 @@ CMPIStatus CmpiIndicationMI::driveMustPoll(
 CMPIStatus CmpiIndicationMI::driveActivateFilter(
     CMPIIndicationMI* mi,
     const CMPIContext* eCtx,
-    const CMPIResult* eRslt,
     const CMPISelectExp* eSe,
-    const char* ns,
-    const CMPIObjectPath* eCop, 
+    const char* clsName,
+    const CMPIObjectPath* eCop,
     CMPIBoolean first)
 {
     try
     {
         const CmpiContext ctx((CMPIContext*)eCtx);
-        CmpiResult rslt((CMPIResult*)eRslt);
         const CmpiObjectPath cop((CMPIObjectPath*)eCop);
         const CmpiSelectExp se(eSe);
         CmpiBaseMI* cmi = reinterpret_cast<CmpiBaseMI*> (mi->hdl);
         CmpiIndicationMI* nmi = dynamic_cast<CmpiIndicationMI*>(cmi);
         return nmi->activateFilter(
             ctx,
-            rslt,
             se,
-            ns,
+            clsName,
             cop,
             first).status();
     }
@@ -881,25 +870,22 @@ CMPIStatus CmpiIndicationMI::driveActivateFilter(
 CMPIStatus CmpiIndicationMI::driveDeActivateFilter(
     CMPIIndicationMI* mi,
     const CMPIContext* eCtx,
-    const CMPIResult* eRslt,
     const CMPISelectExp* eSe,
-    const char* ns,
-    const CMPIObjectPath* eCop, 
+    const char* clsName,
+    const CMPIObjectPath* eCop,
     CMPIBoolean last)
 {
     try
     {
         const CmpiContext ctx((CMPIContext*)eCtx);
-        CmpiResult rslt((CMPIResult*)eRslt);
         const CmpiObjectPath cop((CMPIObjectPath*)eCop);
         const CmpiSelectExp se(eSe);
         CmpiBaseMI* cmi = reinterpret_cast<CmpiBaseMI*> (mi->hdl);
         CmpiIndicationMI* nmi = dynamic_cast<CmpiIndicationMI*>(cmi);
         return nmi->deActivateFilter(
             ctx,
-            rslt,
             se,
-            ns,
+            clsName,
             cop,
             last).status();
     }
@@ -912,37 +898,43 @@ CMPIStatus CmpiIndicationMI::driveDeActivateFilter(
     }
 }
 
-void CmpiIndicationMI::driveEnableIndications(
-    CMPIIndicationMI* mi)
+CMPIStatus CmpiIndicationMI::driveEnableIndications(
+    CMPIIndicationMI* mi,
+    const CMPIContext* eCtx)
 {
     try
     {
+        const CmpiContext ctx((CMPIContext*)eCtx);
         CmpiBaseMI* cmi = reinterpret_cast<CmpiBaseMI*> (mi->hdl);
         CmpiIndicationMI* nmi = dynamic_cast<CmpiIndicationMI*>(cmi);
-        nmi->enableIndications();
+        return nmi->enableIndications(ctx).status();
     }
     catch (const CmpiStatus& stat)
     {
 #ifdef PEGASUS_DEBUG
         cerr << "caught status :" << stat.rc() << " "  << stat.msg() << endl;
 #endif
+        return stat.status();
     }
 }
 
-void CmpiIndicationMI::driveDisableIndications(
-    CMPIIndicationMI* mi)
+CMPIStatus CmpiIndicationMI::driveDisableIndications(
+    CMPIIndicationMI* mi,
+    const CMPIContext* eCtx)
 {
     try
     {
+        const CmpiContext ctx((CMPIContext*)eCtx);
         CmpiBaseMI* cmi = reinterpret_cast<CmpiBaseMI*> (mi->hdl);
         CmpiIndicationMI* nmi = dynamic_cast<CmpiIndicationMI*>(cmi);
-        nmi->disableIndications();
+        return nmi->disableIndications(ctx).status();
     }
     catch (const CmpiStatus& stat)
     {
 #ifdef PEGASUS_DEBUG
         cerr << "caught status :" << stat.rc() << " "  << stat.msg() << endl;
 #endif
+        return stat.status();
     }
 }
 
@@ -955,7 +947,6 @@ void CmpiIndicationMI::driveDisableIndications(
 
 CmpiStatus CmpiIndicationMI::authorizeFilter(
     const CmpiContext& ctx,
-    CmpiResult& rslt,
     const CmpiSelectExp& se,
     const char* ns,
     const CmpiObjectPath& op,
@@ -966,7 +957,6 @@ CmpiStatus CmpiIndicationMI::authorizeFilter(
 
 CmpiStatus CmpiIndicationMI::mustPoll(
     const CmpiContext& ctx,
-    CmpiResult& rslt,
     const CmpiSelectExp& se,
     const char* ns,
     const CmpiObjectPath& op)
@@ -976,7 +966,6 @@ CmpiStatus CmpiIndicationMI::mustPoll(
 
 CmpiStatus CmpiIndicationMI::activateFilter(
     const CmpiContext& ctx,
-    CmpiResult& rslt,
     const CmpiSelectExp& se,
     const char* ns,
     const CmpiObjectPath& op,
@@ -987,7 +976,6 @@ CmpiStatus CmpiIndicationMI::activateFilter(
 
 CmpiStatus CmpiIndicationMI::deActivateFilter(
     const CmpiContext& ctx,
-    CmpiResult& rslt,
     const CmpiSelectExp& se,
     const char* ns,
     const CmpiObjectPath& op,
@@ -996,15 +984,18 @@ CmpiStatus CmpiIndicationMI::deActivateFilter(
     return CmpiStatus(CMPI_RC_ERR_NOT_SUPPORTED);
 }
 
-void CmpiIndicationMI::enableIndications()
+CmpiStatus CmpiIndicationMI::enableIndications
+      (const CmpiContext& ctx)
 {
+  return CmpiStatus(CMPI_RC_ERR_NOT_SUPPORTED);
 }
 
-void CmpiIndicationMI::disableIndications()
+CmpiStatus CmpiIndicationMI::disableIndications
+      (const CmpiContext& ctx)
 {
+  return CmpiStatus(CMPI_RC_ERR_NOT_SUPPORTED);
 }
 
-
 //---------------------------------------------------
 //--
 //  CmpiArray member functions
@@ -1483,7 +1474,7 @@ CmpiData::operator CmpiDateTime() const
     {
         return CmpiDateTime(_data.value.dateTime);
     }
-        
+
 }
 
 CmpiData::operator CMPISint8() const
@@ -1496,7 +1487,7 @@ CmpiData::operator CMPISint8() const
     {
         return _data.value.sint8;
     }
-        
+
 }
 CmpiData::operator CMPISint16() const
 {
@@ -2108,7 +2099,7 @@ CmpiData CmpiInstance::getProperty(const char* name) const
     CmpiData d;
     CMPIStatus rc={CMPI_RC_OK,NULL};
     d._data=getEnc()->ft->getProperty(getEnc(),name,&rc);
-    if ((rc.rc != CMPI_RC_OK) && (rc.rc != CMPI_RC_ERR_NOT_FOUND))
+    if ((rc.rc != CMPI_RC_OK) && (rc.rc != CMPI_RC_ERR_NO_SUCH_PROPERTY))
     {
         if (rc.msg)
         {
@@ -2230,7 +2221,7 @@ CMPIrc CmpiStatus::rc() const
 
 const char*  CmpiStatus::msg() const
 {
-    return st.msg ? CMGetCharPtr(st.msg) : 0;
+    return st.msg ? CMGetCharsPtr(st.msg,NULL) : 0;
 }
 
 CmpiStatus::CmpiStatus()
@@ -2316,7 +2307,7 @@ void *CmpiObjectPath::makeObjectPath(
     const char *cls)
 {
     CMPIStatus rc={CMPI_RC_OK,NULL};
-    void *op=mb->eft->newObjectPath(mb,CMGetCharPtr(ns.getEnc()),cls,&rc);
+    void *op=mb->eft->newObjectPath(mb,CMGetCharsPtr(ns.getEnc(),NULL),cls,&rc);
     if (rc.rc != CMPI_RC_OK)
     {
         throw CmpiStatus(rc);
@@ -2430,7 +2421,7 @@ CmpiData CmpiObjectPath::getKey(const int pos, CmpiString *name) const
     {
         throw CmpiStatus(rc);
     }
-    if (name) 
+    if (name)
     {
         *name=CmpiString(s);
     }
@@ -2579,7 +2570,7 @@ CmpiEnumeration CmpiBroker::enumInstanceNames(
     const CmpiObjectPath& cop)
 {
     CMPIStatus rc={CMPI_RC_OK,NULL};
-    CMPIEnumeration* en=getEnc()->bft->enumInstanceNames(
+    CMPIEnumeration* en=getEnc()->bft->enumerateInstanceNames(
         getEnc(),
         ctx.getEnc(),
         cop.getEnc(),
@@ -2689,7 +2680,7 @@ CmpiEnumeration CmpiBroker::enumInstances(
     const char** properties)
 {
     CMPIStatus rc={CMPI_RC_OK,NULL};
-    CMPIEnumeration* en=getEnc()->bft->enumInstances(
+    CMPIEnumeration* en=getEnc()->bft->enumerateInstances(
         getEnc(),
         ctx.getEnc(),
         cop.getEnc(),
@@ -3130,7 +3121,7 @@ CmpiSelectExp::CmpiSelectExp()
 //--
 //---------------------------------------------------
 
-/** 
+/**
    Constructor from CMPI type.
 */
 CmpiDateTime::CmpiDateTime(const CMPIDateTime* newEnc)
