@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -57,23 +55,19 @@ public:
     {
         try
         {
-             // assume default client timeout
-             _lock.timed_lock(PEGASUS_DEFAULT_CLIENT_TIMEOUT_MILLISECONDS);
-        }
-        catch (WaitFailed &)
-        {
-            PEG_TRACE_CSTRING(TRC_CIMOM_HANDLE, Tracer::LEVEL2,
-                "WaitFailed Exception waiting for CIMOMHandle,"
-                    " throwing CIMException");
- 
-            throw CIMException(CIM_ERR_ACCESS_DENIED, MessageLoaderParms(
-                "Provider.CIMOMHandle.CIMOMHANDLE_TIMEOUT",
-                "Timeout waiting for CIMOMHandle"));
+            // assume default client timeout
+            if (!_lock.timed_lock(PEGASUS_DEFAULT_CLIENT_TIMEOUT_MILLISECONDS))
+            {
+                throw CIMException(CIM_ERR_ACCESS_DENIED, MessageLoaderParms(
+                    "Provider.CIMOMHandle.CIMOMHANDLE_TIMEOUT",
+                    "Timeout waiting for CIMOMHandle"));
+            }
         }
         catch (Exception& e)
         {
-            PEG_TRACE_STRING(TRC_CIMOM_HANDLE, Tracer::LEVEL2,
-                String("Unexpected Exception: ") + e.getMessage());
+            PEG_TRACE((TRC_CIMOM_HANDLE, Tracer::LEVEL2,
+                "Unexpected Exception: %s",
+                (const char*)e.getMessage().getCString()));
             throw;
         }
         catch (...)
@@ -93,8 +87,9 @@ public:
         }
         catch (Exception& e)
         {
-            PEG_TRACE_STRING(TRC_CIMOM_HANDLE, Tracer::LEVEL2,
-                String("Ignoring Exception: ") + e.getMessage());
+            PEG_TRACE((TRC_CIMOM_HANDLE, Tracer::LEVEL2,
+                "Ignoring Exception: %s",
+                (const char*)e.getMessage().getCString()));
         }
         catch (...)
         {
@@ -134,13 +129,13 @@ public:
         //
         if (client == 0)
         {
-            PEG_TRACE_CSTRING(TRC_CIMOM_HANDLE, Tracer::LEVEL2,
+            PEG_TRACE_CSTRING(TRC_CIMOM_HANDLE, Tracer::LEVEL3,
                 "Creating CIMClient connection");
             client = new CIMClient();
 
             //
             // If connection fails, we need to make sure that subsequent
-            // calls will try to connect again. 
+            // calls will try to connect again.
             //
             try
             {
@@ -218,7 +213,7 @@ public:
                  if (curThrd != NULL)
                  {
                      // deletes the old tsd and creates a new one
-                     curThrd->put_tsd("cimomHandleContentLanguages",
+                     curThrd->put_tsd(TSD_CIMOM_HANDLE_CONTENT_LANGUAGES,
                          deleteContentLanguage,
                          sizeof(ContentLanguageList*),
                          new ContentLanguageList(
@@ -235,12 +230,13 @@ public:
         }
         catch (Exception& e)
         {
-            PEG_TRACE_STRING(TRC_CIMOM_HANDLE, Tracer::LEVEL2,
-                String("Ignoring Exception: ") + e.getMessage());
+            PEG_TRACE((TRC_CIMOM_HANDLE, Tracer::LEVEL1,
+                "Ignoring Exception: %s",
+                (const char*)e.getMessage().getCString()));
         }
         catch (...)
         {
-            PEG_TRACE_CSTRING(TRC_CIMOM_HANDLE, Tracer::LEVEL2,
+            PEG_TRACE_CSTRING(TRC_CIMOM_HANDLE, Tracer::LEVEL1,
                 "Ignoring unknown exception");
         }
     }
@@ -734,9 +730,9 @@ OperationContext ClientCIMOMHandleRep::getResponseContext()
     else
     {
         ContentLanguageList* contentLangs = (ContentLanguageList*)
-            curThrd->reference_tsd("cimomHandleContentLanguages");
+            curThrd->reference_tsd(TSD_CIMOM_HANDLE_CONTENT_LANGUAGES);
         curThrd->dereference_tsd();
- 
+
         if (contentLangs == NULL)
         {
             ctx.insert(ContentLanguageListContainer(ContentLanguageList()));
@@ -745,7 +741,7 @@ OperationContext ClientCIMOMHandleRep::getResponseContext()
         {
             ctx.insert(ContentLanguageListContainer(*contentLangs));
             // delete the old tsd to free the memory
-            curThrd->delete_tsd("cimomHandleContentLanguages");
+            curThrd->delete_tsd(TSD_CIMOM_HANDLE_CONTENT_LANGUAGES);
         }
     }
 
