@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -49,10 +47,11 @@ InternalCIMOMHandleMessageQueue::InternalCIMOMHandleMessageQueue()
     : MessageQueue(PEGASUS_QUEUENAME_INTERNALCLIENT),
     _output_qid(0),
     _return_qid(0),
+    _responseReady(0),
     _response(0)
 {
-    // output queue is the binary message handler
-    MessageQueue* out = MessageQueue::lookup(PEGASUS_QUEUENAME_BINARY_HANDLER);
+    // output queue is the request dispatcher
+    MessageQueue* out = MessageQueue::lookup(PEGASUS_QUEUENAME_OPREQDISPATCHER);
 
     PEGASUS_ASSERT(out != 0);
 
@@ -64,14 +63,6 @@ InternalCIMOMHandleMessageQueue::InternalCIMOMHandleMessageQueue()
 
 InternalCIMOMHandleMessageQueue::~InternalCIMOMHandleMessageQueue()
 {
-    try
-    {
-        // ATTN: release any unprocessed responses
-        _response.clear();
-    }
-    catch (...)
-    {
-    }
 }
 
 void InternalCIMOMHandleMessageQueue::handleEnqueue()
@@ -128,8 +119,8 @@ void InternalCIMOMHandleMessageQueue::handleEnqueue()
     case CIM_GET_PROPERTY_RESPONSE_MESSAGE:
     case CIM_SET_PROPERTY_RESPONSE_MESSAGE:
     case CIM_INVOKE_METHOD_RESPONSE_MESSAGE:
-        _response.enqueue(message);
-
+        _response = message;
+        _responseReady.signal();
         break;
     default:
         PEG_TRACE_CSTRING(
@@ -155,7 +146,6 @@ CIMResponseMessage* InternalCIMOMHandleMessageQueue::sendRequest(
     // update message to include routing information
     request->dest = _output_qid;
     request->queueIds.push(_return_qid);
-    request->queueIds.push(_output_qid);
 
     // locate destination
     MessageQueueService* service =
@@ -165,15 +155,12 @@ CIMResponseMessage* InternalCIMOMHandleMessageQueue::sendRequest(
     PEGASUS_ASSERT(service != 0);
 
     // forward request
-    if (service->SendForget(request) == false)
-    {
-        PEG_METHOD_EXIT();
-        throw Exception("Failed to send message");
-    }
+    service->enqueue(request);
 
     // wait for response
-    CIMResponseMessage* response =
-        dynamic_cast<CIMResponseMessage *>(_response.dequeue_wait());
+    _responseReady.wait();
+    CIMResponseMessage* response = dynamic_cast<CIMResponseMessage*>(_response);
+    _response = 0;
 
     PEG_METHOD_EXIT();
     return response;
@@ -252,7 +239,6 @@ CIMResponseMessage* InternalCIMOMHandleRep::do_request(
     CIMRequestMessage* request)
 {
     PEG_METHOD_ENTER(TRC_CIMOM_HANDLE, "InternalCIMOMHandleRep::do_request");
-
     /*
     Uint32 timeout = 0;
 
@@ -273,20 +259,24 @@ CIMResponseMessage* InternalCIMOMHandleRep::do_request(
     {
         if (timeout)
         {
-            _msg_avail.time_wait(timeout);
+            if (!_msg_avail.time_wait(timeout))
+            {
+                PEG_TRACE_CSTRING(TRC_CIMOM_HANDLE, Tracer::LEVEL2,
+                    "timeout waiting for response");
+                throw PEGASUS_CIM_EXCEPTION_L(CIM_ERR_FAILED,
+                    MessageLoaderParms(
+                        "Provider.CIMOMHandle.EMPTY_CIM_RESPONSE",
+                        "Empty CIM Response"));
+            }
         }
         else
         {
             _msg_avail.wait();
         }
     }
-    catch (TimeOut&)
+    catch (CIMException&)
     {
-        PEG_TRACE_CSTRING(TRC_CIMOM_HANDLE, Tracer::LEVEL2,
-                        "timeout waiting for response");
-        throw PEGASUS_CIM_EXCEPTION_L(CIM_ERR_FAILED, MessageLoaderParms(
-            "Provider.CIMOMHandle.EMPTY_CIM_RESPONSE",
-            "Empty CIM Response"));
+        throw;
     }
     catch (...)
     {
@@ -337,7 +327,7 @@ CIMResponseMessage* InternalCIMOMHandleRep::do_request(
             {
                 // deletes the old tsd and creates a new one
                 currentThread->put_tsd(
-                    "cimomHandleContentLanguages",
+                    TSD_CIMOM_HANDLE_CONTENT_LANGUAGES,
                     _deleteContentLanguage,
                     sizeof(ContentLanguageList*),
                     new ContentLanguageList(container.getLanguages()));
@@ -392,7 +382,7 @@ CIMClass InternalCIMOMHandleRep::getClass(
         {
             PEG_TRACE_CSTRING(
                 TRC_CIMOM_HANDLE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Incorrect response type in CIMOMHandle");
 
             throw CIMException(CIM_ERR_FAILED);
@@ -407,7 +397,7 @@ CIMClass InternalCIMOMHandleRep::getClass(
     {
         PEG_TRACE_CSTRING(
             TRC_CIMOM_HANDLE,
-            Tracer::LEVEL2,
+            Tracer::LEVEL1,
             "Exception caught in CIMOMHandle");
 
         PEG_METHOD_EXIT();
@@ -460,7 +450,7 @@ Array<CIMClass> InternalCIMOMHandleRep::enumerateClasses(
         {
             PEG_TRACE_CSTRING(
                 TRC_CIMOM_HANDLE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Incorrect response type in CIMOMHandle");
 
             throw CIMException(CIM_ERR_FAILED);
@@ -475,7 +465,7 @@ Array<CIMClass> InternalCIMOMHandleRep::enumerateClasses(
     {
         PEG_TRACE_CSTRING(
             TRC_CIMOM_HANDLE,
-            Tracer::LEVEL2,
+            Tracer::LEVEL1,
             "Exception caught in CIMOMHandle");
 
         PEG_METHOD_EXIT();
@@ -524,7 +514,7 @@ Array<CIMName> InternalCIMOMHandleRep::enumerateClassNames(
         {
             PEG_TRACE_CSTRING(
                 TRC_CIMOM_HANDLE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Incorrect response type in CIMOMHandle");
 
             throw CIMException(CIM_ERR_FAILED);
@@ -539,7 +529,7 @@ Array<CIMName> InternalCIMOMHandleRep::enumerateClassNames(
     {
         PEG_TRACE_CSTRING(
             TRC_CIMOM_HANDLE,
-            Tracer::LEVEL2,
+            Tracer::LEVEL1,
             "Exception caught in CIMOMHandle");
 
         PEG_METHOD_EXIT();
@@ -585,7 +575,7 @@ void InternalCIMOMHandleRep::createClass(
         {
             PEG_TRACE_CSTRING(
                 TRC_CIMOM_HANDLE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Incorrect response type in CIMOMHandle");
 
             throw CIMException(CIM_ERR_FAILED);
@@ -600,7 +590,7 @@ void InternalCIMOMHandleRep::createClass(
     {
         PEG_TRACE_CSTRING(
             TRC_CIMOM_HANDLE,
-            Tracer::LEVEL2,
+            Tracer::LEVEL1,
             "Exception caught in CIMOMHandle");
 
         PEG_METHOD_EXIT();
@@ -644,7 +634,7 @@ void InternalCIMOMHandleRep::modifyClass(
         {
             PEG_TRACE_CSTRING(
                 TRC_CIMOM_HANDLE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Incorrect response type in CIMOMHandle");
 
             throw CIMException(CIM_ERR_FAILED);
@@ -659,7 +649,7 @@ void InternalCIMOMHandleRep::modifyClass(
     {
         PEG_TRACE_CSTRING(
             TRC_CIMOM_HANDLE,
-            Tracer::LEVEL2,
+            Tracer::LEVEL1,
             "Exception caught in CIMOMHandle");
 
         PEG_METHOD_EXIT();
@@ -704,7 +694,7 @@ void InternalCIMOMHandleRep::deleteClass(
         {
             PEG_TRACE_CSTRING(
                 TRC_CIMOM_HANDLE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Incorrect response type in CIMOMHandle");
 
             throw CIMException(CIM_ERR_FAILED);
@@ -719,7 +709,7 @@ void InternalCIMOMHandleRep::deleteClass(
     {
         PEG_TRACE_CSTRING(
             TRC_CIMOM_HANDLE,
-            Tracer::LEVEL2,
+            Tracer::LEVEL1,
             "Exception caught in CIMOMHandle");
 
         PEG_METHOD_EXIT();
@@ -752,7 +742,7 @@ CIMInstance InternalCIMOMHandleRep::getInstance(
             XmlWriter::getNextMessageId(),
             nameSpace,
             instanceName,
-            localOnly,
+            false, // localOnly is deprecated
             includeQualifiers,
             includeClassOrigin,
             propertyList,
@@ -772,7 +762,7 @@ CIMInstance InternalCIMOMHandleRep::getInstance(
         {
             PEG_TRACE_CSTRING(
                 TRC_CIMOM_HANDLE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Incorrect response type in CIMOMHandle");
 
             throw CIMException(CIM_ERR_FAILED);
@@ -787,7 +777,7 @@ CIMInstance InternalCIMOMHandleRep::getInstance(
     {
         PEG_TRACE_CSTRING(
             TRC_CIMOM_HANDLE,
-            Tracer::LEVEL2,
+            Tracer::LEVEL1,
             "Exception caught in CIMOMHandle");
 
         PEG_METHOD_EXIT();
@@ -798,7 +788,8 @@ CIMInstance InternalCIMOMHandleRep::getInstance(
                 "Exception caught in CIMOMHandle"));
     }
 
-    CIMInstance cimInstance = response->cimInstance;
+    // The CIM instance must be resolved from XML if any.
+    CIMInstance cimInstance = response->getCimInstance();
 
     PEG_METHOD_EXIT();
     return cimInstance;
@@ -824,7 +815,7 @@ Array<CIMInstance> InternalCIMOMHandleRep::enumerateInstances(
             nameSpace,
             className,
             deepInheritance,
-            localOnly,
+            false, //localOnly is deprecated.
             includeQualifiers,
             includeClassOrigin,
             propertyList,
@@ -844,7 +835,7 @@ Array<CIMInstance> InternalCIMOMHandleRep::enumerateInstances(
         {
             PEG_TRACE_CSTRING(
                 TRC_CIMOM_HANDLE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Incorrect response type in CIMOMHandle");
 
             throw CIMException(CIM_ERR_FAILED);
@@ -859,7 +850,7 @@ Array<CIMInstance> InternalCIMOMHandleRep::enumerateInstances(
     {
         PEG_TRACE_CSTRING(
             TRC_CIMOM_HANDLE,
-            Tracer::LEVEL2,
+            Tracer::LEVEL1,
             "Exception caught in CIMOMHandle");
 
         PEG_METHOD_EXIT();
@@ -870,7 +861,7 @@ Array<CIMInstance> InternalCIMOMHandleRep::enumerateInstances(
                 "Exception caught in CIMOMHandle"));
     }
 
-    Array<CIMInstance> cimInstances = response->cimNamedInstances;
+    const Array<CIMInstance>& cimInstances = response->getNamedInstances();
 
     PEG_METHOD_EXIT();
     return cimInstances;
@@ -907,7 +898,7 @@ Array<CIMObjectPath> InternalCIMOMHandleRep::enumerateInstanceNames(
         {
             PEG_TRACE_CSTRING(
                 TRC_CIMOM_HANDLE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Incorrect response type in CIMOMHandle");
 
             throw CIMException(CIM_ERR_FAILED);
@@ -922,7 +913,7 @@ Array<CIMObjectPath> InternalCIMOMHandleRep::enumerateInstanceNames(
     {
         PEG_TRACE_CSTRING(
             TRC_CIMOM_HANDLE,
-            Tracer::LEVEL2,
+            Tracer::LEVEL1,
             "Exception caught in CIMOMHandle");
 
         PEG_METHOD_EXIT();
@@ -968,7 +959,7 @@ CIMObjectPath InternalCIMOMHandleRep::createInstance(
         {
             PEG_TRACE_CSTRING(
                 TRC_CIMOM_HANDLE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Incorrect response type in CIMOMHandle");
 
             throw CIMException(CIM_ERR_FAILED);
@@ -983,7 +974,7 @@ CIMObjectPath InternalCIMOMHandleRep::createInstance(
     {
         PEG_TRACE_CSTRING(
             TRC_CIMOM_HANDLE,
-            Tracer::LEVEL2,
+            Tracer::LEVEL1,
             "Exception caught in CIMOMHandle");
 
         PEG_METHOD_EXIT();
@@ -1034,7 +1025,7 @@ void InternalCIMOMHandleRep::modifyInstance(
         {
             PEG_TRACE_CSTRING(
                 TRC_CIMOM_HANDLE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Incorrect response type in CIMOMHandle");
 
             throw CIMException(CIM_ERR_FAILED);
@@ -1049,7 +1040,7 @@ void InternalCIMOMHandleRep::modifyInstance(
     {
         PEG_TRACE_CSTRING(
             TRC_CIMOM_HANDLE,
-            Tracer::LEVEL2,
+            Tracer::LEVEL1,
             "Exception caught in CIMOMHandle");
 
         PEG_METHOD_EXIT();
@@ -1094,7 +1085,7 @@ void InternalCIMOMHandleRep::deleteInstance(
         {
             PEG_TRACE_CSTRING(
                 TRC_CIMOM_HANDLE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Incorrect response type in CIMOMHandle");
 
             throw CIMException(CIM_ERR_FAILED);
@@ -1109,7 +1100,7 @@ void InternalCIMOMHandleRep::deleteInstance(
     {
         PEG_TRACE_CSTRING(
             TRC_CIMOM_HANDLE,
-            Tracer::LEVEL2,
+            Tracer::LEVEL1,
             "Exception caught in CIMOMHandle");
 
         PEG_METHOD_EXIT();
@@ -1155,7 +1146,7 @@ Array<CIMObject> InternalCIMOMHandleRep::execQuery(
         {
             PEG_TRACE_CSTRING(
                 TRC_CIMOM_HANDLE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Incorrect response type in CIMOMHandle");
 
             throw CIMException(CIM_ERR_FAILED);
@@ -1170,7 +1161,7 @@ Array<CIMObject> InternalCIMOMHandleRep::execQuery(
     {
         PEG_TRACE_CSTRING(
             TRC_CIMOM_HANDLE,
-            Tracer::LEVEL2,
+            Tracer::LEVEL1,
             "Exception caught in CIMOMHandle");
 
         PEG_METHOD_EXIT();
@@ -1230,7 +1221,7 @@ Array<CIMObject> InternalCIMOMHandleRep::associators(
         {
             PEG_TRACE_CSTRING(
                 TRC_CIMOM_HANDLE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Incorrect response type in CIMOMHandle");
 
             throw CIMException(CIM_ERR_FAILED);
@@ -1245,7 +1236,7 @@ Array<CIMObject> InternalCIMOMHandleRep::associators(
     {
         PEG_TRACE_CSTRING(
             TRC_CIMOM_HANDLE,
-            Tracer::LEVEL2,
+            Tracer::LEVEL1,
             "Exception caught in CIMOMHandle");
 
         PEG_METHOD_EXIT();
@@ -1300,7 +1291,7 @@ Array<CIMObjectPath> InternalCIMOMHandleRep::associatorNames(
         {
             PEG_TRACE_CSTRING(
                 TRC_CIMOM_HANDLE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Incorrect response type in CIMOMHandle");
 
             throw CIMException(CIM_ERR_FAILED);
@@ -1315,7 +1306,7 @@ Array<CIMObjectPath> InternalCIMOMHandleRep::associatorNames(
     {
         PEG_TRACE_CSTRING(
             TRC_CIMOM_HANDLE,
-            Tracer::LEVEL2,
+            Tracer::LEVEL1,
             "Exception caught in CIMOMHandle");
 
         PEG_METHOD_EXIT();
@@ -1371,7 +1362,7 @@ Array<CIMObject> InternalCIMOMHandleRep::references(
         {
             PEG_TRACE_CSTRING(
                 TRC_CIMOM_HANDLE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Incorrect response type in CIMOMHandle");
 
             throw CIMException(CIM_ERR_FAILED);
@@ -1386,7 +1377,7 @@ Array<CIMObject> InternalCIMOMHandleRep::references(
     {
         PEG_TRACE_CSTRING(
             TRC_CIMOM_HANDLE,
-            Tracer::LEVEL2,
+            Tracer::LEVEL1,
             "Exception caught in CIMOMHandle");
 
         PEG_METHOD_EXIT();
@@ -1437,7 +1428,7 @@ Array<CIMObjectPath> InternalCIMOMHandleRep::referenceNames(
         {
             PEG_TRACE_CSTRING(
                 TRC_CIMOM_HANDLE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Incorrect response type in CIMOMHandle");
 
             throw CIMException(CIM_ERR_FAILED);
@@ -1452,7 +1443,7 @@ Array<CIMObjectPath> InternalCIMOMHandleRep::referenceNames(
     {
         PEG_TRACE_CSTRING(
             TRC_CIMOM_HANDLE,
-            Tracer::LEVEL2,
+            Tracer::LEVEL1,
             "Exception caught in CIMOMHandle");
 
         PEG_METHOD_EXIT();
@@ -1500,7 +1491,7 @@ CIMValue InternalCIMOMHandleRep::getProperty(
         {
             PEG_TRACE_CSTRING(
                 TRC_CIMOM_HANDLE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Incorrect response type in CIMOMHandle");
 
             throw CIMException(CIM_ERR_FAILED);
@@ -1515,7 +1506,7 @@ CIMValue InternalCIMOMHandleRep::getProperty(
     {
         PEG_TRACE_CSTRING(
             TRC_CIMOM_HANDLE,
-            Tracer::LEVEL2,
+            Tracer::LEVEL1,
             "Exception caught in CIMOMHandle");
 
         PEG_METHOD_EXIT();
@@ -1528,8 +1519,8 @@ CIMValue InternalCIMOMHandleRep::getProperty(
 
     CIMValue cimValue = response->value;
 
-    // Return value in String form.  
-    if (cimValue.getType() != CIMTYPE_STRING && 
+    // Return value in String form.
+    if (cimValue.getType() != CIMTYPE_STRING &&
         cimValue.getType() != CIMTYPE_REFERENCE && !cimValue.isNull())
     {
         Buffer out;
@@ -1575,7 +1566,7 @@ void InternalCIMOMHandleRep::setProperty(
         {
             PEG_TRACE_CSTRING(
                 TRC_CIMOM_HANDLE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Incorrect response type in CIMOMHandle");
 
             throw CIMException(CIM_ERR_FAILED);
@@ -1590,7 +1581,7 @@ void InternalCIMOMHandleRep::setProperty(
     {
         PEG_TRACE_CSTRING(
             TRC_CIMOM_HANDLE,
-            Tracer::LEVEL2,
+            Tracer::LEVEL1,
             "Exception caught in CIMOMHandle");
 
         PEG_METHOD_EXIT();
@@ -1639,7 +1630,7 @@ CIMValue InternalCIMOMHandleRep::invokeMethod(
         {
             PEG_TRACE_CSTRING(
                 TRC_CIMOM_HANDLE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Incorrect response type in CIMOMHandle");
 
             throw CIMException(CIM_ERR_FAILED);
@@ -1654,7 +1645,7 @@ CIMValue InternalCIMOMHandleRep::invokeMethod(
     {
         PEG_TRACE_CSTRING(
             TRC_CIMOM_HANDLE,
-            Tracer::LEVEL2,
+            Tracer::LEVEL1,
             "Exception caught in CIMOMHandle");
 
         PEG_METHOD_EXIT();
@@ -1700,7 +1691,7 @@ OperationContext InternalCIMOMHandleRep::getResponseContext()
     else
     {
         ContentLanguageList* contentLangs = (ContentLanguageList*)
-            curThrd->reference_tsd("cimomHandleContentLanguages");
+            curThrd->reference_tsd(TSD_CIMOM_HANDLE_CONTENT_LANGUAGES);
         curThrd->dereference_tsd();
 
         if (contentLangs == NULL)
@@ -1711,7 +1702,7 @@ OperationContext InternalCIMOMHandleRep::getResponseContext()
         {
             ctx.insert(ContentLanguageListContainer(*contentLangs));
             // delete the old tsd to free the memory
-            curThrd->delete_tsd("cimomHandleContentLanguages");
+            curThrd->delete_tsd(TSD_CIMOM_HANDLE_CONTENT_LANGUAGES);
         }
     }
 
