@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
 //
-//==============================================================================
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -50,7 +48,7 @@ PEGASUS_NAMESPACE_BEGIN
 
 static const char _MSG_CANNOT_INIT_API_KEY[] =
     "ProviderManager.CMPI.CMPIProvider.CANNOT_INIT_API";
-static const char _MSG_CANNOT_INIT_API[] = 
+static const char _MSG_CANNOT_INIT_API[] =
     "Error initializing CMPI MI $0, the following MI"
         " factory function(s) returned an error: $1";
 
@@ -72,7 +70,7 @@ CMPIProvider::CMPIProvider(
     _broker.hdl =0;
     _broker.provider = this;
     if (mv)
-    { 
+    {
         _miVector = *mv;
     }
     unloadStatus = CMPI_RC_DO_NOT_UNLOAD;
@@ -126,16 +124,16 @@ String CMPIProvider::getNameWithType() const
 
 void setError(
     ProviderVector &miVector,
-    String &error,
+    String &errorMessage,
     const String &realProviderName,
     const char *generic,
     const char *spec,
     const CMPIString *optMsg)
 {
     PEG_METHOD_ENTER(TRC_CMPIPROVIDERINTERFACE, "CMPIProvider:setError()");
-    if (error.size() > 0)
+    if (errorMessage.size() > 0)
     {
-        error.append("; ");
+        errorMessage.append("; ");
     }
 
     String MItype;
@@ -157,11 +155,11 @@ void setError(
             MItype,
             CMGetCharsPtr(optMsg,NULL));
 
-        error.append(MessageLoader::getMessage(mlp));
+        errorMessage.append(MessageLoader::getMessage(mlp));
     }
     else
     {
-        error.append(MItype);
+        errorMessage.append(MItype);
     }
     PEG_METHOD_EXIT();
 }
@@ -179,7 +177,6 @@ void CMPIProvider::initialize(
     broker.xft=CMPI_BrokerExt_Ftab;
     broker.mft=NULL;    // CMPI memory services not supported
 
-    broker.clsCache.reset(new ClassCache());
     broker.name=name;
 
     miVector.instMI = NULL;
@@ -249,11 +246,9 @@ Boolean CMPIProvider::tryTerminate()
         }
         catch (...)
         {
-            PEG_TRACE_STRING(
-                TRC_PROVIDERMANAGER,
-                Tracer::LEVEL2,
-                "Exception caught in CMPIProviderFacade::tryTerminate() for " +
-                getName());
+            PEG_TRACE((TRC_PROVIDERMANAGER,Tracer::LEVEL1,
+                "Exception caught in CMPIProviderFacade::tryTerminate() for %s",
+                (const char*)getName().getCString()));
             terminated = false;
 
         }
@@ -337,7 +332,7 @@ void CMPIProvider::_terminate(Boolean terminating)
         // Check the thread list to make sure the thread has been de-allocated
         if (_threadWatchList.size() != 0)
         {
-            PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL2,
+            PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL4,
                 "There are %d provider threads in %s that have to be cleaned "
                 "up.",
                 _threadWatchList.size(), (const char *)getName().getCString()));
@@ -351,8 +346,8 @@ void CMPIProvider::_terminate(Boolean terminating)
                 Thread *t = _threadWatchList.remove_front();
 
                 /* If this a non-production build, DO NOT do the cancellation.
-                   This is done so that the provider developer will notice 
-                   incorrect behaviour when unloading his/her provider and 
+                   This is done so that the provider developer will notice
+                   incorrect behaviour when unloading his/her provider and
                    hopefully fix that.
                 */
 #if !defined(PEGASUS_DEBUG)
@@ -395,6 +390,7 @@ void CMPIProvider::_terminate(Boolean terminating)
 
         // Wait until all of the threads have been cleaned.
         waitUntilThreadsDone();
+
     }
     PEG_METHOD_EXIT();
 }
@@ -421,11 +417,9 @@ void CMPIProvider::terminate()
         }
         catch (...)
         {
-            PEG_TRACE_STRING(
-                TRC_PROVIDERMANAGER,
-                Tracer::LEVEL2,
-                "Exception caught in CMPIProviderFacade::Terminate for " +
-                getName());
+            PEG_TRACE((TRC_PROVIDERMANAGER,Tracer::LEVEL1,
+                "Exception caught in CMPIProviderFacade::Terminate for %s",
+                (const char*)getName().getCString()));
             throw;
         }
     }
@@ -435,8 +429,8 @@ void CMPIProvider::terminate()
 
 /*
  * Wait until all finished provider threads have been cleaned and deleted.
- * Note: This should NEVER be called from the thread that 
- * IS the Thread object that was is finished and called 
+ * Note: This should NEVER be called from the thread that
+ * IS the Thread object that was is finished and called
  * 'removeThreadFromWatch()' . If you do it, you will
  * wait forever.
  */
@@ -481,9 +475,9 @@ void CMPIProvider::threadDelete(Thread *t)
 
 /*
 // Removes the thread from the watch list and schedule the
-// CMPILocalProviderManager to delete the thread. The 
+// CMPILocalProviderManager to delete the thread. The
 // CMPILocalProviderManager after deleting the thread calls
-// the CMPIProvider' "cleanupThread". The CMPILocalProviderManager 
+// the CMPIProvider' "cleanupThread". The CMPILocalProviderManager
 // notifies this CMPIProvider object when the thread
 // is truly dead by calling "threadDeleted" function.
 //
@@ -503,11 +497,26 @@ void CMPIProvider::removeThreadFromWatch(Thread *t)
         "CMPIProvider::removeThreadFromWatch()");
     PEGASUS_ASSERT( t != 0 );
 
-    PEGASUS_ASSERT (_threadWatchList.contains (t));
+    // Note: After MI returned true from cleanup() method , there might be some
+    // threads running in MI. CMPILocalProviderManager::cleanupThread() called
+    // below will take care of joining the running threads in MI.
+    {
+        AutoMutex mtx(_removeThreadMutex);
+        if (_threadWatchList.contains(t))
+        {
+            // Remove it from the watched list
+            _threadWatchList.remove(t);
+        }
+        else
+        {
+            // This thread already has been removed from watch list.
+            PEG_METHOD_EXIT();
+            return;
+        }
+    }
+
     PEGASUS_ASSERT (!_cleanedThreads.contains (t));
 
-    // and remove it from the watched list
-    _threadWatchList.remove(t);
 
     // Add the thread to the CMPIProvider's list.
     // We use this list to keep track of threads that are
@@ -564,7 +573,7 @@ Boolean CMPIProvider::unload_ok()
         PEG_METHOD_EXIT();
         return false;
     }
-    // Do not call CIMOMHandle::unload_ok here. 
+    // Do not call CIMOMHandle::unload_ok here.
     // CIMOMHandle::unload_ok method tests for _providerUnloadProtect
     // and if zero returns true. _providerUnloadProtect is
     // incremented when CIMOMHandle::disallowProviderUnload()
@@ -672,16 +681,16 @@ CMPIInstanceMI *CMPIProvider::getInstMI()
             {
                 mi = _miVector.createGenInstMI(
                     &_broker,
-                    &eCtx, 
+                    &eCtx,
                     (const char *)providerName.getCString(),
                     &rc);
             }
-            else 
+            else
             {
                 mi = _miVector.createInstMI(&_broker, &eCtx, &rc);
             }
 
-            if (!mi || rc.rc != CMPI_RC_OK) 
+            if (!mi || rc.rc != CMPI_RC_OK)
             {
                 String error;
                 setError(
@@ -701,7 +710,7 @@ CMPIInstanceMI *CMPIProvider::getInstMI()
             }
             _miVector.instMI = mi;
         }
-    }    
+    }
 
     return _miVector.instMI;
 }
@@ -719,19 +728,19 @@ CMPIMethodMI *CMPIProvider::getMethMI()
             String providerName = _broker.name;
             CMPIMethodMI *mi;
             PEGASUS_ASSERT(_miVector.miTypes & CMPI_MIType_Method);
-            if (_miVector.genericMode) 
+            if (_miVector.genericMode)
             {
                 mi = _miVector.createGenMethMI(
                     &_broker,
-                    &eCtx, 
+                    &eCtx,
                     (const char *)providerName.getCString(),
                     &rc);
             }
-            else 
+            else
             {
                 mi = _miVector.createMethMI(&_broker, &eCtx, &rc);
             }
-            if (!mi || rc.rc != CMPI_RC_OK) 
+            if (!mi || rc.rc != CMPI_RC_OK)
             {
                 String error;
                 setError(
@@ -752,7 +761,7 @@ CMPIMethodMI *CMPIProvider::getMethMI()
             _miVector.methMI = mi;
         }
     }
-    
+
     return _miVector.methMI;
 }
 
@@ -773,16 +782,16 @@ CMPIAssociationMI *CMPIProvider::getAssocMI()
             {
                 mi = _miVector.createGenAssocMI(
                     &_broker,
-                    &eCtx, 
+                    &eCtx,
                     (const char *)providerName.getCString(),
                     &rc);
-            } 
-            else 
+            }
+            else
             {
                 mi = _miVector.createAssocMI(&_broker, &eCtx, &rc);
             }
 
-            if (!mi || rc.rc != CMPI_RC_OK) 
+            if (!mi || rc.rc != CMPI_RC_OK)
             {
                 String error;
                 setError(
@@ -803,7 +812,7 @@ CMPIAssociationMI *CMPIProvider::getAssocMI()
             _miVector.assocMI = mi;
         }
     }
-    
+
     return _miVector.assocMI;
 }
 
@@ -821,15 +830,15 @@ CMPIPropertyMI *CMPIProvider::getPropMI()
             CMPIPropertyMI *mi;
             PEGASUS_ASSERT(_miVector.miTypes & CMPI_MIType_Property);
 
-            if (_miVector.genericMode) 
+            if (_miVector.genericMode)
             {
                 mi = _miVector.createGenPropMI(
                     &_broker,
-                    &eCtx, 
+                    &eCtx,
                     (const char *)providerName.getCString(),
                     &rc);
             }
-            else 
+            else
             {
                 mi = _miVector.createPropMI(&_broker, &eCtx, &rc);
             }
@@ -855,7 +864,7 @@ CMPIPropertyMI *CMPIProvider::getPropMI()
             _miVector.propMI = mi;
         }
     }
-    
+
     return _miVector.propMI;
 }
 
@@ -876,16 +885,16 @@ CMPIIndicationMI *CMPIProvider::getIndMI()
             {
                 mi = _miVector.createGenIndMI(
                     &_broker,
-                    &eCtx, 
+                    &eCtx,
                     (const char *)providerName.getCString(),
                     &rc);
             }
-            else 
+            else
             {
                 mi = _miVector.createIndMI(&_broker, &eCtx, &rc);
             }
 
-            if (!mi || rc.rc != CMPI_RC_OK) 
+            if (!mi || rc.rc != CMPI_RC_OK)
             {
                 String error;
                 setError(
@@ -906,7 +915,7 @@ CMPIIndicationMI *CMPIProvider::getIndMI()
             _miVector.indMI = mi;
         }
     }
-    
+
     return _miVector.indMI;
 }
 
@@ -917,13 +926,13 @@ CMPIProviderModule *CMPIProvider::getModule()
 
 Uint32 CMPIProvider::getQuantum()
 {
-    AutoMutex mutex(_statusMutex);  
+    AutoMutex mutex(_statusMutex);
     return _quantum;
 }
 
 void CMPIProvider::setQuantum(Uint32 quantum)
 {
-    AutoMutex mutex(_statusMutex);  
+    AutoMutex mutex(_statusMutex);
     _quantum = quantum;
 }
 
