@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -55,18 +53,7 @@ struct CMPI_SelectExp;
 class PEGASUS_CMPIPM_LINKAGE CMPIProviderManager : public ProviderManager
 {
 public:
-    enum Mode
-    {
-        CMPI_MODE,
-        CMPI_R_MODE,
-        CMPI_O_MODE
-    };
-
-    Mode getMode()
-    {
-        return mode;
-    }
-    CMPIProviderManager(Mode=CMPI_MODE);
+    CMPIProviderManager();
     virtual ~CMPIProviderManager();
 
     virtual Message * processMessage(Message * request);
@@ -87,7 +74,7 @@ public:
         Boolean enabled;
         int count;
 #ifdef PEGASUS_ENABLE_REMOTE_CMPI
-        String remoteInfo; 
+        String remoteInfo;
 #endif
         EnableIndicationsResponseHandler* handler;
     };
@@ -114,8 +101,6 @@ public:
 protected:
     CMPILocalProviderManager providerManager;
 
-    Mode mode;
-
     void _setupCMPIContexts(
         CMPI_ContextOnStack * eCtx,
         OperationContext * context,
@@ -157,16 +142,12 @@ protected:
     Message * handleDisableModuleRequest(const Message * message);
     Message * handleEnableModuleRequest(const Message * message);
     Message * handleStopAllProvidersRequest(const Message * message);
-//  Note: The PG_Provider AutoStart property is not yet supported
-#if 0
-    Message * handleInitializeProviderRequest(const Message * message);
-#endif
     Message * handleSubscriptionInitCompleteRequest (const Message * message);
 
     ProviderName _resolveProviderName(const ProviderIdContainer & providerId);
 
     /**
-        Calls the provider's enableIndications() method, if the provider 
+        Calls the provider's enableIndications() method, if the provider
         version supports enableIndications().
 
         Note that since an exception thrown by the provider's
@@ -193,14 +174,16 @@ protected:
         @param remoteInfo Remote Information
      */
     void _callDisableIndications(
-        OpProviderHolder & ph, 
+        OpProviderHolder & ph,
         const char *remoteInfo);
 
-    CIMObjectPath _getFilterPath(
-        const CIMInstance &instance);
+    String _getClassNameFromQuery(
+        CIMOMHandleQueryContext *context,
+        String &query,
+        String &lang);
 };
 
 PEGASUS_NAMESPACE_END
 
 #endif
-    
+
