@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
 //
-//==============================================================================
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -40,6 +38,7 @@
 #include "CMPI_Value.h"
 #include "CMPIProviderManager.h"
 #include "CMPI_String.h"
+#include <Pegasus/ProviderManager2/CMPI/CMPIClassCache.h>
 
 #include <Pegasus/Common/CIMName.h>
 #include <Pegasus/Common/CIMPropertyList.h>
@@ -67,10 +66,10 @@ static const CMPIUint32 MB_CAPABILITIES =
 #define HandlerCatchSetStatus(rc, returnvalue) \
     catch (const CIMException &e) \
     { \
-        PEG_TRACE_STRING( \
+        PEG_TRACE(( \
             TRC_CMPIPROVIDERINTERFACE, \
-            Tracer::LEVEL2, \
-            "CIMException: " + e.getMessage()); \
+            Tracer::LEVEL1, \
+            "CIMException: %s",(const char*)e.getMessage().getCString())); \
         CMSetStatusWithString( \
             rc, \
             (CMPIrc)e.getCode(), \
@@ -108,10 +107,10 @@ static const CMPIUint32 MB_CAPABILITIES =
 #define HandlerCatchReturnStatus() \
     catch (const CIMException &e) \
     { \
-        PEG_TRACE_STRING( \
+        PEG_TRACE(( \
             TRC_CMPIPROVIDERINTERFACE, \
             Tracer::LEVEL2, \
-            "CIMException: " + e.getMessage()); \
+            "CIMException: %s",(const char*)e.getMessage().getCString())); \
         PEG_METHOD_EXIT(); \
         CMReturnWithString( \
             (CMPIrc)e.getCode(), \
@@ -161,53 +160,9 @@ CIMClass* mbGetClass(const CMPIBroker *mb, const CIMObjectPath &cop)
 
     mb=CM_BROKER;
     CMPI_Broker *xBroker=(CMPI_Broker*)mb;
-    String clsId =
-        cop.getNameSpace().getString()+":"+cop.getClassName().getString();
-    CIMClass *ccp;
-
-    {
-        ReadLock readLock (xBroker->rwsemClassCache);
-
-        if (xBroker->clsCache->lookup(clsId,ccp))
-        {
-            PEG_METHOD_EXIT();
-            return ccp;
-        }
-    }
-
-    try
-    {
-        WriteLock writeLock (xBroker->rwsemClassCache);
-
-        if (xBroker->clsCache->lookup(clsId,ccp))
-        {
-            PEG_METHOD_EXIT();
-            return ccp;
-        }
-
-        CIMClass cc = CM_CIMOM(mb)->getClass(
-            OperationContext(),
-            cop.getNameSpace(),
-            cop.getClassName(),
-            (bool)0,
-            (bool)1,
-            (bool)0,
-            CIMPropertyList());
-
-        ccp = new CIMClass(cc);
-        xBroker->clsCache->insert(clsId,ccp);
-        PEG_METHOD_EXIT();
-        return ccp;
-    }
-    catch (const CIMException &e)
-    {
-        PEG_TRACE_STRING(
-            TRC_CMPIPROVIDERINTERFACE,
-            Tracer::LEVEL2,
-            "Exception: " + e.getMessage());
-    }
+    CIMClass * ccp = xBroker->classCache.getClass(xBroker, cop);
     PEG_METHOD_EXIT();
-    return NULL;
+    return ccp;
 }
 
 extern "C"
@@ -240,7 +195,7 @@ extern "C"
                 OperationContext(*CM_Context(ctx)),
                 CM_ObjectPath(cop)->getNameSpace(),
                 qop, //*CM_ObjectPath(cop),
-                CM_LocalOnly(flgs),
+                false, // Use of localOnly is deprecated by DMTF.
                 CM_IncludeQualifiers(flgs),
                 CM_ClassOrigin(flgs),
                 props);
@@ -401,25 +356,29 @@ extern "C"
                     CM_ObjectPath(cop)->getNameSpace(),
                     CM_ObjectPath(cop)->getClassName(),
                     CM_DeepInheritance(flgs),
-                    CM_LocalOnly(flgs),
+                    false, //Use of localOnly is deprecated by DMTF.
                     CM_IncludeQualifiers(flgs),
                     CM_ClassOrigin(flgs),
                     props);
 
             CMSetStatus(rc,CMPI_RC_OK);
 
-            // Workaround for bugzilla 4677
+            // Workaround for bugzilla 4620
             // When running out of process the returned instances don't contain
             // a name space. Create a writable copy of the array and add the
             // namespace from the input parameters.
 
             Array<CIMInstance> * aInst = new Array<CIMInstance>(en);
-            for (unsigned int index=0; index < aInst->size(); index++)
+            Uint32 arrSize = aInst->size();
+            if (arrSize && (*aInst)[0].getPath().getNameSpace().
+                getString().size() == 0)
             {
-                CIMInstance& myInst = (*aInst)[index];
-                CIMObjectPath orgCop = myInst.getPath();
-                orgCop.setNameSpace(CM_ObjectPath(cop)->getNameSpace());
-                (*aInst)[index].setPath(orgCop);
+                for (Uint32 index = 0; index < arrSize; index++)
+                {
+                    CIMObjectPath orgCop = (*aInst)[index].getPath();
+                    orgCop.setNameSpace(CM_ObjectPath(cop)->getNameSpace());
+                    (*aInst)[index].setPath(orgCop);
+                }
             }
 
             CMPIEnumeration* cmpiEnum = reinterpret_cast<CMPIEnumeration*>(
@@ -455,14 +414,18 @@ extern "C"
             // When running out of process the returned instances don't contain
             // a name space. Create a writable copy of the array and add the
             // namespace from the input parameters.
-            Array<CIMObjectPath> * aObj = new Array<CIMObjectPath>(en);
-            for (unsigned int index=0; index < aObj->size(); index++)
+            Array<CIMObjectPath> * aRef = new Array<CIMObjectPath>(en);
+            Uint32 arrSize = aRef->size();
+            if (arrSize && (*aRef)[0].getNameSpace().getString().size() == 0)
             {
-                (*aObj)[index].setNameSpace(
-                    CM_ObjectPath(cop)->getNameSpace());
+                for (Uint32 index = 0; index < arrSize; index++)
+                {
+                    (*aRef)[index].setNameSpace(
+                        CM_ObjectPath(cop)->getNameSpace());
+                }
             }
             CMPIEnumeration* cmpiEnum = reinterpret_cast<CMPIEnumeration*>(
-                new CMPI_Object(new CMPI_OpEnumeration(aObj)));
+                new CMPI_Object(new CMPI_OpEnumeration(aRef)));
             PEG_METHOD_EXIT();
             return cmpiEnum;
         }
@@ -521,20 +484,25 @@ extern "C"
 
             CMSetStatus(rc,CMPI_RC_OK);
 
-            // Workaround for bugzilla 4677
+            // Workaround for bugzilla 4620
             // When running out of process the returned instances don't contain
             // a name space. Create a writable copy of the array and add the
             // namespace from the input parameters.
-            Array<CIMObject> * aInst = new Array<CIMObject>(en);
-            for (unsigned int index=0; index < aInst->size(); index++)
+            Array<CIMObject> * aObj = new Array<CIMObject>(en);
+            Uint32 arrSize = aObj->size();
+            if (arrSize && (*aObj)[0].getPath().getNameSpace().
+                getString().size() == 0)
             {
-                CIMObject& myInst = (*aInst)[index];
-                CIMObjectPath orgCop = myInst.getPath();
-                orgCop.setNameSpace(CM_ObjectPath(cop)->getNameSpace());
-                (*aInst)[index].setPath(orgCop);
+                for (Uint32 index = 0; index < arrSize; index++)
+                {
+                    CIMObjectPath orgCop = (*aObj)[index].getPath();
+                    orgCop.setNameSpace(CM_ObjectPath(cop)->getNameSpace());
+                    (*aObj)[index].setPath(orgCop);
+                }
             }
+
             CMPIEnumeration* cmpiEnum = reinterpret_cast<CMPIEnumeration*>(
-                new CMPI_Object(new CMPI_ObjEnumeration(aInst)));
+                new CMPI_Object(new CMPI_ObjEnumeration(aObj)));
             PEG_METHOD_EXIT();
             return cmpiEnum;
         }
@@ -588,14 +556,19 @@ extern "C"
             // When running out of process the returned instances don't contain
             // a name space. Create a writable copy of the array and add the
             // namespace from the input parameters.
-            Array<CIMObjectPath> * aObj = new Array<CIMObjectPath>(en);
-            for (unsigned int index=0; index < aObj->size(); index++)
+            Array<CIMObjectPath> * aRef = new Array<CIMObjectPath>(en);
+            Uint32 arrSize = aRef->size();
+            if (arrSize && (*aRef)[0].getNameSpace().getString().size() == 0)
             {
-                (*aObj)[index].setNameSpace(
-                    CM_ObjectPath(cop)->getNameSpace());
+                for (Uint32 index = 0; index < arrSize; index++)
+                {
+                    (*aRef)[index].setNameSpace(
+                        CM_ObjectPath(cop)->getNameSpace());
+                }
             }
+
             CMPIEnumeration* cmpiEnum = reinterpret_cast<CMPIEnumeration*>(
-                new CMPI_Object(new CMPI_OpEnumeration(aObj)));
+                new CMPI_Object(new CMPI_OpEnumeration(aRef)));
             PEG_METHOD_EXIT();
             return cmpiEnum;
         }
@@ -650,20 +623,25 @@ extern "C"
                     props);
 
             CMSetStatus(rc,CMPI_RC_OK);
-            // Workaround for bugzilla 4677
+            // Workaround for bugzilla 4620
             // When running out of process the returned instances don't contain
             // a name space. Create a writable copy of the array and add the
             // namespace from the input parameters.
-            Array<CIMObject> * aInst = new Array<CIMObject>(en);
-            for (unsigned int index=0; index < aInst->size(); index++)
+            Array<CIMObject> * aObj = new Array<CIMObject>(en);
+            Uint32 arrSize = aObj->size();
+            if (arrSize && (*aObj)[0].getPath().getNameSpace().
+                getString().size() == 0)
             {
-                CIMObject& myInst = (*aInst)[index];
-                CIMObjectPath orgCop = myInst.getPath();
-                orgCop.setNameSpace(CM_ObjectPath(cop)->getNameSpace());
-                (*aInst)[index].setPath(orgCop);
+                for (Uint32 index = 0; index < arrSize; index++)
+                {
+                    CIMObjectPath orgCop = (*aObj)[index].getPath();
+                    orgCop.setNameSpace(CM_ObjectPath(cop)->getNameSpace());
+                    (*aObj)[index].setPath(orgCop);
+                }
             }
+
             CMPIEnumeration* cmpiEnum = reinterpret_cast<CMPIEnumeration*>(
-                new CMPI_Object(new CMPI_ObjEnumeration(aInst)));
+                new CMPI_Object(new CMPI_ObjEnumeration(aObj)));
             PEG_METHOD_EXIT();
             return cmpiEnum;
         }
@@ -714,14 +692,19 @@ extern "C"
             // When running out of process the returned instances don't contain
             // a name space. Create a writable copy of the array and add the
             // namespace from the input parameters.
-            Array<CIMObjectPath> * aObj = new Array<CIMObjectPath>(en);
-            for (unsigned int index=0; index < aObj->size(); index++)
+            Array<CIMObjectPath> * aRef = new Array<CIMObjectPath>(en);
+            Uint32 arrSize = aRef->size();
+            if (arrSize && (*aRef)[0].getNameSpace().getString().size() == 0)
             {
-                (*aObj)[index].setNameSpace(
-                    CM_ObjectPath(cop)->getNameSpace());
+                for (Uint32 index = 0; index < arrSize; index++)
+                {
+                    (*aRef)[index].setNameSpace(
+                        CM_ObjectPath(cop)->getNameSpace());
+                }
             }
+
             CMPIEnumeration* cmpiEnum = reinterpret_cast<CMPIEnumeration*>(
-                new CMPI_Object(new CMPI_OpEnumeration(aObj)));
+                new CMPI_Object(new CMPI_OpEnumeration(aRef)));
             PEG_METHOD_EXIT();
             return cmpiEnum;
         }
@@ -854,7 +837,7 @@ extern "C"
                 reinterpret_cast<const CMPIArgs*>(eCtx),i,&name,NULL);
             CMPI_Args_Ftab->addArg(
                 reinterpret_cast<CMPIArgs*>(neCtx),
-                CMGetCharPtr(name),
+                CMGetCharsPtr(name,NULL),
                 &data.value,data.type);
         }
         PEG_METHOD_EXIT();
@@ -919,10 +902,9 @@ extern "C"
                 }
                 catch (const Exception &e)
                 {
-                    PEG_TRACE_STRING(
-                        TRC_CMPIPROVIDERINTERFACE,
-                        Tracer::LEVEL2,
-                        "Exception: " + e.getMessage());
+                    PEG_TRACE((TRC_CMPIPROVIDERINTERFACE,Tracer::LEVEL1,
+                        "Exception: %s",
+                        (const char*)e.getMessage().getCString()));
                     Array<CIMObjectPath> subscriptionInstanceNames;
                     context->insert(
                         SubscriptionInstanceNamesContainer(
