@@ -1,37 +1,34 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
 //
-//==============================================================================
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
-#include <Pegasus/Common/CIMNameUnchecked.h>
 #include "CMPI_Version.h"
 
 #include "CMPI_Object.h"
@@ -42,6 +39,7 @@
 #include "CMPIMsgHandleManager.h"
 
 #include <Pegasus/Common/CIMName.h>
+#include <Pegasus/Common/CIMNameCast.h>
 #include <Pegasus/Common/CIMPropertyList.h>
 #if defined (CMPI_VER_85)
 #include <Pegasus/Common/MessageLoader.h>
@@ -49,7 +47,6 @@
 #endif
 #if defined(CMPI_VER_100)
 #include <Pegasus/Common/Logger.h>
-#include <Pegasus/Common/TraceComponents.h>
 #include <Pegasus/Common/Tracer.h>
 #endif
 
@@ -58,7 +55,7 @@
 #include <Pegasus/WQL/WQLParser.h>
 #include <Pegasus/Provider/CIMOMHandleQueryContext.h>
 
-#ifndef PEGASUS_DISABLE_CQL
+#ifdef PEGASUS_ENABLE_CQL
 #include <Pegasus/CQL/CQLSelectStatement.h>
 #include <Pegasus/CQL/CQLParser.h>
 #include <Pegasus/CQL/CQLChainedIdentifier.h>
@@ -114,10 +111,8 @@ static String typeToString(CIMType t)
             return "reference";
         case CIMTYPE_OBJECT:
             return "object";
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
         case CIMTYPE_INSTANCE:
             return "instance";
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
         default:
             return "???";
     }
@@ -247,7 +242,7 @@ static inline CIMName Name(const char *n)
     }
     try
     {
-        name = CIMNameUnchecked(n);
+        name = CIMNameCast(n);
     }
     catch ( ...)
     {
@@ -280,7 +275,7 @@ extern "C"
         {
             PEG_TRACE_CSTRING(
                 TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Received Invalid Parameter in CMPI_BrokerEnc:mbEncToString");
             CMSetStatus(rc, CMPI_RC_ERR_INVALID_PARAMETER);
             PEG_METHOD_EXIT();
@@ -291,7 +286,7 @@ extern "C"
         {
             PEG_TRACE_CSTRING(
                 TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Received Invalid handle in CMPI_BrokerEnc:mbEncToString");
             CMSetStatus(rc, CMPI_RC_ERR_INVALID_PARAMETER);
             PEG_METHOD_EXIT();
@@ -395,7 +390,7 @@ extern "C"
         {
             PEG_TRACE_CSTRING(
                 TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Received Invalid Parameter in CMPI_BrokerEnc:mbEncNewString");
             CMSetStatus(rc, CMPI_RC_ERR_INVALID_PARAMETER);
             PEG_METHOD_EXIT();
@@ -469,7 +464,7 @@ extern "C"
         {
             PEG_TRACE_CSTRING(
                 TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Received Invalid Parameter in CMPI_BrokerEnc:newDateTimeChar");
             CMSetStatus(rc, CMPI_RC_ERR_INVALID_PARAMETER);
         }
@@ -525,7 +520,7 @@ extern "C"
         if (obj==NULL)
         {
             sprintf(msg,"** Null object ptr (%p) **",o);
-            CMSetStatus(rc,CMPI_RC_ERR_FAILED);
+            CMSetStatus(rc,CMPI_RC_ERR_INVALID_PARAMETER);
             CMPIString* cmpiString =
                 reinterpret_cast<CMPIString*>(new CMPI_Object(msg));
             PEG_METHOD_EXIT();
@@ -535,7 +530,7 @@ extern "C"
         if (obj->getHdl()==NULL)
         {
             sprintf(msg,"** Null object hdl (%p) **",o);
-            CMSetStatus(rc,CMPI_RC_ERR_FAILED);
+            CMSetStatus(rc,CMPI_RC_ERR_INVALID_PARAMETER);
             CMPIString* cmpiString =
                 reinterpret_cast<CMPIString*>(new CMPI_Object(msg));
             PEG_METHOD_EXIT();
@@ -580,7 +575,7 @@ extern "C"
         else
         {
             sprintf(msg,"** Object not recognized (%p) **",o);
-            CMSetStatus(rc,CMPI_RC_ERR_FAILED);
+            CMSetStatus(rc,CMPI_RC_ERR_INVALID_PARAMETER);
             CMPIString* cmpiString =
                 reinterpret_cast<CMPIString*>(new CMPI_Object(msg));
             PEG_METHOD_EXIT();
@@ -609,7 +604,7 @@ extern "C"
         {
             PEG_TRACE_CSTRING(
                 TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Received Invalid Parameter - eCp || type in \
                 CMPI_BrokerEnc:mbEncClassPathIsA");
             CMSetStatus(rc, CMPI_RC_ERR_INVALID_PARAMETER);
@@ -620,7 +615,7 @@ extern "C"
         {
             PEG_TRACE_CSTRING(
                 TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Received Invalid Class in \
                 CMPI_BrokerEnc:mbEncClassPathIsA");
             CMSetStatus(rc,CMPI_RC_ERR_INVALID_CLASS);
@@ -1048,7 +1043,7 @@ extern "C"
         {
             if (rc.rc == CMPI_RC_OK)
             {
-                const char* accLangs = CMGetCharPtr(data.value.string);
+                const char* accLangs = CMGetCharsPtr(data.value.string, NULL);
                 if ((accLangs != NULL) && (accLangs[0] != '\0'))
                 {
                     parms->acceptlanguages =
@@ -1059,7 +1054,7 @@ extern "C"
             {
                 PEG_TRACE(
                     (TRC_PROVIDERMANAGER,
-                     Tracer::LEVEL2,
+                     Tracer::LEVEL1,
                      "Failed to get CMPIAcceptLanguage from CMPIContext. RC=%d",
                      rc.rc));
                 PEG_METHOD_EXIT();
@@ -1155,7 +1150,7 @@ extern "C"
 
         if (msgId != NULL)
         {
-            parms->msg_id.assign(msgId);
+            parms->msg_id = msgId;
         }
 
         if ( defMsg != NULL )
@@ -1264,7 +1259,7 @@ extern "C"
 #if defined(CMPI_VER_100)
     CMPIStatus mbEncLogMessage(
         const CMPIBroker*,
-        int severity,
+        CMPISeverity severity,
         const char *id,
         const char *text,
         const CMPIString *string)
@@ -1279,7 +1274,7 @@ extern "C"
         if (id != NULL)
         {
             logString.assign(id);
-            logString.append(":");
+        logString.append(":");
         }
 
         if (string)
@@ -1316,21 +1311,19 @@ extern "C"
         CMReturn ( CMPI_RC_OK);
     }
 
-    inline Uint32 mapTraceLevel(int level)
+    inline Uint32 mapTraceLevel(CMPILevel level)
     {
-        // There are no notion in CMPI spec about what 'level' means.
-        // So we are going to try to map . We don't want to map to LEVEL1
-        // as it requires the PEG_METHOD_ENTER and PEG_METHOD_EXIT macros.
+        // There is no notion in CMPI spec about what 'level' means.
+        // So we are going to try to map.
         switch (level)
         {
-            case 1:
-            case 2:
-                return Tracer::LEVEL2;
-                break;
-            case 3:
+            case CMPI_LEV_INFO:
                 return Tracer::LEVEL3;
                 break;
-            case 4:
+            case CMPI_LEV_WARNING:
+                return Tracer::LEVEL2;
+                break;
+            case CMPI_LEV_VERBOSE:
                 return Tracer::LEVEL4;
                 break;
             default:
@@ -1351,7 +1344,7 @@ extern "C"
 
     CMPIStatus mbEncTracer(
         const CMPIBroker*,
-        int level,
+        CMPILevel level,
         const char *component,
         const char *text,
         const CMPIString *string)
@@ -1405,7 +1398,7 @@ extern "C"
             // Create the CIMOMHandle wrapper.
             CIMOMHandle *cm_handle = CM_CIMOM (mb);
             CIMOMHandleQueryContext qcontext(
-                CIMNamespaceName(CMGetCharPtr(data.value.string)),
+                CIMNamespaceName(CMGetCharsPtr(data.value.string,NULL)),
                 *cm_handle);
 
             String sLang (lang);
@@ -1501,7 +1494,7 @@ extern "C"
             PEG_METHOD_EXIT();
             return (cmpiSelectExp);
         }
-#ifndef PEGASUS_DISABLE_CQL
+#ifdef PEGASUS_ENABLE_CQL
         if ((strncmp (lang, CALL_SIGN_CQL, CALL_SIGN_CQL_SIZE) == 0) ||
             (strncmp (lang, "CIMxCQL", 7) == 0) ||
             (strncmp (lang, "CIM:CQL", 7) == 0))
@@ -1532,7 +1525,7 @@ extern "C"
             // Create the CIMOMHandle wrapper.
             CIMOMHandle *cm_handle = CM_CIMOM (mb);
             CIMOMHandleQueryContext qcontext(
-                CIMNamespaceName(CMGetCharPtr(data.value.string)),
+                CIMNamespaceName(CMGetCharsPtr(data.value.string, NULL)),
                 *cm_handle);
 
             String sLang (lang);
@@ -1550,13 +1543,13 @@ extern "C"
             {
                 PEG_TRACE_CSTRING(
                     TRC_CMPIPROVIDERINTERFACE,
-                    Tracer::LEVEL2,
+                    Tracer::LEVEL1,
                     "Exception: Unknown Exception received...");
                 if (st)
                 {
                     PEG_TRACE_CSTRING(
                         TRC_CMPIPROVIDERINTERFACE,
-                        Tracer::LEVEL2,
+                        Tracer::LEVEL1,
                         "Exception: Invalid Query Exception received...");
                     CMSetStatus (st, CMPI_RC_ERR_INVALID_QUERY);
                 }
@@ -1658,7 +1651,7 @@ extern "C"
         {
             PEG_TRACE_CSTRING(
                 TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Received Query Language is currently NOT SUPPORTED");
             CMSetStatus (st, CMPI_RC_ERR_QUERY_LANGUAGE_NOT_SUPPORTED);
         }
@@ -1680,7 +1673,7 @@ extern "C"
         {
             PEG_TRACE_CSTRING(
                 TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Invalid Parameter cop || ctx in \
                 CMPI_BrokerEnc:mbEncGetKeyList");
             CMSetStatus(rc, CMPI_RC_ERR_INVALID_PARAMETER);
@@ -1693,7 +1686,7 @@ extern "C"
         {
             PEG_TRACE_CSTRING(
                 TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Received Invalid Handle cop->handle in \
                 CMPI_BrokerEnc:mbEncGetKeyList");
             CMSetStatus(rc, CMPI_RC_ERR_INVALID_HANDLE);
