@@ -1,37 +1,34 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
-#include <Pegasus/Common/CIMNameUnchecked.h>
 #include <Pegasus/Common/AutoPtr.h>
 #include "CMPI_Version.h"
 
@@ -40,6 +37,7 @@
 #include "CMPI_Value.h"
 #include "CMPI_String.h"
 
+#include <Pegasus/Common/CIMNameCast.h>
 #include <Pegasus/Common/InternalException.h>
 #include <Pegasus/Common/System.h>
 #include <Pegasus/Common/Mutex.h>
@@ -50,7 +48,7 @@
 PEGASUS_USING_STD;
 PEGASUS_NAMESPACE_BEGIN
 
-extern "C" 
+extern "C"
 {
 
     static CMPIStatus instRelease(CMPIInstance* eInst)
@@ -73,7 +71,7 @@ extern "C"
         CMReturn(CMPI_RC_OK);
     }
 
-    static CMPIInstance* instClone(const CMPIInstance* eInst, CMPIStatus* rc) 
+    static CMPIInstance* instClone(const CMPIInstance* eInst, CMPIStatus* rc)
     {
         PEG_METHOD_ENTER(
             TRC_CMPIPROVIDERINTERFACE,
@@ -92,7 +90,7 @@ extern "C"
             cInst.release();
             obj->unlink();
             CMSetStatus(rc,CMPI_RC_OK);
-            CMPIInstance* cmpiInstance = 
+            CMPIInstance* cmpiInstance =
                 reinterpret_cast<CMPIInstance *>(obj.release());
             PEG_METHOD_EXIT();
             return cmpiInstance;
@@ -121,8 +119,8 @@ extern "C"
         if (pos>inst->getPropertyCount())
         {
             CMSetStatus(rc, CMPI_RC_ERR_NO_SUCH_PROPERTY);
-            CMPIData data={0,CMPI_nullValue|CMPI_notFound,{0}};
-            return data;
+            CMPIData retData={0,CMPI_nullValue|CMPI_notFound,{0}};
+            return retData;
         }
         const CIMProperty& p=inst->getProperty(pos);
         const CIMValue& v=p.getValue();
@@ -141,8 +139,8 @@ extern "C"
         return data;
     }
 
-    static CMPIData instGetProperty(const CMPIInstance* eInst, 
-        const char *name, CMPIStatus* rc)   
+    static CMPIData instGetProperty(const CMPIInstance* eInst,
+        const char *name, CMPIStatus* rc)
     {
         CMPIData data={0,CMPI_nullValue|CMPI_notFound,{0}};
 
@@ -169,8 +167,8 @@ extern "C"
     }
 
 
-    static CMPICount instGetPropertyCount(const CMPIInstance* eInst, 
-        CMPIStatus* rc) 
+    static CMPICount instGetPropertyCount(const CMPIInstance* eInst,
+        CMPIStatus* rc)
     {
         CIMInstance* inst=(CIMInstance*)eInst->hdl;
         if (!inst)
@@ -182,7 +180,7 @@ extern "C"
         return inst->getPropertyCount();
     }
 
-    static CMPIStatus instSetPropertyWithOrigin(const CMPIInstance* eInst, 
+    static CMPIStatus instSetPropertyWithOrigin(const CMPIInstance* eInst,
         const char* name, const CMPIValue* data, const CMPIType type,
         const char* origin)
     {
@@ -197,25 +195,24 @@ extern "C"
         }
         CMPIrc rc;
         CIMValue v=value2CIMValue(data,type,&rc);
-        CIMNameUnchecked sName(name);
         Uint32 pos;
         int count=0;
 
-        if ((pos=inst->findProperty(sName))!=PEG_NOT_FOUND)
+        if ((pos=inst->findProperty(CIMNameCast(name)))!=PEG_NOT_FOUND)
         {
 
             CIMProperty cp=inst->getProperty(pos);
 
 
-            /* The CMPI interface uses the type "CMPI_instance" to represent 
-               both embedded objects and embedded instances. CMPI has no 
-               "CMPI_object" type. So when converting a CMPIValue with type 
-               "CMPI_instance" to a CIMValue (see value2CIMValue) the type 
-               CIMTYPE_OBJECT is always used. If the property's type is 
+            /* The CMPI interface uses the type "CMPI_instance" to represent
+               both embedded objects and embedded instances. CMPI has no
+               "CMPI_object" type. So when converting a CMPIValue with type
+               "CMPI_instance" to a CIMValue (see value2CIMValue) the type
+               CIMTYPE_OBJECT is always used. If the property's type is
                CIMTYPE_INSTANCE, and the value's type is CIMTYPE_OBJECT, then
                we convert the value's type to match the property's type.
             */
-            if (cp.getType() == CIMTYPE_INSTANCE && 
+            if (cp.getType() == CIMTYPE_INSTANCE &&
                 v.getType() == CIMTYPE_OBJECT)
             {
                 if (cp.isArray())
@@ -224,7 +221,7 @@ extern "C"
                     {
                         PEG_TRACE((
                             TRC_CMPIPROVIDERINTERFACE,
-                            Tracer::LEVEL2,
+                            Tracer::LEVEL1,
                             "TypeMisMatch, Expected Type: %s, Actual Type: %s",
                             cimTypeToString(cp.getType()),
                             cimTypeToString(v.getType())));
@@ -237,18 +234,17 @@ extern "C"
                     for (Uint32 i = 0; i < tmpObjs.size() ; ++i)
                     {
                         tmpInsts.append(CIMInstance(tmpObjs[i]));
-                    } 
+                    }
                     v.set(tmpInsts);
                 }
                 else
-                {  
+                {
                     CIMObject co;
                     v.get(co);
                     if (co.isInstance())
                         v.set(CIMInstance(co));
                 }
             }
-
             try
             {
                 cp.setValue(v);
@@ -262,14 +258,14 @@ extern "C"
             {
                 PEG_TRACE((
                     TRC_CMPIPROVIDERINTERFACE,
-                    Tracer::LEVEL2,
+                    Tracer::LEVEL1,
                     " TypeMisMatch exception for: %s",
                     name));
                 if (getenv("PEGASUS_CMPI_CHECKTYPES")!=NULL)
                 {
                     PEG_TRACE_CSTRING(
                         TRC_CMPIPROVIDERINTERFACE,
-                        Tracer::LEVEL2,
+                        Tracer::LEVEL1,
                         " Aborting because of CMPI_CHECKTYPES..");
                         abort();
                 }
@@ -280,7 +276,7 @@ extern "C"
             {
                 PEG_TRACE((
                     TRC_CMPIPROVIDERINTERFACE,
-                    Tracer::LEVEL2,
+                    Tracer::LEVEL1,
                     " InvalidName exception for: %s",
                     origin));
 
@@ -289,15 +285,14 @@ extern "C"
             }
             catch (const Exception &e)
             {
-                PEG_TRACE_STRING(
-                    TRC_CMPIPROVIDERINTERFACE,
-                    Tracer::LEVEL2,
-                    "  " + e.getMessage() + " exception for " + name);
+                PEG_TRACE((TRC_CMPIPROVIDERINTERFACE,Tracer::LEVEL1,
+                    "Exception for %s: %s",name,
+                    (const char*)e.getMessage().getCString()));
                 if (getenv("PEGASUS_CMPI_CHECKTYPES")!=NULL)
                 {
                     PEG_TRACE_CSTRING(
                         TRC_CMPIPROVIDERINTERFACE,
-                        Tracer::LEVEL2,
+                        Tracer::LEVEL1,
                         " Aborting because of CMPI_CHECKTYPES..");
                         abort();
                 }
@@ -320,13 +315,13 @@ extern "C"
     }
 
     static CMPIStatus instSetProperty(const CMPIInstance* eInst,
-        const char *name, const CMPIValue* data, CMPIType type) 
+        const char *name, const CMPIValue* data, CMPIType type)
     {
         return instSetPropertyWithOrigin(eInst, name, data, type, NULL);
     }
 
     static CMPIObjectPath* instGetObjectPath(const CMPIInstance* eInst,
-        CMPIStatus* rc) 
+        CMPIStatus* rc)
     {
         PEG_METHOD_ENTER(
             TRC_CMPIPROVIDERINTERFACE,
@@ -344,24 +339,24 @@ extern "C"
         try
         {
             /* Check if NameSpace is NULL before calling GetClass. When
-               providers run out-of-process and getClass request is made 
-               through CIMClient,  CIMOperationRequestEncoder tries to 
-               encode the request and finds the namespace is invalid 
-               (empty) and throws InvalidNamespaceNameException. 
+               providers run out-of-process and getClass request is made
+               through CIMClient,  CIMOperationRequestEncoder tries to
+               encode the request and finds the namespace is invalid
+               (empty) and throws InvalidNamespaceNameException.
             */
-            if (clsRef.getKeyBindings().size()==0 && 
+            if (clsRef.getKeyBindings().size()==0 &&
                 !clsRef.getNameSpace().isNull())
             {
                 CIMClass *cc=mbGetClass(CMPI_ThreadContext::getBroker(),clsRef);
-                /* It seems that when converting the CIMInstnace to XML form, 
-                   we miss CIMObjectPath from it. When we don't have namespace 
-                   we may not get class, so make ObjectPath with class-name 
+                /* It seems that when converting the CIMInstnace to XML form,
+                   we miss CIMObjectPath from it. When we don't have namespace
+                   we may not get class, so make ObjectPath with class-name
                    only.
-                   TODO: This will create problems when passing the 
+                   TODO: This will create problems when passing the
                    EmbeddedInstances as arguements to MethodProviders, where it
-                   needs to get ObjectPath from instance. Shall we need to 
-                   include CIMObjectPath in CIMInstance while converting to XML 
-                   form ??? ...  
+                   needs to get ObjectPath from instance. Shall we need to
+                   include CIMObjectPath in CIMInstance while converting to XML
+                   form ??? ...
                 */
                 if (!cc)
                 {
@@ -379,10 +374,10 @@ extern "C"
             obj.reset(new CMPI_Object(objPath.get()));
             objPath.release();
             CMSetStatus(rc,CMPI_RC_OK);
-            CMPIObjectPath* cmpiObjectPath = 
+            CMPIObjectPath* cmpiObjectPath =
                 reinterpret_cast<CMPIObjectPath*> (obj.release());
             PEG_METHOD_EXIT();
-            return cmpiObjectPath; 
+            return cmpiObjectPath;
         }
         catch (const PEGASUS_STD(bad_alloc)&)
         {
@@ -393,7 +388,7 @@ extern "C"
     }
 
     static CMPIStatus instSetObjectPath(
-        CMPIInstance* eInst, 
+        CMPIInstance* eInst,
         const CMPIObjectPath *obj)
     {
         PEG_METHOD_ENTER(
@@ -414,7 +409,7 @@ extern "C"
         CIMObjectPath &ref = *(CIMObjectPath*)(obj->hdl);
         try
         {
-            inst->setPath(ref); 
+            inst->setPath(ref);
         }
         catch (const TypeMismatchException &e)
         {
@@ -437,26 +432,26 @@ extern "C"
         const char** listroot2,
         CIMInstance & inst)
     {
-        /* listroot1 never can be 0, this function is only called by 
+        /* listroot1 never can be 0, this function is only called by
            instSetPropertyFilter() and the check is done there already */
-        
+
         /* determine number of properties on the instance */
         int propertyCount = inst.getPropertyCount();
 
         /* number of properties in each property list */
         int numProperties1 = 0;
-        int numProperties2 = 0;            
+        int numProperties2 = 0;
         /* Masks for property lists
            0 = list element not yet found
            1 = list element already found)
-        */            
+        */
         char * plMask1=0;
-        char * plMask2=0;            
+        char * plMask2=0;
         /* end of array of property list names */
         const char **listend1 = listroot1;
         /* place end pointer at end of array and count number of properties
            named in the first list */
-        while (*listend1) 
+        while (*listend1)
         {
             listend1++;
         }
@@ -474,7 +469,7 @@ extern "C"
            named in the first list */
         if (listroot2)
         {
-            while (*listend2) 
+            while (*listend2)
             {
                 listend2++;
             }
@@ -494,7 +489,7 @@ extern "C"
             CIMConstProperty prop = inst.getProperty(idx);
             CString cName = prop.getName().getString().getCString();
             const char* pName = (const char*)cName;
-            
+
             /* work the property list backward too, as often times
                properties on the instance and in the list are ordered in the
                same way, this helps reduce number of required strcasecmp */
@@ -572,12 +567,19 @@ extern "C"
            property filters or have to filter for themselves.
            Removing properties from the CIMInstance here helps to effectively
            avoid the need to carry a property list around in the CMPI layer.
+
+           A (propertyList == 0) means the property list is null and there
+           should be no filtering.
+
+           An empty propertylist(no property to be returned) is represented by
+           a valid propertyList pointer pointing to a null pointer, i.e.
+           (*propertyList == 0)
         */
 
         CIMInstance& inst=*(CIMInstance*)(eInst->hdl);
-        if (propertyList && *propertyList)
+        if (propertyList)
         {
-            if (!(keys && *keys))
+            if (!keys)
             {
                 filterCIMInstance(propertyList, 0, inst);
             }
@@ -653,4 +655,4 @@ CMPI_InstanceOnStack::CMPI_InstanceOnStack(const CIMInstance& ci)
 
 
 PEGASUS_NAMESPACE_END
-    
+
