@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -51,97 +49,13 @@ PEGASUS_NAMESPACE_BEGIN
 
 Mutex errorChainMutex;
 
-CMPIStatus resolveEmbeddedInstanceTypes(
-    OperationResponseHandler * opRes,
-    CIMInstance & inst)
-{
-    PEG_METHOD_ENTER(
-        TRC_CMPIPROVIDERINTERFACE,
-        "CMPI_Result:resolveEmbeddedInstanceTypes()");
-    CIMOperationRequestMessage * request =
-        dynamic_cast<CIMOperationRequestMessage *>(opRes->getRequest());
-    if (request->operationContext.contains(NormalizerContextContainer::NAME) &&
-        request->operationContext.contains(
-            CachedClassDefinitionContainer::NAME))
-    {
-        const NormalizerContextContainer * contextContainer =
-            dynamic_cast<const NormalizerContextContainer *>(
-            &(request->operationContext.get(
-            NormalizerContextContainer::NAME)));
-        PEGASUS_ASSERT(contextContainer);
-        const CachedClassDefinitionContainer * classContainer =
-            dynamic_cast<const CachedClassDefinitionContainer *>(
-            &(request->operationContext.get(
-            CachedClassDefinitionContainer::NAME)));
-        PEGASUS_ASSERT(classContainer);
-
-        CIMClass classDef(classContainer->getClass());
-        for (unsigned int i = 0, n = inst.getPropertyCount(); i < n; ++i)
-        {
-            CIMConstProperty currentProp(inst.getProperty(i));
-            if (currentProp.getType() == CIMTYPE_OBJECT)
-            {
-                Uint32 propIndex = classDef.findProperty(
-                    currentProp.getName());
-                if (propIndex == PEG_NOT_FOUND)
-                {
-                    String message = 
-                        String("Could not find property ")
-                    + currentProp.getName().getString()
-                    + " in class definition";
-                    PEG_METHOD_EXIT();
-                    CMReturnWithString(CMPI_RC_ERR_FAILED,
-                        (CMPIString*)string2CMPIString(message));
-                }
-
-                CIMConstProperty propertyDef(
-                    classDef.getProperty(propIndex));
-
-                /**
-                  Normalize the property: this will ensure that the property
-                  and any embedded instance/object properties are consistent
-                  with the relevant class definitions.
-                */
-                CIMProperty normalizedProperty(
-                    ObjectNormalizer::processProperty(
-                    propertyDef,
-                    currentProp,
-                    false,
-                    false,
-                    contextContainer->getContext(),
-                    request->nameSpace));
-
-                /**
-                   Remove the old property, add the new, and adjust the
-                   loop counters appropriately.
-                */
-                inst.removeProperty(i);
-                inst.addProperty(normalizedProperty);
-                --i;
-                --n;
-            }
-        }
-    }
-    
-    /**
-      else
-      {
-       If the NormalizerContextContainer is not present, then the
-       ObjectNormalizer must be enabled for this operation and the
-       ObjectNormalizer will do the work in the above try block.
-      }
-     */
-    PEG_METHOD_EXIT();
-    CMReturn(CMPI_RC_OK);
-}
-
 extern "C"
 {
 
     PEGASUS_STATIC CMPIStatus resultReturnData(
         const CMPIResult* eRes,
         const CMPIValue* data,
-        const CMPIType type) 
+        const CMPIType type)
     {
         PEG_METHOD_ENTER(
             TRC_CMPIPROVIDERINTERFACE,
@@ -151,7 +65,7 @@ extern "C"
         {
             PEG_TRACE_CSTRING(
                 TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Received invalid handle in CMPI_Result:resultReturnData");
             PEG_METHOD_EXIT();
             CMReturn(CMPI_RC_ERR_INVALID_HANDLE);
@@ -160,7 +74,7 @@ extern "C"
         {
             PEG_TRACE_CSTRING(
                 TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Received Invalid Parameter in CMPI_Result:resultReturnData");
             PEG_METHOD_EXIT();
             CMReturn(CMPI_RC_ERR_INVALID_PARAMETER);
@@ -178,7 +92,6 @@ extern "C"
                     res->processing();
                     ((CMPI_Result*)eRes)->flags|=RESULT_set;
                 }
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
               /**
                  If the CMPI type is CMPI_instance, then the CIM return type
                  could be either an EmbeddedObject or EmbeddedInstance. We
@@ -203,7 +116,7 @@ extern "C"
                             CachedClassDefinitionContainer::NAME)));
                         PEGASUS_ASSERT(classContainer != 0);
 
-                        CIMClass classDef(classContainer->getClass());
+                        CIMConstClass classDef(classContainer->getClass());
                         Uint32 methodIndex = classDef.findMethod(
                             request->methodName);
                         if (methodIndex == PEG_NOT_FOUND)
@@ -215,9 +128,11 @@ extern "C"
                                 (CMPIString*)string2CMPIString(message));
                         }
 
-                        CIMMethod methodDef(classDef.getMethod(methodIndex));
+                        CIMConstMethod methodDef(
+                            classDef.getMethod(methodIndex));
                         if (methodDef.findQualifier(
-                               CIMName("EmbeddedInstance")) != PEG_NOT_FOUND)
+                               PEGASUS_QUALIFIERNAME_EMBEDDEDINSTANCE)
+                            != PEG_NOT_FOUND)
                         {
                             PEGASUS_ASSERT(v.getType() == CIMTYPE_OBJECT);
                             CIMObject tmpObject;
@@ -232,7 +147,6 @@ extern "C"
                             (CMPIString*)string2CMPIString(e.getMessage()));
                     }
                 }
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
                 res->deliver(v);
             }
             else
@@ -248,10 +162,9 @@ extern "C"
         }
         catch (const CIMException &e)
         {
-            PEG_TRACE_STRING(
-                TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
-                "Exception: resultReturnData - msg: " + e.getMessage());
+            PEG_TRACE((TRC_CMPIPROVIDERINTERFACE,Tracer::LEVEL1,
+                "CIMException: resultReturnData - msg: %s",
+                (const char*)e.getMessage().getCString()));
             PEG_METHOD_EXIT();
             CMReturnWithString(
                 CMPI_RC_ERR_FAILED,
@@ -271,11 +184,13 @@ extern "C"
         InstanceResponseHandler* res=(InstanceResponseHandler*)eRes->hdl;
         if ((res == NULL) || (eInst == NULL))
         {
-            PEG_TRACE_CSTRING(
+            PEG_TRACE((
                 TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
-                "Invalid parameter res || eInst in \
-                CMPI_Result:resultReturnInstance");
+                ((res==0) ? (Tracer::LEVEL1) : (Tracer::LEVEL3)),
+                "Invalid parameter res (%p) || eInst (%p) "
+                    "in CMPI_Result:resultReturnInstance",
+                res,
+                eInst));
             PEG_METHOD_EXIT();
             CMReturn(CMPI_RC_ERR_INVALID_PARAMETER);
         }
@@ -284,7 +199,7 @@ extern "C"
         {
             PEG_TRACE_CSTRING(
                 TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Invalid parameter eInst->hdl in \
                 CMPI_Result:resultReturnInstance");
             PEG_METHOD_EXIT();
@@ -311,43 +226,14 @@ extern "C"
                 iop.setNameSpace(op.getNameSpace());
                 inst.setPath(iop);
             }
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
-            /**
-              CMPI does not differentiate between EmbeddedInstances and
-              EmbeddedObjects, so any mismatches between the property type
-              in the instance and the property type in the class definition
-              must be resolved.
-           */
-            EnumerateInstancesResponseHandler * eiRes =
-                dynamic_cast<EnumerateInstancesResponseHandler *>(res);
-            GetInstanceResponseHandler * giRes = 0;
-            CMPIStatus status;
-            if (eiRes)
-            {
-                status = resolveEmbeddedInstanceTypes(eiRes, inst);
-            }
-            else
-            {
-                giRes = dynamic_cast<GetInstanceResponseHandler *>(res);
-                PEGASUS_ASSERT(giRes);
-                status = resolveEmbeddedInstanceTypes(giRes, inst);
-            }
-
-            if (status.rc != CMPI_RC_OK)
-            {
-                PEG_METHOD_EXIT();
-                return status;
-            }
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
 
             res->deliver(inst);
         }
         catch (const CIMException &e)
         {
-            PEG_TRACE_STRING(
-                TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
-                "Exception: resultReturnInstance - msg: " + e.getMessage());
+            PEG_TRACE((TRC_CMPIPROVIDERINTERFACE,Tracer::LEVEL1,
+                "CIMException: resultReturnInstance - msg: %s",
+                (const char*)e.getMessage().getCString()));
             PEG_METHOD_EXIT();
             CMReturnWithString(
                 CMPI_RC_ERR_FAILED,
@@ -368,11 +254,13 @@ extern "C"
 
         if ((res == NULL) || (eInst == NULL))
         {
-            PEG_TRACE_CSTRING(
+            PEG_TRACE((
                 TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
-                "Invalid parameter res || eInst in \
-                CMPI_Result:resultReturnObject");
+                ((res==0) ? (Tracer::LEVEL1) : (Tracer::LEVEL3)),
+                "Invalid parameter res (%p) || eInst (%p) "
+                    "in CMPI_Result:resultReturnObject",
+                res,
+                eInst));
             PEG_METHOD_EXIT();
             CMReturn(CMPI_RC_ERR_INVALID_PARAMETER);
         }
@@ -381,7 +269,7 @@ extern "C"
         {
             PEG_TRACE_CSTRING(
                 TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Invalid parameter eInst->hdl in \
                 CMPI_Result:resultReturnObject");
             PEG_METHOD_EXIT();
@@ -409,82 +297,14 @@ extern "C"
                 inst.setPath(iop);
             }
 
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
-           /**
-             CMPI does not differentiate between EmbeddedInstances and
-             EmbeddedObjects, so any mismatches between the property type
-             in the instance and the property type in the class definition
-             must be resolved.
-            */
-            CMPIStatus status;
-
-            do
-            {
-                // Try EnumerateInstancesResponseHandler:
-
-                EnumerateInstancesResponseHandler * eiRes =
-                    dynamic_cast<EnumerateInstancesResponseHandler *>(res);
-
-                if (eiRes)
-                {
-                    status = resolveEmbeddedInstanceTypes(eiRes, inst);
-                    break;
-                }
-
-                // Try GetInstanceResponseHandler
-
-                GetInstanceResponseHandler * giRes = 0;
-                giRes = dynamic_cast<GetInstanceResponseHandler *>(res);
-
-                if (giRes)
-                {
-                    status = resolveEmbeddedInstanceTypes(giRes, inst);
-                    break;
-                }
-
-                // Try AssociatorsResponseHandler:
-
-                AssociatorsResponseHandler* aRes = 0;
-                aRes = dynamic_cast<AssociatorsResponseHandler*>(res);
-
-                if (aRes)
-                {
-                    status = resolveEmbeddedInstanceTypes(aRes, inst);
-                    break;
-                }
-
-                // Try AssociatorsResponseHandler:
-
-                ReferencesResponseHandler* rRes = 0;
-                rRes = dynamic_cast<ReferencesResponseHandler*>(res);
-
-                if (rRes)
-                {
-                    status = resolveEmbeddedInstanceTypes(rRes, inst);
-                    break;
-                }
-
-                // None of the above.
-
-                PEGASUS_ASSERT(0);
-            }
-            while (0);
-
-            if (status.rc != CMPI_RC_OK)
-            {
-                PEG_METHOD_EXIT();
-                return status;
-            }
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
-
             res->deliver(inst);
         }
         catch (const CIMException &e)
         {
-            PEG_TRACE_STRING(
-                TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
-                "Exception: resultReturnObject - msg: " + e.getMessage());
+            PEG_TRACE((TRC_CMPIPROVIDERINTERFACE,Tracer::LEVEL1,
+                "CIMException: resultReturnObject - msg: %s",
+                (const char*)e.getMessage().getCString()));
+
             PEG_METHOD_EXIT();
             CMReturnWithString(
                 CMPI_RC_ERR_FAILED,
@@ -504,11 +324,13 @@ extern "C"
         ExecQueryResponseHandler* res=(ExecQueryResponseHandler*)eRes->hdl;
         if ((res == NULL) || (eInst == NULL))
         {
-            PEG_TRACE_CSTRING(
+            PEG_TRACE((
                 TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
-                "Invalid parameter res || eInst in \
-                CMPI_Result:resultReturnExecQuery");
+                ((res==0) ? (Tracer::LEVEL1) : (Tracer::LEVEL3)),
+                "Invalid parameter res (%p) || eInst (%p) "
+                    "in CMPI_Result:resultReturnExecQuery",
+                res,
+                eInst));
             PEG_METHOD_EXIT();
             CMReturn(CMPI_RC_ERR_INVALID_PARAMETER);
         }
@@ -517,7 +339,7 @@ extern "C"
         {
             PEG_TRACE_CSTRING(
                 TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Invalid parameter eInst->hdl in \
                 CMPI_Result:resultReturnExecQuery");
             PEG_METHOD_EXIT();
@@ -537,10 +359,9 @@ extern "C"
         }
         catch (const CIMException &e)
         {
-            PEG_TRACE_STRING(
-                TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
-                "Exception: resultReturnExecQuery - msg: " + e.getMessage());
+            PEG_TRACE((TRC_CMPIPROVIDERINTERFACE,Tracer::LEVEL1,
+                "CIMException: resultReturnExecQuery - msg: %s",
+                (const char*)e.getMessage().getCString()));
             PEG_METHOD_EXIT();
             CMReturnWithString(
                 CMPI_RC_ERR_FAILED,
@@ -560,11 +381,13 @@ extern "C"
 
         if ((res == NULL) || (eRef == NULL))
         {
-            PEG_TRACE_CSTRING(
+            PEG_TRACE((
                 TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
-                "Invalid parameter res || eRef in \
-                CMPI_Result:resultReturnObjectPath");
+                ((res==0) ? (Tracer::LEVEL1) : (Tracer::LEVEL3)),
+                "Invalid parameter res (%p) || eRef (%p) "
+                    "in CMPI_Result:resultReturnObjectPath",
+                res,
+                eRef));
             PEG_METHOD_EXIT();
             CMReturn(CMPI_RC_ERR_INVALID_PARAMETER);
         }
@@ -572,7 +395,7 @@ extern "C"
         {
             PEG_TRACE_CSTRING(
                 TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Invalid parameter eRef->hdl in \
                 CMPI_Result:resultReturnObjectPath");
             PEG_METHOD_EXIT();
@@ -591,10 +414,10 @@ extern "C"
         }
         catch (const CIMException &e)
         {
-            PEG_TRACE_STRING(
-                TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
-                "Exception: resultReturnObjectPath - msg: " + e.getMessage());
+            PEG_TRACE((TRC_CMPIPROVIDERINTERFACE,Tracer::LEVEL1,
+                "CIMException: resultReturnObjectPath - msg: %s",
+                (const char*)e.getMessage().getCString()));
+
             PEG_METHOD_EXIT();
             CMReturnWithString(
                 CMPI_RC_ERR_FAILED,
@@ -614,7 +437,7 @@ extern "C"
         {
             PEG_TRACE_CSTRING(
                 TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Invalid parameter in \
                 CMPI_Result:resultReturnInstDone");
             PEG_METHOD_EXIT();
@@ -630,10 +453,10 @@ extern "C"
         }
         catch (const CIMException &e)
         {
-            PEG_TRACE_STRING(
-                TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
-                "Exception: resultReturnInstDone - msg: " + e.getMessage());
+            PEG_TRACE((TRC_CMPIPROVIDERINTERFACE,Tracer::LEVEL1,
+                "CIMException: resultReturnInstDone - msg: %s",
+                (const char*)e.getMessage().getCString()));
+
             PEG_METHOD_EXIT();
             CMReturnWithString(
                 CMPI_RC_ERR_FAILED,
@@ -653,7 +476,7 @@ extern "C"
         {
             PEG_TRACE_CSTRING(
                 TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Invalid parameter in \
                 CMPI_Result:resultReturnRefDone");
             PEG_METHOD_EXIT();
@@ -669,10 +492,10 @@ extern "C"
         }
         catch (const CIMException &e)
         {
-            PEG_TRACE_STRING(
-                TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
-                "Exception: resultReturnRefDone - msg: " + e.getMessage());
+            PEG_TRACE((TRC_CMPIPROVIDERINTERFACE,Tracer::LEVEL1,
+                "CIMException: resultReturnRefDone - msg: %s",
+                (const char*)e.getMessage().getCString()));
+
             PEG_METHOD_EXIT();
             CMReturnWithString(
                 CMPI_RC_ERR_FAILED,
@@ -692,7 +515,7 @@ extern "C"
         {
             PEG_TRACE_CSTRING(
                 TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Invalid parameter in \
                 CMPI_Result:resultReturnDataDone");
             PEG_METHOD_EXIT();
@@ -708,10 +531,10 @@ extern "C"
         }
         catch (const CIMException &e)
         {
-            PEG_TRACE_STRING(
-                TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
-                "Exception: resultReturnDataDone - msg: " + e.getMessage());
+            PEG_TRACE((TRC_CMPIPROVIDERINTERFACE,Tracer::LEVEL1,
+                "CIMException: resultReturnDataDone - msg: %s",
+                (const char*)e.getMessage().getCString()));
+
             PEG_METHOD_EXIT();
             CMReturnWithString(
                 CMPI_RC_ERR_FAILED,
@@ -732,7 +555,7 @@ extern "C"
         {
             PEG_TRACE_CSTRING(
                 TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Invalid parameter in \
                 CMPI_Result:resultReturnMethDone");
             PEG_METHOD_EXIT();
@@ -748,10 +571,10 @@ extern "C"
         }
         catch (const CIMException &e)
         {
-            PEG_TRACE_STRING(
-                TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
-                "Exception: resultReturnMethDone - msg: " + e.getMessage());
+            PEG_TRACE((TRC_CMPIPROVIDERINTERFACE,Tracer::LEVEL1,
+                "CIMException: resultReturnMethDone - msg: %s",
+                (const char*)e.getMessage().getCString()));
+
             PEG_METHOD_EXIT();
             CMReturnWithString(
                 CMPI_RC_ERR_FAILED,
@@ -771,7 +594,7 @@ extern "C"
         {
             PEG_TRACE_CSTRING(
                 TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Invalid parameter in \
                 CMPI_Result:resultReturnObjDone");
             PEG_METHOD_EXIT();
@@ -787,10 +610,10 @@ extern "C"
         }
         catch (const CIMException &e)
         {
-            PEG_TRACE_STRING(
-                TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
-                "Exception: resultReturnObjDone - msg: " + e.getMessage());
+            PEG_TRACE((TRC_CMPIPROVIDERINTERFACE,Tracer::LEVEL1,
+                "CIMException: resultReturnObjDone - msg: %s",
+                (const char*)e.getMessage().getCString()));
+
             PEG_METHOD_EXIT();
             CMReturnWithString(
                 CMPI_RC_ERR_FAILED,
@@ -810,7 +633,7 @@ extern "C"
         {
             PEG_TRACE_CSTRING(
                 TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Invalid parameter in \
                 CMPI_Result:resultReturnExecQueryDone");
             PEG_METHOD_EXIT();
@@ -826,11 +649,10 @@ extern "C"
         }
         catch (const CIMException &e)
         {
-            PEG_TRACE_STRING(
-                TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
-                "Exception: resultReturnExecQueryDone - msg: "
-                + e.getMessage());
+            PEG_TRACE((TRC_CMPIPROVIDERINTERFACE,Tracer::LEVEL1,
+                "CIMException: resultReturnExecQueryDone - msg: %s",
+                (const char*)e.getMessage().getCString()));
+
             PEG_METHOD_EXIT();
             CMReturnWithString(
                 CMPI_RC_ERR_FAILED,
@@ -853,7 +675,7 @@ extern "C"
         {
             PEG_TRACE_CSTRING(
                 TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Invalid parameter eRes->hdl in \
                 CMPI_Result:resultReturnError");
             PEG_METHOD_EXIT();
@@ -864,7 +686,7 @@ extern "C"
         {
             PEG_TRACE_CSTRING(
                 TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Invalid handle in \
                 CMPI_Result:resultReturnError");
             PEG_METHOD_EXIT();
@@ -1091,7 +913,7 @@ CMPI_ResultOnStack::~CMPI_ResultOnStack()
             else
             if (ft==CMPI_ResultExecQueryOnStack_Ftab)
                ((ExecQueryResponseHandler*)hdl)->processing();
-            else 
+            else
                ((ResponseHandler*)hdl)->processing();  // shoul not get here
         }
         if ((flags & RESULT_done)==0)
