@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -39,7 +37,7 @@
 #include "CMPI_String.h"
 #include "CMPI_SelectExpAccessor_WQL.h"
 
-#ifndef PEGASUS_DISABLE_CQL
+#ifdef PEGASUS_ENABLE_CQL
 # include "CMPI_SelectExpAccessor_CQL.h"
 # include <Pegasus/CQL/CQLSelectStatement.h>
 # include <Pegasus/CQL/CQLParser.h>
@@ -63,8 +61,8 @@ extern "C"
         {
             /**
                 Do not call unlinkAndDelete - b/c the CMPI_Object::
-                unlinkAndDelete casts the structure to a CMPI_Object and 
-                deletes it. But this is a CMPI_SelectExp structure so not 
+                unlinkAndDelete casts the structure to a CMPI_Object and
+                deletes it. But this is a CMPI_SelectExp structure so not
                 all of the variables get deleted. Hence we delete them here.
                 ((CMPI_Object*)se)->unlinkAndDelete();
             */
@@ -75,12 +73,12 @@ extern "C"
         CMReturn (CMPI_RC_OK);
     }
 
-    /** 
+    /**
        This will not clone all the CMPISelectExp objects. It clones only when
        original object has either CQLSelectStatement or WQLSelectStatement.
        Any other properties of original object may cause clone to retun error
        CMPI_RC_ERR_NOT_SUPPORTED. Use this only when you have just created
-      CMPISelectExp object with CMNewselectExp 
+      CMPISelectExp object with CMNewselectExp
       (broker,query,lang,projection,rc)
     */
 
@@ -94,8 +92,8 @@ extern "C"
         CMPI_SelectExp *new_se;
         CMPI_SelectExp *se = (CMPI_SelectExp*) eSx;
 
-        if( 
-#ifndef PEGASUS_DISABLE_CQL
+        if(
+#ifdef PEGASUS_ENABLE_CQL
         !se->cql_stmt &&
 #endif
         !se->wql_stmt || se->_context || se->hdl )
@@ -105,14 +103,14 @@ extern "C"
             return NULL;
         }
 
-#ifndef PEGASUS_DISABLE_CQL
+#ifdef PEGASUS_ENABLE_CQL
         CQLSelectStatement *cql_stmt;
 #endif
 
         WQLSelectStatement *wql_stmt;
         Boolean  disable_cql = true;
 
-#ifndef PEGASUS_DISABLE_CQL
+#ifdef PEGASUS_ENABLE_CQL
         if( se->cql_stmt )
         {
             cql_stmt = new CQLSelectStatement (*se->cql_stmt);
@@ -132,7 +130,7 @@ extern "C"
     }
 
     /**
-       Helper functions 
+       Helper functions
     */
     PEGASUS_STATIC CMPIBoolean _check_WQL (
         CMPI_SelectExp * sx,
@@ -150,18 +148,18 @@ extern "C"
             }
             catch( const Exception &e )
             {
-                PEG_TRACE_STRING(
-                    TRC_CMPIPROVIDERINTERFACE,
-                    Tracer::LEVEL2,
-                    "Exception: _check_WQL - msg: " + e.getMessage());
-                if( rc ) 
+                PEG_TRACE((TRC_CMPIPROVIDERINTERFACE,Tracer::LEVEL1,
+                    "Exception: _check_WQL - msg: %s",
+                    (const char*)e.getMessage().getCString()));
+
+                if( rc )
                 {
                     CMSetStatusWithString(
                         rc,
                         CMPI_RC_ERR_INVALID_QUERY,
                         (CMPIString*)string2CMPIString(e.getMessage()));
                 }
-                
+
                 delete stmt;
                 PEG_METHOD_EXIT();
                 return false;
@@ -170,7 +168,7 @@ extern "C"
             {
                 PEG_TRACE_CSTRING(
                     TRC_CMPIPROVIDERINTERFACE,
-                    Tracer::LEVEL2,
+                    Tracer::LEVEL1,
                     "Exception: Unknown Exception in _check_WQL");
                 delete stmt;
                 CMSetStatus (rc, CMPI_RC_ERR_INVALID_QUERY);
@@ -178,16 +176,16 @@ extern "C"
                 return false;
             }
             /**
-               Only set it for success 
+               Only set it for success
             */
             sx->wql_stmt = stmt;
-                                 
+
         /* sx->wql_stmt ... */
         }
         PEG_METHOD_EXIT();
         return true;
     }
-#ifndef PEGASUS_DISABLE_CQL
+#ifdef PEGASUS_ENABLE_CQL
     PEGASUS_STATIC CMPIBoolean _check_CQL (
         CMPI_SelectExp * sx,
         CMPIStatus * rc)
@@ -199,7 +197,7 @@ extern "C"
         if( sx->cql_stmt == NULL )
         {
             /**
-                The constructor should set this to a valid pointer. 
+                The constructor should set this to a valid pointer.
             */
             if( sx->_context == NULL )
             {
@@ -217,10 +215,10 @@ extern "C"
             }
             catch( const Exception &e )
             {
-                PEG_TRACE_STRING(
-                    TRC_CMPIPROVIDERINTERFACE,
-                    Tracer::LEVEL2,
-                    "Exception: _check_CQL - msg: " + e.getMessage());
+                PEG_TRACE((TRC_CMPIPROVIDERINTERFACE,Tracer::LEVEL1,
+                    "Exception: _check_CQL - msg: %s",
+                    (const char*)e.getMessage().getCString()));
+
                 if( rc )
                 {
                     CMSetStatusWithString(
@@ -235,7 +233,7 @@ extern "C"
             {
                 PEG_TRACE_CSTRING(
                     TRC_CMPIPROVIDERINTERFACE,
-                    Tracer::LEVEL2,
+                    Tracer::LEVEL1,
                     "Exception: Unknown Exception in _check_CQL");
                 CMSetStatus (rc, CMPI_RC_ERR_INVALID_QUERY);
                 fail = true;
@@ -265,7 +263,7 @@ extern "C"
         {
             PEG_TRACE_CSTRING(
                 TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Invalid Parameter in \
                 CMPI_SelectExp:selxEvaluate");
             CMSetStatus (rc, CMPI_RC_ERR_INVALID_PARAMETER);
@@ -276,7 +274,7 @@ extern "C"
         {
             PEG_TRACE_CSTRING(
                 TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Invalid parameter inst->hdl in \
                 CMPI_SelectExp:selxEvaluate");
             CMSetStatus (rc, CMPI_RC_ERR_INVALID_PARAMETER);
@@ -286,7 +284,7 @@ extern "C"
         CIMInstance *instance = (CIMInstance *) inst->hdl;
 
         /**
-           WQL 
+           WQL
         */
         if( strncmp (sx->lang.getCString (),
         CALL_SIGN_WQL, CALL_SIGN_WQL_SIZE) == 0 )
@@ -300,10 +298,10 @@ extern "C"
                 }
                 catch( const Exception &e )
                 {
-                    PEG_TRACE_STRING(
-                        TRC_CMPIPROVIDERINTERFACE,
-                        Tracer::LEVEL2,
-                        "Exception: selxEvaluate - msg: " + e.getMessage());
+                    PEG_TRACE((TRC_CMPIPROVIDERINTERFACE,Tracer::LEVEL1,
+                        "Exception: selxEvaluateWQL - msg: %s",
+                        (const char*)e.getMessage().getCString()));
+
                     if( rc )
                     {
                         CMSetStatusWithString(rc,CMPI_RC_ERR_FAILED,
@@ -316,7 +314,7 @@ extern "C"
                 {
                     PEG_TRACE_CSTRING(
                         TRC_CMPIPROVIDERINTERFACE,
-                        Tracer::LEVEL2,
+                        Tracer::LEVEL1,
                         "Exception: Unknown Exception in selxEvaluate");
                     CMSetStatus (rc, CMPI_RC_ERR_FAILED);
                     PEG_METHOD_EXIT();
@@ -330,9 +328,9 @@ extern "C"
             }
         }
         /**
-         CIM:CQL 
+         CIM:CQL
        */
-#ifndef PEGASUS_DISABLE_CQL
+#ifdef PEGASUS_ENABLE_CQL
         if( (strncmp (sx->lang.getCString(),
         CALL_SIGN_CQL, CALL_SIGN_CQL_SIZE) == 0) ||
         (strncmp (sx->lang.getCString(),
@@ -347,10 +345,10 @@ extern "C"
                 }
                 catch( const Exception &e )
                 {
-                    PEG_TRACE_STRING(
-                        TRC_CMPIPROVIDERINTERFACE,
-                        Tracer::LEVEL2,
-                        "Exception: selxEvaluate - msg: " + e.getMessage());
+                    PEG_TRACE((TRC_CMPIPROVIDERINTERFACE,Tracer::LEVEL1,
+                        "Exception: selxEvaluateCQL - msg: %s",
+                        (const char*)e.getMessage().getCString()));
+
                     if( rc )
                     {
                         CMSetStatusWithString(
@@ -365,7 +363,7 @@ extern "C"
                 {
                     PEG_TRACE_CSTRING(
                         TRC_CMPIPROVIDERINTERFACE,
-                        Tracer::LEVEL2,
+                        Tracer::LEVEL1,
                         "Exception: Unknown Exception in selxEvaluate");
                     CMSetStatus (rc, CMPI_RC_ERR_FAILED);
                     PEG_METHOD_EXIT();
@@ -380,7 +378,7 @@ extern "C"
         }
 #endif
          /**
-          Tried some other weird query language which we don't support 
+          Tried some other weird query language which we don't support
         */
         CMSetStatus (rc, CMPI_RC_ERR_NOT_SUPPORTED);
         PEG_METHOD_EXIT();
@@ -400,7 +398,7 @@ extern "C"
         {
             PEG_TRACE_CSTRING(
                 TRC_CMPIPROVIDERINTERFACE,
-                Tracer::LEVEL2,
+                Tracer::LEVEL1,
                 "Invalid Parameter in \
                 CMPI_SelectExp:selxEvaluateUsingAccessor");
             CMSetStatus (rc, CMPI_RC_ERR_INVALID_PARAMETER);
@@ -422,11 +420,10 @@ extern "C"
                 }
                 catch( const Exception &e )
                 {
-                    PEG_TRACE_STRING(
-                        TRC_CMPIPROVIDERINTERFACE,
-                        Tracer::LEVEL2,
-                        "Exception: selxEvaluateUsingAccessor - msg: " +
-                        e.getMessage());
+                    PEG_TRACE((TRC_CMPIPROVIDERINTERFACE,Tracer::LEVEL1,
+                        "Exception: selxEvaluateUsingAccessorWQL - msg: %s",
+                        (const char*)e.getMessage().getCString()));
+
                     if( rc )
                     {
                         CMSetStatusWithString(
@@ -441,7 +438,7 @@ extern "C"
                 {
                     PEG_TRACE_CSTRING(
                         TRC_CMPIPROVIDERINTERFACE,
-                        Tracer::LEVEL2,
+                        Tracer::LEVEL1,
                         "Exception: Unknown Exception in \
                         selxEvaluateUsingAccessor");
                     CMSetStatus (rc, CMPI_RC_ERR_FAILED);
@@ -455,7 +452,7 @@ extern "C"
                 return false;
             }
         }
-#ifndef PEGASUS_DISABLE_CQL
+#ifdef PEGASUS_ENABLE_CQL
         if( (strncmp (sx->lang.getCString(),
             CALL_SIGN_CQL, CALL_SIGN_CQL_SIZE) == 0) ||
             (strncmp (sx->lang.getCString(),
@@ -472,11 +469,10 @@ extern "C"
                 }
                 catch( const Exception &e )
                 {
-                    PEG_TRACE_STRING(
-                        TRC_CMPIPROVIDERINTERFACE,
-                        Tracer::LEVEL2,
-                        "Exception: selxEvaluateUsingAccessor - msg: " +
-                        e.getMessage());
+                    PEG_TRACE((TRC_CMPIPROVIDERINTERFACE,Tracer::LEVEL1,
+                        "Exception: selxEvaluateUsingAccessorCQL - msg: %s",
+                        (const char*)e.getMessage().getCString()));
+
                     if( rc )
                     {
                         CMSetStatusWithString(rc,CMPI_RC_ERR_FAILED,
@@ -489,7 +485,7 @@ extern "C"
                 {
                     PEG_TRACE_CSTRING(
                         TRC_CMPIPROVIDERINTERFACE,
-                        Tracer::LEVEL2,
+                        Tracer::LEVEL1,
                         "Exception: Unknown Exception in \
                         selxEvaluateUsingAccessor");
                     CMSetStatus (rc, CMPI_RC_ERR_FAILED);
@@ -544,11 +540,10 @@ extern "C"
                 }
                 catch( const Exception &e )
                 {
-                    PEG_TRACE_STRING(
-                        TRC_CMPIPROVIDERINTERFACE,
-                        Tracer::LEVEL2,
-                        "Exception: selxGetDOC - msg: " +
-                        e.getMessage());
+                    PEG_TRACE((TRC_CMPIPROVIDERINTERFACE,Tracer::LEVEL1,
+                        "Exception: selxGetDOCWQL - msg: %s",
+                        (const char*)e.getMessage().getCString()));
+
                     if( rc )
                     {
                         CMSetStatusWithString(
@@ -569,9 +564,9 @@ extern "C"
             }
             sc = (CMPISelectCond *) new CMPI_SelectCond (sx->tableau, 0);
         }
-#ifndef PEGASUS_DISABLE_CQL
+#ifdef PEGASUS_ENABLE_CQL
         if( (strncmp (sx->lang.getCString(),
-             CALL_SIGN_CQL, CALL_SIGN_CQL_SIZE) == 0) |
+             CALL_SIGN_CQL, CALL_SIGN_CQL_SIZE) == 0) ||
              (strncmp (sx->lang.getCString(),
              "CIM:CQL", 7) == 0) )
         {
@@ -596,11 +591,10 @@ extern "C"
                 }
                 catch( const Exception &e )
                 {
-                    PEG_TRACE_STRING(
-                        TRC_CMPIPROVIDERINTERFACE,
-                        Tracer::LEVEL2,
-                        "Exception: selxGetDOC - msg: " +
-                        e.getMessage());
+                    PEG_TRACE((TRC_CMPIPROVIDERINTERFACE,Tracer::LEVEL1,
+                        "Exception: selxGetDOCCQL - msg: %s",
+                        (const char*)e.getMessage().getCString()));
+
                     if( rc ) CMSetStatusWithString(rc,CMPI_RC_ERR_FAILED,
                         (CMPIString*)string2CMPIString(e.getMessage()));
                     if( dnf )
@@ -623,8 +617,8 @@ extern "C"
             return reinterpret_cast < CMPISelectCond * >(obj);
         }
 
-        /* 
-          If the sc was null, we just exit 
+        /*
+          If the sc was null, we just exit
         */
         CMSetStatus (rc, CMPI_RC_ERR_FAILED);
         PEG_METHOD_EXIT();
@@ -642,7 +636,7 @@ extern "C"
 
 }
 
-static CMPISelectExpFT selx_FT = 
+static CMPISelectExpFT selx_FT =
 {
     CMPICurrentVersion,
     selxRelease,
@@ -660,19 +654,19 @@ CMPI_SelectExp::~CMPI_SelectExp()
 {
     delete wql_stmt;
     delete wql_dnf;
-#ifndef PEGASUS_DISABLE_CQL
+#ifdef PEGASUS_ENABLE_CQL
     delete cql_dnf;
     delete cql_stmt;
 #endif
 }
 CMPI_SelectExp::CMPI_SelectExp (
     const OperationContext & ct,
-    QueryContext * context, 
+    QueryContext * context,
     String cond_,
     String lang_):ctx (ct),cond (cond_),lang (lang_),
                   _context (context),persistent(true)
 {
-    /** 
+    /**
       We do NOT add ourselves to the CMPI_Object as this is a persitent object.
        Look at the other construtors.
      */
@@ -680,7 +674,7 @@ CMPI_SelectExp::CMPI_SelectExp (
     ft = CMPI_SelectExp_Ftab;
     wql_dnf = NULL;
     wql_stmt = NULL;
-#ifndef PEGASUS_DISABLE_CQL
+#ifdef PEGASUS_ENABLE_CQL
     cql_stmt = NULL;
     cql_dnf = NULL;
 #endif
@@ -703,7 +697,7 @@ CMPI_SelectExp::CMPI_SelectExp (
     ft = CMPI_SelectExp_Ftab;
     props = NULL;
     wql_dnf = NULL;
-#ifndef PEGASUS_DISABLE_CQL
+#ifdef PEGASUS_ENABLE_CQL
     cql_dnf = NULL;
     cql_stmt = NULL;
 #endif
@@ -713,9 +707,9 @@ CMPI_SelectExp::CMPI_SelectExp (
     lang = CALL_SIGN_WQL;
 }
 
-#ifndef PEGASUS_DISABLE_CQL
+#ifdef PEGASUS_ENABLE_CQL
 CMPI_SelectExp::CMPI_SelectExp (CQLSelectStatement * st, Boolean persistent_,
-    QueryContext *context):ctx (OperationContext ()),cql_stmt (st), 
+    QueryContext *context):ctx (OperationContext ()),cql_stmt (st),
     _context(context), persistent (persistent_)
 {
     /** Adding the object to the garbage collector.
