@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
 //
-//==============================================================================
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -179,12 +177,12 @@ CIMValue value2CIMValue(const CMPIValue* data, const CMPIType type, CMPIrc *rc)
         {
             CopyToStringArray(String,string->hdl)
         }
-        else 
+        else
         if( aType == CMPI_charsptr )
         {
             CopyCharsptrToStringArray(String,chars)
         }
-        else 
+        else
         if( aType == CMPI_string )
         {
             CopyToStringArray(String,string->hdl)
@@ -225,11 +223,9 @@ CIMValue value2CIMValue(const CMPIValue* data, const CMPIType type, CMPIrc *rc)
                 case CMPI_dateTime:
                     CopyToEncArray(CIMDateTime,dateTime);
                     break;
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
                 case CMPI_instance:
                     CopyToEncArray(CIMObject,inst);
                     break;
-#endif
                 case CMPI_boolean:
                     CopyToArray(Boolean,boolean);
                     break;
@@ -349,10 +345,10 @@ CIMValue value2CIMValue(const CMPIValue* data, const CMPIType type, CMPIrc *rc)
                 else
                 {
                     return CIMValue(CIMTYPE_OBJECT, false);
-                }   
+                }
                 break;
 
-            case CMPI_ref:      
+            case CMPI_ref:
                 if( data->ref && data->ref->hdl )
                 {
                     v.set(*((CIMObjectPath*)data->ref->hdl));
@@ -362,10 +358,10 @@ CIMValue value2CIMValue(const CMPIValue* data, const CMPIType type, CMPIrc *rc)
                     return CIMValue(CIMTYPE_REFERENCE, false);
                 }
                 break;
-            case CMPI_dateTime: 
+            case CMPI_dateTime:
                 if( data->dateTime && data->dateTime->hdl )
                 {
-                    v.set(*((CIMDateTime*)data->dateTime->hdl)); 
+                    v.set(*((CIMDateTime*)data->dateTime->hdl));
                 }
                 else
                 {
@@ -499,7 +495,6 @@ CMPIrc value2CMPIData(const CIMValue& v, CMPIType t, CMPIData *data)
                 case CMPI_dateTime:
                     CopyFromEncArray(CIMDateTime,CMPIDateTime,dateTime);
                     break;
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
                 case CMPI_instance:
                     if (v.getType() == CIMTYPE_OBJECT)
                     {
@@ -509,14 +504,13 @@ CMPIrc value2CMPIData(const CIMValue& v, CMPIType t, CMPIData *data)
                         {
                           aData[i].value.inst = reinterpret_cast<CMPIInstance*>(
                                 new CMPI_Object(new CIMInstance(tmpObjs[i])));
-                        } 
+                        }
                     }
                     else
                     {
                         CopyFromEncArray(CIMInstance,CMPIInstance,inst);
                     }
                     break;
-#endif
                 case CMPI_boolean:
                     CopyFromArray(Boolean,boolean);
                     break;
@@ -544,7 +538,7 @@ CMPIrc value2CMPIData(const CIMValue& v, CMPIType t, CMPIData *data)
 
     //Start of non-array processing
     //Ckecking for Signed integers
-    else 
+    else
     if( (t & (CMPI_UINT|CMPI_SINT)) == CMPI_SINT )
     {
         switch( t )
@@ -570,7 +564,7 @@ CMPIrc value2CMPIData(const CIMValue& v, CMPIType t, CMPIData *data)
     }
 
     //Check for CMPI_string data type
-    else 
+    else
     if( t == CMPI_string )
     {
         String str;
@@ -628,11 +622,7 @@ CMPIrc value2CMPIData(const CIMValue& v, CMPIType t, CMPIData *data)
                     }
                     else
                     {
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
                         v.get(inst);
-#else
-                        return CMPI_RC_ERR_NOT_SUPPORTED;
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
                     }
 
                     data->value.inst = reinterpret_cast<CMPIInstance*>(
@@ -691,10 +681,8 @@ CMPIType type2CMPIType(CIMType pt, int array)
         CMPI_string,     // STRING,
         CMPI_dateTime,   // DATETIME,
         CMPI_ref,        // REFERENCE
-        CMPI_instance    // Embedded Object
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
-        , CMPI_instance  // Embedded Instance
-#endif // PEGASUS_EMBEDDED_INSTANCE_SUPPORT
+        CMPI_instance,    // Embedded Object
+        CMPI_instance  // Embedded Instance
     };
     int t=types[pt];
     if( array )
@@ -762,10 +750,8 @@ CIMType type2CIMType(CMPIType pt)
 
         case CMPI_ref:
             return CIMTYPE_REFERENCE;
-#ifdef PEGASUS_EMBEDDED_INSTANCE_SUPPORT
         case CMPI_instance:
             return CIMTYPE_INSTANCE;
-#endif
         default:
             return(CIMType)0;
     }
