@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
 //
-//==============================================================================
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -87,9 +85,9 @@ static char *resolveFileName (const char *filename)
 }
 
 /*
-    We need to have wrapper for newthread. When we invoke newThread from 
-    current thread, new thread is not managed by memeory management and may 
-    not have CMPIBroker and CMPIContext assosiated with that. 
+    We need to have wrapper for newthread. When we invoke newThread from
+    current thread, new thread is not managed by memeory management and may
+    not have CMPIBroker and CMPIContext assosiated with that.
     Add them in wrapper. -V 5245
 */
 struct startWrapperArg
@@ -114,13 +112,13 @@ void *_start_wrapper(void *arg_)
 }
 
 static CMPI_THREAD_TYPE newThread(
-    CMPI_THREAD_RETURN (CMPI_THREAD_CDECL *start )(void *), 
+    CMPI_THREAD_RETURN (CMPI_THREAD_CDECL *start )(void *),
     void *parm, int detached)
 {
 #if defined(CMPI_PLATFORM_LINUX_GENERIC_GNU)
     pthread_t t;
     pthread_attr_t tattr;
-    startWrapperArg *wparm = 
+    startWrapperArg *wparm =
         (startWrapperArg*)malloc ( sizeof ( struct startWrapperArg ) );
     wparm->start = start;
     wparm->arg = parm;
@@ -132,7 +130,7 @@ static CMPI_THREAD_TYPE newThread(
         pthread_attr_setdetachstate(&tattr, PTHREAD_CREATE_DETACHED);
         pthread_create(&t, &tattr, (void *(*)(void *)) _start_wrapper, wparm);
     }
-    else 
+    else
     {
         pthread_create(&t, NULL, (void *(*)(void *)) _start_wrapper, wparm);
     }
@@ -144,7 +142,7 @@ static CMPI_THREAD_TYPE newThread(
 
     pthread_t t;
     pthread_attr_t tattr;
-    startWrapperArg *wparm = 
+    startWrapperArg *wparm =
         (startWrapperArg*)malloc ( sizeof ( struct startWrapperArg ) );
     wparm->start = start;
     wparm->arg = parm;
@@ -156,17 +154,17 @@ static CMPI_THREAD_TYPE newThread(
         pthread_attr_setdetachstate(&tattr, PTHREAD_CREATE_DETACHED);
         pthread_create(&t, &tattr, (void *(*)(void *)) _start_wrapper, wparm);
     }
-    else 
+    else
     {
         pthread_create(&t, NULL, (void *(*)(void *)) _start_wrapper, wparm);
     }
 
-    return(CMPI_THREAD_TYPE) &t;
+    return(CMPI_THREAD_TYPE) t;
 #elif defined PEGASUS_OS_TYPE_WINDOWS
 
     unsigned threadid = 0;
     HANDLE hThread;
-    startWrapperArg *wparm = 
+    startWrapperArg *wparm =
         (startWrapperArg*)malloc ( sizeof ( struct startWrapperArg ) );
     wparm->start = start;
     wparm->arg = parm;
@@ -179,6 +177,48 @@ static CMPI_THREAD_TYPE newThread(
 #endif
 }
 
+static int joinThread (
+    CMPI_THREAD_TYPE hdlThread,
+    CMPI_THREAD_RETURN *returnCode)
+{
+#if defined(PEGASUS_OS_TYPE_UNIX)
+   return pthread_join((pthread_t)hdlThread, returnCode);
+#elif defined(PEGASUS_OS_TYPE_WINDOWS)
+   WaitForSingleObject(hdlThread,INFINITE);
+   GetExitCodeThread(hdlThread,returnCode);
+   return CloseHandle(hdlThread);
+#else
+   #error Platform for Remote CMPI daemon not yet supported
+#endif
+}
+
+static int exitThread (CMPI_THREAD_RETURN returnCode)
+{
+
+#if defined(PEGASUS_OS_TYPE_UNIX)
+    pthread_exit (returnCode);
+    return 0;
+#elif defined(PEGASUS_OS_TYPE_WINDOWS)
+    returnCode=0;
+    _endthread();
+    return 0;  /* should never reach here */
+#else
+   #error Platform for Remote CMPI daemon not yet supported
+#endif
+}
+
+static int cancelThread (CMPI_THREAD_TYPE hdlThread)
+{
+#if defined(PEGASUS_OS_TYPE_UNIX)
+    return pthread_cancel ((pthread_t)hdlThread);
+#elif defined(PEGASUS_OS_TYPE_WINDOWS)
+    return TerminateThread(hdlThread,0);
+#else
+   #error Platform for Remote CMPI daemon not yet supported
+#endif
+}
+
+
 #ifdef CMPI_PLATFORM_ZOS_ZSERIES_IBM
 static int threadOnce (pthread_once_t *once, void (*init)(void))
 {
@@ -268,7 +308,7 @@ static CMPI_MUTEX_TYPE newMutex (int opt)
     return m;
 #elif defined(CMPI_PLATFORM_ZOS_ZSERIES_IBM)
     // pthread_mutex_t init_m;
-    pthread_mutex_t *new_mutex = 
+    pthread_mutex_t *new_mutex =
         (pthread_mutex_t*) calloc(1,sizeof(pthread_mutex_t));
     // PTHREAD_MUTEX_INITIALIZER;
     errno = 0;
@@ -371,14 +411,14 @@ static void destroyCondition (CMPI_COND_TYPE c)
 }
 
 static int timedCondWait(
-    CMPI_COND_TYPE c, 
-    CMPI_MUTEX_TYPE m, 
+    CMPI_COND_TYPE c,
+    CMPI_MUTEX_TYPE m,
     struct timespec *wait)
 {
 #if defined(CMPI_PLATFORM_LINUX_GENERIC_GNU)
     return pthread_cond_timedwait(
-        (pthread_cond_t*)c, 
-        (pthread_mutex_t*)m, 
+        (pthread_cond_t*)c,
+        (pthread_mutex_t*)m,
         wait);
 #elif defined(CMPI_PLATFORM_ZOS_ZSERIES_IBM)
     return pthread_cond_timedwait(
@@ -444,7 +484,7 @@ static int condWait(CMPI_COND_TYPE c, CMPI_MUTEX_TYPE m)
 #endif
 }
 
-static void threadSleep(int msec)
+static int threadSleep(CMPIUint32 msec)
 {
 #if defined(PEGASUS_HAVE_NANOSLEEP)
 
@@ -466,7 +506,7 @@ static void threadSleep(int msec)
     if (msec == 0)
     {
         Sleep(0);
-        return;
+        return 0;
     }
 
 
@@ -482,7 +522,7 @@ static void threadSleep(int msec)
     }
     while (end.millitm > now.millitm && end.time >= now.time);
 
-#elif defined(PEGASUS_PLATFORM_ZOS_ZSERIES_IBM)
+#elif defined(PEGASUS_OS_ZOS)
     int seconds;
     if (msec < 1000)
     {
@@ -500,15 +540,16 @@ static void threadSleep(int msec)
     sleep(msec / 1000);
 
 #endif
+    return 0;
 }
 
 static CMPIBrokerExtFT brokerExt_FT={
     CMPICurrentVersion,
     resolveFileName,
     newThread,
-    NULL,                      // Join not implemented yet
-    NULL,                      // exit not implemented yet
-    NULL,                      // cancel not implemented yet
+    joinThread,
+    exitThread,
+    cancelThread,
     threadSleep,
     threadOnce,
 
