@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
 //
-//==============================================================================
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 /*!
@@ -131,7 +129,7 @@ static void TCPCOMM_InstanceMI_enumInstanceNames(
     START_DEBUGGER;
     if (mi)
     {
-        rc = mi->ft->enumInstanceNames(mi, ctx, result, cop);;
+        rc = mi->ft->enumerateInstanceNames(mi, ctx, result, cop);;
     }
     else
     {
@@ -158,7 +156,8 @@ static void TCPCOMM_InstanceMI_enumInstances(
     START_DEBUGGER;
     if (mi)
     {
-        rc = mi->ft->enumInstances(mi, ctx, result, cop, (CONST char **)props);
+        rc = mi->ft->
+            enumerateInstances(mi, ctx, result, cop, (CONST char **)props);
     }
     else
     {
@@ -679,7 +678,7 @@ static void TCPCOMM_IndicationMI_activateFilter(
         socket,
         broker,
         PEGASUS_INDICATION_GLOBAL_CONTEXT);
-    char *indType = (__sft)->deserialize_string(socket, broker);
+    char *clsName = (__sft)->deserialize_string(socket, broker);
     CMPIBoolean firstActivation = (__sft)->deserialize_UINT8(socket);
     CMPIStatus rc;
     CMPIArray *r=NULL;
@@ -698,7 +697,7 @@ static void TCPCOMM_IndicationMI_activateFilter(
             mi,
             ctx,
             filter,
-            indType,
+            clsName,
             cop,
             firstActivation);;
     }
@@ -710,7 +709,7 @@ static void TCPCOMM_IndicationMI_activateFilter(
             ctx,
             result,
             filter,
-            indType,
+            clsName,
             cop,
             firstActivation);;
     }
@@ -735,7 +734,7 @@ static void TCPCOMM_IndicationMI_deActivateFilter(
         socket,
         broker,
         PEGASUS_INDICATION_GLOBAL_CONTEXT);
-    char *indType = (__sft)->deserialize_string(socket, broker);
+    char *clsName = (__sft)->deserialize_string(socket, broker);
     CMPIBoolean lastActivation = (__sft)->deserialize_UINT8(socket);
     CMPIStatus rc;
     CMPIArray *r=NULL;
@@ -754,7 +753,7 @@ static void TCPCOMM_IndicationMI_deActivateFilter(
             mi,
             ctx,
             filter,
-            indType,
+            clsName,
             cop,
             lastActivation);
     }
@@ -766,7 +765,7 @@ static void TCPCOMM_IndicationMI_deActivateFilter(
             ctx,
             result,
             filter,
-            indType,
+            clsName,
             cop,
             lastActivation);
     }
@@ -1607,7 +1606,7 @@ CMPIBoolean TCPCOMM_classPathIsA(
 
 CMPIStatus TCPCOMM_logMessage(
     const CMPIBroker* broker,
-    int severity ,
+    CMPISeverity severity ,
     const char *id,
     const char *text,
     const CMPIString *string)
@@ -1648,7 +1647,7 @@ CMPIStatus TCPCOMM_logMessage(
 
 CMPIStatus  TCPCOMM_trace(
     const CMPIBroker* broker,
-    int level,
+    CMPILevel level,
     const char *component,
     const char *text,
     const CMPIString *string)
