@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -115,7 +113,7 @@ Message* DefaultProviderManager::processMessage(Message* message)
         case CIM_DELETE_SUBSCRIPTION_REQUEST_MESSAGE:
         case CIM_EXPORT_INDICATION_REQUEST_MESSAGE:
         {
-            ProviderIdContainer providerId = 
+            ProviderIdContainer providerId =
                 request->operationContext.get(ProviderIdContainer::NAME);
 
             // resolve provider name
@@ -124,8 +122,8 @@ Message* DefaultProviderManager::processMessage(Message* message)
             // get cached or load new provider module
             ProviderOperationCounter poc(
                 _getProvider(
-                    name.getPhysicalName(), 
-                    name.getModuleName(), 
+                    name.getPhysicalName(),
+                    name.getModuleName(),
                     name.getLogicalName()));
 
             response = poc.GetProvider().processMessage(request);
@@ -150,27 +148,6 @@ Message* DefaultProviderManager::processMessage(Message* message)
             response = _handleSubscriptionInitCompleteRequest(request);
             break;
 
-// Note: The PG_Provider AutoStart property is not yet supported
-#if 0
-        case CIM_INITIALIZE_PROVIDER_REQUEST_MESSAGE:
-        {
-            ProviderIdContainer providerId = 
-                request->operationContext.get(ProviderIdContainer::NAME);
-
-            // resolve provider name
-            ProviderName name = _resolveProviderName(providerId);
-
-            // get cached or load new provider module
-            ProviderOperationCounter poc(
-                _getProvider(
-                    name.getPhysicalName(), 
-                    name.getModuleName(), 
-                    name.getLogicalName()));
-
-            break;
-        }
-#endif
-
         default:
             PEGASUS_ASSERT(0);
             break;
@@ -178,23 +155,23 @@ Message* DefaultProviderManager::processMessage(Message* message)
     }
     catch (CIMException& e)
     {
-        PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL2,
-            "CIMException: " + e.getMessage());
+        PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL1,"CIMException: %s",
+            (const char*)e.getMessage().getCString()));
         response = request->buildResponse();
         response->cimException = PEGASUS_CIM_EXCEPTION_LANG(
             e.getContentLanguages(), e.getCode(), e.getMessage());
     }
     catch (Exception& e)
     {
-        PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL2,
-            "Exception: " + e.getMessage());
+        PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL1,"Exception: %s",
+            (const char*)e.getMessage().getCString()));
         response = request->buildResponse();
         response->cimException = PEGASUS_CIM_EXCEPTION_LANG(
             e.getContentLanguages(), CIM_ERR_FAILED, e.getMessage());
     }
     catch (...)
     {
-        PEG_TRACE_CSTRING(TRC_PROVIDERMANAGER, Tracer::LEVEL2,
+        PEG_TRACE_CSTRING(TRC_PROVIDERMANAGER, Tracer::LEVEL1,
             "Exception: Unknown");
         response = request->buildResponse();
         response->cimException = PEGASUS_CIM_EXCEPTION(
@@ -223,7 +200,7 @@ CIMResponseMessage* DefaultProviderManager::_handleDisableModuleRequest(
         // get provider module name
         String moduleName;
         CIMInstance mInstance = request->providerModule;
-        Uint32 pos = mInstance.findProperty(CIMName("Name"));
+        Uint32 pos = mInstance.findProperty(PEGASUS_PROPERTYNAME_NAME);
         PEGASUS_ASSERT(pos != PEG_NOT_FOUND);
         mInstance.getProperty(pos).getValue().get(moduleName);
 
@@ -236,7 +213,7 @@ CIMResponseMessage* DefaultProviderManager::_handleDisableModuleRequest(
         {
             String pName;
             providerInstances[i].getProperty(
-                providerInstances[i].findProperty("Name")).
+                providerInstances[i].findProperty(PEGASUS_PROPERTYNAME_NAME)).
                     getValue().get(pName);
 
             Sint16 ret_value = _disableProvider(moduleName, pName);
@@ -262,19 +239,19 @@ CIMResponseMessage* DefaultProviderManager::_handleDisableModuleRequest(
     }
     catch (CIMException& e)
     {
-        PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL4,
-                         "Exception: " + e.getMessage());
+        PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL1,"CIMException: %s",
+            (const char*)e.getMessage().getCString()));
         cimException = e;
     }
     catch (Exception& e)
     {
-        PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL4,
-            "Exception: " + e.getMessage());
+        PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL1,"Exception: %s",
+            (const char*)e.getMessage().getCString()));
         cimException = CIMException(CIM_ERR_FAILED, e.getMessage());
     }
     catch (...)
     {
-        PEG_TRACE_CSTRING(TRC_PROVIDERMANAGER, Tracer::LEVEL4,
+        PEG_TRACE_CSTRING(TRC_PROVIDERMANAGER, Tracer::LEVEL1,
             "Exception: Unknown");
         cimException = PEGASUS_CIM_EXCEPTION_L(
             CIM_ERR_FAILED,
@@ -388,11 +365,13 @@ ProviderName DefaultProviderManager::_resolveProviderName(
     CIMValue genericValue;
 
     genericValue = providerId.getModule().getProperty(
-        providerId.getModule().findProperty("Name")).getValue();
+        providerId.getModule().findProperty(
+            PEGASUS_PROPERTYNAME_NAME)).getValue();
     genericValue.get(moduleName);
 
     genericValue = providerId.getProvider().getProperty(
-        providerId.getProvider().findProperty("Name")).getValue();
+        providerId.getProvider().findProperty(
+            PEGASUS_PROPERTYNAME_NAME)).getValue();
     genericValue.get(providerName);
 
     genericValue = providerId.getModule().getProperty(
@@ -404,11 +383,6 @@ ProviderName DefaultProviderManager::_resolveProviderName(
     if (resolvedFileName == String::EMPTY)
     {
         // Provider library not found
-        String moduleName;
-        genericValue = providerId.getModule().getProperty(
-            providerId.getModule().findProperty("Name")).getValue();
-        genericValue.get(moduleName);
-
         throw Exception(MessageLoaderParms(
             "ProviderManager.ProviderManagerService.PROVIDER_FILE_NOT_FOUND",
             "File \"$0\" was not found for provider module \"$1\".",
@@ -444,8 +418,8 @@ ProviderOperationCounter DefaultProviderManager::_getProvider(
 
     ProviderOperationCounter poc(pr);
 
-    PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL4,
-        "Returning Provider " + providerName);
+    PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL4,"Returning Provider %s",
+        (const char*)providerName.getCString()));
 
     PEG_METHOD_EXIT();
     return poc;
@@ -473,22 +447,23 @@ ProviderMessageHandler* DefaultProviderManager::_lookupProvider(
     ProviderMessageHandler* pr = 0;
     if (_providers.lookup(key, pr))
     {
-        PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL4,
-            "Found Provider " + providerName + " in Provider Manager Cache");
+        PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL4,
+            "Found Provider %s in Provider Manager Cache",
+            (const char*)providerName.getCString()));
     }
     else
     {
         // create provider
         pr = new ProviderMessageHandler(
-            moduleName, providerName, 
+            moduleName, providerName,
             0, _indicationCallback, _responseChunkCallback,
             _subscriptionInitComplete);
 
         // insert provider in provider table
         _providers.insert(key, pr);
 
-        PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL4,
-            "Created provider " + pr->getName());
+        PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL4,"Created provider %s",
+            (const char*)pr->getName().getCString()));
     }
 
     PEG_METHOD_EXIT();
@@ -517,8 +492,9 @@ ProviderMessageHandler* DefaultProviderManager::_initProvider(
         return provider;
     }
 
-    PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL4,
-        "Loading/Linking Provider Module " + moduleFileName);
+    PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL4,
+        "Loading/Linking Provider Module %s",
+        (const char*)moduleFileName.getCString()));
 
     // load the provider
     try
@@ -527,16 +503,16 @@ ProviderMessageHandler* DefaultProviderManager::_initProvider(
     }
     catch (...)
     {
-        PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL4,
-            "Exception caught Loading/Linking Provider Module " +
-            moduleFileName);
+        PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL1,
+            "Exception caught Loading/Linking Provider Module %s",
+            (const char*)moduleFileName.getCString()));
         PEG_METHOD_EXIT();
         throw;
     }
 
     // initialize the provider
-    PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL2,
-        "Initializing Provider " + provider->getName());
+    PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL2, "Initializing Provider %s",
+        (const char*)provider->getName().getCString()));
 
     CIMOMHandle* cimomHandle = new CIMOMHandle();
     provider->status.setCIMOMHandle(cimomHandle);
@@ -600,15 +576,16 @@ ProviderModule* DefaultProviderManager::_lookupModule(
     if (_modules.lookup(moduleFileName, module))
     {
         // found provider module in cache
-        PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL4,
-            "Found Provider Module " + moduleFileName +
-            " in Provider Manager Cache");
+        PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL4,
+            "Found Provider Module %s in Provider Manager Cache",
+            (const char*)moduleFileName.getCString()));
     }
     else
     {
         // provider module not found in cache, create provider module
-        PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL4,
-            "Creating Provider Module " + moduleFileName);
+        PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL4,
+            "Creating Provider Module %s",
+            (const char*)moduleFileName.getCString()));
 
         module = new ProviderModule(moduleFileName);
 
@@ -644,7 +621,7 @@ Boolean DefaultProviderManager::hasActiveProviders()
     catch (...)
     {
         // Unexpected exception; do not assume that no providers are loaded
-        PEG_TRACE_CSTRING(TRC_PROVIDERMANAGER, Tracer::LEVEL2,
+        PEG_TRACE_CSTRING(TRC_PROVIDERMANAGER, Tracer::LEVEL1,
             "Unexpected Exception in hasActiveProviders.");
         PEG_METHOD_EXIT();
         return true;
@@ -690,23 +667,25 @@ void DefaultProviderManager::unloadIdleProviders()
             struct timeval providerTime = {0, 0};
             provider->status.getLastOperationEndTime(&providerTime);
 
-            PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL4,
-                "provider->status.isIdle() returns: " +
-                CIMValue(provider->status.isIdle()).toString());
+            PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL4,
+                "provider->status.isIdle() returns: %s",
+                (const char*)CIMValue(provider->status.isIdle())
+                       .toString().getCString()));
 
             if (provider->status.isIdle() &&
                 ((now.tv_sec - providerTime.tv_sec) >
                  ((Sint32)PEGASUS_PROVIDER_IDLE_TIMEOUT_SECONDS)))
             {
-                PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL2,
-                    "Unloading idle provider: " + provider->getName());
+                PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL3,
+                    "Unloading idle provider: %s",
+                    (const char*)provider->getName().getCString()));
                 _unloadProvider(provider);
             }
         }
     }
     catch (...)
     {
-        PEG_TRACE_CSTRING(TRC_PROVIDERMANAGER, Tracer::LEVEL2,
+        PEG_TRACE_CSTRING(TRC_PROVIDERMANAGER, Tracer::LEVEL1,
             "Caught unexpected exception in unloadIdleProviders.");
     }
 
@@ -730,7 +709,7 @@ void DefaultProviderManager::_shutdownAllProviders()
             ProviderMessageHandler* provider = i.value();
             PEGASUS_ASSERT(provider != 0);
 
-            AutoMutex lock(provider->status.getStatusMutex());
+            AutoMutex lock2(provider->status.getStatusMutex());
 
             if (provider->status.isInitialized())
             {
@@ -740,7 +719,7 @@ void DefaultProviderManager::_shutdownAllProviders()
     }
     catch (...)
     {
-        PEG_TRACE_CSTRING(TRC_PROVIDERMANAGER, Tracer::LEVEL4,
+        PEG_TRACE_CSTRING(TRC_PROVIDERMANAGER, Tracer::LEVEL2,
             "Unexpected Exception in _shutdownAllProviders().");
     }
 
@@ -757,14 +736,15 @@ Sint16 DefaultProviderManager::_disableProvider(
     ProviderMessageHandler* pr = _lookupProvider(moduleName, providerName);
     if (!pr->status.isInitialized())
     {
-        PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL2,
-            "Provider " + providerName + " is not loaded");
+        PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL2,
+            "Provider %s is not loaded",
+            (const char*)providerName.getCString()));
         PEG_METHOD_EXIT();
         return 1;
     }
 
-    PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL4,
-        "Disable Provider " + pr->getName());
+    PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL4,"Disable Provider %s",
+        (const char*)pr->getName().getCString()));
     //
     // Check to see if there are pending requests. If there are pending
     // requests and the disable timeout has not expired, loop and wait one
@@ -793,15 +773,17 @@ Sint16 DefaultProviderManager::_disableProvider(
 
         if (pr->status.isInitialized())
         {
-            PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL4,
-                "Unloading Provider " + pr->getName());
+            PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL4,
+                "Unloading Provider %s",
+                (const char*)pr->getName().getCString()));
             _unloadProvider(pr);
         }
     }
     catch (...)
     {
-        PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL4,
-            "Unload provider failed " + pr->getName());
+        PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL2,
+            "Unload provider failed %s",
+            (const char*)pr->getName().getCString()));
         PEG_METHOD_EXIT();
         return -1;
     }
@@ -823,26 +805,28 @@ void DefaultProviderManager::_unloadProvider(ProviderMessageHandler* provider)
 
     if (provider->status.numCurrentOperations() > 0)
     {
-        PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL4,
-            "Provider cannot be unloaded due to pending operations: " +
-            provider->getName());
+        PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL4,
+            "Provider cannot be unloaded due to pending operations: %s",
+            (const char*)provider->getName().getCString()));
     }
     else
     {
-        PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL4,
-            "Terminating Provider " + provider->getName());
+        PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL4,
+            "Terminating Provider %s",
+            (const char*)provider->getName().getCString()));
 
         provider->terminate();
 
         // unload provider module
         PEGASUS_ASSERT(provider->status.getModule() != 0);
-        PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL2,
-            "Unloading provider module: " + provider->getName());
+        PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL3,
+            "Unloading provider module: %s",
+            (const char*)provider->getName().getCString()));
         provider->status.getModule()->unloadModule();
 
-        Logger::put(Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
-            "DefaultProviderManager:  Unloaded provider $0",
-            provider->getName());
+        PEG_TRACE((TRC_PROVIDERMANAGER,Tracer::LEVEL3,
+            "DefaultProviderManager: Unloaded provider %s",
+            (const char*)provider->getName().getCString()));
 
         // NOTE: The "delete provider->status.getCIMOMHandle()" operation
         //   was moved to be called after the unloadModule() call above
@@ -856,8 +840,9 @@ void DefaultProviderManager::_unloadProvider(ProviderMessageHandler* provider)
         //   above the unloadModule() call. See bugzilla 3669 for details.
 
         // delete the cimom handle
-        PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL4,
-            "Destroying provider's CIMOMHandle: " + provider->getName());
+        PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL4,
+            "Destroying provider's CIMOMHandle: %s",
+            (const char*)provider->getName().getCString()));
         delete provider->status.getCIMOMHandle();
 
         // set provider status to uninitialized
