@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -67,14 +65,14 @@
         }                                                              \
         catch (CIMException& e)                                        \
         {                                                              \
-            PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL4,            \
+            PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL1,            \
                 "Provider CIMException: %s",                           \
                 (const char*)e.getMessage().getCString()));            \
             handler.setCIMException(e);                                \
         }                                                              \
         catch (Exception& e)                                           \
         {                                                              \
-            PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL4,            \
+            PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL1,            \
                 "Provider Exception: %s",                              \
                 (const char*)e.getMessage().getCString()));            \
             handler.setStatus(                                         \
@@ -84,13 +82,13 @@
         }                                                              \
         catch (const PEGASUS_STD(exception)& e)                        \
         {                                                              \
-            PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL4,            \
+            PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL1,            \
                 "Provider exception: %s", e.what()));                  \
             handler.setStatus(CIM_ERR_FAILED, e.what());               \
         }                                                              \
         catch (...)                                                    \
         {                                                              \
-            PEG_TRACE_CSTRING(TRC_PROVIDERMANAGER, Tracer::LEVEL4,     \
+            PEG_TRACE_CSTRING(TRC_PROVIDERMANAGER, Tracer::LEVEL1,     \
                 "Provider unknown exception");                         \
             handler.setStatus(CIM_ERR_FAILED, "Unknown error.");       \
         }                                                              \
@@ -167,7 +165,7 @@ void ProviderMessageHandler::initialize(CIMOMHandle& cimom)
     }
     catch (...)
     {
-        PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL2,
+        PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL1,
             "Caught exception from provider %s initialize() method.",
             (const char*)_fullyQualifiedProviderName.getCString()));
         throw;
@@ -192,7 +190,7 @@ void ProviderMessageHandler::terminate()
     }
     catch (...)
     {
-        PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL2,
+        PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL1,
             "Caught exception from provider %s terminate() method.",
             (const char*)_fullyQualifiedProviderName.getCString()));
         throw;
@@ -305,23 +303,23 @@ CIMResponseMessage* ProviderMessageHandler::processMessage(
     }
     catch (CIMException& e)
     {
-        PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL2,
-            "CIMException: " + e.getMessage());
+        PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL1,"CIMException: %s",
+            (const char*)e.getMessage().getCString()));
         response = request->buildResponse();
         response->cimException = PEGASUS_CIM_EXCEPTION_LANG(
             e.getContentLanguages(), e.getCode(), e.getMessage());
     }
     catch (Exception& e)
     {
-        PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL2,
-            "Exception: " + e.getMessage());
+        PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL1,"Exception: %s",
+            (const char*)e.getMessage().getCString()));
         response = request->buildResponse();
         response->cimException = PEGASUS_CIM_EXCEPTION_LANG(
             e.getContentLanguages(), CIM_ERR_FAILED, e.getMessage());
     }
     catch (...)
     {
-        PEG_TRACE_CSTRING(TRC_PROVIDERMANAGER, Tracer::LEVEL2,
+        PEG_TRACE_CSTRING(TRC_PROVIDERMANAGER, Tracer::LEVEL1,
             "Exception: Unknown");
         response = request->buildResponse();
         response->cimException = PEGASUS_CIM_EXCEPTION(
@@ -371,10 +369,12 @@ CIMResponseMessage* ProviderMessageHandler::_handleGetInstanceRequest(
         request->instanceName.getClassName(),
         request->instanceName.getKeyBindings());
 
-    PEG_LOGGER_TRACE((Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
+    PEG_TRACE((
+        TRC_PROVIDERMANAGER,
+        Tracer::LEVEL3,
         "ProviderMessageHandler::_handleGetInstanceRequest - "
-            "Object path: $0",
-        objectPath.toString()));
+            "Object path: %s",
+        (const char*) objectPath.toString().getCString()));
 
     OperationContext providerContext(
         _createProviderOperationContext(request->operationContext));
@@ -426,10 +426,12 @@ CIMResponseMessage* ProviderMessageHandler::_handleEnumerateInstancesRequest(
         request->nameSpace,
         request->className);
 
-    PEG_LOGGER_TRACE((Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
+    PEG_TRACE((
+        TRC_PROVIDERMANAGER,
+        Tracer::LEVEL3,
         "ProviderMessageHandler::_handleEnumerateInstancesRequest - "
-            "Object path: $0",
-        objectPath.toString()));
+            "Object path: %s",
+        (const char*) objectPath.toString().getCString()));
 
     OperationContext providerContext(
         _createProviderOperationContext(request->operationContext));
@@ -482,10 +484,12 @@ CIMResponseMessage*
         request->nameSpace,
         request->className);
 
-    PEG_LOGGER_TRACE((Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
+    PEG_TRACE((
+        TRC_PROVIDERMANAGER,
+        Tracer::LEVEL3,
         "ProviderMessageHandler::_handleEnumerateInstanceNamesRequest - "
-            "Object path: $0",
-        objectPath.toString()));
+            "Object path: %s",
+        (const char*) objectPath.toString().getCString()));
 
     OperationContext providerContext(
         _createProviderOperationContext(request->operationContext));
@@ -535,10 +539,12 @@ CIMResponseMessage* ProviderMessageHandler::_handleCreateInstanceRequest(
         request->newInstance.getPath().getClassName(),
         request->newInstance.getPath().getKeyBindings());
 
-    PEG_LOGGER_TRACE((Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
+    PEG_TRACE((
+        TRC_PROVIDERMANAGER,
+        Tracer::LEVEL3,
         "ProviderMessageHandler::_handleCreateInstanceRequest - "
-            "Object path: $0",
-        objectPath.toString()));
+            "Object path: %s",
+        (const char*) objectPath.toString().getCString()));
 
     OperationContext providerContext(
         _createProviderOperationContext(request->operationContext));
@@ -589,10 +595,12 @@ CIMResponseMessage* ProviderMessageHandler::_handleModifyInstanceRequest(
         request->modifiedInstance.getPath().getClassName(),
         request->modifiedInstance.getPath().getKeyBindings());
 
-    PEG_LOGGER_TRACE((Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
+    PEG_TRACE((
+        TRC_PROVIDERMANAGER,
+        Tracer::LEVEL3,
         "ProviderMessageHandler::_handleModifyInstanceRequest - "
-            "Object path: $0",
-        objectPath.toString()));
+            "Object path: %s",
+        (const char*) objectPath.toString().getCString()));
 
     OperationContext providerContext(
         _createProviderOperationContext(request->operationContext));
@@ -645,10 +653,12 @@ CIMResponseMessage* ProviderMessageHandler::_handleDeleteInstanceRequest(
         request->instanceName.getClassName(),
         request->instanceName.getKeyBindings());
 
-    PEG_LOGGER_TRACE((Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
+    PEG_TRACE((
+        TRC_PROVIDERMANAGER,
+        Tracer::LEVEL3,
         "ProviderMessageHandler::_handleDeleteInstanceRequest - "
-            "Object path: $0",
-        objectPath.toString()));
+            "Object path: %s",
+        (const char*) objectPath.toString().getCString()));
 
     OperationContext providerContext(
         _createProviderOperationContext(request->operationContext));
@@ -697,10 +707,12 @@ CIMResponseMessage* ProviderMessageHandler::_handleExecQueryRequest(
         request->nameSpace,
         request->className);
 
-    PEG_LOGGER_TRACE((Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
+    PEG_TRACE((
+        TRC_PROVIDERMANAGER,
+        Tracer::LEVEL3,
         "ProviderMessageHandler::_handleExecQueryRequest - "
-            "Object path: $0",
-        objectPath.toString()));
+            "Object path: %s",
+        (const char*) objectPath.toString().getCString()));
 
     QueryExpression qx(request->queryLanguage,request->query);
 
@@ -754,10 +766,12 @@ CIMResponseMessage* ProviderMessageHandler::_handleAssociatorsRequest(
 
     objectPath.setKeyBindings(request->objectName.getKeyBindings());
 
-    PEG_LOGGER_TRACE((Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
+    PEG_TRACE((
+        TRC_PROVIDERMANAGER,
+        Tracer::LEVEL3,
         "ProviderMessageHandler::_handleAssociatorsRequest - "
-            "Object path: $0",
-        objectPath.toString()));
+            "Object path: %s",
+        (const char*) objectPath.toString().getCString()));
 
     CIMObjectPath assocPath(
         System::getHostName(),
@@ -820,10 +834,12 @@ CIMResponseMessage* ProviderMessageHandler::_handleAssociatorNamesRequest(
 
     objectPath.setKeyBindings(request->objectName.getKeyBindings());
 
-    PEG_LOGGER_TRACE((Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
+    PEG_TRACE((
+        TRC_PROVIDERMANAGER,
+        Tracer::LEVEL3,
         "ProviderMessageHandler::_handleAssociationNamesRequest - "
-            "Object path: $0",
-        objectPath.toString()));
+            "Object path: %s",
+        (const char*) objectPath.toString().getCString()));
 
     CIMObjectPath assocPath(
         System::getHostName(),
@@ -883,10 +899,12 @@ CIMResponseMessage* ProviderMessageHandler::_handleReferencesRequest(
 
     objectPath.setKeyBindings(request->objectName.getKeyBindings());
 
-    PEG_LOGGER_TRACE((Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
+    PEG_TRACE((
+        TRC_PROVIDERMANAGER,
+        Tracer::LEVEL3,
         "ProviderMessageHandler::_handleReferencesRequest - "
-            "Object path: $0",
-        objectPath.toString()));
+            "Object path: %s",
+        (const char*) objectPath.toString().getCString()));
 
     CIMObjectPath resultPath(
         System::getHostName(),
@@ -947,10 +965,12 @@ CIMResponseMessage* ProviderMessageHandler::_handleReferenceNamesRequest(
 
     objectPath.setKeyBindings(request->objectName.getKeyBindings());
 
-    PEG_LOGGER_TRACE((Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
+    PEG_TRACE((
+        TRC_PROVIDERMANAGER,
+        Tracer::LEVEL3,
         "ProviderMessageHandler::_handleReferenceNamesRequest - "
-            "Object path: $0",
-        objectPath.toString()));
+            "Object path: %s",
+        (const char*) objectPath.toString().getCString()));
 
     CIMObjectPath resultPath(
         System::getHostName(),
@@ -1035,10 +1055,13 @@ CIMResponseMessage* ProviderMessageHandler::_handleGetPropertyRequest(
         getInstanceRequest.instanceName.getClassName(),
         getInstanceRequest.instanceName.getKeyBindings());
 
-    PEG_LOGGER_TRACE((Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
+    PEG_TRACE((
+        TRC_PROVIDERMANAGER,
+        Tracer::LEVEL3,
         "ProviderMessageHandler::_handleGetPropertyRequest - "
-            "Object path: $0, Property: $1",
-        objectPath.toString(), request->propertyName.getString()));
+            "Object path: %s, Property: %s",
+        (const char*) objectPath.toString().getCString(),
+        (const char*) request->propertyName.getString().getCString()));
 
     OperationContext providerContext(
         _createProviderOperationContext(getInstanceRequest.operationContext));
@@ -1069,7 +1092,7 @@ CIMResponseMessage* ProviderMessageHandler::_handleGetPropertyRequest(
 
     if (response->cimException.getCode() == CIM_ERR_SUCCESS)
     {
-        CIMInstance instance = getInstanceResponse->cimInstance;
+        CIMInstance instance = getInstanceResponse->getCimInstance();
 
         Uint32 pos = instance.findProperty(request->propertyName);
 
@@ -1148,10 +1171,13 @@ CIMResponseMessage* ProviderMessageHandler::_handleSetPropertyRequest(
     ModifyInstanceResponseHandler handler(
         &modifyInstanceRequest, modifyInstanceResponse.get(), 0);
 
-    PEG_LOGGER_TRACE((Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
+    PEG_TRACE((
+        TRC_PROVIDERMANAGER,
+        Tracer::LEVEL3,
         "ProviderMessageHandler::_handleSetPropertyRequest - "
-            "Object path: $0, Property: $1",
-        objectPath.toString(), request->propertyName.getString()));
+            "Object path: %s, Property: %s",
+        (const char*) objectPath.toString().getCString(),
+        (const char*) request->propertyName.getString().getCString()));
 
     OperationContext providerContext(
         _createProviderOperationContext(request->operationContext));
@@ -1211,10 +1237,13 @@ CIMResponseMessage* ProviderMessageHandler::_handleInvokeMethodRequest(
         request->instanceName.getClassName(),
         request->instanceName.getKeyBindings());
 
-    PEG_LOGGER_TRACE((Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
+    PEG_TRACE((
+        TRC_PROVIDERMANAGER,
+        Tracer::LEVEL3,
         "ProviderMessageHandler::_handleInvokeMethodRequest - "
-            "Object path: $0, Method: $1",
-        objectPath.toString(), request->methodName.getString()));
+            "Object path: %s, Method: %s",
+        (const char*) objectPath.toString().getCString(),
+        (const char*) request->methodName.getString().getCString()));
 
     OperationContext providerContext(
         _createProviderOperationContext(request->operationContext));
@@ -1270,13 +1299,14 @@ CIMResponseMessage* ProviderMessageHandler::_handleCreateSubscriptionRequest(
         }
     }
 
-    PEG_LOGGER_TRACE((Logger::STANDARD_LOG, System::CIMSERVER,
-        Logger::TRACE,
+    PEG_TRACE((
+        TRC_PROVIDERMANAGER,
+        Tracer::LEVEL3,
         "ProviderMessageHandler::_handleCreateSubscriptionRequest - "
-            "Host name: $0  Name space: $1  Class name(s): $2",
-        System::getHostName(),
-        request->nameSpace.getString(),
-        temp));
+            "Host name: %s  Name space: %s  Class name(s): %s",
+        (const char*) System::getHostName().getCString(),
+        (const char*) request->nameSpace.getString().getCString(),
+        (const char*) temp.getCString()));
 
     //
     //  Save the provider instance from the request
@@ -1378,13 +1408,14 @@ CIMResponseMessage* ProviderMessageHandler::_handleModifySubscriptionRequest(
         }
     }
 
-    PEG_LOGGER_TRACE((Logger::STANDARD_LOG, System::CIMSERVER,
-        Logger::TRACE,
-        "ProviderMessageHandler::_handleCreateSubscriptionRequest - "
-            "Host name: $0  Name space: $1  Class name(s): $2",
-        System::getHostName(),
-        request->nameSpace.getString(),
-        temp));
+    PEG_TRACE((
+        TRC_PROVIDERMANAGER,
+        Tracer::LEVEL3,
+        "ProviderMessageHandler::_handleModifySubscriptionRequest - "
+            "Host name: %s  Name space: %s  Class name(s): %s",
+        (const char*) System::getHostName().getCString(),
+        (const char*) request->nameSpace.getString().getCString(),
+        (const char*) temp.getCString()));
 
     // convert arguments
 
@@ -1460,13 +1491,14 @@ CIMResponseMessage* ProviderMessageHandler::_handleDeleteSubscriptionRequest(
         }
     }
 
-    PEG_LOGGER_TRACE((Logger::STANDARD_LOG, System::CIMSERVER,
-        Logger::TRACE,
+    PEG_TRACE((
+        TRC_PROVIDERMANAGER,
+        Tracer::LEVEL3,
         "ProviderMessageHandler::_handleDeleteSubscriptionRequest - "
-            "Host name: $0  Name space: $1  Class name(s): $2",
-        System::getHostName(),
-        request->nameSpace.getString(),
-        temp));
+            "Host name: %s  Name space: %s  Class name(s): %s",
+        (const char*) System::getHostName().getCString(),
+        (const char*) request->nameSpace.getString().getCString(),
+        (const char*) temp.getCString()));
 
     Array<CIMObjectPath> classNames;
 
@@ -1600,7 +1632,7 @@ void ProviderMessageHandler::_enableIndications()
         }
         catch (...)
         {
-            PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL2,
+            PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL1,
                 "Caught exception from provider %s "
                     "enableIndications() method.",
                 (const char*)_fullyQualifiedProviderName.getCString()));
@@ -1613,25 +1645,21 @@ void ProviderMessageHandler::_enableIndications()
     }
     catch (Exception& e)
     {
-        PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL2,
-            "Exception: " + e.getMessage());
-
         Logger::put_l(Logger::ERROR_LOG, System::CIMSERVER, Logger::WARNING,
-            "ProviderManager.Default.DefaultProviderManager."
-                "ENABLE_INDICATIONS_FAILED",
-            "Failed to enable indications for provider $0: $1.",
-             _fullyQualifiedProviderName, e.getMessage());
+            MessageLoaderParms(
+                "ProviderManager.Default.DefaultProviderManager."
+                    "ENABLE_INDICATIONS_FAILED",
+                "Failed to enable indications for provider $0: $1.",
+                 _fullyQualifiedProviderName, e.getMessage()));
     }
     catch(...)
     {
-        PEG_TRACE_CSTRING(TRC_PROVIDERMANAGER, Tracer::LEVEL2,
-            "Unexpected error in _enableIndications");
-
         Logger::put_l(Logger::ERROR_LOG, System::CIMSERVER, Logger::WARNING,
-            "ProviderManager.Default.DefaultProviderManager."
-                "ENABLE_INDICATIONS_FAILED_UNKNOWN",
-            "Failed to enable indications for provider $0.",
-            _fullyQualifiedProviderName);
+            MessageLoaderParms(
+                "ProviderManager.Default.DefaultProviderManager."
+                    "ENABLE_INDICATIONS_FAILED_UNKNOWN",
+                "Failed to enable indications for provider $0.",
+                _fullyQualifiedProviderName));
     }
 
     PEG_METHOD_EXIT();
@@ -1659,7 +1687,7 @@ void ProviderMessageHandler::_disableIndications()
             }
             catch (...)
             {
-                PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL2,
+                PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL1,
                     "Caught exception from provider %s "
                         "disableIndications() method.",
                     (const char*)_fullyQualifiedProviderName.getCString()));
