@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -43,16 +41,9 @@
 #include <Pegasus/ProviderManagerService/ProviderManagerModule.h>
 #include <Pegasus/ProviderManager2/ProviderManager.h>
 
-// ProviderManager library names.  Should these be defined elsewhere?
-#define LIBRARY_NAME_CMPIPM    "CMPIProviderManager"
-#define LIBRARY_NAME_JMPIPM    "JMPIProviderManager"
 
 PEGASUS_NAMESPACE_BEGIN
 
-static const char UNSUPPORTED_INTERFACE_TYPE_KEY [] =
-    "ProviderManager.BasicProviderManagerRouter.UNSUPPORTED_INTERFACE_TYPE";
-static const char UNSUPPORTED_INTERFACE_TYPE [] =
-    "Unsupported InterfaceType \"$0\" in ProviderModule \"$1\".";
 
 class ProviderManagerContainer
 {
@@ -73,8 +64,9 @@ public:
     _physicalName = ConfigManager::getHomedPath(provDir) + "/" +
                        FileSystem::buildLibraryFileName(physicalName);
 #else
-        _physicalName = ConfigManager::getHomedPath(PEGASUS_DEST_LIB_DIR) +
-            String("/") + FileSystem::buildLibraryFileName(physicalName);
+        _physicalName = physicalName;  // providerMgrPath comes with full path
+        //_physicalName = ConfigManager::getHomedPath(PEGASUS_DEST_LIB_DIR) +
+        //    String("/") + FileSystem::buildLibraryFileName(physicalName);
 #endif
 
         _logicalName = logicalName;
@@ -95,23 +87,16 @@ public:
 
         if (_manager == 0)
         {
-            PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL2,
-                "Failed to load ProviderManager \"" + _physicalName + "\".");
-
+            MessageLoaderParms parms(
+                "ProviderManager.BasicProviderManagerRouter."
+                    "PROVIDERMANAGER_LOAD_FAILED",
+                "Failed to load the Provider Manager for interface "
+                    "type \"$0\" from library \"$1\".",
+                _interfaceName, _physicalName);
             Logger::put_l(
                 Logger::ERROR_LOG, System::CIMSERVER, Logger::SEVERE,
-                "ProviderManager.BasicProviderManagerRouter."
-                    "PROVIDERMANAGER_LOAD_FAILED",
-                "Failed to load the Provider Manager for interface type \"$0\""
-                    " from library \"$1\".",
-                _interfaceName, _physicalName);
-
-            throw PEGASUS_CIM_EXCEPTION_L(CIM_ERR_FAILED, MessageLoaderParms(
-                "ProviderManager.BasicProviderManagerRouter."
-                    "PROVIDERMANAGER_LOAD_FAILED",
-                "Failed to load the Provider Manager for interface type \"$0\""
-                    " from library \"$1\".",
-                _interfaceName, _physicalName));
+                parms);
+            throw PEGASUS_CIM_EXCEPTION_L(CIM_ERR_FAILED, parms);
         }
 
         _manager->setIndicationCallback(indicationCallback);
@@ -225,8 +210,7 @@ Message* BasicProviderManagerRouter::processMessage(Message * message)
     CIMInstance providerModule;
 
     if ((dynamic_cast<CIMOperationRequestMessage*>(request) != 0) ||
-        (request->getType() == CIM_EXPORT_INDICATION_REQUEST_MESSAGE) ||
-        (request->getType() == CIM_INITIALIZE_PROVIDER_REQUEST_MESSAGE))
+        (request->getType() == CIM_EXPORT_INDICATION_REQUEST_MESSAGE))
     {
         // Provider information is in OperationContext
         ProviderIdContainer pidc = (ProviderIdContainer)
@@ -312,24 +296,59 @@ Message* BasicProviderManagerRouter::processMessage(Message * message)
         // Get ProviderModule name.
         String providerModuleName;
         CIMValue nameValue = providerModule.getProperty(
-            providerModule.findProperty("Name")).getValue();
-        nameValue.get(providerModuleName); 
+            providerModule.findProperty(PEGASUS_PROPERTYNAME_NAME)).getValue();
+        nameValue.get(providerModuleName);
+        // Get providerManager path
+        String provMgrPath;
+        if (request->operationContext.contains(ProviderIdContainer::NAME))
+        {
+            ProviderIdContainer pidc = (ProviderIdContainer)
+            request->operationContext.get(ProviderIdContainer::NAME);
+            provMgrPath = pidc.getProvMgrPath();
+        }
+
         ProviderManager* pm = 0;
         Boolean gotError = false;
         try
         {
             // Look up the appropriate ProviderManager by InterfaceType
-            pm = _getProviderManager(interfaceType, providerModuleName);
+
+            pm = _getProviderManager(interfaceType, providerModuleName,
+                provMgrPath);
         }
         catch (const CIMException& e)
         {
-            CIMResponseMessage* cimResponse = request->buildResponse();
-            cimResponse->cimException = e;
-            response = cimResponse;
+            // This is not an error incase of CIMEnableModuleRequestMessage or
+            // CIMDisableModuleRequestMessage. This means there is no provider
+            // to enable or disable.
+            if (request->getType() == CIM_ENABLE_MODULE_REQUEST_MESSAGE)
+            {
+                CIMEnableModuleResponseMessage* emResponse =
+                    dynamic_cast<CIMEnableModuleResponseMessage*>(
+                        request->buildResponse());
+                emResponse->operationalStatus.append(
+                    CIM_MSE_OPSTATUS_VALUE_OK);
+                response = emResponse;
+            }
+            else if (request->getType() == CIM_DISABLE_MODULE_REQUEST_MESSAGE)
+            {
+                CIMDisableModuleResponseMessage* dmResponse =
+                    dynamic_cast<CIMDisableModuleResponseMessage*>(
+                        request->buildResponse());
+                dmResponse->operationalStatus.append(
+                    CIM_MSE_OPSTATUS_VALUE_STOPPED);
+                response = dmResponse;
+            }
+            else
+            {
+                CIMResponseMessage *cimResponse = request->buildResponse();
+                cimResponse->cimException = e;
+                response = cimResponse;
+            }
             gotError = true;
         }
 
-        if (!gotError && remoteNameSpaceRequest && 
+        if (!gotError && remoteNameSpaceRequest &&
             !pm->supportsRemoteNameSpaces())
         {
             CIMResponseMessage* resp = request->buildResponse();
@@ -346,18 +365,15 @@ Message* BasicProviderManagerRouter::processMessage(Message * message)
         }
     }
 
-    // preserve message key
-    // set HTTP method in response from request
-    // set closeConnect
-   ((CIMResponseMessage *)response)->syncAttributes(request);
-
     PEG_METHOD_EXIT();
     return response;
 }
 
 // ATTN: May need to add interfaceVersion parameter to further constrain lookup
 ProviderManager* BasicProviderManagerRouter::_getProviderManager(
-    const String& interfaceType, const String& providerModuleName)
+    const String& interfaceType,
+    const String& providerModuleName,
+    const String& providerManagerPath)
 {
     PEG_METHOD_ENTER(TRC_PROVIDERMANAGER,
         "BasicProviderManagerRouter::_getProviderManager");
@@ -389,11 +405,6 @@ ProviderManager* BasicProviderManagerRouter::_getProviderManager(
             return pm;
         }
 
-        // ATTN: this section is a temporary solution to populate the list of
-        // enabled provider managers for a given distribution.  It includes
-        // another temporary solution for converting a generic file name into
-        // a file name useable by each platform.
-
         // The DefaultProviderManager is now statically linked rather than
         // dynamically loaded. This code is no longer used but remains for
         // reference purposes.
@@ -410,59 +421,23 @@ ProviderManager* BasicProviderManagerRouter::_getProviderManager(
                 _subscriptionInitComplete,
                 pm);
             _providerManagerTable.append(pmc);
+            PEG_METHOD_EXIT();
             return pmc->getProviderManager();
         }
 #endif
 
-#if defined(PEGASUS_ENABLE_CMPI_PROVIDER_MANAGER)
-        if (interfaceType == "CMPI")
-        {
-            ProviderManagerContainer* pmc = new ProviderManagerContainer(
-                LIBRARY_NAME_CMPIPM,
-                "CMPI",
-                "CMPI",
-                _indicationCallback,
-                _responseChunkCallback,
-                _subscriptionInitComplete);
-            _providerManagerTable.append(pmc);
-            return pmc->getProviderManager();
-        }
-#endif
-
-#if defined(PEGASUS_ENABLE_JMPI_PROVIDER_MANAGER)
-        if (  interfaceType == "JMPI"
-           || interfaceType == "JMPIExperimental"
-           )
-        {
-            ProviderManagerContainer* pmc = new ProviderManagerContainer(
-                LIBRARY_NAME_JMPIPM,
-                interfaceType,
-                interfaceType,
-                _indicationCallback,
-                _responseChunkCallback,
-                _subscriptionInitComplete);
-            _providerManagerTable.append(pmc);
-            return pmc->getProviderManager();
-        }
-#endif
-        // END TEMP SECTION
+        ProviderManagerContainer* pmc = new ProviderManagerContainer(
+            providerManagerPath,
+            interfaceType,
+            interfaceType,
+            _indicationCallback,
+            _responseChunkCallback,
+            _subscriptionInitComplete);
+        _providerManagerTable.append(pmc);
+        PEG_METHOD_EXIT();
+        return pmc->getProviderManager();
     }
 
-    // Error: ProviderManager not found for the specified interface type
-    PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL2,
-      "Failed to get ProviderManager for interface type\"" 
-                   + interfaceType + "\".");
-
-    Logger::put_l(
-        Logger::ERROR_LOG, System::CIMSERVER, Logger::WARNING,
-        UNSUPPORTED_INTERFACE_TYPE_KEY,
-        UNSUPPORTED_INTERFACE_TYPE, interfaceType, providerModuleName);
-
-    PEG_METHOD_EXIT();
-
-    throw PEGASUS_CIM_EXCEPTION_L(CIM_ERR_FAILED, MessageLoaderParms(
-          UNSUPPORTED_INTERFACE_TYPE_KEY,
-          UNSUPPORTED_INTERFACE_TYPE, interfaceType, providerModuleName));
 }
 
 // NOTE: The caller must lock _providerManagerTableLock before calling this
