@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -48,6 +46,7 @@
 #include <Pegasus/Common/MessageQueueService.h>
 #include <Pegasus/Config/ConfigManager.h>
 #include <Pegasus/Common/Executor.h>
+#include <Pegasus/Common/StringConversion.h>
 
 #if defined (PEGASUS_OS_TYPE_WINDOWS)
 # include <windows.h>  // For CreateProcess()
@@ -303,12 +302,6 @@ private:
     */
     static Mutex _numProviderProcessesMutex;
 
-    /**
-        The maximum number of Provider Agent processes that may be initialized
-        (active) at one time.
-    */
-    static Uint32 _maxProviderProcesses;
-
     /**
         A value indicating that a request message has not been processed.
         A CIMResponseMessage pointer with this value indicates that the
@@ -329,7 +322,6 @@ private:
 
 Uint32 ProviderAgentContainer::_numProviderProcesses = 0;
 Mutex ProviderAgentContainer::_numProviderProcessesMutex;
-Uint32 ProviderAgentContainer::_maxProviderProcesses = PEG_NOT_FOUND;
 
 // Set this to a value that no valid CIMResponseMessage* will have.
 CIMResponseMessage* ProviderAgentContainer::_REQUEST_NOT_PROCESSED =
@@ -343,7 +335,7 @@ ProviderAgentContainer::ProviderAgentContainer(
     PEGASUS_RESPONSE_CHUNK_CALLBACK_T responseChunkCallback,
     PEGASUS_PROVIDERMODULEFAIL_CALLBACK_T providerModuleFailCallback,
     Boolean subscriptionInitComplete)
-    : 
+    :
       _moduleName(moduleName),
       _userName(userName),
       _userContext(userContext),
@@ -407,7 +399,7 @@ void ProviderAgentContainer::_startAgentProcess()
 
     if (status != 0)
     {
-        PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL2,
+        PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL1,
             "Executor::startProviderAgent() failed"));
         PEG_METHOD_EXIT();
         throw Exception(MessageLoaderParms(
@@ -520,19 +512,22 @@ void ProviderAgentContainer::_initialize()
         return;
     }
 
-    if (_maxProviderProcesses == PEG_NOT_FOUND)
-    {
-        String maxProviderProcesses = ConfigManager::getInstance()->
-            getCurrentValue("maxProviderProcesses");
-        CString maxProviderProcessesString = maxProviderProcesses.getCString();
-        char* end = 0;
-        _maxProviderProcesses = strtol(maxProviderProcessesString, &end, 10);
-    }
+    //Get the current value of maxProviderProcesses
+    String maxProviderProcessesString = ConfigManager::getInstance()->
+        getCurrentValue("maxProviderProcesses");
+    Uint64 v;
+    StringConversion::decimalStringToUint64(
+        maxProviderProcessesString.getCString(),
+        v);
+    Uint32 maxProviderProcesses = (Uint32)v;
+
+    char* end = 0;
 
     {
         AutoMutex lock(_numProviderProcessesMutex);
-        if ((_maxProviderProcesses != 0) &&
-            (_numProviderProcesses >= _maxProviderProcesses))
+
+        if ((maxProviderProcesses != 0) &&
+            (_numProviderProcesses >= maxProviderProcesses))
         {
             throw PEGASUS_CIM_EXCEPTION(
                 CIM_ERR_FAILED,
@@ -566,12 +561,7 @@ void ProviderAgentContainer::_initialize()
             }
             else
             {
-                Logger::put(
-                    Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
-                    "Not enough threads to process responses from the "
-                        "provider agent.");
-
-                PEG_TRACE_CSTRING(TRC_PROVIDERMANAGER, Tracer::LEVEL2,
+                PEG_TRACE_CSTRING(TRC_PROVIDERMANAGER, Tracer::LEVEL1,
                     "Could not allocate thread to process responses from the "
                         "provider agent.");
 
@@ -597,7 +587,7 @@ void ProviderAgentContainer::_initialize()
 
             if (status == -1)
             {
-                PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL2,
+                PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL1,
                     "ProviderAgentContainer::_initialize(): "
                         "Executor::reapProviderAgent() failed"));
             }
@@ -646,7 +636,7 @@ void ProviderAgentContainer::_uninitialize(Boolean cleanShutdown)
         _providerModuleCache = CIMInstance();
 
         {
-            AutoMutex lock(_numProviderProcessesMutex);
+            AutoMutex lock2(_numProviderProcessesMutex);
             _numProviderProcesses--;
         }
 
@@ -671,9 +661,9 @@ void ProviderAgentContainer::_uninitialize(Boolean cleanShutdown)
                      _outstandingRequestTable.start();
                  i != 0; i++)
             {
-                PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL2,
-                    String("Completing messageId \"") + i.key() +
-                        "\" with a null response.");
+                PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL4,
+                    "Completing messageId \"%s\" with a null response.",
+                    (const char*)i.key().getCString()));
                 i.value()->responseMessage = response;
                 i.value()->responseReady->signal();
             }
@@ -865,9 +855,9 @@ CIMResponseMessage* ProviderAgentContainer::_processMessage(
             //
             try
             {
-                PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL3,
-                    String("Sending request to agent with messageId ") +
-                        uniqueMessageId);
+                PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL3,
+                    "Sending request to agent with messageId %s",
+                    (const char*)uniqueMessageId.getCString()));
 
                 request->messageId = uniqueMessageId;
                 AnonymousPipe::Status writeStatus =
@@ -881,7 +871,7 @@ CIMResponseMessage* ProviderAgentContainer::_processMessage(
 
                 if (writeStatus != AnonymousPipe::STATUS_SUCCESS)
                 {
-                    PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL2,
+                    PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL1,
                         "Failed to write message to pipe.  writeStatus = %d.",
                         writeStatus));
 
@@ -921,7 +911,7 @@ CIMResponseMessage* ProviderAgentContainer::_processMessage(
                     request->operationContext.set(*origProviderId.get());
                 }
 
-                PEG_TRACE_CSTRING(TRC_PROVIDERMANAGER, Tracer::LEVEL2,
+                PEG_TRACE_CSTRING(TRC_PROVIDERMANAGER, Tracer::LEVEL1,
                     "Failed to write message to pipe.");
                 // Remove the OutstandingRequestTable entry for this request
                 {
@@ -982,15 +972,17 @@ CIMResponseMessage* ProviderAgentContainer::_processMessage(
     }
     catch (CIMException& e)
     {
-        PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL2,
-            String("Caught exception: ") + e.getMessage());
+        PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL1,
+            "Caught CIMException: %s",
+            (const char*)e.getMessage().getCString()));
         response = request->buildResponse();
         response->cimException = e;
     }
     catch (Exception& e)
     {
-        PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL2,
-            String("Caught exception: ") + e.getMessage());
+        PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL1,
+            "Caught Exception: %s",
+            (const char*)e.getMessage().getCString()));
         response = request->buildResponse();
         response->cimException = PEGASUS_CIM_EXCEPTION(
             CIM_ERR_FAILED, e.getMessage());
@@ -1005,6 +997,7 @@ CIMResponseMessage* ProviderAgentContainer::_processMessage(
     }
 
     response->messageId = originalMessageId;
+    response->syncAttributes(request);
 
     PEG_METHOD_EXIT();
     return response;
@@ -1130,8 +1123,9 @@ void ProviderAgentContainer::_processResponses()
         }
         catch (Exception& e)
         {
-            PEG_TRACE_STRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
-                String("Ignoring exception: ") + e.getMessage());
+            PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL2,
+                "Ignoring exception: %s",
+                (const char*)e.getMessage().getCString()));
         }
         catch (...)
         {
@@ -1294,7 +1288,7 @@ Message* OOPProviderManagerRouter::processMessage(Message* message)
         // Retrieve the provider module name
         String moduleName;
         CIMValue nameValue = providerModule.getProperty(
-            providerModule.findProperty("Name")).getValue();
+            providerModule.findProperty(PEGASUS_PROPERTYNAME_NAME)).getValue();
         nameValue.get(moduleName);
 
         // Look up the Provider Agents for this module
@@ -1324,9 +1318,9 @@ Message* OOPProviderManagerRouter::processMessage(Message* message)
                 PEGASUS_ASSERT(dmResponse != 0);
 
                 Boolean isStopped = false;
-                for (Uint32 i=0; i < dmResponse->operationalStatus.size(); i++)
+                for (Uint32 j=0; j < dmResponse->operationalStatus.size(); j++)
                 {
-                    if (dmResponse->operationalStatus[i] ==
+                    if (dmResponse->operationalStatus[j] ==
                         CIM_MSE_OPSTATUS_VALUE_STOPPED)
                     {
                         isStopped = true;
@@ -1364,7 +1358,7 @@ Message* OOPProviderManagerRouter::processMessage(Message* message)
         // Retrieve the provider module name
         String moduleName;
         CIMValue nameValue = providerModule.getProperty(
-            providerModule.findProperty("Name")).getValue();
+            providerModule.findProperty(PEGASUS_PROPERTYNAME_NAME)).getValue();
         nameValue.get(moduleName);
 
         // Look up the Provider Agents for this module
@@ -1390,9 +1384,9 @@ Message* OOPProviderManagerRouter::processMessage(Message* message)
                 PEGASUS_ASSERT(emResponse != 0);
 
                 Boolean isOk = false;
-                for (Uint32 i=0; i < emResponse->operationalStatus.size(); i++)
+                for (Uint32 j=0; j < emResponse->operationalStatus.size(); j++)
                 {
-                    if (emResponse->operationalStatus[i] ==
+                    if (emResponse->operationalStatus[j] ==
                         CIM_MSE_OPSTATUS_VALUE_OK)
                     {
                         isOk = true;
@@ -1439,8 +1433,6 @@ Message* OOPProviderManagerRouter::processMessage(Message* message)
         response.reset(pa->processMessage(request));
     }
 
-    response->syncAttributes(request);
-
     PEG_METHOD_EXIT();
     return response.release();
 }
@@ -1452,7 +1444,7 @@ ProviderAgentContainer* OOPProviderManagerRouter::_lookupProviderAgent(
     // Retrieve the provider module name
     String moduleName;
     CIMValue nameValue = providerModule.getProperty(
-        providerModule.findProperty("Name")).getValue();
+        providerModule.findProperty(PEGASUS_PROPERTYNAME_NAME)).getValue();
     nameValue.get(moduleName);
 
     // Retrieve the provider user context configuration
@@ -1524,12 +1516,14 @@ ProviderAgentContainer* OOPProviderManagerRouter::_lookupProviderAgent(
         userName = System::getPrivilegedUserName();
     }
 
-    PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL4,
-        "Module name = " + moduleName);
-    PEG_TRACE((TRC_PROVIDERMANAGER, Tracer::LEVEL4,
-        "User context = %hd.", userContext));
-    PEG_TRACE_STRING(TRC_PROVIDERMANAGER, Tracer::LEVEL4,
-        "User name = " + userName);
+    PEG_TRACE((
+        TRC_PROVIDERMANAGER,
+        Tracer::LEVEL4,
+        "Module name = %s, User context = %hd, User name = %s",
+        (const char*) moduleName.getCString(),
+        userContext,
+        (const char*) userName.getCString()));
+
 
     ProviderAgentContainer* pa = 0;
 #ifdef PEGASUS_OS_PASE
