@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -40,7 +38,7 @@
 #include <Pegasus/Config/ConfigManager.h>
 #include <Pegasus/ProviderManager2/Default/DefaultProviderManager.h>
 
-#if defined(PEGASUS_PLATFORM_ZOS_ZSERIES_IBM) && defined(PEGASUS_ZOS_SECURITY)
+#if defined(PEGASUS_OS_ZOS) && defined(PEGASUS_ZOS_SECURITY)
 // This include file will not be provided in the OpenGroup CVS for now.
 // Do NOT try to include it in your compile
 #include <Pegasus/Common/safCheckzOS_inline.h>
@@ -49,7 +47,6 @@
 #include "ProviderAgent.h"
 
 #ifdef PEGASUS_OS_PASE
-#include <as400_protos.h>
 #include <ILEWrapper/ILEUtilities.h>
 #endif
 
@@ -166,14 +163,14 @@ void ProviderAgent::run()
         }
         catch (Exception& e)
         {
-            PEG_TRACE_STRING(TRC_PROVIDERAGENT, Tracer::LEVEL2,
-                String("Unexpected exception from _readAndProcessRequest(): ") +
-                    e.getMessage());
+            PEG_TRACE((TRC_PROVIDERAGENT, Tracer::LEVEL1,
+                "Unexpected Exception from _readAndProcessRequest(): %s",
+                (const char*)e.getMessage().getCString()));
             _terminating = true;
         }
         catch (...)
         {
-            PEG_TRACE_CSTRING(TRC_PROVIDERAGENT, Tracer::LEVEL2,
+            PEG_TRACE_CSTRING(TRC_PROVIDERAGENT, Tracer::LEVEL1,
                 "Unexpected exception from _readAndProcessRequest().");
             _terminating = true;
         }
@@ -208,7 +205,7 @@ void ProviderAgent::run()
             catch (...)
             {
                 // Do not terminate the agent on this exception
-                PEG_TRACE_CSTRING(TRC_PROVIDERAGENT, Tracer::LEVEL2,
+                PEG_TRACE_CSTRING(TRC_PROVIDERAGENT, Tracer::LEVEL1,
                     "Unexpected exception from hasActiveProviders()");
             }
         }
@@ -238,7 +235,7 @@ Boolean ProviderAgent::_readAndProcessRequest()
     // Read operation was interrupted
     if (readStatus == AnonymousPipe::STATUS_INTERRUPT)
     {
-        PEG_TRACE_CSTRING(TRC_PROVIDERAGENT, Tracer::LEVEL2,
+        PEG_TRACE_CSTRING(TRC_PROVIDERAGENT, Tracer::LEVEL1,
             "Read operation was interrupted.");
         PEG_METHOD_EXIT();
         return false;
@@ -256,13 +253,15 @@ Boolean ProviderAgent::_readAndProcessRequest()
 
     if (readStatus == AnonymousPipe::STATUS_ERROR)
     {
-        PEG_TRACE_CSTRING(TRC_PROVIDERAGENT, Tracer::LEVEL2,
+        PEG_TRACE_CSTRING(TRC_PROVIDERAGENT, Tracer::LEVEL1,
             "Error reading from pipe. Exiting.");
         Logger::put_l(Logger::ERROR_LOG, System::CIMSERVER, Logger::WARNING,
-            "ProviderManager.ProviderAgent.ProviderAgent."
-                "CIMSERVER_COMMUNICATION_FAILED",
-            "cimprovagt \"$0\" communication with CIM Server failed.  Exiting.",
-            _agentId);
+            MessageLoaderParms(
+                "ProviderManager.ProviderAgent.ProviderAgent."
+                    "CIMSERVER_COMMUNICATION_FAILED",
+                "cimprovagt \"$0\" communication with CIM Server failed.  "
+                    "Exiting.",
+                _agentId));
         _terminating = true;
         PEG_METHOD_EXIT();
         return false;
@@ -294,15 +293,19 @@ Boolean ProviderAgent::_readAndProcessRequest()
         return false;
     }
 
-    PEG_TRACE_STRING(TRC_PROVIDERAGENT, Tracer::LEVEL3,
-        String("Received request from server with messageId ") +
-            request->messageId);
+    PEG_TRACE((TRC_PROVIDERAGENT, Tracer::LEVEL3,
+        "Received request from server with messageId %s",
+        (const char*)request->messageId.getCString()));
+
+    const AcceptLanguageListContainer acceptLang =
+        request->operationContext.get(AcceptLanguageListContainer::NAME);
+    Thread::setLanguages(acceptLang.getLanguages());
 
     // Get the ProviderIdContainer to complete the provider module instance
     // optimization.  If the provider module instance is blank (optimized
     // out), fill it in from our cache.  If it is not blank, update our
     // cache.  (See the _providerModuleCache member description.)
-    try
+    if (request->operationContext.contains(ProviderIdContainer::NAME))
     {
         ProviderIdContainer pidc = request->operationContext.get(
             ProviderIdContainer::NAME);
@@ -319,10 +322,6 @@ Boolean ProviderAgent::_readAndProcessRequest()
             _providerModuleCache = pidc.getModule();
         }
     }
-    catch (...)
-    {
-        // No ProviderIdContainer to optimize
-    }
 
     //
     // It never should be possible to receive a request other than "initialise"
@@ -333,15 +332,13 @@ Boolean ProviderAgent::_readAndProcessRequest()
     if (!_isInitialised &&
         (request->getType() != CIM_INITIALIZE_PROVIDER_AGENT_REQUEST_MESSAGE))
     {
-        PEG_TRACE_CSTRING(TRC_PROVIDERAGENT, Tracer::LEVEL2,
-            "Provider Agent was not yet initialised,"
-            " prior to receiving a request message.");
         Logger::put_l(Logger::ERROR_LOG, System::CIMSERVER, Logger::WARNING,
-            "ProviderManager.ProviderAgent.ProviderAgent."
-            "PROVIDERAGENT_NOT_INITIALIZED",
-            "cimprovagt \"$0\" was not yet initialised"
-            " prior to receiving a request message. Exiting.",
-            _agentId);
+            MessageLoaderParms(
+                "ProviderManager.ProviderAgent.ProviderAgent."
+                    "PROVIDERAGENT_NOT_INITIALIZED",
+                "cimprovagt \"$0\" was not yet initialized "
+                    "prior to receiving a request message. Exiting.",
+                _agentId));
         _terminating = true;
         PEG_METHOD_EXIT();
         return false;
@@ -357,8 +354,8 @@ Boolean ProviderAgent::_readAndProcessRequest()
             dynamic_cast<CIMInitializeProviderAgentRequestMessage*>(request));
         PEGASUS_ASSERT(ipaRequest.get() != 0);
 
+        ConfigManager::setPegasusHome(ipaRequest->pegasusHome);
         ConfigManager* configManager = ConfigManager::getInstance();
-        configManager->setPegasusHome(ipaRequest->pegasusHome);
 
         // Initialize the configuration properties
         for (Uint32 i = 0; i < ipaRequest->configProperties.size(); i++)
@@ -394,7 +391,7 @@ Boolean ProviderAgent::_readAndProcessRequest()
         Uint32 messageLength = 0;
         _pipeToServer->writeBuffer((const char*)&messageLength, sizeof(Uint32));
 
-#if defined(PEGASUS_PLATFORM_ZOS_ZSERIES_IBM) && defined(PEGASUS_ZOS_SECURITY)
+#if defined(PEGASUS_OS_ZOS) && defined(PEGASUS_ZOS_SECURITY)
         // prepare and setup the thread-level security environment on z/OS
         // if security initialization fails
         startupCheckBPXServer(false);
@@ -402,10 +399,11 @@ Boolean ProviderAgent::_readAndProcessRequest()
         if (!isZOSSecuritySetup())
         {
             Logger::put_l(Logger::ERROR_LOG, ZOS_SECURITY_NAME, Logger::FATAL,
-                          "ProviderManager.ProviderAgent.ProviderAgent."
-                          "UNINITIALIZED_SECURITY_SETUP.PEGASUS_OS_ZOS",
-                          "Security environment could not be initialised. "
-                          "Assume security fraud. Stopping Provider Agent.");
+                MessageLoaderParms(
+                    "ProviderManager.ProviderAgent.ProviderAgent."
+                        "UNINITIALIZED_SECURITY_SETUP.PEGASUS_OS_ZOS",
+                    "Security environment could not be initialised. "
+                        "Assume security fraud. Stopping Provider Agent."));
             exit(1);
         }
 #endif
@@ -511,11 +509,7 @@ Boolean ProviderAgent::_readAndProcessRequest()
             }
             else
             {
-                Logger::put(
-                    Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
-                    "Not enough threads to process agent request.");
-
-                PEG_TRACE_CSTRING(TRC_PROVIDERAGENT, Tracer::LEVEL2,
+                PEG_TRACE_CSTRING(TRC_PROVIDERAGENT, Tracer::LEVEL1,
                     "Could not allocate thread to process agent request.");
 
                 AutoPtr<CIMResponseMessage> response(request->buildResponse());
@@ -555,9 +549,9 @@ Message* ProviderAgent::_processRequest(CIMRequestMessage* request)
     }
     catch (Exception& e)
     {
-        PEG_TRACE_STRING(TRC_PROVIDERAGENT, Tracer::LEVEL2,
-            String("Caught exception while processing request: ") +
-                e.getMessage());
+        PEG_TRACE((TRC_PROVIDERAGENT, Tracer::LEVEL1,
+            "Caught exception while processing request: %s",
+            (const char*)e.getMessage().getCString()));
         CIMResponseMessage* cimResponse = request->buildResponse();
         cimResponse->cimException = PEGASUS_CIM_EXCEPTION(
             CIM_ERR_FAILED, e.getMessage());
@@ -565,7 +559,7 @@ Message* ProviderAgent::_processRequest(CIMRequestMessage* request)
     }
     catch (...)
     {
-        PEG_TRACE_CSTRING(TRC_PROVIDERAGENT, Tracer::LEVEL2,
+        PEG_TRACE_CSTRING(TRC_PROVIDERAGENT, Tracer::LEVEL1,
             "Caught exception while processing request.");
         CIMResponseMessage* cimResponse = request->buildResponse();
         cimResponse->cimException = PEGASUS_CIM_EXCEPTION(
@@ -597,26 +591,29 @@ void ProviderAgent::_writeResponse(Message* message)
 
         if (writeStatus != AnonymousPipe::STATUS_SUCCESS)
         {
-            PEG_TRACE_CSTRING(TRC_PROVIDERAGENT, Tracer::LEVEL2,
+            PEG_TRACE_CSTRING(TRC_PROVIDERAGENT, Tracer::LEVEL1,
                 "Error writing response to pipe.");
             Logger::put_l(Logger::ERROR_LOG, System::CIMSERVER, Logger::WARNING,
-                "ProviderManager.ProviderAgent.ProviderAgent."
-                    "CIMSERVER_COMMUNICATION_FAILED",
-                "cimprovagt \"$0\" communication with CIM Server failed.  "
-                    "Exiting.",
-                _agentId);
+                MessageLoaderParms(
+                    "ProviderManager.ProviderAgent.ProviderAgent."
+                        "CIMSERVER_COMMUNICATION_FAILED",
+                    "cimprovagt \"$0\" communication with CIM Server failed.  "
+                        "Exiting.",
+                    _agentId));
             _terminating = true;
         }
     }
     catch (...)
     {
-        PEG_TRACE_CSTRING(TRC_PROVIDERAGENT, Tracer::LEVEL2,
+        PEG_TRACE_CSTRING(TRC_PROVIDERAGENT, Tracer::LEVEL1,
             "Caught exception while writing response.");
         Logger::put_l(Logger::ERROR_LOG, System::CIMSERVER, Logger::WARNING,
-            "ProviderManager.ProviderAgent.ProviderAgent."
-                "CIMSERVER_COMMUNICATION_FAILED",
-            "cimprovagt \"$0\" communication with CIM Server failed.  Exiting.",
-            _agentId);
+            MessageLoaderParms(
+                "ProviderManager.ProviderAgent.ProviderAgent."
+                    "CIMSERVER_COMMUNICATION_FAILED",
+                "cimprovagt \"$0\" communication with CIM Server failed.  "
+                    "Exiting.",
+                _agentId));
         _terminating = true;
     }
 
@@ -639,6 +636,10 @@ ProviderAgent::_processRequestAndWriteResponse(void* arg)
         ProviderAgent* agent = agentRequest->agent;
         AutoPtr<CIMRequestMessage> request(agentRequest->request);
 
+        const AcceptLanguageListContainer acceptLang =
+            request->operationContext.get(AcceptLanguageListContainer::NAME);
+        Thread::setLanguages(acceptLang.getLanguages());
+
         // Process the request
         AutoPtr<Message> response(agent->_processRequest(request.get()));
 
@@ -647,13 +648,13 @@ ProviderAgent::_processRequestAndWriteResponse(void* arg)
     }
     catch (const Exception& e)
     {
-        PEG_TRACE_STRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
-            "Caught exception: \"" + e.getMessage() +
-                "\".  Exiting _processRequestAndWriteResponse.");
+        PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL1,
+            "Exiting _processRequestAndWriteResponse. Caught Exception: %s",
+            (const char*)e.getMessage().getCString()));
     }
     catch (...)
     {
-        PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL2,
+        PEG_TRACE_CSTRING(TRC_DISCARDED_DATA, Tracer::LEVEL1,
             "Caught unrecognized exception.  "
                 "Exiting _processRequestAndWriteResponse.");
     }
@@ -710,11 +711,7 @@ void ProviderAgent::_unloadIdleProviders()
     }
     if (rtn != PEGASUS_THREAD_OK)
     {
-
-         Logger::put(Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
-             "Not enough threads to unload idle providers.");
-
-         PEG_TRACE_CSTRING(TRC_PROVIDERAGENT, Tracer::LEVEL2,
+         PEG_TRACE_CSTRING(TRC_PROVIDERAGENT, Tracer::LEVEL1,
              "Could not allocate thread to unload idle providers.");
     }
     PEG_METHOD_EXIT();
@@ -791,16 +788,13 @@ void ProviderAgent::_synchronousSignalHandler(
     {
         _providerAgent->_terminating = true;
     }
- 
+
     char fullJobName[29];
     umeGetJobName(fullJobName, true);
-    Logger::put_l(Logger::ERROR_LOG, "provider agent", Logger::SEVERE, \
-        "ProviderManager.ProviderAgent.RECEIVE_SYN_SIGNAL.PEGASUS_OS_PASE", \
-        "$0 received synchronous signal: $1", fullJobName, s_n);
-
-    /* save job log */
-    systemCL ("QSYS/CHGJOB JOB(*) LOG(4 00 *NOLIST)", \
-        SYSTEMCL_MSG_STDOUT | SYSTEMCL_MSG_STDERR);
+    Logger::put_l(Logger::ERROR_LOG, "provider agent", Logger::SEVERE,
+        MessageLoaderParms(
+            "ProviderManager.ProviderAgent.RECEIVE_SYN_SIGNAL.PEGASUS_OS_PASE",
+            "$0 received synchronous signal: $1", fullJobName, s_n));
 }
 
 void ProviderAgent::_asynchronousSignalHandler(
@@ -819,9 +813,10 @@ void ProviderAgent::_asynchronousSignalHandler(
 
     char fullJobName[29];
     umeGetJobName(fullJobName, true);
-    Logger::put_l(Logger::ERROR_LOG, "provider agent", Logger::SEVERE, \
-        "ProviderManager.ProviderAgent.RECEIVE_ASYN_SIGNAL.PEGASUS_OS_PASE", \
-        "$0 received asynchronous signal: $1", fullJobName, s_n);
+    Logger::put_l(Logger::ERROR_LOG, "provider agent", Logger::SEVERE,
+        MessageLoaderParms(
+            "ProviderManager.ProviderAgent.RECEIVE_ASYN_SIGNAL.PEGASUS_OS_PASE",
+            "$0 received asynchronous signal: $1", fullJobName, s_n));
 }
 #endif
 
