@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
 //
-//==============================================================================
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -40,7 +38,6 @@
 #include <Pegasus/Common/CIMInstance.h>
 #include <Pegasus/Common/CIMPropertyList.h>
 #include <Pegasus/Common/CIMQualifierDecl.h>
-#include <Pegasus/Common/ContentLanguageList.h>
 #include <Pegasus/Config/ConfigManager.h>
 #include <Pegasus/Repository/NameSpaceManager.h>
 #include <Pegasus/Repository/Linkage.h>
@@ -71,13 +68,14 @@ public:
     /// Constructor
     CIMRepository(
         const String& repositoryRoot,
-        Uint32 mode = CIMRepository::MODE_DEFAULT);
+        Uint32 mode = CIMRepository::MODE_DEFAULT,
+        RepositoryDeclContext* declContext = 0);
 
     /// Descructor
-    virtual ~CIMRepository();
+    ~CIMRepository();
 
     /// getClass
-    virtual CIMClass getClass(
+    CIMClass getClass(
         const CIMNamespaceName& nameSpace,
         const CIMName& className,
         Boolean localOnly = true,
@@ -85,8 +83,13 @@ public:
         Boolean includeClassOrigin = false,
         const CIMPropertyList& propertyList = CIMPropertyList());
 
+    // getFullConstClass
+    CIMConstClass getFullConstClass(
+        const CIMNamespaceName& nameSpace,
+        const CIMName& className);
+
     /// getInstance
-    virtual CIMInstance getInstance(
+    CIMInstance getInstance(
         const CIMNamespaceName& nameSpace,
         const CIMObjectPath& instanceName,
         Boolean localOnly = true,
@@ -95,43 +98,39 @@ public:
         const CIMPropertyList& propertyList = CIMPropertyList());
 
     /// deleteClass
-    virtual void deleteClass(
+    void deleteClass(
         const CIMNamespaceName& nameSpace,
         const CIMName& className);
 
     /// deleteInstance
-    virtual void deleteInstance(
+    void deleteInstance(
         const CIMNamespaceName& nameSpace,
         const CIMObjectPath& instanceName);
 
     /// createClass
-    virtual void createClass(
+    void createClass(
         const CIMNamespaceName& nameSpace,
-        const CIMClass& newClass,
-        const ContentLanguageList& contentLangs = ContentLanguageList());
+        const CIMClass& newClass);
 
     /// createInstance
-    virtual CIMObjectPath createInstance(
+    CIMObjectPath createInstance(
         const CIMNamespaceName& nameSpace,
-        const CIMInstance& newInstance,
-        const ContentLanguageList& contentLangs = ContentLanguageList());
+        const CIMInstance& newInstance);
 
     /// modifyClass
-    virtual void modifyClass(
+    void modifyClass(
         const CIMNamespaceName& nameSpace,
-        const CIMClass& modifiedClass,
-        const ContentLanguageList& contentLangs = ContentLanguageList());
+        const CIMClass& modifiedClass);
 
     /// modifyInstance
-    virtual void modifyInstance(
+    void modifyInstance(
         const CIMNamespaceName& nameSpace,
         const CIMInstance& modifiedInstance,
         Boolean includeQualifiers = true,
-        const CIMPropertyList& propertyList = CIMPropertyList(),
-        const ContentLanguageList& contentLangs = ContentLanguageList());
+        const CIMPropertyList& propertyList = CIMPropertyList());
 
     /// enumerateClasses
-    virtual Array<CIMClass> enumerateClasses(
+    Array<CIMClass> enumerateClasses(
         const CIMNamespaceName& nameSpace,
         const CIMName& className = CIMName(),
         Boolean deepInheritance = false,
@@ -140,7 +139,7 @@ public:
         Boolean includeClassOrigin = false);
 
     /// enumerateClassNames
-    virtual Array<CIMName> enumerateClassNames(
+    Array<CIMName> enumerateClassNames(
         const CIMNamespaceName& nameSpace,
         const CIMName& className = CIMName(),
         Boolean deepInheritance = false);
@@ -155,7 +154,7 @@ public:
         This method is useful mainly for testing purposes, and should not be
         relied upon for complete results in a CIM Server environment.
     */
-    virtual Array<CIMInstance> enumerateInstancesForSubtree(
+    Array<CIMInstance> enumerateInstancesForSubtree(
         const CIMNamespaceName& nameSpace,
         const CIMName& className,
         Boolean deepInheritance = true,
@@ -169,7 +168,7 @@ public:
         This method mimics the provider behavior for the EnumerateInstances
         operation.
     */
-    virtual Array<CIMInstance> enumerateInstancesForClass(
+    Array<CIMInstance> enumerateInstancesForClass(
         const CIMNamespaceName& nameSpace,
         const CIMName& className,
         Boolean localOnly = true,
@@ -193,7 +192,7 @@ public:
         @return An Array of CIMObjectPath objects containing the names of the
             instances of the specified class in the specified namespace.
     */
-    virtual Array<CIMObjectPath> enumerateInstanceNamesForSubtree(
+    Array<CIMObjectPath> enumerateInstanceNamesForSubtree(
         const CIMNamespaceName& nameSpace,
         const CIMName& className);
 
@@ -208,13 +207,13 @@ public:
         @return An Array of CIMObjectPath objects containing the names of the
             instances of the specified class in the specified namespace.
     */
-    virtual Array<CIMObjectPath> enumerateInstanceNamesForClass(
+    Array<CIMObjectPath> enumerateInstanceNamesForClass(
         const CIMNamespaceName& nameSpace,
         const CIMName& className);
 
 
     /// associators
-    virtual Array<CIMObject> associators(
+    Array<CIMObject> associators(
         const CIMNamespaceName& nameSpace,
         const CIMObjectPath& objectName,
         const CIMName& assocClass = CIMName(),
@@ -226,7 +225,7 @@ public:
         const CIMPropertyList& propertyList = CIMPropertyList());
 
     /// associatorNames
-    virtual Array<CIMObjectPath> associatorNames(
+    Array<CIMObjectPath> associatorNames(
         const CIMNamespaceName& nameSpace,
         const CIMObjectPath& objectName,
         const CIMName& assocClass = CIMName(),
@@ -235,7 +234,7 @@ public:
         const String& resultRole = String::EMPTY);
 
     /// references
-    virtual Array<CIMObject> references(
+    Array<CIMObject> references(
         const CIMNamespaceName& nameSpace,
         const CIMObjectPath& objectName,
         const CIMName& resultClass = CIMName(),
@@ -245,97 +244,74 @@ public:
         const CIMPropertyList& propertyList = CIMPropertyList());
 
     /// referenceNames
-    virtual Array<CIMObjectPath> referenceNames(
+    Array<CIMObjectPath> referenceNames(
         const CIMNamespaceName& nameSpace,
         const CIMObjectPath& objectName,
         const CIMName& resultClass = CIMName(),
         const String& role = String::EMPTY);
 
     /// getProperty
-    virtual CIMValue getProperty(
+    CIMValue getProperty(
         const CIMNamespaceName& nameSpace,
         const CIMObjectPath& instanceName,
         const CIMName& propertyName);
 
     /// setProperty
-    virtual void setProperty(
+    void setProperty(
         const CIMNamespaceName& nameSpace,
         const CIMObjectPath& instanceName,
         const CIMName& propertyName,
-        const CIMValue& newValue = CIMValue(),
-        const ContentLanguageList& contentLangs = ContentLanguageList());
+        const CIMValue& newValue = CIMValue());
 
     /// getQualifier
-    virtual CIMQualifierDecl getQualifier(
+    CIMQualifierDecl getQualifier(
         const CIMNamespaceName& nameSpace,
         const CIMName& qualifierName);
 
     /// setQualifier
-    virtual void setQualifier(
+    void setQualifier(
         const CIMNamespaceName& nameSpace,
-        const CIMQualifierDecl& qualifierDecl,
-        const ContentLanguageList& contentLangs = ContentLanguageList());
+        const CIMQualifierDecl& qualifierDecl);
 
     /// deleteQualifier
-    virtual void deleteQualifier(
+    void deleteQualifier(
         const CIMNamespaceName& nameSpace,
         const CIMName& qualifierName);
 
     /// enumerateQualifiers
-    virtual Array<CIMQualifierDecl> enumerateQualifiers(
+    Array<CIMQualifierDecl> enumerateQualifiers(
         const CIMNamespaceName& nameSpace);
 
     typedef HashTable <String, String, EqualNoCaseFunc, HashLowerCaseFunc>
         NameSpaceAttributes;
 
-    /** CIMMethod createNameSpace - Creates a new namespace in the repository
-        @param String with the name of the namespace
-        @exception - Throws "Already_Exists if the Namespace exits.
-        Throws "CannotCreateDirectory" if there are problems in the
-        creation.
-    */
-
-    virtual void createNameSpace(const CIMNamespaceName& nameSpace,
+    void createNameSpace(const CIMNamespaceName& nameSpace,
         const NameSpaceAttributes& attributes = NameSpaceAttributes());
 
-    virtual void modifyNameSpace(const CIMNamespaceName& nameSpace,
+    void modifyNameSpace(const CIMNamespaceName& nameSpace,
         const NameSpaceAttributes& attributes = NameSpaceAttributes());
 
-    /** CIMMethod enumerateNameSpaces - Get all of the namespaces in the
-        repository. \Ref{NAMESPACE}
-        @return Array of strings with the namespaces
-    */
-    virtual Array<CIMNamespaceName> enumerateNameSpaces() const;
+    Array<CIMNamespaceName> enumerateNameSpaces() const;
 
-    /** CIMMethod deleteNameSpace - Deletes a namespace in the repository.
+    /** Deletes a namespace in the repository.
         The deleteNameSpace method will only delete a namespace if there are
         no classed defined in the namespace.  Today this is a Pegasus
         characteristics and not defined as part of the DMTF standards.
         @param String with the name of the namespace
         @exception - Throws NoSuchDirectory if the Namespace does not exist.
     */
-    virtual void deleteNameSpace(const CIMNamespaceName& nameSpace);
+    void deleteNameSpace(const CIMNamespaceName& nameSpace);
 
-    virtual Boolean getNameSpaceAttributes(
+    Boolean getNameSpaceAttributes(
         const CIMNamespaceName& nameSpace,
         NameSpaceAttributes& attributes);
 
     ////////////////////////////////////////////////////////////////////////////
 
-    /** CIMMethod setDeclContext - allows the Declaration Context set
-        by default in the CIMRepository constructor to be overridden.
-        This is useful, for example, when a compiler wants to check syntax
-        without actually adding to the repository.
-    */
-    void setDeclContext(RepositoryDeclContext* context);
-
     /** Indicates whether instance operations that do not have a provider
         registered should be served by this repository.
     */
-    Boolean isDefaultInstanceProvider()
-    {
-        return _isDefaultInstanceProvider;
-    }
+    Boolean isDefaultInstanceProvider();
 
     /** Get subclass names of the given class in the given namespace.
         @param nameSpaceName
@@ -346,33 +322,21 @@ public:
         @param subClassNames - output argument to hold subclass names.
         @exception CIMException(CIM_ERR_INVALID_CLASS)
     */
-    virtual void getSubClassNames(
+    void getSubClassNames(
         const CIMNamespaceName& nameSpaceName,
         const CIMName& className,
         Boolean deepInheritance,
-        Array<CIMName>& subClassNames) const
-    {
-        ReadLock lock(const_cast<ReadWriteSem&>(_lock));
-        _nameSpaceManager.getSubClassNames(nameSpaceName,
-                                           className,
-                                           deepInheritance,
-                                           subClassNames);
-    }
+        Array<CIMName>& subClassNames) const;
 
     /** Get the names of all superclasses (direct and indirect) of this
         class.
     */
-    virtual void getSuperClassNames(
+    void getSuperClassNames(
         const CIMNamespaceName& nameSpaceName,
         const CIMName& className,
-        Array<CIMName>& subClassNames) const
-    {
-        ReadLock lock(const_cast<ReadWriteSem&>(_lock));
-        _nameSpaceManager.getSuperClassNames(
-            nameSpaceName, className, subClassNames);
-    }
+        Array<CIMName>& subClassNames) const;
 
-    virtual Boolean isRemoteNameSpace(
+    Boolean isRemoteNameSpace(
         const CIMNamespaceName& nameSpaceName,
         String& remoteInfo);
 
@@ -383,13 +347,17 @@ public:
 protected:
 
     // Internal getClass implementation that does not do access control
+    // If readOnlyClass is true, then the caller ensures that the returned
+    // class, will never be modified, which allows returning a reference to
+    // the one that is in the cache.
     CIMClass _getClass(
         const CIMNamespaceName& nameSpace,
         const CIMName& className,
         Boolean localOnly,
         Boolean includeQualifiers,
         Boolean includeClassOrigin,
-        const CIMPropertyList& propertyList);
+        const CIMPropertyList& propertyList,
+        Boolean clone = true);
 
     /// Internal getInstance implementation that does not do access control
     CIMInstance _getInstance(
@@ -398,7 +366,8 @@ protected:
         Boolean localOnly,
         Boolean includeQualifiers,
         Boolean includeClassOrigin,
-        const CIMPropertyList& propertyList);
+        const CIMPropertyList& propertyList,
+        Boolean resolveInstance);
 
     /// Internal createClass implementation that does not do access control
     void _createClass(
@@ -443,157 +412,9 @@ protected:
 
 private:
 
-    /**
-        Searches for incomplete instance transactions for all classes in all
-        namespaces.  Restores instance index and data files to void an
-        incomplete operation.  If no incomplete instance transactions are
-        outstanding, this method has no effect.
-     */
-    void _rollbackIncompleteTransactions();
-
-    void _createAssocInstEntries(
-        const CIMNamespaceName& nameSpace,
-        const CIMConstClass& cimClass,
-        const CIMInstance& cimInstance,
-        const CIMObjectPath& instanceName);
-
-    void _createAssocClassEntries(
-        const CIMNamespaceName& nameSpace,
-        const CIMConstClass& assocClass);
-
-    /**
-        Checks whether an instance with the specified key values exists in the
-        class hierarchy of the specified class.
-
-        @param   nameSpace      the namespace of the instance
-        @param   instanceName   the name of the instance
-
-        @return  true           if the instance is found
-                 false          if the instance cannot be found
-     */
-    Boolean _checkInstanceAlreadyExists(
-        const CIMNamespaceName& nameSpace,
-        const CIMObjectPath& instanceName) const;
-
-    /** Returns the file path of the instance index file.
-
-        @param   nameSpace      the namespace of the instance
-        @param   className      the name of the class
-
-        @return  a string containing the index file path
-     */
-    String _getInstanceIndexFilePath(
-        const CIMNamespaceName& nameSpace,
-        const CIMName& className) const;
-
-    /** Returns the file path of the instance file.
-
-        @param   nameSpace      the namespace of the instance
-        @param   className      the name of the class
-
-        @return  a string containing the instance file path
-     */
-    String _getInstanceDataFilePath(
-        const CIMNamespaceName& nameSpace,
-        const CIMName& className) const;
-
-    /** Saves an instance object from memory to disk file.  The byte
-        position and the size of the newly inserted instance record are
-        returned.  Returns true on success.
-
-        @param   path      the file path of the instance file
-        @param   object    the CIMInstance object to be saved
-        @param   index     the byte positon of the saved instance record
-        @param   size      the size of the saved instance record
-
-        @return  true      if successful
-                 false     if an error occurs in saving the instance to file
-     */
-    Boolean _saveInstance(
-        const String& path,
-        const CIMInstance& object,
-        Uint32& index,
-        Uint32& size);
-
-    /** loads an instance object from disk to memory.  The caller passes
-        the byte position and the size of the instance record to be loaded.
-        Returns true on success.
-
-        @param   path      the file path of the instance file
-        @param   object    the CIMInstance object to be returned
-        @param   index     the byte positon of the instance record
-        @param   size      the size of the instance record
-        @param   data      the buffer to hold the instance data
-
-        @return  true      if successful
-                 false     if an error occurs in loading the instance from file
-     */
-    Boolean _loadInstance(
-        const String& path,
-        CIMInstance& object,
-        Uint32 index,
-        Uint32 size);
-
-    /** loads all the instance objects from disk to memeory.  Returns true
-        on success.
-
-        @param   nameSpace      the namespace of the instances to be loaded
-        @param   className      the class of the instances to be loaded
-        @param   namedInstances an array of CIMInstance objects to which
-                                the loaded instances are appended
-
-        @return  true      if successful
-                 false     if an error occurs in loading the instances
-     */
-    Boolean _loadAllInstances(
-        const CIMNamespaceName& nameSpace,
-        const CIMName& className,
-        Array<CIMInstance>& namedInstances);
-
-    /** Modifies an instance object saved in the disk file.  The byte position
-        and the size of the newly added instance record are returned.  Returns
-        true on success.
-
-        @param   path      the file path of the instance file
-        @param   object    the modified CIMInstance object
-        @param   oldIndex  the byte positon of the old instance record
-        @param   oldSize   the size of the old instance record
-        @param   newIndex  the byte positon of the new instance record
-        @param   newSize   the size of the new instance record
-
-        @return  true      if successful
-                 false     if an error occurs in modifying the instance
-     */
-    Boolean _modifyInstance(
-        const String& path,
-        const CIMInstance& object,
-        Uint32 oldIndex,
-        Uint32 oldSize,
-        Uint32& newIndex,
-        Uint32& newSize);
-
-    String _repositoryRoot;
-    NameSpaceManager _nameSpaceManager;
-
-    // This must be initialized in the constructor using values from the
-    // ConfigManager.
-    Boolean _isDefaultInstanceProvider;
-
-protected:
-
-    ObjectStreamer *streamer;
-    ReadWriteSem _lock;
-
+    class CIMRepositoryRep* _rep;
     friend class compilerDeclContext;
     friend class RepositoryDeclContext;
-    RepositoryDeclContext* _context;
-
-    /** Used by getInstance(); indicates whether instance should be resolved
-        after it is retrieved from the file.
-     */
-    Boolean _resolveInstance;
-
-    CString _lockFile;
 };
 
 PEGASUS_NAMESPACE_END
