@@ -1,42 +1,37 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
 //
-//==============================================================================
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
 #include <Pegasus/Common/String.h>
 #include <Pegasus/Common/HashTable.h>
-#include <Pegasus/Common/Dir.h>
-#include <Pegasus/Common/XmlWriter.h>
-#include <Pegasus/Common/CommonUTF.h>
-#include <Pegasus/Common/CIMNameUnchecked.h>
+#include <Pegasus/Common/CIMNameCast.h>
 #include "InheritanceTree.h"
 
 #if 0
@@ -50,20 +45,6 @@ PEGASUS_NAMESPACE_BEGIN
 
 PEGASUS_USING_STD;
 
-////////////////////////////////////////////////////////////////////////////////
-//
-// NoCaseEqualFunc
-//
-////////////////////////////////////////////////////////////////////////////////
-
-struct NoCaseEqualFunc
-{
-    static Boolean equal(const String& x, const String& y)
-    {
-        return String::equalNoCase(x, y);
-    }
-};
-
 ////////////////////////////////////////////////////////////////////////////////
 //
 // InheritanceTreeRep
@@ -75,7 +56,7 @@ struct InheritanceTreeNode;
 struct InheritanceTreeRep
 {
     typedef HashTable<
-        String, InheritanceTreeNode*, NoCaseEqualFunc, HashLowerCaseFunc> Table;
+        String, InheritanceTreeNode*, EqualNoCaseFunc, HashLowerCaseFunc> Table;
     Table table;
 
     // Tradeoff: chosing a larger value decreases hash lookup time but
@@ -106,7 +87,7 @@ struct InheritanceTreeExt
 
 struct InheritanceTreeNode
 {
-    InheritanceTreeNode(const CIMName& className);
+    InheritanceTreeNode(const CIMName& className_);
     ~InheritanceTreeNode();
 
     void addSubClass(InheritanceTreeNode* subClass);
@@ -135,8 +116,8 @@ struct InheritanceTreeNode
     Boolean extension;
 };
 
-InheritanceTreeNode::InheritanceTreeNode(const CIMName& className)
-    : className(className), superClass(0),
+InheritanceTreeNode::InheritanceTreeNode(const CIMName& className_)
+    : className(className_), superClass(0),
     sibling(0), subClasses(0), provisional(true), extension(false)
 {
 }
@@ -249,13 +230,13 @@ void InheritanceTreeNode::getSuperClassNames(Array<CIMName>& superClassNames)
 
 void InheritanceTreeNode::print(PEGASUS_STD(ostream)& os) const
 {
-    os << className << " : " ;
-    os << (superClass ? superClass->className : CIMName ());
+    os << className.getString() << " : " ;
+    os << (superClass ? superClass->className : CIMName()).getString();
 
     os << " { ";
 
     for (InheritanceTreeNode* p = subClasses; p; p = p->sibling)
-        os << p->className << ' ';
+        os << p->className.getString() << ' ';
 
     os << "}" << endl;
 }
@@ -290,7 +271,7 @@ void InheritanceTree::insert(
         !parentTree._rep->table.lookup(superClassName, superClassNode))
     {
         superClassNode =
-            new InheritanceTreeNode(CIMNameUnchecked(superClassName));
+            new InheritanceTreeNode(CIMNameCast(superClassName));
         parentTree._rep->table.insert(superClassName, superClassNode);
     }
 
@@ -298,7 +279,7 @@ void InheritanceTree::insert(
 
     if (!parentTree._rep->table.lookup(className, extNode))
     {
-        extNode = new InheritanceTreeNode(CIMNameUnchecked(className));
+        extNode = new InheritanceTreeNode(CIMNameCast(className));
         parentTree._rep->table.insert(className, extNode);
         extNode->extension=true;
         extNode->extNodes=new Array<InheritanceTreeExt*>;
@@ -336,7 +317,7 @@ void InheritanceTree::insert(
         !_rep->table.lookup(superClassName, superClassNode))
     {
         superClassNode =
-            new InheritanceTreeNode(CIMNameUnchecked(superClassName));
+            new InheritanceTreeNode(CIMNameCast(superClassName));
         _rep->table.insert(superClassName, superClassNode);
     }
 
@@ -346,7 +327,7 @@ void InheritanceTree::insert(
 
     if (!_rep->table.lookup(className, classNode))
     {
-        classNode = new InheritanceTreeNode(CIMNameUnchecked(className));
+        classNode = new InheritanceTreeNode(CIMNameCast(className));
         _rep->table.insert(className, classNode);
     }
 
@@ -358,52 +339,6 @@ void InheritanceTree::insert(
         superClassNode->addSubClass(classNode);
 }
 
-void InheritanceTree::insertFromPath(const String& path,
-      InheritanceTree* parentTree,
-      NameSpace* ns)
-{
-    for (Dir dir(path); dir.more(); dir.next())
-    {
-        String fileName = dir.getName();
-
-        // Ignore the current and parent directories.
-
-        if (fileName == "." || fileName == "..")
-            continue;
-
-        Uint32 dot = fileName.find('.');
-
-        // Ignore files without dots in them:
-
-        if (dot == PEG_NOT_FOUND)
-            continue;
-
-        String className = fileName.subString(0, dot);
-        String superClassName = fileName.subString(dot + 1);
-
-        if (superClassName == "#")
-            superClassName.clear();
-
-
-#ifdef PEGASUS_REPOSITORY_ESCAPE_UTF8
-        if (ns)
-            insert(
-                escapeStringDecoder(className),
-                escapeStringDecoder(superClassName),
-                *parentTree, ns);
-        else
-            insert(
-                escapeStringDecoder(className),
-                escapeStringDecoder(superClassName));
-#else
-        if (ns)
-            insert(className, superClassName, *parentTree, ns);
-        else
-            insert(className, superClassName);
-#endif
-    }
-}
-
 void InheritanceTree::check() const
 {
     for (InheritanceTreeRep::Table::Iterator i = _rep->table.start(); i; i++)
@@ -436,15 +371,15 @@ Boolean InheritanceTree::getSubClassNames(
                     InheritanceTreeExt* itx=(*(itn->extNodes))[j];
                     if (itx->tag==ns)
                     {
-                        InheritanceTreeNode* itn=itx->node;
+                        InheritanceTreeNode* itxn=itx->node;
                         if (deepInheritance)
                         {
-                            subClassNames.append(CIMNameUnchecked(i.key()));
-                            itn->getSubClassNames(
+                            subClassNames.append(CIMNameCast(i.key()));
+                            itxn->getSubClassNames(
                                 subClassNames, deepInheritance, ns);
                         }
                         else if (!i.value()->superClass)
-                            subClassNames.append(CIMNameUnchecked(i.key()));
+                            subClassNames.append(CIMNameCast(i.key()));
                         break;
                     }
                 }
@@ -452,12 +387,12 @@ Boolean InheritanceTree::getSubClassNames(
             else if (deepInheritance)
             {
                 // Append all classes:
-                subClassNames.append(CIMNameUnchecked(i.key()));
+                subClassNames.append(CIMNameCast(i.key()));
             }
             else if (!i.value()->superClass)
             {
                 // Just append root classes:
-                subClassNames.append(CIMNameUnchecked(i.key()));
+                subClassNames.append(CIMNameCast(i.key()));
             }
         }
         return true;
@@ -468,7 +403,7 @@ Boolean InheritanceTree::getSubClassNames(
 
     for (InheritanceTreeRep::Table::Iterator i = _rep->table.start(); i; i++)
     {
-        if (className.equal (CIMNameUnchecked(i.key())))
+        if (className.equal (CIMNameCast(i.key())))
         {
             i.value()->getSubClassNames(subClassNames, deepInheritance, ns);
             return true;
