@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
 //
-//==============================================================================
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -45,8 +43,6 @@ PEGASUS_USING_STD;
 
 PEGASUS_NAMESPACE_BEGIN
 
-static const Uint32 _MAX_FREE_COUNT = 16;
-
 ////////////////////////////////////////////////////////////////////////////////
 //
 // Local routines:
@@ -72,7 +68,7 @@ static Uint32 getOffset( streampos sp )
 //
 // Converts a CIMObjectPath to a form that can be used as a key in the index
 // file.  Newline and carriage return characters are escaped to prevent
-// problems with the line-based file format. 
+// problems with the line-based file format.
 //
 
 static String _convertInstanceNameToKey(const CIMObjectPath& instanceName)
@@ -136,60 +132,6 @@ static CIMObjectPath _convertKeyToInstanceName(const char* key)
     return CIMObjectPath(keyString);
 }
 
-//
-// Gets one line from the given file.
-//
-
-static Boolean _GetLine(fstream& fs, Buffer& x)
-{
-    const Uint32 buffersize = 1023 + 1;
-    Uint32 xcount = 0;
-    Uint32 gcount = 0;
-
-    x.clear();
-    x.reserveCapacity(buffersize);
-
-    // The general idea is, we will read the stream at buffersize each time.
-    // if we get exactly buffersize-1, that means we didn't hit a \n
-    // so we loop again to read more,
-    // until we get a buffer that's not completely full.
-    // That means we hit a \n so we exit the loop.
-    do
-    {
-        char input[buffersize];
-
-        // This will read up to buffersize-1 char,
-        // but stop as soon as it hit \n.
-        // This will NOT consume the \n at the end.
-        fs.get(input, buffersize, '\n');
-
-        gcount = (Uint32)fs.gcount();
-        x.append(input, gcount);
-        xcount += gcount;
-
-    } while (gcount == buffersize-1 && fs.rdstate() != istream::failbit);
-
-    // if we read 0 byte in the last call, that's because the read buffer is
-    // exactly multiple of the input line.
-    // So the 2nd last get() read everything up to the \n and
-    // the last get() read 0 char and set the failbit on the
-    // stream.  The clear() call will set the stream to ready state.
-    if (gcount == 0)
-    {
-        fs.clear();
-    }
-
-    if (!fs.eof())
-    {
-        // we need to consume the '\n', because get() doesn't
-        char c = 0;
-        fs.get(c);
-    }
-
-    // if xcount is non zero, then we have read something from the buffer.
-    return (xcount != 0);
-}
-
 inline void _SkipWhitespace(char*& p)
 {
     while (*p && isspace(*p))
@@ -202,19 +144,19 @@ inline void _SkipWhitespace(char*& p)
 //
 
 Boolean _GetIntField(
-    char*& ptr,
-    Boolean& error,
+    const char*& ptr,
+    Boolean& errorOccurred,
     Uint32& value,
     int base)
 {
     char* end = 0;
     value = strtoul(ptr, &end, base);
 
-    error = false;
+    errorOccurred = false;
 
     if (!end)
     {
-        error = true;
+        errorOccurred = true;
         return false;
     }
 
@@ -222,7 +164,7 @@ Boolean _GetIntField(
 
     if (*end == '\0')
     {
-        error = true;
+        errorOccurred = true;
         return false;
     }
 
@@ -242,29 +184,29 @@ static Boolean _GetNextRecord(
     Uint32& index,
     Uint32& size,
     const char*& instanceName,
-    Boolean& error)
+    Boolean& errorOccurred)
 {
-    error = false;
+    errorOccurred = false;
 
     //
     // Get next line:
     //
 
-    if (!_GetLine(fs, line))
+    if (!GetLine(fs, line))
         return false;
 
     //
     // Get the free flag field:
     //
 
-    char* end = (char*)line.getData();
+    const char* end = (char*)line.getData();
 
-    if (!_GetIntField(end, error, freeFlag, 10))
+    if (!_GetIntField(end, errorOccurred, freeFlag, 10))
         return false;
 
     if (freeFlag != 0 && freeFlag != 1)
     {
-        error = true;
+        errorOccurred = true;
         return false;
     }
 
@@ -272,21 +214,21 @@ static Boolean _GetNextRecord(
     // Get the hash-code field:
     //
 
-    if (!_GetIntField(end, error, hashCode, 16))
+    if (!_GetIntField(end, errorOccurred, hashCode, 16))
         return false;
 
     //
     // Get index field:
     //
 
-    if (!_GetIntField(end, error, index, 10))
+    if (!_GetIntField(end, errorOccurred, index, 10))
         return false;
 
     //
     // Get size field:
     //
 
-    if (!_GetIntField(end, error, size, 10))
+    if (!_GetIntField(end, errorOccurred, size, 10))
         return false;
 
     //
@@ -546,10 +488,10 @@ Boolean InstanceIndexFile::enumerateEntries(
     const char* instanceName;
     Uint32 index;
     Uint32 size;
-    Boolean error;
+    Boolean errorOccurred;
 
     while (_GetNextRecord(
-        fs, line, freeFlag, hashCode, index, size, instanceName, error))
+        fs, line, freeFlag, hashCode, index, size, instanceName, errorOccurred))
     {
         if (!freeFlag || includeFreeEntries)
         {
@@ -560,7 +502,7 @@ Boolean InstanceIndexFile::enumerateEntries(
         }
     }
 
-    if (error)
+    if (errorOccurred)
     {
         PEG_METHOD_EXIT();
         return false;
@@ -776,23 +718,14 @@ Boolean InstanceIndexFile::_lookupEntry(
     sizeOut = 0;
     entryOffset = 0;
 
-    // For for bugzilla 1508. Hostname and namespace are not included
-    // in the comparison here. Instances in the repository index file
-    // are generally stored without hostname and namespace. If the hostname
-    // and namespace of the instance to look up would not match, we would have
-    // not gotten here at all.
-    CIMObjectPath shortInstanceName = instanceName;
-    shortInstanceName.setNameSpace(CIMNamespaceName());
-    shortInstanceName.setHost(String::EMPTY);
-
-    Uint32 targetHashCode = shortInstanceName.makeHashCode();
+    Uint32 targetHashCode = instanceName.makeHashCode();
     Buffer line;
     Uint32 freeFlag;
     Uint32 hashCode;
     const char* instanceNameTmp;
     Uint32 index;
     Uint32 size;
-    Boolean error;
+    Boolean errorOccurred;
 #ifndef PEGASUS_OS_ZOS
         entryOffset = (Uint32)fs.tellp();
 #else
@@ -800,7 +733,8 @@ Boolean InstanceIndexFile::_lookupEntry(
 #endif
 
     while (_GetNextRecord(
-        fs, line, freeFlag, hashCode, index, size, instanceNameTmp, error))
+        fs, line, freeFlag, hashCode, index,
+        size, instanceNameTmp, errorOccurred))
     {
 
 #ifdef PEGASUS_REPOSITORY_NOT_NORMALIZED
@@ -808,11 +742,11 @@ Boolean InstanceIndexFile::_lookupEntry(
         // are not normalized, then the hashcodes cannot be used for
         // the look up (because the hash is based on the normalized path).
         if (freeFlag == 0 &&
-            _convertKeyToInstanceName(instanceNameTmp) == shortInstanceName)
+            _convertKeyToInstanceName(instanceNameTmp) == instanceName)
 #else
         if (freeFlag == 0 &&
             hashCode == targetHashCode &&
-            _convertKeyToInstanceName(instanceNameTmp) == shortInstanceName)
+            _convertKeyToInstanceName(instanceNameTmp) == instanceName)
 #endif
         {
             indexOut = index;
@@ -852,16 +786,25 @@ Boolean InstanceIndexFile::compact(
     }
 
     //
-    // Open temporary file (delete it first):
+    // Open the output file (temporary data file):
     //
 
+    const String outputFilePath = path + ".tmp";
+    String leftoverOutputFilePath;
+
+    // Ensure the output file does not already exist
+    if (FileSystem::existsNoCase(outputFilePath, leftoverOutputFilePath))
+    {
+        if (!FileSystem::removeFile(leftoverOutputFilePath))
+        {
+            PEG_METHOD_EXIT();
+            return false;
+        }
+    }
+
     fstream tmpFs;
-    String tmpPath = path;
-    tmpPath.append(".tmp");
 
-    FileSystem::removeFileNoCase(tmpPath);
-
-    if (!_openFile(tmpPath, tmpFs, true))
+    if (!_openFile(outputFilePath, tmpFs, true))
     {
         PEG_METHOD_EXIT();
         return false;
@@ -877,11 +820,11 @@ Boolean InstanceIndexFile::compact(
     const char* instanceName;
     Uint32 index;
     Uint32 size;
-    Boolean error;
+    Boolean errorOccurred;
     Uint32 adjust = 0;
 
     while (_GetNextRecord(
-        fs, line, freeFlag, hashCode, index, size, instanceName, error))
+        fs, line, freeFlag, hashCode, index, size, instanceName, errorOccurred))
     {
         //
         // Copy the entry over to the temporary file if it is not free.
@@ -898,7 +841,7 @@ Boolean InstanceIndexFile::compact(
             if (!_appendEntry(tmpFs, _convertKeyToInstanceName(instanceName),
                 index - adjust, size))
             {
-                error = true;
+                errorOccurred = true;
                 break;
             }
         }
@@ -917,9 +860,9 @@ Boolean InstanceIndexFile::compact(
     // return false.
     //
 
-    if (error)
+    if (errorOccurred)
     {
-        FileSystem::removeFileNoCase(tmpPath);
+        FileSystem::removeFile(outputFilePath);
         PEG_METHOD_EXIT();
         return false;
     }
@@ -928,20 +871,8 @@ Boolean InstanceIndexFile::compact(
     // Replace index file with temporary file:
     //
 
-    if (!FileSystem::removeFileNoCase(path))
-    {
-        PEG_METHOD_EXIT();
-        return false;
-    }
-
-    if (!FileSystem::renameFile(tmpPath, path))
-    {
-        PEG_METHOD_EXIT();
-        return false;
-    }
-
     PEG_METHOD_EXIT();
-    return true;
+    return FileSystem::renameFile(outputFilePath, path);
 }
 
 Boolean InstanceIndexFile::hasNonFreeEntries(const String& path)
@@ -1057,19 +988,9 @@ Boolean InstanceIndexFile::rollbackTransaction(const String& path)
     }
 
     //
-    // To roll back, simply delete the index file and rename
-    // the rollback file over it.
+    // To roll back, simply rename the rollback file over the index file.
     //
 
-    if (FileSystem::existsNoCase(path))
-    {
-        if (!FileSystem::removeFileNoCase(path))
-        {
-            PEG_METHOD_EXIT();
-            return false;
-        }
-    }
-
     PEG_METHOD_EXIT();
     return FileSystem::renameFileNoCase(path + ".rollback", path);
 }
