@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
 //
-//==============================================================================
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -39,6 +37,7 @@
 #include <Pegasus/Common/CIMInstance.h>
 #include <Pegasus/Common/HashTable.h>
 #include <Pegasus/Common/Mutex.h>
+#include <Pegasus/Common/PegasusAssert.h>
 #include <Pegasus/Repository/Linkage.h>
 
 PEGASUS_NAMESPACE_BEGIN
@@ -52,12 +51,20 @@ public:
 
     ObjectCache(size_t maxEntries);
 
-    void put(const String& path, OBJECT& object);
+    ~ObjectCache()
+    {
+        clear();
+    }
 
-    bool get(const String& path, OBJECT& object);
+    void put(const String& path, OBJECT& object, bool clone = true);
+
+    bool get(const String& path, OBJECT& object, bool clone = true);
 
     bool evict(const String& path);
 
+    // Removes all the entries from the cache.
+    void clear();
+
 #ifdef PEGASUS_DEBUG
     void DisplayCacheStatistics()
     {
@@ -128,7 +135,10 @@ ObjectCache<OBJECT>::ObjectCache(size_t maxEntries)
 }
 
 template<class OBJECT>
-void ObjectCache<OBJECT>::put(const String& path, OBJECT& object)
+void ObjectCache<OBJECT>::put(
+    const String& path,
+    OBJECT& object,
+    bool clone)
 {
     if (_maxEntries == 0)
         return;
@@ -145,32 +155,35 @@ void ObjectCache<OBJECT>::put(const String& path, OBJECT& object)
         if (code == p->code && _equal(p->path, path))
         {
             // Update the repository.
-            p->object = object.clone();
+            if (clone)
+                p->object = object.clone();
+            else
+                p->object = object;
             return;
         }
     }
 
     //// Add to hash table:
 
-    Entry* entry = new Entry(code, path, object);
-    entry->hashNext = _chains[index];
-    _chains[index] = entry;
+    Entry* newEntry = new Entry(code, path, object);
+    newEntry->hashNext = _chains[index];
+    _chains[index] = newEntry;
 
-    //// Add to back of FIFO queue:
+    //// Add to back of LRU queue:
 
-    entry->queueNext = 0;
+    newEntry->queueNext = 0;
 
     if (_back)
     {
-        _back->queueNext = entry;
-        entry->queuePrev = _back;
-        _back = entry;
+        _back->queueNext = newEntry;
+        newEntry->queuePrev = _back;
+        _back = newEntry;
     }
     else
     {
-        _front = entry;
-        _back = entry;
-        entry->queuePrev = 0;
+        _front = newEntry;
+        _back = newEntry;
+        newEntry->queuePrev = 0;
     }
 
     _numEntries++;
@@ -183,17 +196,17 @@ void ObjectCache<OBJECT>::put(const String& path, OBJECT& object)
 
         //// Remove from hash table first.
 
-        Uint32 index = entry->code % NUM_CHAINS;
+        Uint32 frontIndex = entry->code % NUM_CHAINS;
         Entry* hashPrev = 0;
 
-        for (Entry* p = _chains[index]; p; p = p->hashNext)
+        for (Entry* p = _chains[frontIndex]; p; p = p->hashNext)
         {
             if (p->code == entry->code && _equal(p->path, entry->path))
             {
                 if (hashPrev)
                     hashPrev->hashNext = p->hashNext;
                 else
-                    _chains[index] = p->hashNext;
+                    _chains[frontIndex] = p->hashNext;
 
                 break;
             }
@@ -217,7 +230,7 @@ void ObjectCache<OBJECT>::put(const String& path, OBJECT& object)
 }
 
 template<class OBJECT>
-bool ObjectCache<OBJECT>::get(const String& path, OBJECT& object)
+bool ObjectCache<OBJECT>::get(const String& path, OBJECT& object, bool clone)
 {
     if (_maxEntries == 0)
         return false;
@@ -233,9 +246,36 @@ bool ObjectCache<OBJECT>::get(const String& path, OBJECT& object)
     {
         if (code == p->code && _equal(p->path, path))
         {
-            object = p->object.clone();
+            // If this entry is not already at the end of the LRU queue, move
+            // it there.
+
+            if (p->queueNext)
+            {
+                // Remove from queue:
+
+                if (p->queuePrev)
+                    p->queuePrev->queueNext = p->queueNext;
+                else
+                    _front = p->queueNext;
+
+                p->queueNext->queuePrev = p->queuePrev;
+
+                // Add to back of queue:
+
+                PEGASUS_ASSERT(_back);
+                p->queueNext = 0;
+                _back->queueNext = p;
+                p->queuePrev = _back;
+                _back = p;
+            }
+
+            if (clone)
+                object = p->object.clone();
+            else
+                object = p->object;
+
 #ifdef PEGASUS_DEBUG
-        _cacheReadHit++;
+            _cacheReadHit++;
 #endif
             return true;
         }
@@ -302,6 +342,26 @@ bool ObjectCache<OBJECT>::evict(const String& path)
     return false;
 }
 
+template<class OBJECT>
+void ObjectCache<OBJECT>::clear()
+{
+    AutoMutex lock(_mutex);
+
+    Entry* p = _front;
+    while (p)
+    {
+        Entry* next = p->queueNext;
+        delete p;
+        p = next;
+    }
+
+    _front = 0;
+    _back = 0;
+    _numEntries = 0;
+
+    memset(_chains, 0, sizeof(_chains));
+}
+
 PEGASUS_NAMESPACE_END
 
 #endif /* PegasusRepository_ObjectCache_h */
