@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -51,7 +49,7 @@ PEGASUS_NAMESPACE_BEGIN
 
 BasicAuthenticationHandler::BasicAuthenticationHandler()
 {
-    PEG_METHOD_ENTER(TRC_AUTHENTICATION, 
+    PEG_METHOD_ENTER(TRC_AUTHENTICATION,
         "BasicAuthenticationHandler::BasicAuthenticationHandler()");
 
 #ifdef PEGASUS_PAM_AUTHENTICATION
@@ -65,7 +63,7 @@ BasicAuthenticationHandler::BasicAuthenticationHandler()
 
 BasicAuthenticationHandler::~BasicAuthenticationHandler()
 {
-    PEG_METHOD_ENTER(TRC_AUTHENTICATION, 
+    PEG_METHOD_ENTER(TRC_AUTHENTICATION,
         "BasicAuthenticationHandler::~BasicAuthenticationHandler()");
 
     delete _basicAuthenticator;
@@ -73,7 +71,7 @@ BasicAuthenticationHandler::~BasicAuthenticationHandler()
     PEG_METHOD_EXIT();
 }
 
-Boolean BasicAuthenticationHandler::authenticate(    
+Boolean BasicAuthenticationHandler::authenticate(
     const String& authHeader,
     AuthenticationInfo* authInfo)
 {
@@ -104,7 +102,7 @@ Boolean BasicAuthenticationHandler::authenticate(
 
     decodedArray = Base64::decode( userPassArray );
 
-    String decodedStr = 
+    String decodedStr =
         String( (const char*)decodedArray.getData(), decodedArray.size() );
 
     Uint32 pos = decodedStr.find(':');
@@ -124,15 +122,17 @@ Boolean BasicAuthenticationHandler::authenticate(
     {
         String badUserName = userName.subString(0, PEGASUS_MAX_USER_NAME_LEN);
 
-        Logger::put_l (Logger::STANDARD_LOG, System::CIMSERVER,
-                Logger::INFORMATION,  BASIC_AUTHENTICATION_FAILED_KEY, 
-                BASIC_AUTHENTICATION_FAILED, badUserName );
+        Logger::put_l(Logger::STANDARD_LOG, System::CIMSERVER,
+            Logger::INFORMATION,
+            MessageLoaderParms(
+                BASIC_AUTHENTICATION_FAILED_KEY,
+                BASIC_AUTHENTICATION_FAILED, badUserName));
         PEG_METHOD_EXIT();
         return false;
     }
 
     // PASE APIs require user profile to be uppercase
-#ifdef PEGASUS_OS_PASE 
+#ifdef PEGASUS_OS_PASE
     for (Uint32 i = 0; i < userNameLen; i++)
     {
         userName[i] = toupper(userName[i]);
@@ -169,9 +169,11 @@ Boolean BasicAuthenticationHandler::authenticate(
         //
         //  Log a message for basic authentication failure
         //
-        Logger::put_l (Logger::STANDARD_LOG, System::CIMSERVER,
-                       Logger::INFORMATION,  BASIC_AUTHENTICATION_FAILED_KEY, 
-                       BASIC_AUTHENTICATION_FAILED, userName );
+        Logger::put_l(Logger::STANDARD_LOG, System::CIMSERVER,
+            Logger::INFORMATION,
+            MessageLoaderParms(
+                BASIC_AUTHENTICATION_FAILED_KEY,
+                BASIC_AUTHENTICATION_FAILED, userName));
     }
 #endif
 
@@ -190,7 +192,7 @@ String BasicAuthenticationHandler::getAuthResponseHeader(
     const String& userName,
     AuthenticationInfo* authInfo)
 {
-    PEG_METHOD_ENTER(TRC_AUTHENTICATION, 
+    PEG_METHOD_ENTER(TRC_AUTHENTICATION,
         "BasicAuthenticationHandler::getAuthResponseHeader()");
 
     String respHeader = _basicAuthenticator->getAuthResponseHeader();
