@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -49,6 +47,7 @@
 #include \
     <Pegasus/Server/ProviderRegistrationManager/ProviderRegistrationManager.h>
 #include <Pegasus/Server/Linkage.h>
+#include <Pegasus/Server/reg_table.h>
 
 #include <Pegasus/Common/QueryExpressionRep.h>
 
@@ -60,8 +59,9 @@ PEGASUS_NAMESPACE_BEGIN
 class PEGASUS_SERVER_LINKAGE ProviderInfo
 {
 public:
-    ProviderInfo(const CIMName& className)
-        : className(className),
+    ProviderInfo(const CIMName& className_)
+        : className(className_),
+          serviceId(0),
           hasProvider(false),
           hasProviderNormalization(false),
           hasNoQuery(true)
@@ -69,12 +69,12 @@ public:
     }
 
     ProviderInfo(
-        const CIMName& className,
-        const String& serviceName,
-        const String& controlProviderName)
-        : className(className),
-          serviceName(serviceName),
-          controlProviderName(controlProviderName),
+        const CIMName& className_,
+        Uint32 serviceId_,
+        const String& controlProviderName_)
+        : className(className_),
+          serviceId(serviceId_),
+          controlProviderName(controlProviderName_),
           hasProvider(false),
           hasProviderNormalization(false),
           hasNoQuery(true)
@@ -83,7 +83,7 @@ public:
 
     ProviderInfo(const ProviderInfo& providerInfo)
         : className(providerInfo.className),
-          serviceName(providerInfo.serviceName),
+          serviceId(providerInfo.serviceId),
           controlProviderName(providerInfo.controlProviderName),
           hasProvider(providerInfo.hasProvider),
           hasProviderNormalization(providerInfo.hasProviderNormalization),
@@ -101,7 +101,7 @@ public:
         if (&providerInfo != this)
         {
             className = providerInfo.className;
-            serviceName = providerInfo.serviceName;
+            serviceId = providerInfo.serviceId;
             controlProviderName = providerInfo.controlProviderName;
             hasProvider = providerInfo.hasProvider;
             hasProviderNormalization = providerInfo.hasProviderNormalization;
@@ -120,7 +120,7 @@ public:
     }
 
     CIMName className;
-    String serviceName;
+    Uint32 serviceId;
     String controlProviderName;
     Boolean hasProvider;
     Boolean hasProviderNormalization;
@@ -358,7 +358,7 @@ protected:
     Boolean _lookupInternalProvider(
         const CIMNamespaceName& nameSpace,
         const CIMName& className,
-        String& service,
+        Uint32 &serviceId,
         String& provider);
 
     /* Boolean _lookupNewQueryProvider(
@@ -402,7 +402,7 @@ protected:
     Boolean _lookupNewAssociationProvider(
         const CIMNamespaceName& nameSpace,
         const CIMName& assocClass,
-        String& serviceName,
+        Uint32 &serviceId,
         String& controlProviderName,
         ProviderIdContainer** container);
 
@@ -418,12 +418,12 @@ protected:
         ProviderIdContainer** providerIdContainer);
 
     void _forwardRequestToService(
-        const String& serviceName,
+        Uint32 serviceId,
         CIMRequestMessage* request,
         CIMRequestMessage* requestCopy);
 
     void _forwardRequestForAggregation(
-        const String& serviceName,
+        Uint32 serviceId,
         const String& controlProviderName,
         CIMRequestMessage* request,
         OperationAggregate* poA,
@@ -431,7 +431,7 @@ protected:
 
     void _forwardRequestToProviderManager(
         const CIMName& className,
-        const String& serviceName,
+        Uint32 serviceId,
         const String& controlProviderName,
         CIMRequestMessage* request,
         CIMRequestMessage* requestCopy);
@@ -471,7 +471,7 @@ protected:
         const CIMNamespaceName& nameSpace,
         const CIMName& className);
 
-    CIMClass _getClass(
+    CIMConstClass _getClass(
         const CIMNamespaceName& nameSpace,
         const CIMName& className,
         CIMException& cimException);
@@ -499,9 +499,8 @@ protected:
     Boolean _enableIndicationService;
     Uint32 _maximumEnumerateBreadth;
     static Uint64 cimOperationAggregationSN;
-
+    Uint32 _providerManagerServiceId;
 #ifdef PEGASUS_ENABLE_OBJECT_NORMALIZATION
-    Boolean _enableNormalization;
     Array<String> _excludeModulesFromNormalization;
 #endif
 
@@ -523,6 +522,7 @@ protected:
 private:
     static void _handle_enqueue_callback(AsyncOpNode*, MessageQueue*, void*);
 
+    DynamicRoutingTable *_routing_table;
 };
 
 PEGASUS_NAMESPACE_END
