@@ -1,41 +1,41 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
 #include <Pegasus/Common/Config.h>
 #include <Pegasus/Common/Constants.h>
+#include <Pegasus/Common/CIMBuffer.h>
 #include <cctype>
 #include <cstdio>
 #include <Pegasus/Common/HTTPConnection.h>
+#include <Pegasus/Common/BinaryCodec.h>
 #include <Pegasus/Common/XmlParser.h>
 #include <Pegasus/Common/XmlReader.h>
 #include <Pegasus/Common/XmlWriter.h>
@@ -51,10 +51,6 @@ PEGASUS_USING_STD;
 
 PEGASUS_NAMESPACE_BEGIN
 
-const String CIMOperationResponseEncoder::OUT_OF_MEMORY_MESSAGE =
-    "A System error has occurred. Please retry the CIM Operation at a "
-        "later time.";
-
 CIMOperationResponseEncoder::CIMOperationResponseEncoder()
     : Base(PEGASUS_QUEUENAME_OPRESPENCODER)
 {
@@ -64,16 +60,63 @@ CIMOperationResponseEncoder::~CIMOperationResponseEncoder()
 {
 }
 
+//==============================================================================
+//
+// CIMOperationResponseEncoder::sendResponse()
+//
+//     This function is called once for every chunk comprising the inner part
+//     of the HTTP payload. This is true whether chunking is enabled or not.
+//     The "bodygiven" parameter contains all or part of the inner response
+//     body. For example, in the case of the enumerate-instances XML response,
+//     each "bodygiven" contains a complete named-instance as shown below.
+//
+//         <VALUE.NAMEDINSTANCE>
+//         ...
+//         <VALUE.NAMEDINSTANCE>
+//
+//     In the case of the get-class XML response, bodygiven contains the
+//     entire class. Sometimes bodygiven is null, probably indicating that
+//     one of the responding threads returned an empty response (for example,
+//     a provider may return zero instances).
+//
+//     This function wraps the inner payload with the following elements:
+//
+//         1. HTTP status line.
+//         2. HTTP headers.
+//         3. Payload header.
+//         4. Payload footer.
+//
+//     In the case of an enumerate-instances XML response, the payload header
+//     contains all the XML leading up to the first XML chunk. For example:
+//
+//         <?xml version="1.0" encoding="utf-8" ?>
+//         <CIM CIMVERSION="2.0" DTDVERSION="2.0">
+//         <MESSAGE ID="1000" PROTOCOLVERSION="1.0">
+//         <SIMPLERSP>
+//         <IMETHODRESPONSE NAME="EnumerateInstances">
+//         <IRETURNVALUE>
+//
+//     The payload footer then would just contain the closing tags for these:
+//
+//         </IRETURNVALUE>
+//         </IMETHODRESPONSE>
+//         </MESSAGE>
+//         </SIMPLERSP>
+//         </CIM>
+//
+//==============================================================================
+
 void CIMOperationResponseEncoder::sendResponse(
     CIMResponseMessage* response,
     const String& name,
     Boolean isImplicit,
     Buffer* bodygiven)
 {
-    static String funcname = "CIMOperationResponseEncoder::sendResponse: ";
-    static String funcnameClassS = String(funcname + "for class " + name);
-    static CString funcnameClass = funcnameClassS.getCString();
-    PEG_METHOD_ENTER(TRC_DISPATCHER, funcnameClass);
+    PEG_METHOD_ENTER(TRC_DISPATCHER,
+        "CIMOperationResponseEncoder::sendResponse");
+    PEG_TRACE((TRC_HTTP, Tracer::LEVEL4,
+        "name = %s",
+        (const char*)name.getCString()));
 
     if (! response)
     {
@@ -87,7 +130,7 @@ void CIMOperationResponseEncoder::sendResponse(
     Boolean closeConnect = response->getCloseConnect();
     PEG_TRACE((
         TRC_HTTP,
-        Tracer::LEVEL3,
+        Tracer::LEVEL4,
         "CIMOperationResponseEncoder::sendResponse()- "
             "response->getCloseConnect() returned %d",
         closeConnect));
@@ -96,7 +139,7 @@ void CIMOperationResponseEncoder::sendResponse(
 
     if (!queue)
     {
-        PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL2,
+        PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL1,
             "ERROR: non-existent queueId = %u, response not sent.", queueId));
         PEG_METHOD_EXIT();
         return;
@@ -106,7 +149,7 @@ void CIMOperationResponseEncoder::sendResponse(
 
     if (! httpQueue)
     {
-        PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL2,
+        PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL1,
             "ERROR: Unknown queue type. queueId = %u, response not sent.",
             queueId));
         PEG_METHOD_EXIT();
@@ -163,8 +206,16 @@ void CIMOperationResponseEncoder::sendResponse(
     }
     else
     {
-        formatResponse = XmlWriter::formatSimpleIMethodRspMessage;
         formatError = XmlWriter::formatSimpleIMethodErrorRspMessage;
+
+        if (response->binaryResponse)
+        {
+            formatResponse = BinaryCodec::formatSimpleIMethodRspMessage;
+        }
+        else
+        {
+            formatResponse = XmlWriter::formatSimpleIMethodRspMessage;
+        }
     }
 
     if (cimException.getCode() != CIM_ERR_SUCCESS)
@@ -228,19 +279,18 @@ void CIMOperationResponseEncoder::sendResponse(
                 isFirst,
                 isLast);
         }
-#if defined(PEGASUS_OS_TYPE_WINDOWS)
-        catch (std::bad_alloc&)
-#else
-        catch (bad_alloc&)
-#endif
+        catch (PEGASUS_STD(bad_alloc)&)
         {
-            Logger::put(Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
-                funcname + OUT_OF_MEMORY_MESSAGE);
+            MessageLoaderParms parms(
+                "Server.CIMOperationResponseEncoder.OUT_OF_MEMORY",
+                "A System error has occurred. Please retry the CIM Operation "
+                    "at a later time.");
 
-            cimException = PEGASUS_CIM_EXCEPTION_L(
-                CIM_ERR_FAILED, MessageLoaderParms(
-                    "Server.CIMOperationResponseEncoder.OUT_OF_MEMORY",
-                    OUT_OF_MEMORY_MESSAGE));
+            Logger::put_l(
+                Logger::ERROR_LOG, System::CIMSERVER, Logger::WARNING,
+                parms);
+
+            cimException = PEGASUS_CIM_EXCEPTION_L(CIM_ERR_FAILED, parms);
 
             // try again with new error and no body
             body.clear();
@@ -271,16 +321,8 @@ void CIMOperationResponseEncoder::sendResponse(
         httpMessage->contentLanguages = contentLanguage;
     }
 
-
-    PEG_LOGGER_TRACE((
-        Logger::STANDARD_LOG,
-        System::CIMSERVER,
-        Logger::TRACE,
-        "CIMOperationResponseEncoder::sendResponse - QueueId: $0  "
-            "XML content: $1",queueId,
-        String(message.getData(), message.size())));
-
     httpMessage->setCloseConnect(closeConnect);
+
     queue->enqueue(httpMessage.release());
 
     PEG_METHOD_EXIT();
@@ -302,22 +344,40 @@ void CIMOperationResponseEncoder::handleEnqueue(Message* message)
         return;
     }
 
-    CIMResponseMessage* response = (CIMResponseMessage*)message;
-    if (response->thread_changed())
-    {
-        AutoPtr<AcceptLanguageList> langs(new AcceptLanguageList((
-            (AcceptLanguageListContainer)response->operationContext.get(
-                AcceptLanguageListContainer::NAME)).getLanguages()));
-        Thread::setLanguages(langs.release());
-    }
+    CIMResponseMessage* response = dynamic_cast<CIMResponseMessage*>(message);
+    PEGASUS_ASSERT(response);
+
+    response->updateThreadLanguages();
 
     PEG_TRACE((
         TRC_HTTP,
-        Tracer::LEVEL3,
+        Tracer::LEVEL4,
         "CIMOperationResponseEncoder::handleEnque()- "
             "message->getCloseConnect() returned %d",
         message->getCloseConnect()));
 
+    // Handle binary messages up front:
+    {
+        CIMResponseMessage* msg = dynamic_cast<CIMResponseMessage*>(message);
+
+        if (msg && msg->binaryResponse)
+        {
+            if (msg->cimException.getCode() == CIM_ERR_SUCCESS)
+            {
+                Buffer body;
+                CIMName name;
+
+                if (BinaryCodec::encodeResponseBody(body, msg, name))
+                {
+                    sendResponse(msg, name.getString(), true, &body);
+                    delete msg;
+                    PEG_METHOD_EXIT();
+                    return;
+                }
+            }
+        }
+    }
+
     switch (message->getType())
     {
         case CIM_GET_CLASS_RESPONSE_MESSAGE:
@@ -520,7 +580,18 @@ void CIMOperationResponseEncoder::encodeGetInstanceResponse(
 {
     Buffer body;
     if (response->cimException.getCode() == CIM_ERR_SUCCESS)
-        XmlWriter::appendInstanceElement(body, response->cimInstance);
+    {
+        if (response->resolveCallback && !response->binaryEncoding)
+        {
+            body.append(
+                (char*)response->instanceData.getData(),
+                response->instanceData.size()-1);
+        }
+        else
+        {
+            XmlWriter::appendInstanceElement(body, response->getCimInstance());
+        }
+    }
     sendResponse(response, "GetInstance", true, &body);
 }
 
@@ -534,10 +605,31 @@ void CIMOperationResponseEncoder::encodeEnumerateInstancesResponse(
     CIMEnumerateInstancesResponseMessage* response)
 {
     Buffer body;
+
     if (response->cimException.getCode() == CIM_ERR_SUCCESS)
-        for (Uint32 i = 0, n = response->cimNamedInstances.size(); i < n; i++)
-            XmlWriter::appendValueNamedInstanceElement(
-                body, response->cimNamedInstances[i]);
+    {
+        if (response->resolveCallback && !response->binaryEncoding)
+        {
+            const Array<ArraySint8>& a = response->instancesData;
+            const Array<ArraySint8>& b = response->referencesData;
+
+            for (Uint32 i = 0, n = a.size(); i < n; i++)
+            {
+                body << STRLIT("<VALUE.NAMEDINSTANCE>\n");
+                body.append((char*)b[i].getData(), b[i].size() - 1);
+                body.append((char*)a[i].getData(), a[i].size() - 1);
+                body << STRLIT("</VALUE.NAMEDINSTANCE>\n");
+            }
+        }
+        else
+        {
+            const Array<CIMInstance>& a = response->getNamedInstances();
+
+            for (Uint32 i = 0, n = a.size(); i < n; i++)
+                XmlWriter::appendValueNamedInstanceElement(body, a[i]);
+        }
+    }
+
     sendResponse(response, "EnumerateInstances", true, &body);
 }
 
@@ -545,10 +637,13 @@ void CIMOperationResponseEncoder::encodeEnumerateInstanceNamesResponse(
     CIMEnumerateInstanceNamesResponseMessage* response)
 {
     Buffer body;
+
     if (response->cimException.getCode() == CIM_ERR_SUCCESS)
+    {
         for (Uint32 i = 0, n = response->instanceNames.size(); i < n; i++)
             XmlWriter::appendInstanceNameElement(
                 body, response->instanceNames[i]);
+    }
     sendResponse(response, "EnumerateInstanceNames", true, &body);
 }
 
