@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
 //
-//=============================================================================
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%////////////////////////////////////////////////////////////////////////////
 
@@ -87,16 +85,18 @@ void ZOSConsoleManager::stripTrailingBlanks( char* token )
 
 void ZOSConsoleManager::issueSyntaxError(const char* command)
 {
-    PEG_METHOD_ENTER(TRC_SERVER, 
+    PEG_METHOD_ENTER(TRC_SERVER,
         "ZOSConsoleManager::issueSyntaxError");
     Logger::put_l(
         Logger::ERROR_LOG, System::CIMSERVER, Logger::SEVERE,
-        "Server.ConsoleManager_zOS.CON_SYNTAX_ERR.PEGASUS_OS_ZOS",
-        "CIM MODIFY COMMAND REJECTED DUE TO SYNTAX ERROR");
+        MessageLoaderParms(
+            "Server.ConsoleManager_zOS.CON_SYNTAX_ERR.PEGASUS_OS_ZOS",
+            "CIM MODIFY COMMAND REJECTED DUE TO SYNTAX ERROR"));
     Logger::put_l(
         Logger::STANDARD_LOG, System::CIMSERVER, Logger::INFORMATION,
-        "Server.ConsoleManager_zOS.CON_MODIFY_SYNTAX.PEGASUS_OS_ZOS",
-        "Syntax is: MODIFY CFZCIM,APPL=CONFIG,<name>=<value>[,PLANNED]");
+        MessageLoaderParms(
+            "Server.ConsoleManager_zOS.CON_MODIFY_SYNTAX.PEGASUS_OS_ZOS",
+            "Syntax is: MODIFY CFZCIM,APPL=CONFIG,<name>=<value>[,PLANNED]"));
 
     PEG_METHOD_EXIT();
     return;
@@ -108,7 +108,7 @@ void ZOSConsoleManager::updateConfiguration( const String& configProperty,
                                              Boolean currentValueIsNull,
                                              Boolean planned)
 {
-    PEG_METHOD_ENTER(TRC_SERVER, 
+    PEG_METHOD_ENTER(TRC_SERVER,
         "ZOSConsoleManager::updateConfiguration");
 
     String preValue;
@@ -131,19 +131,21 @@ void ZOSConsoleManager::updateConfiguration( const String& configProperty,
             {
                 Logger::put_l(
                     Logger::ERROR_LOG, System::CIMSERVER, Logger::SEVERE,
-                    "Server.ConsoleManager_zOS."
-                     "CON_MODIFY_FAILED.PEGASUS_OS_ZOS",
-                    "Failed to update CONFIG value.");
+                    MessageLoaderParms(
+                        "Server.ConsoleManager_zOS."
+                            "CON_MODIFY_FAILED.PEGASUS_OS_ZOS",
+                        "Failed to update CONFIG value."));
             }
             else
             {
                 Logger::put_l(
                     Logger::STANDARD_LOG, System::CIMSERVER,
                     Logger::INFORMATION,
-                    "Server.ConsoleManager_zOS."
-                     "CON_MODIFY_UPDATED.PEGASUS_OS_ZOS",
-                    "Updated current value for $0 to $1",
-                    configProperty, propertyValue);
+                    MessageLoaderParms(
+                        "Server.ConsoleManager_zOS."
+                            "CON_MODIFY_UPDATED.PEGASUS_OS_ZOS",
+                        "Updated current value for $0 to $1",
+                        configProperty, propertyValue));
             }
         }
         else
@@ -157,26 +159,29 @@ void ZOSConsoleManager::updateConfiguration( const String& configProperty,
             {
                 Logger::put_l(
                     Logger::ERROR_LOG, System::CIMSERVER, Logger::SEVERE,
-                    "Server.ConsoleManager_zOS."
-                     "CON_MODIFY_FAILED.PEGASUS_OS_ZOS",
-                    "Failed to update CONFIG value.");
+                    MessageLoaderParms(
+                        "Server.ConsoleManager_zOS."
+                            "CON_MODIFY_FAILED.PEGASUS_OS_ZOS",
+                        "Failed to update CONFIG value."));
             }
             else
             {
                 Logger::put_l(
                     Logger::STANDARD_LOG, System::CIMSERVER,
                     Logger::INFORMATION,
-                    "Server.ConsoleManager_zOS."
-                     "CON_MODIFY_PLANNED.PEGASUS_OS_ZOS",
-                    "Updated planned value for $0 to $1",
-                    configProperty, propertyValue);
+                    MessageLoaderParms(
+                        "Server.ConsoleManager_zOS."
+                            "CON_MODIFY_PLANNED.PEGASUS_OS_ZOS",
+                        "Updated planned value for $0 to $1",
+                        configProperty, propertyValue));
                 Logger::put_l(
                     Logger::STANDARD_LOG, System::CIMSERVER,
                     Logger::INFORMATION,
-                    "Server.ConsoleManager_zOS."
-                     "CON_MODIFY_PLANNED2.PEGASUS_OS_ZOS",
-                    "This change will become effective "
-                    "after CIM Server restart.");
+                    MessageLoaderParms(
+                        "Server.ConsoleManager_zOS."
+                            "CON_MODIFY_PLANNED2.PEGASUS_OS_ZOS",
+                        "This change will become effective "
+                        "after CIM Server restart."));
             }
         }
 
@@ -206,25 +211,28 @@ void ZOSConsoleManager::updateConfiguration( const String& configProperty,
     {
         Logger::put_l(
             Logger::ERROR_LOG, System::CIMSERVER, Logger::SEVERE,
-            "Server.ConsoleManager_zOS.CON_MODIFY_ERR.PEGASUS_OS_ZOS",
-            "MODIFY command failed: \"$0\"",
-            ndcp.getMessage());
+            MessageLoaderParms(
+                "Server.ConsoleManager_zOS.CON_MODIFY_ERR.PEGASUS_OS_ZOS",
+                "MODIFY command failed: \"$0\"",
+                ndcp.getMessage()));
     }
     catch (const InvalidPropertyValue& ipv)
     {
         Logger::put_l(
             Logger::ERROR_LOG, System::CIMSERVER, Logger::SEVERE,
-            "Server.ConsoleManager_zOS.CON_MODIFY_ERR.PEGASUS_OS_ZOS",
-            "MODIFY command failed: \"$0\"",
-            ipv.getMessage());
+            MessageLoaderParms(
+                "Server.ConsoleManager_zOS.CON_MODIFY_ERR.PEGASUS_OS_ZOS",
+                "MODIFY command failed: \"$0\"",
+                ipv.getMessage()));
     }
     catch (const UnrecognizedConfigProperty&)
     {
         Logger::put_l(
             Logger::ERROR_LOG, System::CIMSERVER, Logger::SEVERE,
-            "Server.ConsoleManager_zOS.CON_MODIFY_INVALID.PEGASUS_OS_ZOS",
-            "$0 is not a valid configuration property",
-            configProperty);
+            MessageLoaderParms(
+                "Server.ConsoleManager_zOS.CON_MODIFY_INVALID.PEGASUS_OS_ZOS",
+                "$0 is not a valid configuration property",
+                configProperty));
     }
 
     PEG_METHOD_EXIT();
@@ -234,7 +242,7 @@ void ZOSConsoleManager::updateConfiguration( const String& configProperty,
 
 void ZOSConsoleManager::processModifyCommand( char* command )
 {
-    PEG_METHOD_ENTER(TRC_SERVER, 
+    PEG_METHOD_ENTER(TRC_SERVER,
         "ZOSConsoleManager::processModifyCommand");
 
     char* currentPtr = command;
@@ -371,7 +379,7 @@ void ZOSConsoleManager::processModifyCommand( char* command )
 
 void ZOSConsoleManager::startConsoleWatchThread(void)
 {
-    PEG_METHOD_ENTER(TRC_SERVER, 
+    PEG_METHOD_ENTER(TRC_SERVER,
         "ZOSConsoleManager::startConsoleWatchThread");
 
     pthread_t thid;
@@ -384,12 +392,13 @@ void ZOSConsoleManager::startConsoleWatchThread(void)
         char str_errno2[10];
         sprintf(str_errno2,"%08X",__errno2());
         Logger::put_l(Logger::ERROR_LOG, System::CIMSERVER, Logger::SEVERE,
-            "Server.ConsoleManager_zOS.NO_CONSOLE_THREAD.PEGASUS_OS_ZOS",
-            "CIM Server Console command thread cannot be created: "
-                "$0 ( errno $1, reason code 0x$2 ).",
-            strerror(errno),
-            errno,
-            str_errno2);
+            MessageLoaderParms(
+                "Server.ConsoleManager_zOS.NO_CONSOLE_THREAD.PEGASUS_OS_ZOS",
+                "CIM Server Console command thread cannot be created: "
+                    "$0 ( errno $1, reason code 0x$2 ).",
+                strerror(errno),
+                errno,
+                str_errno2));
     }
 
     PEG_METHOD_EXIT();
@@ -403,7 +412,7 @@ void ZOSConsoleManager::startConsoleWatchThread(void)
 //
 void* ZOSConsoleManager::consoleCommandWatchThread(void*)
 {
-    PEG_METHOD_ENTER(TRC_SERVER, 
+    PEG_METHOD_ENTER(TRC_SERVER,
         "ZOSConsoleManager::consoleCommandWatchThread");
 
     struct __cons_msg    cons;
@@ -424,17 +433,15 @@ void* ZOSConsoleManager::consoleCommandWatchThread(void*)
             char str_errno2[10];
             sprintf(str_errno2,"%08X",__errno2());
 
-            PEG_TRACE((TRC_SERVER, Tracer::LEVEL2,
-                "Failed to issue __console() command: %s",
-                       strerror(errornumber)));
             Logger::put_l(
                 Logger::ERROR_LOG, System::CIMSERVER, Logger::SEVERE,
-                "Server.ConsoleManager_zOS.CONSOLE_ERROR.PEGASUS_OS_ZOS",
-                "Console Communication Service failed:"
-                "$0 ( errno $1, reason code 0x$2 ).",
-                strerror(errornumber),
-                errornumber,
-                str_errno2);
+                MessageLoaderParms(
+                    "Server.ConsoleManager_zOS.CONSOLE_ERROR.PEGASUS_OS_ZOS",
+                    "Console Communication Service failed:"
+                        "$0 ( errno $1, reason code 0x$2 ).",
+                    strerror(errornumber),
+                    errornumber,
+                    str_errno2));
 
             break;
         }
@@ -457,16 +464,19 @@ void* ZOSConsoleManager::consoleCommandWatchThread(void*)
             // not recognized and wait again for the stop command.
             Logger::put_l(
                 Logger::STANDARD_LOG, System::CIMSERVER, Logger::INFORMATION,
-                "Server.ConsoleManager_zOS.CONSOLE_NO_MODIFY.PEGASUS_OS_ZOS",
-                "Command not recognized by CIM server.");
+                MessageLoaderParms(
+                    "Server.ConsoleManager_zOS.CONSOLE_NO_MODIFY."
+                        "PEGASUS_OS_ZOS",
+                    "Command not recognized by CIM server."));
         }
         else
         {
             Logger::put_l(
                 Logger::STANDARD_LOG, System::CIMSERVER, Logger::INFORMATION,
-                "Server.ConsoleManager_zOS.CONSOLE_STOP.PEGASUS_OS_ZOS",
-                "STOP command received from z/OS console,"
-                    " initiating shutdown.");
+                MessageLoaderParms(
+                    "Server.ConsoleManager_zOS.CONSOLE_STOP.PEGASUS_OS_ZOS",
+                    "STOP command received from z/OS console,"
+                        " initiating shutdown."));
         }
 
     // keep on until we encounter an error or received a STOP
@@ -518,8 +528,7 @@ void ZOSConsoleManager::_sendNotifyConfigChangeMessage(
         AsyncLegacyOperationStart asyncRequest(
             NULL,
             service->getQueueId(),
-            notify_req,
-            service->getQueueId());
+            notify_req);
 
         AutoPtr<AsyncReply> asyncReply(
             controller->ClientSendWait(service->getQueueId(), &asyncRequest));
