@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%////////////////////////////////////////////////////////////////////////////
 
@@ -129,7 +127,9 @@ void ShutdownService::shutdown(
         //
         _cimserver->setState(CIMServerState::TERMINATING);
 
-        Logger::put(Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
+        PEG_TRACE_CSTRING(
+            TRC_SHUTDOWN,
+            Tracer::LEVEL4,
             "ShutdownService::shutdown - CIM server state set to "
                 "CIMServerState::TERMINATING");
 
@@ -138,8 +138,9 @@ void ShutdownService::shutdown(
         //
         _cimserver->stopClientConnection();
 
-
-        Logger::put(Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
+        PEG_TRACE_CSTRING(
+            TRC_SHUTDOWN,
+            Tracer::LEVEL3,
             "ShutdownService::shutdown - No longer accepting new client "
                 "connection requests.");
 
@@ -149,24 +150,32 @@ void ShutdownService::shutdown(
         //
         Boolean noMoreRequests = waitUntilNoMoreRequests(requestPending);
 
-        Logger::put(Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
+        PEG_TRACE((
+            TRC_SHUTDOWN,
+            Tracer::LEVEL4,
             "ShutdownService::shutdown - All outstanding CIM operations "
-                "complete = $0",
-            noMoreRequests);
+                "complete = %s",
+            (noMoreRequests) ? "true" : "false"));
 
         //
-        // proceed to shutdown the CIMServer
+        // Send a shutdown signal to the CIMServer. CIMServer itself will take
+        // care of shutting down the CimomServices and deleting them. In other
+        // words, _DO_ _NOT_ call 'shutdownCimomServices' from a provider.
         //
-        _shutdownCIMServer();
+        _cimserver->shutdown();
+
+        PEG_TRACE_CSTRING(TRC_SHUTDOWN, Tracer::LEVEL3,
+            "ShutdownService::shutdown - CIMServer instructed to shut down.");
     }
     catch (Exception& e)
     {
-        PEG_TRACE_STRING(TRC_SHUTDOWN, Tracer::LEVEL4,
-            "Error occurred during CIMServer shutdown: " + e.getMessage());
+        PEG_TRACE((TRC_SHUTDOWN, Tracer::LEVEL2,
+            "Error occurred during CIMServer shutdown: %s",
+            (const char*)e.getMessage().getCString()));
     }
     catch (...)
     {
-        PEG_TRACE_CSTRING(TRC_SHUTDOWN, Tracer::LEVEL4,
+        PEG_TRACE_CSTRING(TRC_SHUTDOWN, Tracer::LEVEL2,
             "Unexpected error occurred during CIMServer shutdown. ");
     }
 
@@ -177,34 +186,6 @@ void ShutdownService::shutdown(
 /*  private methods                                       */
 /**********************************************************/
 
-void ShutdownService::_shutdownCIMServer()
-{
-    PEG_METHOD_ENTER(TRC_SHUTDOWN, "ShutdownService::_shutdownCIMServer");
-
-    //
-    // Shutdown the providers
-    //
-
-    _shutdownProviders();
-
-    Logger::put(Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
-        "ShutdownService::_shutdownCIMServer - CIM server provider shutdown "
-            "complete");
-
-    //
-    // Send a shutdown signal to the CIMServer. CIMServer itself will take
-    // care of shutting down the CimomServices and deleting them. In other
-    // words, _DO_ _NOT_ call 'shutdownCimomServices' from a provider.
-    //
-    _cimserver->shutdown();
-
-    Logger::put(Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
-        "ShutdownService::_shutdownCIMServer - Cimom services shutdown "
-            "complete");
-
-    PEG_METHOD_EXIT();
-}
-
 void ShutdownService::shutdownCimomServices()
 {
     PEG_METHOD_ENTER(TRC_SHUTDOWN, "ShutdownService::shutdownCimomServices");
@@ -249,11 +230,6 @@ void ShutdownService::shutdownCimomServices()
     //
     _sendShutdownRequestToService(PEGASUS_QUEUENAME_EXPORTREQDISPATCHER);
 
-    //
-    // shutdown binary message handler
-    //
-    _sendShutdownRequestToService(PEGASUS_QUEUENAME_BINARY_HANDLER);
-
     //
     // shutdown  CIM Operation Request Dispatcher Service
     //
@@ -272,21 +248,20 @@ void ShutdownService::_sendShutdownRequestToService(const char* serviceName)
 {
     MessageQueueService* _mqs = static_cast<MessageQueueService*>(_controller);
 
-    Array<Uint32> _services;
+    MessageQueue *queue = MessageQueue::lookup(serviceName);
     Uint32 _queueId;
-
-    _mqs->find_services(String(serviceName), 0, 0, &_services);
-
-    if (_services.size() == 0 )
+    if (queue)
+    {
+        _queueId =  queue->getQueueId();
+    }
+    else
     {
         // service not found, just return
         return;
     }
-    _queueId = _services[0];
-
     // send a Stop (this is a legacy message that in some of the MQS does
     // termination of its internal stuff. Then follow it with a Stop (to
-    // open up its incoming queue), and then with a AsyncIoctl::IO_CLOSE
+    // open up its incoming queue), and then with a AsyncIoClose
     // which closes the incoming queue.
 
     // All of these messages MUST be sequential. Do not use SendForget or
@@ -312,22 +287,19 @@ void ShutdownService::_sendShutdownRequestToService(const char* serviceName)
     AutoPtr <AsyncReply> StartAsyncReply(
         _controller->ClientSendWait(_queueId, &start_message));
 
-    AsyncIoctl close_request(
+    AsyncIoClose close_request(
         NULL,
         _queueId,
         _controller->getQueueId(),
-        false,
-        AsyncIoctl::IO_CLOSE,
-        0,
-        0);
+        false);
 
     AutoPtr <AsyncReply> CloseAsyncReply(
         _controller->ClientSendWait(_queueId, &close_request));
 }
 
-void ShutdownService::_shutdownProviders()
+void ShutdownService::shutdownProviders()
 {
-    PEG_METHOD_ENTER(TRC_SHUTDOWN, "ShutdownService::_shutdownProviders");
+    PEG_METHOD_ENTER(TRC_SHUTDOWN, "ShutdownService::shutdownProviders");
 
     //
     // get provider manager service
@@ -360,8 +332,7 @@ void ShutdownService::_shutdownProviders()
         new AsyncLegacyOperationStart(
             NULL,
             _queueId,
-            stopRequest,
-            _queueId);
+            stopRequest);
 
     // Use SendWait, which is serialized and waits. Do not use asynchronous
     // callback as the response might be received _after_ the provider or
@@ -376,16 +347,10 @@ void ShutdownService::_shutdownProviders()
     if (response->cimException.getCode() != CIM_ERR_SUCCESS)
     {
         Logger::put_l(Logger::ERROR_LOG, System::CIMSERVER, Logger::SEVERE,
-            "Server.ShutdownService.CIM_PROVIDER_SHUTDOWN",
-            "$0 - CIM provider shutdown exception has occurred.",
-            "ShutdownService::_shutdownProviders");
-
-        CIMException e = response->cimException;
-        delete asyncRequest;
-        delete asyncReply;
-        delete response;
-        PEG_METHOD_EXIT();
-        throw e;
+            MessageLoaderParms(
+                "Server.ShutdownService.CIM_PROVIDER_SHUTDOWN",
+                "A provider shutdown exception has occurred: $0",
+                response->cimException.getMessage()));
     }
 
     delete asyncRequest;
@@ -413,10 +378,12 @@ Boolean ShutdownService::waitUntilNoMoreRequests(Boolean requestPending)
             return true;
         }
 
-        Logger::put(Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
+        PEG_TRACE((
+            TRC_SHUTDOWN,
+            Tracer::LEVEL4,
             "ShutdownService waiting for outstanding CIM operations to "
-                "complete.  Request count: $0",
-            requestCount);
+                "complete.  Request count: %d",
+            requestCount));
         Threads::sleep(waitInterval * 1000);
         waitTime -= waitInterval;
     }
