@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -47,9 +45,11 @@ void WQLOperationRequestDispatcher::applyQueryToEnumeration(
         (CIMEnumerateInstancesResponseMessage*) msg;
     WQLSelectStatement* qs = ((WQLQueryExpressionRep*)query)->_stmt;
 
-    for (int i = enr->cimNamedInstances.size() - 1; i >= 0; i--)
+    Array<CIMInstance>& a = enr->getNamedInstances();
+
+    for (int i = a.size() - 1; i >= 0; i--)
     {
-        WQLInstancePropertySource ips(enr->cimNamedInstances[i]);
+        WQLInstancePropertySource ips(a[i]);
         try
         {
             if (qs->evaluateWhereClause(&ips))
@@ -58,13 +58,13 @@ void WQLOperationRequestDispatcher::applyQueryToEnumeration(
                 // Specify that missing requested project properties are
                 // allowed to be consistent with clarification from DMTF
                 //
-                qs->applyProjection(enr->cimNamedInstances[i], true);
+                qs->applyProjection(a[i], true);
             }
-            else enr->cimNamedInstances.remove(i);
+            else a.remove(i);
         }
         catch (...)
         {
-            enr->cimNamedInstances.remove(i);
+            a.remove(i);
         }
     }
 }
@@ -73,15 +73,18 @@ void WQLOperationRequestDispatcher::handleQueryResponseAggregation(
     OperationAggregate* poA)
 {
     PEG_METHOD_ENTER(TRC_DISPATCHER,
-        "CIMOperationRequestDispatcher::handleExecQueryResponse");
+        "WQLOperationRequestDispatcher::handleQueryResponseAggregation");
 
     Uint32 numberResponses = poA->numberResponses();
-    Logger::put(Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
-        "CIMOperationRequestDispatcher::ExecQuery Response - "
-        "Name Space: $0  Class name: $1 Response Count: $2",
-        poA->_nameSpace.getString(),
-        poA->_className.getString(),
-        numberResponses);
+
+    PEG_TRACE((
+        TRC_DISPATCHER,
+        Tracer::LEVEL4,
+        "WQLOperationRequestDispatcher::ExecQuery Response - "
+            "Name Space: %s  Class name: %s Response Count: %u",
+        (const char*) poA->_nameSpace.getString().getCString(),
+        (const char*) poA->_className.getString().getCString(),
+        numberResponses));
 
     if (numberResponses == 0)
         return;
@@ -93,6 +96,7 @@ void WQLOperationRequestDispatcher::handleQueryResponseAggregation(
     Boolean manyResponses = true;
     if (response->getType() == CIM_ENUMERATE_INSTANCES_RESPONSE_MESSAGE)
     {
+        // Create an ExecQuery response from an EnumerateInstances request
         CIMRequestMessage* request = poA->getRequest();
         AutoPtr<CIMExecQueryResponseMessage> query(
             new CIMExecQueryResponseMessage(
@@ -124,10 +128,11 @@ void WQLOperationRequestDispatcher::handleQueryResponseAggregation(
             CIMClass cimClass;
 
             Boolean clsRead=false;
-            for (Uint32 j = 0, m = fromResponse->cimNamedInstances.size();
+            Array<CIMInstance>& a = fromResponse->getNamedInstances();
+            for (Uint32 j = 0, m = a.size();
                  j < m; j++)
             {
-                CIMObject co=CIMObject(fromResponse->cimNamedInstances[j]);
+                CIMObject co=CIMObject(a[j]);
                 CIMObjectPath op=co.getPath();
                 const Array<CIMKeyBinding>& kbs=op.getKeyBindings();
                 if (kbs.size() == 0)
@@ -139,7 +144,7 @@ void WQLOperationRequestDispatcher::handleQueryResponseAggregation(
                             false,true,false, CIMPropertyList());
                         clsRead=true;
                     }
-                    op = fromResponse->cimNamedInstances[j].buildPath(cimClass);
+                    op = a[j].buildPath(cimClass);
                 }
                 op.setNameSpace(poA->_nameSpace);
                 op.setHost(System::getHostName());
@@ -197,7 +202,7 @@ void WQLOperationRequestDispatcher::handleQueryRequest(
     CIMExecQueryRequestMessage* request)
 {
     PEG_METHOD_ENTER(TRC_DISPATCHER,
-        "CIMOperationRequestDispatcher::handleExecQueryRequest");
+        "WQLOperationRequestDispatcher::handleQueryRequest");
 
     Boolean exception=false;
     AutoPtr<WQLSelectStatement> selectStatement(new WQLSelectStatement());
@@ -270,11 +275,11 @@ void WQLOperationRequestDispatcher::handleQueryRequest(
                 className,
                 providerCount);
     }
-    catch (CIMException& exception)
+    catch (CIMException& e)
     {
         // Return exception response if exception from getSubClasses
         CIMResponseMessage* response = request->buildResponse();
-        response->cimException = exception;
+        response->cimException = e;
 
         _enqueueResponse(request, response);
         PEG_METHOD_EXIT();
@@ -286,14 +291,7 @@ void WQLOperationRequestDispatcher::handleQueryRequest(
     // of instances returned.
     if (providerCount > _maximumEnumerateBreadth)
     {
-        Logger::put(Logger::STANDARD_LOG, System::CIMSERVER, Logger::TRACE,
-            "Request-too-broad exception.  Namespace: $0  "
-                "Class Name: $1 Limit: $2  ProviderCount: $3",
-            request->nameSpace.getString(),
-            request->className.getString(),
-            _maximumEnumerateBreadth, providerCount);
-
-        PEG_TRACE((TRC_DISPATCHER, Tracer::LEVEL2,
+        PEG_TRACE((TRC_DISPATCHER, Tracer::LEVEL1,
             "ERROR: Enumerate operation too broad for class %s.  "
                 "Limit = %u, providerCount = %u",
             (const char*)request->className.getString().getCString(),
@@ -303,8 +301,8 @@ void WQLOperationRequestDispatcher::handleQueryRequest(
         CIMResponseMessage* response = request->buildResponse();
         response->cimException =
             PEGASUS_CIM_EXCEPTION_L(CIM_ERR_NOT_SUPPORTED, MessageLoaderParms(
-                "Server.CIMOperationRequestDispatcher.QUERY_REQ_TOO_BROAD",
-                "Query request too Broad"));
+                "Server.WQLOperationRequestDispatcher.QUERY_REQ_TOO_BROAD",
+                "The query request is too broad."));
 
         _enqueueResponse(request, response);
         PEG_METHOD_EXIT();
@@ -315,8 +313,9 @@ void WQLOperationRequestDispatcher::handleQueryRequest(
     // return CIM_ERR_NOT_SUPPORTED
     if ((providerCount == 0) && !(_repository->isDefaultInstanceProvider()))
     {
-        PEG_TRACE_STRING(TRC_DISPATCHER, Tracer::LEVEL4,
-            "CIM_ERROR_NOT_SUPPORTED for " + request->className.getString());
+        PEG_TRACE((TRC_DISPATCHER, Tracer::LEVEL2,
+            "CIM_ERROR_NOT_SUPPORTED for %s",
+            (const char*)request->className.getString().getCString()));
 
         CIMResponseMessage* response = request->buildResponse();
         response->cimException =
@@ -365,30 +364,30 @@ void WQLOperationRequestDispatcher::handleQueryRequest(
                 (unsigned int)(numClasses),
                 (unsigned int)(poA->_aggregationSN)));
 
+            // Create an EnumerateInstances response from an ExecQuery request
             AutoPtr<CIMEnumerateInstancesResponseMessage> response(
                 new CIMEnumerateInstancesResponseMessage(
                     request->messageId,
                     CIMException(),
-                    request->queueIds.copyAndPop(),
-                    Array<CIMInstance>()));
+                    request->queueIds.copyAndPop()));
             response->syncAttributes(request);
 
             try
             {
                 // Enumerate instances only for this class
-                response->cimNamedInstances =
+                response->setNamedInstances(
                     _repository->enumerateInstancesForClass(
                         request->nameSpace,
-                        providerInfo.className);
+                        providerInfo.className));
             }
-            catch (CIMException& exception)
+            catch (CIMException& e)
             {
-                response->cimException = exception;
+                response->cimException = e;
             }
-            catch (Exception& exception)
+            catch (Exception& e)
             {
                 response->cimException = PEGASUS_CIM_EXCEPTION(
-                    CIM_ERR_FAILED, exception.getMessage());
+                    CIM_ERR_FAILED, e.getMessage());
             }
             catch (...)
             {
@@ -408,7 +407,7 @@ void WQLOperationRequestDispatcher::handleQueryRequest(
             handleEnumerateInstancesResponseAggregation(poA);
             CIMResponseMessage* response = poA->removeResponse(0);
             _forwardRequestForAggregation(
-                String(PEGASUS_QUEUENAME_OPREQDISPATCHER),
+                getQueueId(),
                 String(),
                 new CIMExecQueryRequestMessage(*request),
                 poA, response);
@@ -435,7 +434,7 @@ void WQLOperationRequestDispatcher::handleQueryRequest(
                 "service \"%s\" for control provider \"%s\".  "
                 "Class # %u of %u, aggregation SN %u.",
             (const char*)providerInfo.className.getString().getCString(),
-            (const char*)providerInfo.serviceName.getCString(),
+            lookup(providerInfo.serviceId)->getQueueName(),
             (const char*)providerInfo.controlProviderName.getCString(),
             (unsigned int)(i + 1),
             (unsigned int)numClasses,
@@ -468,7 +467,7 @@ void WQLOperationRequestDispatcher::handleQueryRequest(
                 context->insert(*providerIdContainer);
             context->insert(identityContainer);
             _forwardRequestForAggregation(
-                 providerInfo.serviceName,
+                 providerInfo.serviceId,
                  providerInfo.controlProviderName,
                  enumReq.release(), poA);
         }
@@ -485,7 +484,7 @@ void WQLOperationRequestDispatcher::handleQueryRequest(
             requestCopy->className = providerInfo.className;
 
             _forwardRequestForAggregation(
-                providerInfo.serviceName,
+                providerInfo.serviceId,
                 providerInfo.controlProviderName,
                 requestCopy.release(), poA);
         }
