@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 ///////////////////////////////////////////////////////////////////////////////
 
@@ -54,14 +52,6 @@
 
 PEGASUS_USING_STD;
 
-#if 0
-# define OSP_DEBUG(X) \
-    Logger::put(Logger::DEBUG_LOG, "Linux OSProvider", Logger::INFORMATION, \
-        "$0", X)
-#else
-# define OSP_DEBUG(X)
-#endif
-
 OperatingSystem::OperatingSystem()
 {
 }
@@ -354,39 +344,38 @@ static CIMDateTime time_t_to_CIMDateTime(time_t *time_to_represent)
 /**
    getLastBootUpTime method for Linux implementation of OS Provider
 
-   gets information from /proc/uptime file
+   gets information from /proc/stat file's btime entry.
   */
 
 Boolean OperatingSystem::getLastBootUpTime(CIMDateTime& lastBootUpTime)
 {
-   const CIMDateTime NULLTIME;
-   const char *UPTIME_FILE = "/proc/uptime";
+   FILE* statFile;
+   char buffer[MAXPATHLEN];
+   unsigned long btimeValue = 0;
+   time_t bootTime;
 
-   CIMDateTime dt;
-   FILE *procfile;
-   unsigned long seconds_since_boot;
-   char read_buffer[MAXPATHLEN];
-   time_t t_now, t_then;
-   struct tm tm_now;
-
-   dt = NULLTIME;
-   procfile = fopen(UPTIME_FILE, "r");
-   if (procfile)
+   if ((statFile = fopen("/proc/stat", "r")) == 0)
    {
-      if (fgets(read_buffer, MAXPATHLEN, procfile))
-         if (sscanf(read_buffer, " %lu.", &seconds_since_boot))
-         {
-            //-- convert displacement in seconds to a date and time
-            t_now = time(NULL);
-            localtime_r(&t_now, &tm_now);
-            tm_now.tm_sec -= seconds_since_boot;
-            t_then = mktime(&tm_now);
-            dt = time_t_to_CIMDateTime(&t_then);
-         }
-      fclose(procfile);
+       return false;
    }
-   lastBootUpTime = dt;
-   return true;
+
+   while (fgets(buffer, MAXPATHLEN, statFile))
+   {
+       // Look for the btime entry
+       if (strncmp(buffer, "btime ", 6) == 0)
+       {
+           if (sscanf(&buffer[6], "%lu", &btimeValue))
+           {
+               fclose(statFile);
+               bootTime = (time_t) btimeValue;
+               lastBootUpTime = time_t_to_CIMDateTime(&bootTime);
+               return true;
+           }
+       }
+   }
+
+   fclose(statFile);
+   return false;
 }
 
 /**
