@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -45,6 +43,7 @@
 #include <utmpx.h>          // for utxent calls
 #include <sys/pstat.h>      // for pstat
 #include <dl.h>             // for shl_findsym
+#include <time.h>           // for localtime_r
 
 /**
    goodCSCreationClassName method for the OS Provider Test Client
@@ -81,7 +80,7 @@ Boolean OSTestClient::goodCSName(const String &csname, Boolean verbose)
    }
    hostName[sizeof(hostName)-1] = 0;
 
-   if (he = gethostbyname(hostName))
+   if ((he = gethostbyname(hostName)) != 0)
    {
       strncpy(hostName, he->h_name, sizeof(hostName)-1);
    }
@@ -331,7 +330,7 @@ Boolean OSTestClient::goodLocalDateTime(
 
    if (verbose) {
       cout<<" Should be close to " << currentDT.toString() << endl;
-      printf( " Delta should be within 360 seconds, is %lld\n",delta);
+      printf( " Delta should be within 360 seconds, is %llu\n",delta);
       fflush(stdout);
    }
    // arbitrary choice of expecting them to be within 360 seconds
@@ -478,7 +477,7 @@ Boolean OSTestClient::goodNumberOfProcesses(
 
    if (verbose)
    {
-      printf (" Delta should be within 10, is %d\n", delta);
+      printf (" Delta should be within 10, is %u\n", delta);
       fflush(stdout);
    }
 
@@ -534,7 +533,7 @@ static Uint64 _totalVM()
         // Now extract the total swap space size from the swapinfo output.
         while (fgets(mline, 80, mswapInfo))
         {
-           sscanf(mline, "%d", &swapSize);
+           sscanf(mline, "%u", &swapSize);
         }  // end while
 
         (void)pclose (mswapInfo);
@@ -556,7 +555,7 @@ Boolean OSTestClient::goodTotalSwapSpaceSize(
 
    if (verbose)
    {
-      printf("Checking TotalSwapSpaceSize %lld\n", totalswap);
+      printf("Checking TotalSwapSpaceSize %llu\n", totalswap);
       fflush(stdout);
    }
 
@@ -566,7 +565,7 @@ Boolean OSTestClient::goodTotalSwapSpaceSize(
 
    if (verbose)
    {
-      printf(" Should be %lld\n", mTotalSwapSpaceSize);
+      printf(" Should be %llu\n", mTotalSwapSpaceSize);
       fflush(stdout);
    }
    return (totalswap == mTotalSwapSpaceSize);
@@ -636,7 +635,7 @@ Boolean OSTestClient::goodFreeVirtualMemory(
 
    if (verbose)
    {
-      printf (" Delta should be within 131072, is %lld\n", delta);
+      printf (" Delta should be within 131072, is %llu\n", delta);
       fflush(stdout);
    }
 
@@ -898,7 +897,7 @@ Boolean OSTestClient::goodMaxProcessMemorySize(
 
    if (verbose)
    {
-      printf("Checking maxProcessMemorySize = 0x%llx = %lld\n",
+      printf("Checking maxProcessMemorySize = 0x%llx = %llu\n",
              maxpmem, maxpmem);
       fflush(stdout);   // flush, especially since mix of cout and printf
    }
@@ -957,7 +956,7 @@ Boolean OSTestClient::goodMaxProcessMemorySize(
 
    if (verbose)
    {
-      printf(" Should be 0x%llx = %lld\n", maxProcessMemorySize,
+      printf(" Should be 0x%llx = %llu\n", maxProcessMemorySize,
              maxProcessMemorySize);
       fflush(stdout);
    }
@@ -1007,7 +1006,7 @@ Boolean OSTestClient::goodMaxProcessesPerUser(
             // Now extract the value
             while (fgets(mline, 80, mtuneInfo))
             {
-                sscanf(mline, "maxuprc %lld", &ret);
+                sscanf(mline, "maxuprc %llu", &ret);
             }
             (void)pclose (mtuneInfo);
         }
@@ -1110,7 +1109,7 @@ Boolean OSTestClient::goodSystemUpTime(const Uint64 &uptime, Boolean verbose)
 
    if (verbose)
    {
-      printf (" Should be slightly > %lld\n", calcUpTime);
+      printf (" Should be slightly > %llu\n", calcUpTime);
       fflush(stdout);
    }
 
