@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -41,7 +39,7 @@
 //     CMPI_TEST_Person
 //     CMPI_TEST_Vehicle
 //     CMPI_TEST_Racing  (association class)
-//     
+//
 // The executable for this CIM client application is: cmpiAssociationTestClient.
 // To display the test results (returned instances or classes), define the
 // environment variable PEGASUS_TEST_VERBOSE.
@@ -72,9 +70,7 @@ Boolean verbose = false;
 // exepected results - number of returned objects expected for each test
 
 static const Uint32 resultArray_asso_P1[] = { 3, 3 };
-static const Uint32 resultArray_asso_P2[] = { 3, 3 };
 static const Uint32 resultArray_asso_V1[] = { 3, 3 };
-static const Uint32 resultArray_asso_V2[] = { 3, 3 };
 static const Uint32 resultArray_ref_P[] =   { 3, 3, 3, 3 };
 static const Uint32 resultArray_ref_V[] =   { 3, 3, 3, 3 };
 
@@ -98,7 +94,7 @@ void _errorExit(String message)
 //  terminate the program.
 //
 void _verifyResult(const Uint32 numObjects, const Uint32 numExpectedObjects)
-{   
+{
     if (numObjects != numExpectedObjects)
     {
         cerr << "Error: Unexpected number of objects returned. " << endl;;
@@ -207,7 +203,7 @@ void _testAssociatorNames(CIMClient& client, CIMName assocClass,
         // specified source instance via an instance of the AssocClass.
         //
         CIMName resultClass;
-   
+
         String role;
         String resultRole;
 
@@ -230,7 +226,7 @@ void _testAssociatorNames(CIMClient& client, CIMName assocClass,
 //  _testReferences
 ////////////////////////////////////////////////////////////////////////////
 
-void _testReferences(CIMClient& client, CIMObjectPath instancePath, 
+void _testReferences(CIMClient& client, CIMObjectPath instancePath,
                      Uint32 numExpectedObjects)
 {
     if (verbose)
@@ -380,7 +376,7 @@ void _testCMPIAssociationClassOperations(CIMClient& client, CIMName className)
 
     if (verbose)
     {
-        cout << "+++++ Test references for (" << className.getString() 
+        cout << "+++++ Test references for (" << className.getString()
              << ")" << endl;
     }
 
@@ -497,7 +493,7 @@ int main(int argc, char** argv)
     */
     Uint32 numPersonInstances = personRefs.size();
     Uint32 numVehicleInstances = vehicleRefs.size();
-    
+
 
     // =======================================================================
     // Test associators
@@ -506,7 +502,7 @@ int main(int argc, char** argv)
     // instance via an instance of a specified association class.
     // =======================================================================
 
-    if (verbose) 
+    if (verbose)
     {
         cout << "+++++ Test associators" << endl;
     }
@@ -533,7 +529,7 @@ int main(int argc, char** argv)
     // source CIM instance via an instance of a association class.
     // =======================================================================
 
-    if (verbose) 
+    if (verbose)
     {
         cout << "+++++ Test associatorNames" << endl;
     }
