@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -115,7 +113,7 @@ static int _testBrokerEnc (const CMPIContext * ctx,
     objPath1 = CMNewObjectPath (_broker, _Namespace, "abc", &rc);
     PROV_LOG ("++++ New object path with wrong classname : (%s)",
         strCMPIStatus (rc));
-    
+
     instance = CMNewInstance(_broker, NULL, &rc);
     PROV_LOG ("++++ New Instance with NULL object path : (%s)",
         strCMPIStatus (rc));
@@ -243,7 +241,7 @@ static int _testBrokerEnc (const CMPIContext * ctx,
         strCMPIStatus (rc));
 
     type = CDToString (_broker, objPath1, &rc);
-    if ( rc.rc == CMPI_RC_ERR_FAILED)
+    if ( rc.rc == CMPI_RC_ERR_INVALID_PARAMETER)
     {
         PROV_LOG ("++++ Error status of mbEncToString with object path with "
             "NULL handle: (%s)",
@@ -822,7 +820,7 @@ static int _testBrokerEnc (const CMPIContext * ctx,
     PROV_LOG ("++++ Status of GetMessage2 with 0 argument (%s) type (%s)",
             strCMPIStatus (rc),
         CMGetCharsPtr(type, NULL));
-   
+
     type = CMGetMessage2(_broker,
         "Common.CIMStatusCode.CIM_ERR_SUCCESS",
         msgFileHandle,
@@ -832,7 +830,7 @@ static int _testBrokerEnc (const CMPIContext * ctx,
     PROV_LOG ("++++ Status of GetMessage2 with 1 argument (%s) type (%s)",
             strCMPIStatus (rc),
         CMGetCharsPtr(type, NULL));
-   
+
     type = CMGetMessage2(_broker,
         "Common.CIMStatusCode.CIM_ERR_SUCCESS",
         msgFileHandle,
@@ -842,7 +840,7 @@ static int _testBrokerEnc (const CMPIContext * ctx,
     PROV_LOG ("++++ Status of GetMessage2 with 2 arguments (%s) type (%s)",
             strCMPIStatus (rc),
         CMGetCharsPtr(type, NULL));
-   
+
     type = CMGetMessage2 (_broker,
         "Common.CIMStatusCode.CIM_ERR_SUCCESS",
         msgFileHandle,
@@ -1002,14 +1000,14 @@ CMPIStatus TestCMPIBrokerEncProviderInvokeMethod (CMPIMethodMI * mi,
     class = CMGetClassName (ref, &rc);
 
     PROV_LOG ("InvokeMethod: checking for correct classname [%s]",
-        CMGetCharPtr (class));
+        CMGetCharsPtr (class,NULL));
 
     PROV_LOG ("Calling CMGetArgCount");
     arg_cnt = CMGetArgCount (in, &rc);
     PROV_LOG ("++++ (%s)", strCMPIStatus (rc));
 
     PROV_LOG ("InvokeMethod: We have %d arguments for operation [%s]: ",
-        arg_cnt, 
+        arg_cnt,
         methodName);
 
     if (arg_cnt > 0)
@@ -1022,29 +1020,32 @@ CMPIStatus TestCMPIBrokerEncProviderInvokeMethod (CMPIMethodMI * mi,
             {
                 PROV_LOG ("#%d: %s (uint32), value: %d",
                     index,
-                    CMGetCharPtr (argName),
+                    CMGetCharsPtr (argName,NULL),
                     data.value.uint32);
             }
             else if (data.type == CMPI_string)
             {
                 PROV_LOG ("#%d: %s (string) value: %s",
                     index,
-                    CMGetCharPtr (argName),
-                    CMGetCharPtr (data.value.string));
+                    CMGetCharsPtr (argName,NULL),
+                    CMGetCharsPtr (data.value.string,NULL));
             }
             else
             {
                 PROV_LOG ("#%d: %s (type: %x)",
                     index,
-                    CMGetCharPtr (argName),
+                    CMGetCharsPtr (argName,NULL),
                     data.type);
             }
             CMRelease (argName);
         }
     }
-    if (strncmp (CMGetCharPtr (class), _ClassName, strlen (_ClassName)) == 0)
+    if (strncmp(
+        CMGetCharsPtr (class,NULL),
+        _ClassName,
+        strlen (_ClassName)) == 0)
     {
-        if (strncmp("testBrokerEnc", 
+        if (strncmp("testBrokerEnc",
             methodName,
             strlen ("testBrokerEnc"))== 0)
         {
