@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -102,8 +100,6 @@ static int _testInstance ()
     CMPIData retData;
     CMPIData returnedData1;
 
-    CMPIString *name;
-
     const char* property_name = "s";
     const char* origin = "origin";
 
@@ -115,7 +111,7 @@ static int _testInstance ()
 
     objPath = make_ObjectPath(_broker, _Namespace, "TestCMPI_Instance");
     instance = make_Instance(objPath);
-   
+
     /* Test cases to increase coverage in instSetPropertyWithOrigin function */
 
     /* Setting n64 property in class TestCMPI_Instance. So origin has been
@@ -135,7 +131,7 @@ static int _testInstance ()
        set. */
     retData = CMGetProperty(instance, "n64", &rc);
 
-    if (retData.type == CMPI_uint64 && 
+    if (retData.type == CMPI_uint64 &&
            retData.value.uint64 == PEGASUS_UINT64_LITERAL(5000000000))
     {
          PROV_LOG("++++  CMGetProperty for n64 property status : (%s),"
@@ -170,12 +166,12 @@ static int _testInstance ()
         PROV_LOG("++++ CMGetProperty with NULL property name status: (%s) ",
             strCMPIStatus(rc));
     }
-    /*-----------------------------------------------------------------------*/ 
+    /*-----------------------------------------------------------------------*/
 
-    /* Test cases to cover error paths for instSetObjectPath and 
+    /* Test cases to cover error paths for instSetObjectPath and
        instSetPropertyFilter*/
 
-    /* Testing error path by passing CMPIObjectPath with class name different 
+    /* Testing error path by passing CMPIObjectPath with class name different
        from the classname for CMPIInstance in CMSetObjectPath*/
 
     objPathFake = CMNewObjectPath(_broker,
@@ -190,7 +186,7 @@ static int _testInstance ()
 
     /* Testing error path by passing NULL to instSetObjectPath*/
     rc = CMSetObjectPath(instance, NULL);
-    if ( rc.rc == CMPI_RC_ERR_INVALID_PARAMETER || 
+    if ( rc.rc == CMPI_RC_ERR_INVALID_PARAMETER ||
         rc.rc == CMPI_RC_ERR_NOT_SUPPORTED)
     {
         PROV_LOG("++++  Test for CMSetObjectPath with NULL input passed ");
@@ -245,16 +241,10 @@ CMPIStatus TestCMPIInstanceProviderInvokeMethod (CMPIMethodMI * mi,
 
     CMPIString *argName = NULL;
 
-    CMPIInstance *instance = NULL;
-    CMPIInstance *paramInst = NULL;
-
     unsigned int arg_cnt = 0, index = 0;
 
     CMPIValue value;
 
-    char *result = NULL;
-
-
     PROV_LOG_OPEN ("TestCMPI_Instance", _ProviderLocation);
 
     PROV_LOG ("--- %s CMPI InvokeMethod() called", _ClassName);
@@ -262,14 +252,14 @@ CMPIStatus TestCMPIInstanceProviderInvokeMethod (CMPIMethodMI * mi,
     class = CMGetClassName (ref, &rc);
 
     PROV_LOG ("InvokeMethod: checking for correct classname [%s]",
-        CMGetCharPtr (class));
+        CMGetCharsPtr (class,NULL));
 
     PROV_LOG ("Calling CMGetArgCount");
     arg_cnt = CMGetArgCount (in, &rc);
     PROV_LOG ("++++ (%s)", strCMPIStatus (rc));
 
     PROV_LOG ("InvokeMethod: We have %d arguments for operation [%s]: ",
-        arg_cnt, 
+        arg_cnt,
         methodName);
 
     if (arg_cnt > 0)
@@ -282,29 +272,32 @@ CMPIStatus TestCMPIInstanceProviderInvokeMethod (CMPIMethodMI * mi,
             {
                 PROV_LOG ("#%d: %s (uint32), value: %d",
                     index,
-                    CMGetCharPtr (argName),
+                    CMGetCharsPtr (argName,NULL),
                     data.value.uint32);
             }
             else if (data.type == CMPI_string)
             {
                 PROV_LOG ("#%d: %s (string) value: %s",
                     index,
-                    CMGetCharPtr (argName),
-                    CMGetCharPtr (data.value.string));
+                    CMGetCharsPtr (argName,NULL),
+                    CMGetCharsPtr (data.value.string,NULL));
             }
             else
             {
                 PROV_LOG ("#%d: %s (type: %x)",
                     index,
-                    CMGetCharPtr (argName),
+                    CMGetCharsPtr (argName,NULL),
                     data.type);
             }
             CMRelease (argName);
         }
     }
-    if (strncmp (CMGetCharPtr (class), _ClassName, strlen (_ClassName)) == 0)
+    if (strncmp(
+        CMGetCharsPtr (class,NULL),
+        _ClassName,
+        strlen (_ClassName)) == 0)
     {
-        if (strncmp("testInstance", 
+        if (strncmp("testInstance",
             methodName,
             strlen ("testInstance"))== 0)
         {
