@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -71,7 +69,6 @@ TestCMPIErrorProviderInvokeMethod (CMPIMethodMI * mi,
   CMPIStatus rc = { CMPI_RC_OK, NULL };
   CMPIError *cmpiError;
   CMPIError *cmpiErrorClone;
-  CMPIError *cmpiErrorExcep;
   CMPICount i, arrSize;
   CMPIObjectPath *objPath = NULL;
 
@@ -123,17 +120,17 @@ TestCMPIErrorProviderInvokeMethod (CMPIMethodMI * mi,
   else
   {
       PROV_LOG("CMPI_MB_Supports_Extended_Error Support : False");
-      CMReturnWithString(CMPI_RC_ERR_NOT_SUPPORTED, 
+      CMReturnWithString(CMPI_RC_ERR_NOT_SUPPORTED,
           CMNewString(_broker,
           "Extended error support not avilable", NULL));
-  } 
+  }
 
   PROV_LOG ("--- %s CMPI InvokeMethod() called", _ClassName);
 
   class_name = CMGetClassName (ref, &rc);
 
   PROV_LOG ("InvokeMethod: checking for correct classname [%s]",
-            CMGetCharPtr (class_name));
+            CMGetCharsPtr (class_name,NULL));
 
   PROV_LOG ("Calling CMNewCMPIError");
   cmpiError = CMNewCMPIError(_broker, inOwningEntity, inMsgID, inMsg,
@@ -199,30 +196,30 @@ TestCMPIErrorProviderInvokeMethod (CMPIMethodMI * mi,
   PROV_LOG ("++++ (%s) CMClone", strCMPIStatus (rc));
 
   PROV_LOG ("Ok, reading back fields to verify");
-  
+
   PROV_LOG ("Calling CMGetErrorType");
   outErrType = CMGetErrorType(cmpiErrorClone, &rc);
   PROV_LOG ("++++ (%s) CMGetErrorType (%d)", strCMPIStatus (rc), outErrType);
 
   PROV_LOG ("Calling CMGetOtherErrorType");
   outOtherErrType = CMGetOtherErrorType(cmpiErrorClone, &rc);
-  PROV_LOG ("++++ (%s) CMGetOtherErrorType (%s)", strCMPIStatus (rc), 
-      CMGetCharPtr(outOtherErrType));
+  PROV_LOG ("++++ (%s) CMGetOtherErrorType (%s)", strCMPIStatus (rc),
+      CMGetCharsPtr(outOtherErrType,NULL));
 
   PROV_LOG ("Calling CMGetOwningEntity");
   outOwningEntity = CMGetOwningEntity(cmpiErrorClone, &rc);
-  PROV_LOG ("++++ (%s) CMGetOwningEntity (%s)", strCMPIStatus (rc), 
-      CMGetCharPtr(outOwningEntity));
+  PROV_LOG ("++++ (%s) CMGetOwningEntity (%s)", strCMPIStatus (rc),
+      CMGetCharsPtr(outOwningEntity,NULL));
 
   PROV_LOG ("Calling CMGetMessageID");
   outMsgID = CMGetMessageID(cmpiErrorClone, &rc);
-  PROV_LOG ("++++ (%s) CMGetMessageID (%s)", strCMPIStatus (rc), 
-      CMGetCharPtr(outMsgID));
+  PROV_LOG ("++++ (%s) CMGetMessageID (%s)", strCMPIStatus (rc),
+      CMGetCharsPtr(outMsgID,NULL));
 
   PROV_LOG ("Calling CMGetErrorMessage");
   outMsg = CMGetErrorMessage(cmpiErrorClone, &rc);
-  PROV_LOG ("++++ (%s) CMGetErrorMessage (%s)", strCMPIStatus (rc), 
-      CMGetCharPtr(outMsg));
+  PROV_LOG ("++++ (%s) CMGetErrorMessage (%s)", strCMPIStatus (rc),
+      CMGetCharsPtr(outMsg,NULL));
 
   PROV_LOG ("Calling CMGetPerceivedSeverity");
   outSev = CMGetPerceivedSeverity(cmpiErrorClone, &rc);
@@ -238,7 +235,7 @@ TestCMPIErrorProviderInvokeMethod (CMPIMethodMI * mi,
   outPcd = CMGetProbableCauseDescription(cmpiErrorClone, &rc);
   PROV_LOG ("++++ (%s) CMGetProbableCauseDescription (%s)",
       strCMPIStatus (rc),
-      CMGetCharPtr(outPcd));
+      CMGetCharsPtr(outPcd,NULL));
 
   PROV_LOG ("Calling CMGetRecommendedActions");
   outRecActions = CMGetRecommendedActions(cmpiErrorClone, &rc);
@@ -249,13 +246,13 @@ TestCMPIErrorProviderInvokeMethod (CMPIMethodMI * mi,
   {
       CMPIData dta = CMGetArrayElementAt(outRecActions, i, &rc);
       PROV_LOG ("++++ (%s) CMGetArrayElementAt (%d:%s)", strCMPIStatus (rc),
-          i, CMGetCharPtr(dta.value.string));
+          i, CMGetCharsPtr(dta.value.string,NULL));
   }
 
   PROV_LOG ("Calling CMGetErrorSource");
   outErrSource = CMGetErrorSource(cmpiErrorClone, &rc);
   PROV_LOG ("++++ (%s) CMGetErrorSource (%s)", strCMPIStatus (rc),
-      CMGetCharPtr(outErrSource));
+      CMGetCharsPtr(outErrSource,NULL));
 
   PROV_LOG ("Calling CMGetErrorSourceFormat");
   outErrSourceFormat = CMGetErrorSourceFormat(cmpiErrorClone, &rc);
@@ -265,7 +262,7 @@ TestCMPIErrorProviderInvokeMethod (CMPIMethodMI * mi,
   PROV_LOG ("Calling CMGetOtherErrorSourceFormat");
   outOtherErrSourceFormat = CMGetOtherErrorSourceFormat(cmpiErrorClone, &rc);
   PROV_LOG ("++++ (%s) CMGetOtherErrorSourceFormat (%s)", strCMPIStatus (rc),
-      CMGetCharPtr(outOtherErrSourceFormat));
+      CMGetCharsPtr(outOtherErrSourceFormat,NULL));
 
   PROV_LOG ("Calling CMGetCIMStatusCode");
   outCIMStatusCode = CMGetCIMStatusCode(cmpiErrorClone, &rc);
@@ -275,7 +272,7 @@ TestCMPIErrorProviderInvokeMethod (CMPIMethodMI * mi,
   PROV_LOG ("Calling CMGetCIMStatusCodeDescription");
   outCIMStatusCodeDesc = CMGetCIMStatusCodeDescription(cmpiErrorClone, &rc);
   PROV_LOG ("++++ (%s) CMGetCIMStatusCodeDescription (%s)", strCMPIStatus (rc),
-      CMGetCharPtr(outCIMStatusCodeDesc));
+      CMGetCharsPtr(outCIMStatusCodeDesc,NULL));
 
   PROV_LOG ("Calling CMGetMessageArguments");
   outMsgArgs = CMGetMessageArguments(cmpiErrorClone, &rc);
@@ -286,7 +283,7 @@ TestCMPIErrorProviderInvokeMethod (CMPIMethodMI * mi,
   {
       CMPIData dta = CMGetArrayElementAt(outMsgArgs, i, &rc);
       PROV_LOG ("++++ (%s) CMGetArrayElementAt (%d:%s)", strCMPIStatus (rc),
-          i, CMGetCharPtr(dta.value.string));
+          i, CMGetCharsPtr(dta.value.string,NULL));
   }
 
   PROV_LOG ("Calling CMPIResultFT.returnData");
@@ -300,7 +297,7 @@ TestCMPIErrorProviderInvokeMethod (CMPIMethodMI * mi,
 //Test Error Paths
   PROV_LOG ("Testing for Error Paths in CMPI_Error.cpp");
   PROV_LOG ("Calling CMNewCMPIError");
-  cmpiError = CMNewCMPIError(_broker, 
+  cmpiError = CMNewCMPIError(_broker,
       inOwningEntity,
       inMsgID,
       inMsg,
@@ -533,10 +530,10 @@ TestCMPIErrorProviderInvokeMethod (CMPIMethodMI * mi,
   {
       PROV_LOG ("++++ (%s) CMInvokeMethod", strCMPIStatus (rc));
   }
-  PROV_LOG ("--- %s CMPI InvokeMethod() exited with CMPI_RC_ERR_FAILED", 
+  PROV_LOG ("--- %s CMPI InvokeMethod() exited with CMPI_RC_ERR_FAILED",
       _ClassName);
   PROV_LOG_CLOSE();
-  CMReturnWithString(inCIMStatusCode, 
+  CMReturnWithString(inCIMStatusCode,
       CMNewString(_broker, "TestError invokeMethod() expected failure", NULL));
 }
 
