@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
 //
-//==============================================================================
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 #include <stdlib.h>
@@ -35,7 +33,7 @@
 #include <string.h>
 #include <ctype.h>
 #include <stdarg.h>
-#ifdef PEGASUS_PLATFORM_ZOS_ZSERIES_IBM
+#ifdef PEGASUS_OS_ZOS
 #include <pthread.h>
 #endif
 
@@ -70,7 +68,6 @@ static CMPIObjectPath *objPath;
 static CMPIBoolean _enabled = CMPI_false;
 static CMPIUint32 _nextUID = 1;
 static CMPIUint32 _numSubscriptions = 0;
-static CMPIIndicationMI *_indMI = NULL;
 static CMPIArray *correlatedIndications = NULL;
 static char *namespaceName;
 
@@ -139,7 +136,7 @@ CMPIStatus TestCMPIIndicationStressTestProviderActivateFilter(
                                           CMPIIndicationMI * mi,
                                           const CMPIContext * ctx,
                                           const CMPISelectExp * se,
-                                          const char *ns,
+                                          const char *clsName,
                                           const CMPIObjectPath * op,
                                           CMPIBoolean firstActivation)
 {
@@ -152,7 +149,7 @@ CMPIStatus TestCMPIIndicationStressTestProviderDeActivateFilter(
                                             CMPIIndicationMI * mi,
                                             const CMPIContext * ctx,
                                             const CMPISelectExp * se,
-                                            const char *ns,
+                                            const char *clsName,
                                             const CMPIObjectPath * op,
                                             CMPIBoolean lastActivation)
 {
@@ -209,7 +206,6 @@ CMPIStatus TestCMPIIndicationStressTestProviderInvokeMethod(
                                     const char *methodName,
                                     const CMPIArgs * in, CMPIArgs * out)
 {
-    CMPIBoolean sendIndication = CMPI_false;
     CMPIUint32 indicationSendCount = 0;
     CMPIInstance *indicationInstance = 0;
     CMPIData data;
@@ -235,7 +231,7 @@ CMPIStatus TestCMPIIndicationStressTestProviderInvokeMethod(
     data = CMGetArgAt (in, 1, NULL, NULL);
     if (data.type == CMPI_string)
     {
-        namespaceName = strdup(CMGetCharPtr (data.value.string));
+        namespaceName = strdup(CMGetCharsPtr (data.value.string,NULL));
     }
     else
     {
@@ -254,7 +250,7 @@ CMPIStatus TestCMPIIndicationStressTestProviderInvokeMethod(
     {
         for (seqNum = 1; seqNum < indicationSendCount+1; seqNum++)
         {
-             sprintf(UIDbuffer, "%d", _nextUID++);
+             sprintf(UIDbuffer, "%u", _nextUID++);
              indicationInstance = getIndicationInstance (seqNum, UIDbuffer);
              CBDeliverIndication (_broker, ctx, namespaceName,
                                            indicationInstance);
