@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 // Author: Dave Sudlik (dsudlik@us.ibm.com)
 //
@@ -75,7 +73,7 @@ static const String ASSOC_CLASSNAME("TST_ChunkingStressAssoc");
 ////////////////////////////////////////////////////////////////////////////////
 class T_Parms{
    public:
-    AutoPtr<CIMClient> client;
+    CIMClient* client;
     Uint32 duration;
     Uint32 uniqueID;
 };
@@ -113,26 +111,26 @@ time to execute.  Grow this to a class so we have start and stop and time
 display with success/failure for each function.
 */
 static void _testStart(
-    const String& cimop, const Uint32 uniqueID, 
+    const String& cimop, const Uint32 uniqueID,
     const Uint32 duration, const String& message)
 {
-    cout << "+++++ " << cimop << " thread " << uniqueID << ": " << message 
+    cout << "+++++ " << cimop << " thread " << uniqueID << ": " << message
          << " for " << duration << " seconds" << endl;
 }
 
 static void _testEnd(
-    const String& cimop, const Uint32 uniqueID, 
+    const String& cimop, const Uint32 uniqueID,
     const Uint32 iterations, const double elapsedTime)
 {
     if (shutdownFlag)
     {
-        cout << "????? " << cimop << " thread " << uniqueID 
-             << ": shutting down due to indicated failure on another thread" 
+        cout << "????? " << cimop << " thread " << uniqueID
+             << ": shutting down due to indicated failure on another thread"
              << endl;
     }
     else
     {
-        cout << "+++++ " << cimop << " thread " << uniqueID 
+        cout << "+++++ " << cimop << " thread " << uniqueID
              << ": passed in " << elapsedTime
              << " seconds with " << iterations << " iterations" << endl;
     }
@@ -142,7 +140,7 @@ ThreadReturnType PEGASUS_THREAD_CDECL _executeEI(void *parm)
 {
     Thread *my_thread = (Thread *)parm;
     T_Parms *parms = (T_Parms *)my_thread->get_parm();
-    CIMClient *client = parms->client.get();
+    CIMClient *client = parms->client;
     Uint32 duration = parms->duration;
     Uint32 uniqueID = parms->uniqueID;
 
@@ -160,7 +158,7 @@ ThreadReturnType PEGASUS_THREAD_CDECL _executeEI(void *parm)
         {
             expectedResults++;
 
-            iterations++; 
+            iterations++;
             elapsedTime.start();
 
             Array<CIMInstance> cimInstances =
@@ -175,19 +173,19 @@ ThreadReturnType PEGASUS_THREAD_CDECL _executeEI(void *parm)
             {
                 if (true) // alternative: check verbose flag
                 {
-                    cout << "      EI thread " << uniqueID 
-                         << ": iteration " << iterations 
+                    cout << "      EI thread " << uniqueID
+                         << ": iteration " << iterations
                          << ": received " << cimInstances.size()
-                         << " instances," 
+                         << " instances,"
                          << " et " << elapsedSeconds
                          << " of " << duration << endl;
                 }
             }
-            else 
+            else
             {
                 shutdownFlag = true;
-                sprintf(exceptionMsg, 
-                    "----- EI thread %d expected %d instances, received %d",
+                sprintf(exceptionMsg,
+                    "----- EI thread %u expected %d instances, received %u",
                     uniqueID,
                     EXPECTED_INSTANCES,
                     cimInstances.size());
@@ -197,20 +195,22 @@ ThreadReturnType PEGASUS_THREAD_CDECL _executeEI(void *parm)
         }
         _testEnd("EI", uniqueID, iterations, elapsedSeconds);
     }
-    catch(Exception e)
+    catch (Exception& e)
     {
-        cout << "---- EI thread " << uniqueID << " caught exception: " 
+        cout << "---- EI thread " << uniqueID << " caught exception: "
             << e.getMessage() << endl;
     }
-    my_thread->exit_self((ThreadReturnType)0);
-    return(0);
+
+    delete parms;
+
+    return ThreadReturnType(0);
 }
 
 ThreadReturnType PEGASUS_THREAD_CDECL _executeNI(void *parm)
 {
     Thread *my_thread = (Thread *)parm;
     T_Parms *parms = (T_Parms *)my_thread->get_parm();
-    CIMClient *client = parms->client.get();
+    CIMClient *client = parms->client;
     Uint32 duration = parms->duration;
     Uint32 uniqueID = parms->uniqueID;
 
@@ -228,7 +228,7 @@ ThreadReturnType PEGASUS_THREAD_CDECL _executeNI(void *parm)
         {
             expectedResults++;
 
-            iterations++; 
+            iterations++;
             elapsedTime.start();
 
             Array<CIMObjectPath> cimInstanceNames =
@@ -243,19 +243,19 @@ ThreadReturnType PEGASUS_THREAD_CDECL _executeNI(void *parm)
             {
                 if (true) // alternative: check verbose flag
                 {
-                    cout << "      NI thread " << uniqueID 
-                         << ": iteration " << iterations 
+                    cout << "      NI thread " << uniqueID
+                         << ": iteration " << iterations
                          << ": received " << cimInstanceNames.size()
-                         << " inst names," 
+                         << " inst names,"
                          << " et " << elapsedSeconds
                          << " of " << duration << endl;
                 }
             }
-            else 
+            else
             {
                 shutdownFlag = true;
-                sprintf(exceptionMsg, 
-                    "----- NI thread %d expected %d instancenames, received %d",
+                sprintf(exceptionMsg,
+                    "----- NI thread %u expected %d instancenames, received %u",
                     uniqueID,
                     EXPECTED_INSTANCENAMES,
                     cimInstanceNames.size());
@@ -265,20 +265,22 @@ ThreadReturnType PEGASUS_THREAD_CDECL _executeNI(void *parm)
         }
         _testEnd("NI", uniqueID, iterations, elapsedSeconds);
     }
-    catch(Exception e)
+    catch (Exception& e)
     {
-        cout << "---- NI thread " << uniqueID << " caught exception: " 
+        cout << "---- NI thread " << uniqueID << " caught exception: "
             << e.getMessage() << endl;
     }
-    my_thread->exit_self((ThreadReturnType)0);
-    return(0);
+
+    delete parms;
+
+    return ThreadReturnType(0);
 }
 
 ThreadReturnType PEGASUS_THREAD_CDECL _executeA(void *parm)
 {
     Thread *my_thread = (Thread *)parm;
     T_Parms *parms = (T_Parms *)my_thread->get_parm();
-    CIMClient *client = parms->client.get();
+    CIMClient *client = parms->client;
     Uint32 duration = parms->duration;
     Uint32 uniqueID = parms->uniqueID;
 
@@ -296,7 +298,7 @@ ThreadReturnType PEGASUS_THREAD_CDECL _executeA(void *parm)
         {
             expectedResults++;
 
-            iterations++; 
+            iterations++;
             elapsedTime.start();
 
             Array<CIMObject> cimObjects =
@@ -311,19 +313,19 @@ ThreadReturnType PEGASUS_THREAD_CDECL _executeA(void *parm)
             {
                 if (true) // alternative: check verbose flag
                 {
-                    cout << "      A  thread " << uniqueID 
-                         << ": iteration " << iterations 
+                    cout << "      A  thread " << uniqueID
+                         << ": iteration " << iterations
                          << ": received " << cimObjects.size()
-                         << " objects," 
+                         << " objects,"
                          << " et " << elapsedSeconds
                          << " of " << duration << endl;
                 }
             }
-            else 
+            else
             {
                 shutdownFlag = true;
-                sprintf(exceptionMsg, 
-                    "----- A  thread %d expected %d objects, received %d",
+                sprintf(exceptionMsg,
+                    "----- A  thread %u expected %d objects, received %u",
                     uniqueID,
                     EXPECTED_ASSOCIATORS,
                     cimObjects.size());
@@ -333,20 +335,22 @@ ThreadReturnType PEGASUS_THREAD_CDECL _executeA(void *parm)
         }
         _testEnd("A ", uniqueID, iterations, elapsedSeconds);
     }
-    catch(Exception e)
+    catch (Exception& e)
     {
-        cout << "---- A  thread " << uniqueID << " caught exception: " 
+        cout << "---- A  thread " << uniqueID << " caught exception: "
             << e.getMessage() << endl;
     }
-    my_thread->exit_self((ThreadReturnType)0);
-    return(0);
+
+    delete parms;
+
+    return ThreadReturnType(0);
 }
 
 ThreadReturnType PEGASUS_THREAD_CDECL _executeAN(void *parm)
 {
     Thread *my_thread = (Thread *)parm;
     T_Parms *parms = (T_Parms *)my_thread->get_parm();
-    CIMClient *client = parms->client.get();
+    CIMClient *client = parms->client;
     Uint32 duration = parms->duration;
     Uint32 uniqueID = parms->uniqueID;
 
@@ -364,7 +368,7 @@ ThreadReturnType PEGASUS_THREAD_CDECL _executeAN(void *parm)
         {
             expectedResults++;
 
-            iterations++; 
+            iterations++;
             elapsedTime.start();
 
             Array<CIMObjectPath> cimObjectNames =
@@ -379,19 +383,19 @@ ThreadReturnType PEGASUS_THREAD_CDECL _executeAN(void *parm)
             {
                 if (true) // alternative: check verbose flag
                 {
-                    cout << "      AN thread " << uniqueID 
-                         << ": iteration " << iterations 
+                    cout << "      AN thread " << uniqueID
+                         << ": iteration " << iterations
                          << ": received " << cimObjectNames.size()
-                         << " object names," 
+                         << " object names,"
                          << " et " << elapsedSeconds
                          << " of " << duration << endl;
                 }
             }
-            else 
+            else
             {
                 shutdownFlag = true;
-                sprintf(exceptionMsg, 
-                    "----- AN thread %d expected %d objectnames, received %d",
+                sprintf(exceptionMsg,
+                    "----- AN thread %u expected %d objectnames, received %u",
                     uniqueID,
                     EXPECTED_ASSOCIATORNAMES,
                     cimObjectNames.size());
@@ -401,20 +405,22 @@ ThreadReturnType PEGASUS_THREAD_CDECL _executeAN(void *parm)
         }
         _testEnd("AN", uniqueID, iterations, elapsedSeconds);
     }
-    catch(Exception e)
+    catch (Exception& e)
     {
         cout << "---- AN thread " << uniqueID << " caught exception: "
             << e.getMessage() << endl;
     }
-    my_thread->exit_self((ThreadReturnType)0);
-    return(0);
+
+    delete parms;
+
+    return ThreadReturnType(0);
 }
 
 ThreadReturnType PEGASUS_THREAD_CDECL _executeR(void *parm)
 {
     Thread *my_thread = (Thread *)parm;
     T_Parms *parms = (T_Parms *)my_thread->get_parm();
-    CIMClient *client = parms->client.get();
+    CIMClient *client = parms->client;
     Uint32 duration = parms->duration;
     Uint32 uniqueID = parms->uniqueID;
 
@@ -432,7 +438,7 @@ ThreadReturnType PEGASUS_THREAD_CDECL _executeR(void *parm)
         {
             expectedResults++;
 
-            iterations++; 
+            iterations++;
             elapsedTime.start();
 
             Array<CIMObject> cimObjects =
@@ -447,19 +453,19 @@ ThreadReturnType PEGASUS_THREAD_CDECL _executeR(void *parm)
             {
                 if (true) // alternative: check verbose flag
                 {
-                    cout << "      R  thread " << uniqueID 
-                         << ": iteration " << iterations 
+                    cout << "      R  thread " << uniqueID
+                         << ": iteration " << iterations
                          << ": received " << cimObjects.size()
-                         << " objects," 
+                         << " objects,"
                          << " et " << elapsedSeconds
                          << " of " << duration << endl;
                 }
             }
-            else 
+            else
             {
                 shutdownFlag = true;
-                sprintf(exceptionMsg, 
-                    "----- R  thread %d expected %d objects, received %d",
+                sprintf(exceptionMsg,
+                    "----- R  thread %u expected %d objects, received %u",
                     uniqueID,
                     EXPECTED_REFERENCES,
                     cimObjects.size());
@@ -469,20 +475,22 @@ ThreadReturnType PEGASUS_THREAD_CDECL _executeR(void *parm)
         }
         _testEnd("R ", uniqueID, iterations, elapsedSeconds);
     }
-    catch(Exception e)
+    catch (Exception& e)
     {
         cout << "---- R  thread " << uniqueID << " caught exception: "
             << e.getMessage() << endl;
     }
-    my_thread->exit_self((ThreadReturnType)0);
-    return(0);
+
+    delete parms;
+
+    return ThreadReturnType(0);
 }
 
 ThreadReturnType PEGASUS_THREAD_CDECL _executeRN(void *parm)
 {
     Thread *my_thread = (Thread *)parm;
     T_Parms *parms = (T_Parms *)my_thread->get_parm();
-    CIMClient *client = parms->client.get();
+    CIMClient *client = parms->client;
     Uint32 duration = parms->duration;
     Uint32 uniqueID = parms->uniqueID;
 
@@ -500,7 +508,7 @@ ThreadReturnType PEGASUS_THREAD_CDECL _executeRN(void *parm)
         {
             expectedResults++;
 
-            iterations++; 
+            iterations++;
             elapsedTime.start();
 
             Array<CIMObjectPath> cimObjectNames =
@@ -515,19 +523,19 @@ ThreadReturnType PEGASUS_THREAD_CDECL _executeRN(void *parm)
             {
                 if (true) // alternative: check verbose flag
                 {
-                    cout << "      RN thread " << uniqueID 
-                         << ": iteration " << iterations 
+                    cout << "      RN thread " << uniqueID
+                         << ": iteration " << iterations
                          << ": received " << cimObjectNames.size()
-                         << " object names," 
+                         << " object names,"
                          << " et " << elapsedSeconds
                          << " of " << duration << endl;
                 }
             }
-            else 
+            else
             {
                 shutdownFlag = true;
-                sprintf(exceptionMsg, 
-                    "----- RN thread %d expected %d objectnames, received %d",
+                sprintf(exceptionMsg,
+                    "----- RN thread %u expected %d objectnames, received %u",
                     uniqueID,
                     EXPECTED_REFERENCENAMES,
                     cimObjectNames.size());
@@ -537,13 +545,15 @@ ThreadReturnType PEGASUS_THREAD_CDECL _executeRN(void *parm)
         }
         _testEnd("RN", uniqueID, iterations, elapsedSeconds);
     }
-    catch(Exception e)
+    catch (Exception& e)
     {
         cout << "---- RN thread " << uniqueID << " caught exception: "
             << e.getMessage() << endl;
     }
-    my_thread->exit_self((ThreadReturnType)0);
-    return(0);
+
+    delete parms;
+
+    return ThreadReturnType(0);
 }
 
 Thread * _runTestThreads(
@@ -554,7 +564,7 @@ Thread * _runTestThreads(
 {
     // package parameters, create thread and run...
     AutoPtr<T_Parms> parms(new T_Parms());
-    parms->client.reset(client);
+    parms->client = client;
     parms->duration = duration;
     parms->uniqueID = uniqueID;
     AutoPtr<Thread> t(new Thread(_executeFn, (void*)parms.release(), false));
@@ -570,7 +580,7 @@ void _beginTest(const Uint32 duration, const char* thdCountStr)
     // of the chunking CIM operations.
     Uint32 totalThdCount;
     Uint32 ei_count, ni_count, a_count, an_count, r_count, rn_count;
-    sscanf(thdCountStr, "%1u%1u%1u%1u%1u%1u", 
+    sscanf(thdCountStr, "%1u%1u%1u%1u%1u%1u",
            &ei_count, &ni_count, &a_count, &an_count, &r_count, &rn_count);
 
     totalThdCount = ei_count+ni_count+a_count+an_count+r_count+rn_count;
@@ -659,16 +669,13 @@ void _beginTest(const Uint32 duration, const char* thdCountStr)
     // clean up connections
     for(Uint32 i=0; i< clientConnections.size(); i++)
     {
-        if(clientConnections[i])
-            delete clientConnections[i];
+        delete clientConnections[i];
     }
     // clean up threads
     for(Uint32 i=0; i < clientThreads.size(); i++)
     {
-        if(clientThreads[i])
-            delete clientThreads[i];
+        delete clientThreads[i];
     }
-
 }
 
 int main(int argc, char** argv)
@@ -719,7 +726,7 @@ int main(int argc, char** argv)
     }
     catch(const CIMException & e)
     {
-        cout << "CIMException: " << e.getCode() << " " 
+        cout << "CIMException: " << e.getCode() << " "
             << e.getMessage() << endl;
         return(1);
     }
