@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -338,8 +336,8 @@ Array<CIMObjectPath> _filterAssocInstanceToTargetPaths(
             {
                 if (resultClass.isNull() || resultClass == path.getClassName())
                 {
-                    if (resultRole == String::EMPTY ||
-                        p.getName().getString() == resultRole)
+                    if ((resultRole.size() == 0) ||
+                        (CIMName(resultRole) == p.getName()))
                     {
                         returnPaths.append(path);
                     }
@@ -357,7 +355,8 @@ Array<CIMObjectPath> _filterAssocInstanceToTargetPaths(
     @param target - The target path for the association. Localization assumed.
     @param instance - The association class instance we are searching for
     references
-    @param role - The role we require. I there is no role, this is String::EMPTY
+    @param role The role we require. If there is no role filter, the value is
+        an empty string.
     @return - returns Boolean true if target is found in a reference that is
     the same role
  */
@@ -368,7 +367,7 @@ Boolean _isInstanceValidReference(
 {
     // Test if role parameter is valid property.
     Uint32 pos;
-    if (role != String::EMPTY)
+    if (role.size() != 0)
     {
         // Test if property with this role exists.
         if ((pos = instance.findProperty(role)) == PEG_NOT_FOUND)
@@ -392,7 +391,7 @@ Boolean _isInstanceValidReference(
             v.get(path);
 
             // if no role or role == this role and target = this path, rtn true.
-            if ((role == String::EMPTY) || (role == p.getName().getString()))
+            if ((role.size() == 0) || (CIMName(role) == p.getName()))
             {
                 if (target.identical(path))
                     return(true);
@@ -547,11 +546,11 @@ CIMInstance _buildInstanceLabeledLineageDynamic(
 }
 
 /**************************** FamilyProvider class Implementation*********/
-FamilyProvider::FamilyProvider(void)
+FamilyProvider::FamilyProvider()
 {
 }
 
-FamilyProvider::~FamilyProvider(void)
+FamilyProvider::~FamilyProvider()
 {
 }
 
@@ -575,14 +574,14 @@ CIMClass FamilyProvider::_getClass(const CIMName& className)
             true,
             CIMPropertyList());
     }
-    catch(CIMException& e)
+    catch (CIMException& e)
     {
-        PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL2,
+        PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL1,
             "FamilyProvider GetClass operation failed: Class %s. Msg %s",
             (const char*) className.getString().getCString(),
             (const char*) e.getMessage().getCString()));
     }
-    return(c);
+    return c;
 }
 
 void FamilyProvider::initialize(CIMOMHandle & cimom)
@@ -652,7 +651,7 @@ void FamilyProvider::initialize(CIMOMHandle & cimom)
     _instances.append(_buildPersonDynamicInstance(_personDynamicClass,
         String("Daughter1"), String( "five"), 5));
 
-    for(Uint32 i = 0, n = _instances.size(); i < n; i++)
+    for (Uint32 i = 0, n = _instances.size(); i < n; i++)
     {
         // Create Instance Names
         _instanceNames.append(_instances[i].buildPath(_personDynamicClass));
@@ -681,7 +680,7 @@ void FamilyProvider::initialize(CIMOMHandle & cimom)
         _instancesLineageDynamic.append(_buildInstanceLineageDynamic(
             _assocClass, _instanceNames[Mother],_instanceNames[Daughter1]));
 
-        for(Uint32 i = 0, n = _instancesLineageDynamic.size(); i < n; i++)
+        for (Uint32 i = 0, n = _instancesLineageDynamic.size(); i < n; i++)
         {
             // Create Instance Names
             _instanceNamesLineageDynamic.append(
@@ -718,7 +717,7 @@ void FamilyProvider::initialize(CIMOMHandle & cimom)
                 _assocLabeledClass, _instanceNames[Mother],
                 _instanceNames[Daughter1], String("six")));
 
-        for(Uint32 i=0, n = _instancesLabeledLineageDynamic.size(); i < n; i++)
+        for (Uint32 i=0, n = _instancesLabeledLineageDynamic.size(); i < n; i++)
         {
             // Create Instance Names
             _instanceNamesLabeledLineageDynamic.append(
@@ -734,7 +733,7 @@ void FamilyProvider::initialize(CIMOMHandle & cimom)
     PEG_METHOD_EXIT();
 }
 
-void FamilyProvider::terminate(void)
+void FamilyProvider::terminate()
 {
     PEG_TRACE_CSTRING(TRC_CONTROLPROVIDER, Tracer::LEVEL4, "Terminate");
     delete this;
@@ -763,12 +762,11 @@ void FamilyProvider::_getInstance(
 {
     // convert a potential fully qualified reference into a local reference
     // (class name and keys only).
-    CIMObjectPath localReference =
-            _makeRefLocal(instanceReference);
+    CIMObjectPath localReference = _makeRefLocal(instanceReference);
 
-    for(Uint32 i = 0, n = instanceArray.size(); i < n; i++)
+    for (Uint32 i = 0, n = instanceArray.size(); i < n; i++)
     {
-        if(localReference == instanceArray[i].getPath())
+        if (localReference == instanceArray[i].getPath())
         {
             // deliver filtered clone of requested instance
             handler.deliver(filterInstance(instanceArray[i],
@@ -848,7 +846,7 @@ void FamilyProvider::_enumerateInstances(
     const CIMPropertyList & propertyList,
     InstanceResponseHandler & handler)
 {
-    for(Uint32 i = 0, n = instanceArray.size(); i < n; i++)
+    for (Uint32 i = 0, n = instanceArray.size(); i < n; i++)
     {
         handler.deliver(filterInstance(instanceArray[i],
             includeQualifiers, includeClassOrigin, propertyList,
@@ -917,7 +915,7 @@ void FamilyProvider::_enumerateInstanceNames(
     const CIMObjectPath & classReference,
     ObjectPathResponseHandler & handler)
 {
-    for(Uint32 i = 0, n = instanceArray.size(); i < n; i++)
+    for (Uint32 i = 0, n = instanceArray.size(); i < n; i++)
     {
         // Set the host and namespace into these.
         handler.deliver(setCompleteObjectPath(instanceArray[i].getPath(),
@@ -978,10 +976,10 @@ void FamilyProvider::_modifyInstance(
     ResponseHandler & handler)
 {
 
-    for(Uint32 i = 0, n = instanceArray.size(); i < n; i++)
+    for (Uint32 i = 0, n = instanceArray.size(); i < n; i++)
     {
         // ATTN: We will need to localize the input here.
-        if(localReference == instanceArray[i].getPath())
+        if (localReference == instanceArray[i].getPath())
         {
             // overwrite existing instance
             // ATTN:too simplistic.  Does not take into accout
@@ -1011,8 +1009,6 @@ void FamilyProvider::modifyInstance(
 
     CIMObjectPath localReference =_makeRefLocal(instanceReference);
 
-    Boolean instanceFound = false;
-
     // begin processing the request
     handler.processing();
     targetClass myClassEnum =
@@ -1059,11 +1055,10 @@ void FamilyProvider::_createInstance(
     // (class name and keys only).
     CIMObjectPath localReference = _makeRefLocal(instanceReference);
     CIMInstance saveInstance = instanceObject.clone();
-    for(Uint32 i = 0, n = instanceArray.size(); i < n; i++)
+    for (Uint32 i = 0, n = instanceArray.size(); i < n; i++)
     {
-        if(localReference == instanceArray[i].buildPath(_personDynamicClass))
-            throw CIMObjectAlreadyExistsException(
-                                  localReference.toString());
+        if (localReference == instanceArray[i].buildPath(_personDynamicClass))
+            throw CIMObjectAlreadyExistsException(localReference.toString());
     }
     // add the new instance to the array
     // Note that we make it local.  This is a decicision of this provider
@@ -1135,9 +1130,9 @@ void FamilyProvider::_deleteInstance(
     const CIMObjectPath & localReference,
     ResponseHandler & handler)
 {
-    for(Uint32 i = 0, n = instanceArray.size(); i < n; i++)
+    for (Uint32 i = 0, n = instanceArray.size(); i < n; i++)
     {
-        if(localReference == instanceArray[i].getPath())
+        if (localReference == instanceArray[i].getPath())
         {
             // remove instance from the array
             instanceArray.remove(i);
@@ -1226,18 +1221,18 @@ void FamilyProvider::_associators(
                                     resultRole);
 
         // Loop to process all resultPaths
-        for (Uint32 i = 0 ; i < resultPaths.size() ; i++)
+        for (Uint32 j = 0 ; j < resultPaths.size() ; j++)
         {
             // instance index corresponds to reference index
             // For each resultInstance, if matches result path, Deliver.
-            for(Uint32 j = 0, n = resultInstanceArray.size(); j < n; j++)
+            for (Uint32 k = 0, n = resultInstanceArray.size(); k < n; k++)
             {
-                CIMObjectPath newPath = resultInstanceArray[j].getPath();
+                CIMObjectPath newPath = resultInstanceArray[k].getPath();
 
-                if(resultPaths[i].identical(newPath))
+                if (resultPaths[j].identical(newPath))
                 {
 
-                    handler.deliver(filterInstance(resultInstanceArray[j],
+                    handler.deliver(filterInstance(resultInstanceArray[k],
                         includeQualifiers, includeClassOrigin, propertyList,
                         objectName));
                 }
@@ -1338,10 +1333,10 @@ void FamilyProvider::_associatorNames(
         resultPaths = _filterAssocInstanceToTargetPaths(
             assocInstances[i], localObjectName, resultClass, resultRole);
 
-        for (Uint32 i = 0 ; i < resultPaths.size() ; i++)
+        for (Uint32 j = 0 ; j < resultPaths.size() ; j++)
         {
             handler.deliver(
-                setCompleteObjectPath(resultPaths[i],localObjectName));
+                setCompleteObjectPath(resultPaths[j],localObjectName));
         }
     }
 }
