@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
 //
-//==============================================================================
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -48,6 +46,7 @@
 #include <Pegasus/Consumer/CIMIndicationConsumer.h>
 #include <Pegasus/Listener/CIMListener.h>
 
+
 PEGASUS_USING_PEGASUS;
 PEGASUS_USING_STD;
 
@@ -103,7 +102,7 @@ enum indicationHandleProtocol {
 
 class T_Parms{
    public:
-    AutoPtr<CIMClient> client;
+    CIMClient* client;
     Uint32 indicationSendCount;
     Uint32 uniqueID;
 };
@@ -129,9 +128,9 @@ private:
 
 };
 
-MyIndicationConsumer::MyIndicationConsumer(String name)
+MyIndicationConsumer::MyIndicationConsumer(String name_)
 {
-    this->name = name;
+    this->name = name_;
     for (Uint32 i=0; i < MAX_UNIQUE_IDS; i++)
       seqNumPrevious[i] = 1;
 
@@ -177,7 +176,7 @@ void MyIndicationConsumer::consumeIndication(
   // Calculate the time diference between when sent and received (now)
   //
 
-  Uint32 indicationTimeIndex = 
+  Uint32 indicationTimeIndex =
       indicationInstance.findProperty("IndicationTime");
 
 
@@ -190,16 +189,16 @@ void MyIndicationConsumer::consumeIndication(
     }
 
 
-  CIMConstProperty indicationTime_property = 
+  CIMConstProperty indicationTime_property =
       indicationInstance.getProperty(indicationTimeIndex);
-  // cout << "indicationTime = " 
+  // cout << "indicationTime = "
   //      << indicationTime_property.getValue().toString() << endl;
 
   CIMDateTime indicationTime;
   indicationTime_property.getValue().get(indicationTime);
 
   CIMDateTime currentDateTime = CIMDateTime::getCurrentDateTime ();
-  Sint64 sendRecvDeltaTime = 
+  Sint64 sendRecvDeltaTime =
       CIMDateTime::getDifference(indicationTime, currentDateTime);
 
   // cout << "sendRecvDeltaTime = "
@@ -221,7 +220,7 @@ void MyIndicationConsumer::consumeIndication(
   // across tests runs as long as the server continues to run)
   //
 
-  Uint32 uniqueIDIndex = 
+  Uint32 uniqueIDIndex =
       indicationInstance.findProperty("IndicationIdentifier");
 
 
@@ -234,7 +233,7 @@ void MyIndicationConsumer::consumeIndication(
     }
 
 
-  CIMConstProperty uniqueID_property = 
+  CIMConstProperty uniqueID_property =
       indicationInstance.getProperty(uniqueIDIndex);
   // cout << "uniqueID = " << uniqueID_property.getValue().toString() << endl;
 
@@ -249,7 +248,7 @@ void MyIndicationConsumer::consumeIndication(
   // Get the seq number
   //
 
-  Uint32 seqNumIndex = 
+  Uint32 seqNumIndex =
       indicationInstance.findProperty ("IndicationSequenceNumber");
 
   if (seqNumIndex == PEG_NOT_FOUND)
@@ -265,7 +264,7 @@ void MyIndicationConsumer::consumeIndication(
           maxUniqueIDMsgIssued = true;
           cout << endl;
           cout << "+++++ ERROR: Indication Stress TestConsumer - recvd"
-               << " uniqueID( " << (long)uniqueID 
+               << " uniqueID( " << (long)uniqueID
                << " ) >= MAX_UNIQUE_IDS ( " << MAX_UNIQUE_IDS << " )"
                << endl;
           cout << "+++++        To correct: Stop and start the server, this"
@@ -308,7 +307,7 @@ void MyIndicationConsumer::consumeIndication(
       // The "out of sequence" counts for "(actual != expected)" are A=3, B=2,
       // while "(actual < previous)" gives A=1, B=2.
       //
-      // Thanks to Roger Kump at HP for suggesting the 
+      // Thanks to Roger Kump at HP for suggesting the
       // actual <  previous method.
       //
       // JR Wunderlich 7/14/2005
@@ -321,7 +320,7 @@ void MyIndicationConsumer::consumeIndication(
             {
               cout << "+++++ ERROR: Indication Stress Test Consumer"
                    << "- Sequence error "
-                   << " previous = " 
+                   << " previous = "
                    << (unsigned long) seqNumPrevious[uniqueID]
                    << " received = " << (unsigned long) seqNumRecvd << endl;
             }
@@ -489,9 +488,9 @@ static Uint32  _getCount(CIMClient&  client)
     Array <CIMParamValue> inParams;
     Array <CIMParamValue> outParams;
     Uint32 result;
-  
+
     CIMObjectPath  objPath;
-    
+
     objPath.setNameSpace("test/TestProvider");
     objPath.setClassName("TestCMPI_IndicationStressTestClass");
 
@@ -503,8 +502,8 @@ static Uint32  _getCount(CIMClient&  client)
         outParams);
 
     retValue.get(result);
-    PEGASUS_TEST_ASSERT (result == 2);  
- 
+    PEGASUS_TEST_ASSERT (result == 2);
+
     return result;
 }
 
@@ -616,11 +615,11 @@ void _usage ()
         << "            Note: the <threads> parameter must be specified if\n"
         << "            the <SenderIdentity> value is defined.\n"
         << endl << endl
-        << "    TestIndicationStressTest ClassName Namespace " 
+        << "    TestIndicationStressTest ClassName Namespace "
         << "getSubscriptionCount\n "
         << "       getSubscriptionCount returns the number of\n"
         << "           active Subscriptions from Provider.\n"
-        << endl << endl 
+        << endl << endl
         << "    TestIndicationStressTest ClassName Namespace cleanup"
         << endl << endl;
 }
@@ -797,18 +796,18 @@ void _setup (CIMClient & client, String& qlang,
                  else
                  {
                      destinationProtocol = HTTP_IPV4_DESTINATION;
-                 } 
+                 }
             }
             else if (handleProtocol == PROTOCOL_CIMXML_HTTPS)
             {
                  if (Ipv6Test)
-                 { 
+                 {
                      destinationProtocol = HTTPS_IPV6_DESTINATION;
                  }
                  else
                  {
                      destinationProtocol = HTTPS_IPV4_DESTINATION;
-                 }  
+                 }
             }
             else
             {
@@ -867,7 +866,7 @@ void _setup (CIMClient & client, String& qlang,
             // Create the handler with this program as the CIMListener
             clientHandlerObjectPath = _createHandlerInstance (client,
                 CLIENT_RESIDENT_HANDLER_NAME,
-                Ipv6Test ? 
+                Ipv6Test ?
                 String ("http://[::1]:2005/TestIndicationStressTest") :
                 String ("http://localhost:2005/TestIndicationStressTest"));
         }
@@ -1018,12 +1017,12 @@ ThreadReturnType PEGASUS_THREAD_CDECL _executeTests(void *parm)
 {
     Thread *my_thread = (Thread *)parm;
     T_Parms *parms = (T_Parms *)my_thread->get_parm();
-    CIMClient *client = parms->client.get();
+    CIMClient *client = parms->client;
     Uint32 indicationSendCount = parms->indicationSendCount;
     Uint32 id = parms->uniqueID;
     char id_[4];
     memset(id_,0x00,sizeof(id_));
-    sprintf(id_,"%i",id);
+    sprintf(id_,"%u",id);
     String uniqueID = "_";
     uniqueID.append(id_);
 
@@ -1043,8 +1042,10 @@ ThreadReturnType PEGASUS_THREAD_CDECL _executeTests(void *parm)
     {
         cout << e.getMessage() << endl;
     }
-    my_thread->exit_self((ThreadReturnType)5);
-    return(0);
+
+    delete parms;
+
+    return ThreadReturnType(0);
 }
 
 Thread * _runTestThreads(
@@ -1054,7 +1055,7 @@ Thread * _runTestThreads(
 {
     // package parameters, create thread and run...
     AutoPtr<T_Parms> parms(new T_Parms());
-    parms->client.reset(client);
+    parms->client = client;
     parms->indicationSendCount = indicationSendCount;
     parms->uniqueID = uniqueID;
     AutoPtr<Thread> t(new Thread(_executeTests, (void*)parms.release(), false));
@@ -1265,13 +1266,11 @@ int _beginTest(CIMClient& workClient, const char* opt,
         // clean up
         for(Uint32 i=0; i< clientConnections.size(); i++)
         {
-            if(clientConnections[i])
-                delete clientConnections[i];
+            delete clientConnections[i];
         }
         for(Uint32 i=0; i < clientThreads.size(); i++)
         {
-            if(clientThreads[i])
-                delete clientThreads[i];
+            delete clientThreads[i];
         }
 
         //
@@ -1469,7 +1468,7 @@ int _beginTest(CIMClient& workClient, const char* opt,
                 currentServerResidentIndicationCount);
             if (expectedSenderIdentity != String::EMPTY)
             {
-                assert(indicationSendCountTotal ==
+                PEGASUS_TEST_ASSERT(indicationSendCountTotal ==
                     currentServerResidentIdentityIndicationCount);
             }
         }
@@ -1490,7 +1489,7 @@ int _beginTest(CIMClient& workClient, const char* opt,
     {
         Uint32 res = _getCount(workClient);
         cout << " ++++++++ Number of Subscriptions " << res <<endl;
-    }    
+    }
     else if (String::equalNoCase (opt, "cleanup"))
     {
         _cleanup (workClient);
@@ -1550,7 +1549,7 @@ int main (int argc, char** argv)
     Ipv6Test = false;
 
     // Check if class name is IPv6TestClass, handle this class name
-    // differently. We use default class-name and namespace for 
+    // differently. We use default class-name and namespace for
     // IPv6TestClass class. IPv6TestClass class does not exist, it is used
     // to test IndicationStressTestProvider on IPv6.
     if (!strcmp(argv[1], "IPv6TestClass"))
@@ -1564,7 +1563,7 @@ int main (int argc, char** argv)
     {
         indicationClassName = argv[1];
         sourceNamespace = CIMNamespaceName (argv[2]);
-    } 
+    }
     cout << "++++ Testing with class " << indicationClassName
          << " and Namespace " << sourceNamespace.getString () << endl;
 
