@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -364,7 +362,7 @@ CIMClass TestAggregationOutputProvider::_getClass(const CIMName& className)
     }
     catch (CIMException& e)
     {
-        PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL2,
+        PEG_TRACE((TRC_DISCARDED_DATA, Tracer::LEVEL1,
             "TestAggregationOutputProvider GetClass operation failed: "
                 "Class %s. Msg %s",
             (const char*) className.getString().getCString(),
@@ -443,7 +441,6 @@ void TestAggregationOutputProvider::initialize(CIMOMHandle & cimom)
         }
 
         // Make the instances for the associations
-        Uint32 temp  = _instancesTeaches.size();
 
         CIMInstance ciminstance;
         ciminstance = _buildInstanceTeaches(
@@ -713,18 +710,18 @@ void TestAggregationOutputProvider::_associators(
                     resultRole);
 
             // Loop to process all resultPaths
-            for (Uint32 i = 0 ; i < resultPaths.size() ; ++i)
+            for (Uint32 j = 0 ; j < resultPaths.size() ; ++j)
             {
                 // instance index corresponds to reference index
                 // For each resultInstance, if matches result path, Deliver.
-                for(Uint32 j = 0, n = resultInstanceArray.size(); j < n; ++j)
+                for(Uint32 k = 0, n = resultInstanceArray.size(); k < n; ++k)
                 {
-                    CIMObjectPath newPath = resultInstanceArray[j].getPath();
+                    CIMObjectPath newPath = resultInstanceArray[k].getPath();
 
-                    if(resultPaths[i].identical(newPath))
+                    if(resultPaths[j].identical(newPath))
                     {
                         handler.deliver(_filter(
-                            resultInstanceArray[j],
+                            resultInstanceArray[k],
                             includeQualifiers,
                             includeClassOrigin,
                             propertyList));
@@ -813,9 +810,9 @@ void TestAggregationOutputProvider::_associatorNames(
                     resultClass,
                     resultRole);
 
-            for (Uint32 i = 0 ; i < resultPaths.size() ; ++i)
+            for (Uint32 j = 0 ; j < resultPaths.size() ; ++j)
             {
-                CIMObjectPath sendPath = resultPaths[i];
+                CIMObjectPath sendPath = resultPaths[j];
                 String host = System::getHostName();
                 if (sendPath.getHost().size() == 0)
                     sendPath.setHost(host);
@@ -848,7 +845,6 @@ void TestAggregationOutputProvider::associatorNames(
     ObjectPathResponseHandler & handler)
 {
     // Get the namespace and host names to create the CIMObjectPath
-    String host = System::getHostName();
     CIMObjectPath localobjectName = _makeRefLocal (objectName);
     handler.processing();
     targetClass myClassEnum  = _verifyValidAssocClassInput(associationClass);
@@ -1141,7 +1137,6 @@ void TestAggregationOutputProvider::modifyInstance(
     const CIMPropertyList & propertyList,
     ResponseHandler & handler)
 {
-    Boolean instanceFound = false;
     // begin processing the request
     handler.processing();
     targetClass myClassEnum =
