@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
 //
-//==============================================================================
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -299,7 +297,7 @@ printData (const CmpiData& d)
          L;CMPIUint64 dt = v.getDateTime();
          cout << dt;
       }
-      catch (const CmpiStatus& e)
+      catch (const CmpiStatus&)
       {
          cout << "(null)";
       }
@@ -416,7 +414,14 @@ TestCMPI_CXX::initialize (const CmpiContext& ctx)
         L;CMPIReal32     r32Data1   = 10;
         L;CMPIReal64     r64Data1   = 11;
         L;CmpiString     strData1   = "12";
-        L;const char     achData1[] = { '1', '3', '\0' };
+
+        union
+        {
+            CMPIUint64 alignment;
+            char achData1[3];
+        };
+        strcpy(achData1, "13");
+
         L;CmpiDateTime   dtData1;
         L;CmpiObjectPath copData1 ("root/SampleProvider", "CWS_PlainFile_CXX");
         L;CmpiInstance   ciData1 (copData1);
@@ -886,7 +891,7 @@ TestCMPI_CXX::initialize (const CmpiContext& ctx)
         L;CmpiDateTime dtData4 ("20070501152143.164592-300");
         // echo `date --date='2007-05-01 15:21:43' +%s`*1000000+164592 | bc
         // 1178050903164592LL
-        L;CmpiDateTime dtData5 
+        L;CmpiDateTime dtData5
             (PEGASUS_UINT64_LITERAL(1178050903164592), false);
         L;CmpiDateTime dtData6 ("00000011125959.123456:000");
         L;CmpiDateTime dtData7 (PEGASUS_UINT64_LITERAL(997199123456), true);
@@ -1064,7 +1069,7 @@ TestCMPI_CXX::enumInstances (const CmpiContext&     ctx,
                              const CmpiObjectPath&  cop,
                              const char*           *properties)
 {
-   return CmpiStatus 
+   return CmpiStatus
        (CMPI_RC_ERR_NOT_SUPPORTED, "TestCMPI_CXX: cannot enumInstances");
 }
 
@@ -1074,7 +1079,7 @@ TestCMPI_CXX::getInstance (const CmpiContext&     ctx,
                            const CmpiObjectPath&  cop,
                            const char*           *properties)
 {
-    return CmpiStatus 
+    return CmpiStatus
         (CMPI_RC_ERR_NOT_SUPPORTED, "TestCMPI_CXX: cannot getInstance");
 }
 
@@ -1085,7 +1090,7 @@ TestCMPI_CXX::setInstance (const CmpiContext&     ctx,
                            const CmpiInstance&    inst,
                            const char*           *properties)
 {
-    return CmpiStatus 
+    return CmpiStatus
         (CMPI_RC_ERR_NOT_SUPPORTED, "TestCMPI_CXX: cannot setInstance");
 }
 
@@ -1095,7 +1100,7 @@ TestCMPI_CXX::createInstance (const CmpiContext&    ctx,
                               const CmpiObjectPath& cop,
                               const CmpiInstance&   inst)
 {
-    return CmpiStatus 
+    return CmpiStatus
         (CMPI_RC_ERR_NOT_SUPPORTED, "TestCMPI_CXX: cannot createInstance");
 }
 
@@ -1104,6 +1109,6 @@ TestCMPI_CXX::deleteInstance (const CmpiContext&    ctx,
                               CmpiResult&           rslt,
                               const CmpiObjectPath& cop)
 {
-    return CmpiStatus 
+    return CmpiStatus
         (CMPI_RC_ERR_NOT_SUPPORTED, "TestCMPI_CXX: cannot deleteInstance");
 }
