@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -86,6 +84,7 @@
 #include <Pegasus/Common/FileSystem.h>
 #include <Pegasus/Common/PegasusVersion.h>
 #include <Pegasus/Common/Logger.h>
+#include <Pegasus/Common/StringConversion.h>
 #include <Pegasus/Common/System.h>
 #include <Pegasus/Common/Tracer.h>
 #include <Pegasus/Common/LanguageParser.h>
@@ -96,7 +95,7 @@
 #include <Service/ServerShutdownClient.h>
 #include <Service/ServerRunStatus.h>
 
-#if defined(PEGASUS_PLATFORM_ZOS_ZSERIES_IBM)
+#if defined(PEGASUS_OS_ZOS)
 #include <Pegasus/Common/SetFileDescriptorToEBCDICEncoding.h>
 #include <Service/ARM_zOS.h>
 # ifdef PEGASUS_ZOS_SECURITY
@@ -447,7 +446,7 @@ int main(int argc, char** argv)
     if ( setEBCDICEncoding(STDOUT_FILENO)==-1 ||
          setEBCDICEncoding(STDERR_FILENO)==-1 )
     {
-       PEG_TRACE_CSTRING(TRC_SERVER,Tracer::LEVEL4,
+       PEG_TRACE_CSTRING(TRC_SERVER,Tracer::LEVEL1,
            "Coud not set stdout or stderr to EBCDIC encoding.");
     }
     // Need to initialize timezone information in the
@@ -469,7 +468,7 @@ int main(int argc, char** argv)
     const char *tmp = getenv("PEGASUS_HOME");
     pegasusHome = (tmp == 0) ? PASE_DEFAULT_PEGASUS_HOME : tmp;
 # elif !defined(PEGASUS_USE_RELEASE_DIRS) || \
-    defined(PEGASUS_PLATFORM_ZOS_ZSERIES_IBM)
+    defined(PEGASUS_OS_ZOS)
     const char* tmp = getenv("PEGASUS_HOME");
 
     if (tmp)
@@ -686,7 +685,7 @@ int CIMServerProcess::cimserver_run(
         exit (1);
     }
 
-    // Direct standard input, output, and error to /dev/null, 
+    // Direct standard input, output, and error to /dev/null,
     // PASE run this job in background, any output in not allowed
     freopen("/dev/null", "r", stdin);
     freopen("/dev/null", "w", stdout);
@@ -716,55 +715,68 @@ int CIMServerProcess::cimserver_run(
         MessageLoader::setPegasusMsgHome(ConfigManager::getHomedPath(
             ConfigManager::getInstance()->getCurrentValue("messageDir")));
 
-#ifdef PEGASUS_OS_PASE
-    // set ccsid to unicode for entire job
-    // ccsid is globolization mechanism in PASE environment
-    if (_SETCCSID(1208) == -1)
-    {
-        MessageLoaderParms parms(
-                "src.Server.cimserver.SET_CCSID_ERROR.PEGASUS_OS_PASE",
-                "Failed to set CCSID, server will stop.");
-        cerr << MessageLoader::getMessage(parms) << endl;
-        Logger::put_l(Logger::ERROR_LOG, System::CIMSERVER, Logger::FATAL,
-                "src.Server.cimserver.SET_CCSID_ERROR.PEGASUS_OS_PASE",
-                "Failed to set CCSID, server will stop.\n");
-        exit (1);
-    }
+#if !defined(PEGASUS_USE_SYSLOGS)
+        String logsDirectory = ConfigManager::getHomedPath(
+            configManager->getCurrentValue("logdir"));
 
-    char fullJobName[29];
-    umeGetJobName(fullJobName, true);
-    Logger::put_l(Logger::STANDARD_LOG, System::CIMSERVER, Logger::INFORMATION,
-            "src.Server.cimserver.SERVER_JOB_NAME.PEGASUS_OS_PASE",
-            "CIM Server's Job Name is: $0", fullJobName);
+        // Set up the Logger.  This does not open the logs.
+        // Might be more logical to clean before set.
+        Logger::setHomeDirectory(logsDirectory);
 #endif
 
-    Boolean enableHttpConnection = ConfigManager::parseBooleanValue(
-        configManager->getCurrentValue("enableHttpConnection"));
-    Boolean enableHttpsConnection = ConfigManager::parseBooleanValue(
-        configManager->getCurrentValue("enableHttpsConnection"));
 
-    // Make sure at least one connection is enabled
+#ifdef PEGASUS_OS_PASE
+        /* write job log to tell where pegasus log is.*/
+        if(logsDirectory.size() > 0)
+            // this function only can be found in PASE environment
+            logPegasusDir2joblog(logsDirectory.getCString());
+        else
+            logPegasusDir2joblog(".");
+
+        // set ccsid to unicode for entire job
+        // ccsid is globolization mechanism in PASE environment
+        if (_SETCCSID(1208) == -1)
+        {
+            MessageLoaderParms parms(
+                    "src.Server.cimserver.SET_CCSID_ERROR.PEGASUS_OS_PASE",
+                    "Failed to set CCSID, server will stop.");
+            cerr << MessageLoader::getMessage(parms) << endl;
+            Logger::put_l(Logger::ERROR_LOG, System::CIMSERVER, Logger::FATAL,
+                    parms);
+            exit (1);
+        }
+
+        char fullJobName[29];
+        umeGetJobName(fullJobName, true);
+        Logger::put_l(Logger::STANDARD_LOG, System::CIMSERVER,
+                Logger::INFORMATION,
+                MessageLoaderParms(
+                    "src.Server.cimserver.SERVER_JOB_NAME.PEGASUS_OS_PASE",
+                    "CIM Server's Job Name is: $0", fullJobName));
+#endif
+
 #ifdef PEGASUS_DISABLE_LOCAL_DOMAIN_SOCKET
-    if (!enableHttpConnection && !enableHttpsConnection)
-    {
-        //l10n
-        //Logger::put(Logger::STANDARD_LOG, System::CIMSERVER, Logger::WARNING,
-            //"Neither HTTP nor HTTPS connection is enabled.  "
-            //"CIMServer will not be started.");
-        Logger::put_l(Logger::STANDARD_LOG, System::CIMSERVER, Logger::WARNING,
-            "src.Server.cimserver.HTTP_NOT_ENABLED_SERVER_NOT_STARTING",
-            "Neither HTTP nor HTTPS connection is enabled."
-            "  CIMServer will not be started.");
-        //cerr << "Neither HTTP nor HTTPS connection is enabled.  "
-            //"CIMServer will not be started." << endl;
-        MessageLoaderParms parms(
+        // Make sure at least one connection is enabled
+
+        Boolean enableHttpConnection = ConfigManager::parseBooleanValue(
+            configManager->getCurrentValue("enableHttpConnection"));
+        Boolean enableHttpsConnection = ConfigManager::parseBooleanValue(
+            configManager->getCurrentValue("enableHttpsConnection"));
+
+        if (!enableHttpConnection && !enableHttpsConnection)
+        {
+            MessageLoaderParms parms(
                 "src.Server.cimserver.HTTP_NOT_ENABLED_SERVER_NOT_STARTING",
                 "Neither HTTP nor HTTPS connection is enabled."
-                "  CIMServer will not be started.");
-        cerr << MessageLoader::getMessage(parms) << endl;
-        return(1);
-    }
+                    "  CIMServer will not be started.");
+            Logger::put_l(
+                Logger::STANDARD_LOG, System::CIMSERVER, Logger::WARNING,
+                parms);
+            cerr << MessageLoader::getMessage(parms) << endl;
+            return 1;
+        }
 #endif
+
         //
         // Check to see if we should start Pegasus as a daemon
         //
@@ -781,24 +793,6 @@ int CIMServerProcess::cimserver_run(
             daemonOption = true;
         }
 
-#if !defined(PEGASUS_USE_SYSLOGS)
-        String logsDirectory = ConfigManager::getHomedPath(
-            configManager->getCurrentValue("logdir"));
-
-        // Set up the Logger.  This does not open the logs.
-        // Might be more logical to clean before set.
-        Logger::setHomeDirectory(logsDirectory);
-        
-# ifdef PEGASUS_OS_PASE
-    /* write job log to tell where pegasus log is.*/
-    if(logsDirectory.size() > 0)
-        // this function only can be found in PASE environment
-        logPegasusDir2joblog(logsDirectory.getCString());
-    else
-        logPegasusDir2joblog(".");
-# endif
-#endif
-
         //
         // Check to see if we need to shutdown CIMOM
         //
@@ -808,10 +802,6 @@ int CIMServerProcess::cimserver_run(
                 configManager->getCurrentValue("shutdownTimeout");
             Uint32 timeoutValue =
                 strtol(configTimeout.getCString(), (char **)0, 10);
-#ifdef PEGASUS_SLP_REG_TIMEOUT
-            // To deregister Pegasus with SLP
-            unregisterPegasusFromSLP();
-#endif
 
             ServerShutdownClient serverShutdownClient(&_serverRunStatus);
             serverShutdownClient.shutdown(timeoutValue);
@@ -835,14 +825,14 @@ int CIMServerProcess::cimserver_run(
     {
         MessageLoaderParms parms("src.Server.cimserver.SERVER_NOT_STARTED",
             "cimserver not started: $0", e.getMessage());
-        Logger::put(Logger::ERROR_LOG, System::CIMSERVER, Logger::SEVERE,
-            MessageLoader::getMessage(parms));
+        Logger::put_l(Logger::ERROR_LOG, System::CIMSERVER, Logger::SEVERE,
+            parms);
         cerr << MessageLoader::getMessage(parms) << endl;
 
         return 1;
     }
 
-#if defined(PEGASUS_PLATFORM_ZOS_ZSERIES_IBM) && defined(PEGASUS_ZOS_SECURITY)
+#if defined(PEGASUS_OS_ZOS) && defined(PEGASUS_ZOS_SECURITY)
     startupCheckBPXServer(true);
     startupCheckProfileCIMSERVclassWBEM();
     startupEnableMSC();
@@ -877,18 +867,17 @@ int CIMServerProcess::cimserver_run(
     // The run function for the dummy Thread should never be called,
     dummyInitialThread = new Thread(dummyThreadFunc, NULL, false);
     Thread::setCurrent(dummyInitialThread);
-    AcceptLanguageList default_al;
     try
     {
-        default_al = LanguageParser::getDefaultAcceptLanguages();
-        Thread::setLanguages(new AcceptLanguageList(default_al));
+        Thread::setLanguages(LanguageParser::getDefaultAcceptLanguages());
     }
     catch (InvalidAcceptLanguageHeader& e)
     {
         Logger::put_l(Logger::ERROR_LOG, System::CIMSERVER, Logger::SEVERE,
-            "src.Server.cimserver.FAILED_TO_SET_PROCESS_LOCALE",
-            "Could not convert the system process locale into a valid "
-                "AcceptLanguage format.");
+            MessageLoaderParms(
+                "src.Server.cimserver.FAILED_TO_SET_PROCESS_LOCALE",
+                "Could not convert the system process locale into a valid "
+                    "AcceptLanguage format."));
         Logger::put(Logger::ERROR_LOG, System::CIMSERVER, Logger::SEVERE,
             e.getMessage());
     }
@@ -930,9 +919,9 @@ int CIMServerProcess::cimserver_run(
             MessageLoaderParms parms(
                 "src.Server.cimserver.UNABLE_TO_START_SERVER_ALREADY_RUNNING",
                 "Unable to start CIMServer. CIMServer is already running.");
-            Logger::put(
+            Logger::put_l(
                 Logger::ERROR_LOG, System::CIMSERVER, Logger::INFORMATION,
-                MessageLoader::getMessage(parms));
+                parms);
             cerr << MessageLoader::getMessage(parms) << endl;
 
             if (daemonOption)
@@ -988,9 +977,9 @@ int CIMServerProcess::cimserver_run(
             MessageLoaderParms parms(
                 "src.Server.cimserver.IPV6_STACK_NOT_ACTIVE",
                 "IPv6 stack is not active, using IPv4 socket.");
-            Logger::put(
+            Logger::put_l(
                 Logger::STANDARD_LOG, System::CIMSERVER, Logger::INFORMATION,
-                MessageLoader::getMessage(parms));
+                parms);
 #if defined(PEGASUS_DEBUG)
             cout << MessageLoader::getMessage(parms) << endl;
 #endif
@@ -1047,13 +1036,18 @@ int CIMServerProcess::cimserver_run(
                 _cimServer->addAcceptor(HTTPAcceptor::IPV4_CONNECTION,
                     portNumberHttp, false);
             }
-
+            // The port number is converted to a string to avoid the
+            //  addition of localized characters (e.g., "5,988").
+            char scratchBuffer[22];
+            Uint32 n;
+            const char * portNumberHttpStr = Uint32ToString(
+                scratchBuffer, portNumberHttp, n);
             MessageLoaderParms parms(
                 "src.Server.cimserver.LISTENING_ON_HTTP_PORT",
-                "Listening on HTTP port $0.", portNumberHttp);
-            Logger::put(
+                "Listening on HTTP port $0.", portNumberHttpStr);
+            Logger::put_l(
                 Logger::STANDARD_LOG, System::CIMSERVER, Logger::INFORMATION,
-                MessageLoader::getMessage(parms));
+                parms);
 #if defined(PEGASUS_DEBUG)
             cout << MessageLoader::getMessage(parms) << endl;
 #endif
@@ -1085,7 +1079,7 @@ int CIMServerProcess::cimserver_run(
                 }
             }
             if (addIP6Acceptor)
-            { 
+            {
                 _cimServer->addAcceptor(HTTPAcceptor::IPV6_CONNECTION,
                     portNumberHttps, true);
             }
@@ -1094,12 +1088,18 @@ int CIMServerProcess::cimserver_run(
                 _cimServer->addAcceptor(HTTPAcceptor::IPV4_CONNECTION,
                     portNumberHttps, true);
             }
+            // The port number is converted to a string to avoid the
+            //  addition of localized characters (e.g., "5,989").
+            char scratchBuffer[22];
+            Uint32 n;
+            const char * portNumberHttpsStr = Uint32ToString(
+                scratchBuffer, portNumberHttps, n);
             MessageLoaderParms parms(
                 "src.Server.cimserver.LISTENING_ON_HTTPS_PORT",
-                "Listening on HTTPS port $0.", portNumberHttps);
-            Logger::put(
+                "Listening on HTTPS port $0.", portNumberHttpsStr);
+            Logger::put_l(
                 Logger::STANDARD_LOG, System::CIMSERVER, Logger::INFORMATION,
-                MessageLoader::getMessage(parms));
+                parms);
 #if defined(PEGASUS_DEBUG)
             cout << MessageLoader::getMessage(parms) << endl;
 #endif
@@ -1112,9 +1112,9 @@ int CIMServerProcess::cimserver_run(
             MessageLoaderParms parms(
                 "src.Server.cimserver.LISTENING_ON_LOCAL",
                 "Listening on local connection socket.");
-            Logger::put(
+            Logger::put_l(
                 Logger::STANDARD_LOG, System::CIMSERVER, Logger::INFORMATION,
-                MessageLoader::getMessage(parms));
+                parms);
 # if defined(PEGASUS_DEBUG)
             cout << MessageLoader::getMessage(parms) << endl;
 # endif
@@ -1137,10 +1137,11 @@ int CIMServerProcess::cimserver_run(
         // Put server started message to the logger
         Logger::put_l(Logger::STANDARD_LOG, System::CIMSERVER,
             Logger::INFORMATION,
-            "src.Server.cimserver.STARTED_VERSION",
-            "Started $0 version $1.",
-            _cimServerProcess->getProductName(),
-            _cimServerProcess->getCompleteVersion());
+            MessageLoaderParms(
+                "src.Server.cimserver.STARTED_VERSION",
+                "Started $0 version $1.",
+                _cimServerProcess->getProductName(),
+                _cimServerProcess->getCompleteVersion()));
 
 #if defined(PEGASUS_OS_TYPE_UNIX) && !defined(PEGASUS_OS_ZOS)
         if (daemonOption && !debugOutputOption)
@@ -1160,8 +1161,8 @@ int CIMServerProcess::cimserver_run(
     {
         MessageLoaderParms parms("src.Server.cimserver.SERVER_NOT_STARTED",
             "cimserver not started: $0", e.getMessage());
-        Logger::put(Logger::ERROR_LOG, System::CIMSERVER, Logger::SEVERE,
-            MessageLoader::getMessage(parms));
+        Logger::put_l(Logger::ERROR_LOG, System::CIMSERVER, Logger::SEVERE,
+            parms);
         cerr << MessageLoader::getMessage(parms) << endl;
 
         //
@@ -1178,7 +1179,7 @@ int CIMServerProcess::cimserver_run(
 
     try
     {
-#if defined(PEGASUS_PLATFORM_ZOS_ZSERIES_IBM)
+#if defined(PEGASUS_OS_ZOS)
 
         // ARM is a z/OS internal restart facility.
         // This is a z/OS specific change.
@@ -1191,6 +1192,9 @@ int CIMServerProcess::cimserver_run(
 
 #endif
 
+#ifdef PEGASUS_ENABLE_SLP
+        _cimServer->startSLPProvider();
+#endif
         //
         // Loop to call CIMServer's runForever() method until CIMServer
         // has been shutdown
@@ -1204,7 +1208,7 @@ int CIMServerProcess::cimserver_run(
         // normal termination
         //
 
-#if defined(PEGASUS_PLATFORM_ZOS_ZSERIES_IBM)
+#if defined(PEGASUS_OS_ZOS)
 
         // ARM is a z/OS internal restart facility.
         // This is a z/OS specific change.
@@ -1215,9 +1219,11 @@ int CIMServerProcess::cimserver_run(
 #endif
 
         // Put server shutdown message to the logger
-        Logger::put_l(Logger::STANDARD_LOG, System::CIMSERVER,
-            Logger::INFORMATION, "src.Server.cimserver.STOPPED",
-            "$0 stopped.", _cimServerProcess->getProductName());
+        Logger::put_l(
+            Logger::STANDARD_LOG, System::CIMSERVER, Logger::INFORMATION,
+            MessageLoaderParms(
+                "src.Server.cimserver.STOPPED",
+                "$0 stopped.", _cimServerProcess->getProductName()));
     }
     catch (Exception& e)
     {
@@ -1225,8 +1231,8 @@ int CIMServerProcess::cimserver_run(
             "src.Server.cimserver.ERROR",
             "Error: $0",
             e.getMessage());
-        Logger::put(Logger::STANDARD_LOG, System::CIMSERVER, Logger::WARNING,
-            MessageLoader::getMessage(parms));
+        Logger::put_l(Logger::STANDARD_LOG, System::CIMSERVER, Logger::WARNING,
+            parms);
         cerr << MessageLoader::getMessage(parms) << endl;
 
         deleteCIMServer();
