@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -111,7 +109,7 @@ void signal_shutdown()
     AutoMutex am(_cimserverLock);
     _shutdown = true;
     if (_server_proc)
-        _server_proc->cimserver_stop(); 
+        _server_proc->cimserver_stop();
 }
 
 //-------------------------------------------------------------------------
@@ -127,11 +125,11 @@ static unsigned __stdcall cimserver_windows_thread(void* parm)
 }
 
 //-------------------------------------------------------------------------
-//  Windows NT Service Control Code 
+//  Windows NT Service Control Code
 //-------------------------------------------------------------------------
 
 //-------------------------------------------------------------------------
-// START/STOP handler 
+// START/STOP handler
 //-------------------------------------------------------------------------
 int cimserver_windows_main(int flag, int argc, char *argv[])
 {
@@ -168,7 +166,7 @@ int cimserver_windows_main(int flag, int argc, char *argv[])
 
         while (WaitForSingleObject(hThread, 3000) == WAIT_TIMEOUT)
         {
-            pegasus_service.report_status( 
+            pegasus_service.report_status(
                 SERVICE_STOP_PENDING, NO_ERROR, dwCheckPoint++, 5000);
         }
 
@@ -620,9 +618,9 @@ int ServerProcess::platform_run(
         MessageLoaderParms parms(
             "src.Server.cimserver.UNABLE_TO_START_SERVER_ALREADY_RUNNING",
             "Unable to start CIMServer.\nCIMServer is already running.");
-        Logger::put(
+        Logger::put_l(
             Logger::ERROR_LOG, "CIMServer", Logger::SEVERE,
-            MessageLoader::getMessage(parms));
+            parms);
         PEGASUS_STD(cerr) << MessageLoader::getMessage(parms) <<
             PEGASUS_STD(endl);
         return 1;
@@ -655,9 +653,10 @@ int ServerProcess::platform_run(
         // todo: put into localized messages when messages unfreezes.
         Logger::put_l(
             Logger::ERROR_LOG, "CIMServer", Logger::SEVERE,
-            "src.Server.cimserver_windows.LISTENING_ON_HTTP_PORT",
-            "Error during service run: code = $0.",
-            status);
+            MessageLoaderParms(
+                "src.Server.cimserver_windows.LISTENING_ON_HTTP_PORT",
+                "Error during service run: code = $0.",
+                status));
         return 1;
     }
 
