@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//=============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 // Author: Mike Brasher (mbrasher@bmc.com)
 //
@@ -141,7 +139,7 @@ void CIMOperationRequestDispatcher::_enqueueResponse(
     PEG_METHOD_EXIT();
 }
 
-ThreadReturnType PEGASUS_THREAD_CDECL 
+ThreadReturnType PEGASUS_THREAD_CDECL
     CIMOperationRequestDispatcher::_callMethodHandler(void *parm)
 {
     ThreadParm_t* myParms = reinterpret_cast<ThreadParm_t *>(parm);
@@ -331,7 +329,7 @@ void CIMOperationRequestDispatcher::handleEnqueue(Message *request)
 
     // allocate and run one thread for each request
     MessageQueueService::get_thread_pool()->allocate_and_awaken(
-        myParm, 
+        myParm,
         _callMethodHandler);
 
     PEG_METHOD_EXIT();
@@ -351,7 +349,7 @@ void CIMOperationRequestDispatcher::handleGetClassRequest(
 
     try
     {
-        WMIMapperUserInfoContainer container = 
+        WMIMapperUserInfoContainer container =
             request->operationContext.get("WMIMapperUserInfoContainer");
 
         StatProviderTimeMeasurement providerTime(response.get());
@@ -380,7 +378,7 @@ void CIMOperationRequestDispatcher::handleGetClassRequest(
     }
     catch(...)
     {
-        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED, 
+        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED,
             "GetClass() failed!");
     }
 
@@ -409,14 +407,14 @@ void CIMOperationRequestDispatcher::handleGetInstanceRequest(
 
     try
     {
-        WMIMapperUserInfoContainer container = 
+        WMIMapperUserInfoContainer container =
             request->operationContext.get("WMIMapperUserInfoContainer");
 
         StatProviderTimeMeasurement providerTime(response.get());
 
         provider.initialize();
 
-        response->cimInstance = provider.getInstance(
+        CIMInstance cimInstance = provider.getInstance(
             request->nameSpace.getString(),
             ((IdentityContainer) request->operationContext.get
                 (IdentityContainer::NAME)).getUserName(),
@@ -426,6 +424,13 @@ void CIMOperationRequestDispatcher::handleGetInstanceRequest(
             request->includeQualifiers,
             request->includeClassOrigin,
             request->propertyList);
+
+        AutoPtr<CIMGetInstanceResponseMessage> response(
+            dynamic_cast<CIMGetInstanceResponseMessage*>(
+                request->buildResponse()));
+        response->setCimInstance(cimInstance);
+
+
     }
     catch(CIMException& exception)
     {
@@ -438,7 +443,7 @@ void CIMOperationRequestDispatcher::handleGetInstanceRequest(
     }
     catch(...)
     {
-        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED, 
+        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED,
             "GetInstance() failed!");
     }
 
@@ -464,7 +469,7 @@ void CIMOperationRequestDispatcher::handleDeleteClassRequest(
 
     try
     {
-        WMIMapperUserInfoContainer container = 
+        WMIMapperUserInfoContainer container =
             request->operationContext.get("WMIMapperUserInfoContainer");
 
         StatProviderTimeMeasurement providerTime(response.get());
@@ -489,10 +494,10 @@ void CIMOperationRequestDispatcher::handleDeleteClassRequest(
     }
     catch(...)
     {
-        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED, 
+        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED,
             "DeleteClass() failed!");
     }
-    
+
     //terminate the provider
     provider.terminate();
 
@@ -516,7 +521,7 @@ void CIMOperationRequestDispatcher::handleDeleteInstanceRequest(
 
     try
     {
-        WMIMapperUserInfoContainer container = 
+        WMIMapperUserInfoContainer container =
             request->operationContext.get("WMIMapperUserInfoContainer");
 
         StatProviderTimeMeasurement providerTime(response.get());
@@ -541,7 +546,7 @@ void CIMOperationRequestDispatcher::handleDeleteInstanceRequest(
     }
     catch(...)
     {
-        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED, 
+        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED,
             "DeleteInstance() failed!");
     }
 
@@ -568,7 +573,7 @@ void CIMOperationRequestDispatcher::handleCreateClassRequest(
 
     try
     {
-        WMIMapperUserInfoContainer container = 
+        WMIMapperUserInfoContainer container =
             request->operationContext.get("WMIMapperUserInfoContainer");
 
         StatProviderTimeMeasurement providerTime(response.get());
@@ -593,7 +598,7 @@ void CIMOperationRequestDispatcher::handleCreateClassRequest(
     }
     catch(...)
     {
-        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED, 
+        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED,
             "CreateClass() failed!");
     }
 
@@ -620,7 +625,7 @@ void CIMOperationRequestDispatcher::handleCreateInstanceRequest(
 
     try
     {
-        WMIMapperUserInfoContainer container = 
+        WMIMapperUserInfoContainer container =
             request->operationContext.get("WMIMapperUserInfoContainer");
 
         StatProviderTimeMeasurement providerTime(response.get());
@@ -645,10 +650,10 @@ void CIMOperationRequestDispatcher::handleCreateInstanceRequest(
     }
     catch(...)
     {
-        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED, 
+        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED,
             "CreateInstance() failed!");
     }
-    
+
     //terminate the provider
     provider.terminate();
 
@@ -672,7 +677,7 @@ void CIMOperationRequestDispatcher::handleModifyClassRequest(
 
     try
     {
-        WMIMapperUserInfoContainer container = 
+        WMIMapperUserInfoContainer container =
             request->operationContext.get("WMIMapperUserInfoContainer");
 
         StatProviderTimeMeasurement providerTime(response.get());
@@ -724,7 +729,7 @@ void CIMOperationRequestDispatcher::handleModifyInstanceRequest(
 
     try
     {
-        WMIMapperUserInfoContainer container = 
+        WMIMapperUserInfoContainer container =
             request->operationContext.get("WMIMapperUserInfoContainer");
 
         StatProviderTimeMeasurement providerTime(response.get());
@@ -775,10 +780,10 @@ void CIMOperationRequestDispatcher::handleEnumerateClassesRequest(
             request->buildResponse()));
 
     WMIClassProvider provider;
-    
+
     try
     {
-        WMIMapperUserInfoContainer container = 
+        WMIMapperUserInfoContainer container =
             request->operationContext.get("WMIMapperUserInfoContainer");
 
         StatProviderTimeMeasurement providerTime(response.get());
@@ -807,7 +812,7 @@ void CIMOperationRequestDispatcher::handleEnumerateClassesRequest(
     }
     catch(...)
     {
-        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED, 
+        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED,
             "enumerateClasses() failed!");
     }
 
@@ -834,7 +839,7 @@ void CIMOperationRequestDispatcher::handleEnumerateClassNamesRequest(
 
     try
     {
-        WMIMapperUserInfoContainer container = 
+        WMIMapperUserInfoContainer container =
             request->operationContext.get("WMIMapperUserInfoContainer");
 
         StatProviderTimeMeasurement providerTime(response.get());
@@ -860,7 +865,7 @@ void CIMOperationRequestDispatcher::handleEnumerateClassNamesRequest(
     }
     catch(...)
     {
-        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED, 
+        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED,
             "enumerateClassNames() failed!");
     }
 
@@ -884,10 +889,11 @@ void CIMOperationRequestDispatcher::handleEnumerateInstancesRequest(
             request->buildResponse()));
 
     WMIInstanceProvider provider;
+    Array<CIMInstance> cimNamedInstances;
 
     try
     {
-        WMIMapperUserInfoContainer container = 
+        WMIMapperUserInfoContainer container =
             request->operationContext.get("WMIMapperUserInfoContainer");
         CIMPropertyList propertyList(request->propertyList);
 
@@ -895,7 +901,7 @@ void CIMOperationRequestDispatcher::handleEnumerateInstancesRequest(
 
         provider.initialize( );
 
-        response->cimNamedInstances = provider.enumerateInstances(
+        cimNamedInstances = provider.enumerateInstances(
             request->nameSpace.getString(),
             ((IdentityContainer) request->operationContext.get
                 (IdentityContainer::NAME)).getUserName(),
@@ -915,10 +921,12 @@ void CIMOperationRequestDispatcher::handleEnumerateInstancesRequest(
     }
     catch(...)
     {
-        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED, 
+        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED,
             "enumerateInstances() failed!");
     }
 
+    response->setNamedInstances(cimNamedInstances);
+
     // cancel the provider
     provider.terminate();
 
@@ -941,7 +949,7 @@ void CIMOperationRequestDispatcher::handleEnumerateInstanceNamesRequest(
 
     try
     {
-        WMIMapperUserInfoContainer container = 
+        WMIMapperUserInfoContainer container =
             request->operationContext.get("WMIMapperUserInfoContainer");
 
         StatProviderTimeMeasurement providerTime(response.get());
@@ -993,7 +1001,7 @@ void CIMOperationRequestDispatcher::handleAssociatorsRequest(
 
     try
     {
-        WMIMapperUserInfoContainer container = 
+        WMIMapperUserInfoContainer container =
             request->operationContext.get("WMIMapperUserInfoContainer");
         CIMPropertyList propertyList(request->propertyList);
 
@@ -1028,10 +1036,10 @@ void CIMOperationRequestDispatcher::handleAssociatorsRequest(
     }
     catch(...)
     {
-        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED, 
+        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED,
             "associators() failed!");
     }
-    
+
     // cancel the provider
     provider.terminate();
 
@@ -1055,7 +1063,7 @@ void CIMOperationRequestDispatcher::handleAssociatorNamesRequest(
 
     try
     {
-        WMIMapperUserInfoContainer container = 
+        WMIMapperUserInfoContainer container =
             request->operationContext.get("WMIMapperUserInfoContainer");
 
         StatProviderTimeMeasurement providerTime(response.get());
@@ -1084,7 +1092,7 @@ void CIMOperationRequestDispatcher::handleAssociatorNamesRequest(
     }
     catch(...)
     {
-        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED, 
+        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED,
             "associatorNames() failed!");
     }
 
@@ -1111,7 +1119,7 @@ void CIMOperationRequestDispatcher::handleReferencesRequest(
 
     try
     {
-        WMIMapperUserInfoContainer container = 
+        WMIMapperUserInfoContainer container =
             request->operationContext.get("WMIMapperUserInfoContainer");
         CIMPropertyList propertyList(request->propertyList);
 
@@ -1144,10 +1152,10 @@ void CIMOperationRequestDispatcher::handleReferencesRequest(
     }
     catch(...)
     {
-        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED, 
+        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED,
             "references() failed!");
     }
-    
+
     // cancel the provider
     provider.terminate();
 
@@ -1171,7 +1179,7 @@ void CIMOperationRequestDispatcher::handleReferenceNamesRequest(
 
     try
     {
-        WMIMapperUserInfoContainer container = 
+        WMIMapperUserInfoContainer container =
             request->operationContext.get("WMIMapperUserInfoContainer");
 
         StatProviderTimeMeasurement providerTime(response.get());
@@ -1198,10 +1206,10 @@ void CIMOperationRequestDispatcher::handleReferenceNamesRequest(
     }
     catch(...)
     {
-        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED, 
+        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED,
             "referenceNames() failed!");
     }
-    
+
     // cancel the provider
     provider.terminate();
 
@@ -1225,7 +1233,7 @@ void CIMOperationRequestDispatcher::handleGetPropertyRequest(
 
     try
     {
-        WMIMapperUserInfoContainer container = 
+        WMIMapperUserInfoContainer container =
             request->operationContext.get("WMIMapperUserInfoContainer");
 
         StatProviderTimeMeasurement providerTime(response.get());
@@ -1251,7 +1259,7 @@ void CIMOperationRequestDispatcher::handleGetPropertyRequest(
     }
     catch(...)
     {
-        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED, 
+        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED,
             "getProperty() failed!");
     }
 
@@ -1273,9 +1281,13 @@ void CIMOperationRequestDispatcher::handleSetPropertyRequest(
         dynamic_cast<CIMSetPropertyResponseMessage *>(
             request->buildResponse()));
 
+    // corrects the type of an property. Set property xml do not have an
+    // place to specify the input property type. It could cause an
+    // type mismatch in the Object types. To solve it, the method,
+    // _fixSetPropertyValueType gets the correct type from Server side.
+
     WMIInstanceProvider provider;
 
-    /* 
     {
         CIMException cimException;
         try
@@ -1293,7 +1305,7 @@ void CIMOperationRequestDispatcher::handleSetPropertyRequest(
         }
         catch(...)
         {
-            response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED, 
+            response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED,
                 String::EMPTY);
         }
 
@@ -1305,11 +1317,11 @@ void CIMOperationRequestDispatcher::handleSetPropertyRequest(
             return;
         }
     }
-    */
+
 
     try
     {
-        WMIMapperUserInfoContainer container = 
+        WMIMapperUserInfoContainer container =
             request->operationContext.get("WMIMapperUserInfoContainer");
 
         StatProviderTimeMeasurement providerTime(response.get());
@@ -1336,7 +1348,7 @@ void CIMOperationRequestDispatcher::handleSetPropertyRequest(
     }
     catch(...)
     {
-        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED, 
+        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED,
             "setProperty() failed!");
     }
 
@@ -1362,7 +1374,7 @@ void CIMOperationRequestDispatcher::handleGetQualifierRequest(
 
     try
     {
-        WMIMapperUserInfoContainer container = 
+        WMIMapperUserInfoContainer container =
             request->operationContext.get("WMIMapperUserInfoContainer");
 
         StatProviderTimeMeasurement providerTime(response.get());
@@ -1387,7 +1399,7 @@ void CIMOperationRequestDispatcher::handleGetQualifierRequest(
     }
     catch(...)
     {
-        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED, 
+        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED,
             "getQualifier() failed!");
     }
 
@@ -1413,7 +1425,7 @@ void CIMOperationRequestDispatcher::handleSetQualifierRequest(
 
     try
     {
-        WMIMapperUserInfoContainer container = 
+        WMIMapperUserInfoContainer container =
             request->operationContext.get("WMIMapperUserInfoContainer");
 
         StatProviderTimeMeasurement providerTime(response.get());
@@ -1438,7 +1450,7 @@ void CIMOperationRequestDispatcher::handleSetQualifierRequest(
     }
     catch(...)
     {
-        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED, 
+        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED,
             "setQualifier() failed!");
     }
 
@@ -1464,7 +1476,7 @@ void CIMOperationRequestDispatcher::handleDeleteQualifierRequest(
 
     try
     {
-        WMIMapperUserInfoContainer container = 
+        WMIMapperUserInfoContainer container =
             request->operationContext.get("WMIMapperUserInfoContainer");
 
         StatProviderTimeMeasurement providerTime(response.get());
@@ -1489,7 +1501,7 @@ void CIMOperationRequestDispatcher::handleDeleteQualifierRequest(
     }
     catch(...)
     {
-        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED, 
+        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED,
             "deleteQualifier() failed!");
     }
 
@@ -1515,7 +1527,7 @@ void CIMOperationRequestDispatcher::handleEnumerateQualifiersRequest(
 
     try
     {
-        WMIMapperUserInfoContainer container = 
+        WMIMapperUserInfoContainer container =
             request->operationContext.get("WMIMapperUserInfoContainer");
 
         StatProviderTimeMeasurement providerTime(response.get());
@@ -1523,7 +1535,7 @@ void CIMOperationRequestDispatcher::handleEnumerateQualifiersRequest(
         provider.initialize();
 
         response->qualifierDeclarations = provider.enumerateQualifiers(
-            request->nameSpace.getString(),            
+            request->nameSpace.getString(),
             ((IdentityContainer) request->operationContext.get
                 (IdentityContainer::NAME)).getUserName(),
             container.getPassword());
@@ -1539,7 +1551,7 @@ void CIMOperationRequestDispatcher::handleEnumerateQualifiersRequest(
     }
     catch(...)
     {
-        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED, 
+        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED,
             "enumerateQualifiers() failed!");
     }
 
@@ -1565,7 +1577,7 @@ void CIMOperationRequestDispatcher::handleExecQueryRequest(
 
     try
     {
-        WMIMapperUserInfoContainer container = 
+        WMIMapperUserInfoContainer container =
             request->operationContext.get("WMIMapperUserInfoContainer");
 
         StatProviderTimeMeasurement providerTime(response.get());
@@ -1591,7 +1603,7 @@ void CIMOperationRequestDispatcher::handleExecQueryRequest(
     }
     catch(...)
     {
-        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED, 
+        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED,
             "execQuery() failed!");
     }
 
@@ -1630,7 +1642,7 @@ void CIMOperationRequestDispatcher::handleInvokeMethodRequest(
         }
         catch(...)
         {
-            response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED, 
+            response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED,
                 String::EMPTY);
         }
 
@@ -1648,7 +1660,7 @@ void CIMOperationRequestDispatcher::handleInvokeMethodRequest(
 
     try
     {
-        WMIMapperUserInfoContainer container = 
+        WMIMapperUserInfoContainer container =
             request->operationContext.get("WMIMapperUserInfoContainer");
 
         StatProviderTimeMeasurement providerTime(response.get());
@@ -1676,7 +1688,7 @@ void CIMOperationRequestDispatcher::handleInvokeMethodRequest(
     }
     catch(...)
     {
-        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED, 
+        response->cimException = PEGASUS_CIM_EXCEPTION(CIM_ERR_FAILED,
             "invokeMethod() failed!");
     }
 
@@ -1730,7 +1742,7 @@ CIMValue CIMOperationRequestDispatcher::_convertValueType(
         //
         try
         {
-            newValue = XmlReader::stringArrayToValue(0, 
+            newValue = XmlReader::stringArrayToValue(0,
                 constCharPtrArray, type);
         }
         catch (XmlSemanticError&)
@@ -1756,7 +1768,7 @@ CIMValue CIMOperationRequestDispatcher::_convertValueType(
 
         try
         {
-            newValue = XmlReader::stringToValue(0, 
+            newValue = XmlReader::stringToValue(0,
                 stringValue.getCString(), type);
         }
         catch (XmlSemanticError&)
@@ -1813,7 +1825,7 @@ void CIMOperationRequestDispatcher::_fixInvokeMethodParameterTypes(
 
                     provider.initialize();
 
-                    WMIMapperUserInfoContainer container = 
+                    WMIMapperUserInfoContainer container =
                         request->operationContext.get
                         ("WMIMapperUserInfoContainer");
 
@@ -1877,7 +1889,7 @@ void CIMOperationRequestDispatcher::_fixInvokeMethodParameterTypes(
 
                     if (inParameters[i].getValue().isNull())
                     {
-                        newValue.setNullValue(param.getType(), 
+                        newValue.setNullValue(param.getType(),
                             param.isArray());
                     }
                     else if (inParameters[i].getValue().isArray() !=
@@ -1930,7 +1942,7 @@ void CIMOperationRequestDispatcher::_fixSetPropertyValueType(
     CIMName propName = propertyName;
     propertyNames.append(propName);
 
-    CIMPropertyList propertyList = CIMPropertyList(propertyNames);    
+    CIMPropertyList propertyList = CIMPropertyList(propertyNames);
 
     CIMValue inValue = request->newValue;
 
@@ -1952,9 +1964,9 @@ void CIMOperationRequestDispatcher::_fixSetPropertyValueType(
 
     try
     {
-        WMIMapperUserInfoContainer container = 
+        WMIMapperUserInfoContainer container =
             request->operationContext.get("WMIMapperUserInfoContainer");
-        
+
         provider.initialize();
 
         cimClass = provider.getClass(
