@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
 //
-//==============================================================================
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -35,13 +33,33 @@
 #include <Pegasus/Common/FileSystem.h>
 #include "peg_slp_agent.h"
 
-#ifdef PEGASUS_USE_OPENSLP
+#ifdef PEGASUS_USE_EXTERNAL_SLP_TYPE
 #include <slp.h>
-#endif  /* PEGASUS_USE_OPENSLP */
+#endif  /* PEGASUS_USE_EXTERNAL_SLP_TYPE */
 
 PEGASUS_USING_STD;
 PEGASUS_NAMESPACE_BEGIN
 
+// The Solaris version of  external SLP requires the locale parameter to be set.
+// OpenSLP allows NULL so that it can select the locale.
+
+#ifdef PEGASUS_USE_EXTERNAL_SLP_TYPE
+// language typing for slp call only applies to SOLARIS
+#ifdef PEGASUS_OS_SOLARIS
+        // If 2 (i.e. solarisslp). Set language.
+#if     PEGASUS_USE_EXTERNAL_SLP_TYPE == 2
+        const char* slp_service_agent::slp_lang = "en";
+        // if 1, openslp and let slp set language
+#elif PEGASUS_USE_EXTERNAL_SLP_TYPE == 1
+    _   const char* slp_service_agent::slp_lang = NULL;
+#else   // Some other implementation
+        const char* slp_service_agent::slp_lang = NULL;
+#endif  // End PEGASUS_USE_EXTERNAL_SLP_TYPE
+#else   // NOT PEGASUS_OS_SOLARIS
+    const char* slp_service_agent::slp_lang = NULL;
+#endif
+#endif  // PEGASUS_USE_EXTERNAL_SLP_TYPE
+
 class sa_reg_params
 {
 public:
@@ -118,7 +136,7 @@ sa_reg_params::~sa_reg_params()
     }
 }
 
-#ifdef PEGASUS_USE_OPENSLP
+#ifdef PEGASUS_USE_EXTERNAL_SLP_TYPE
 void SLPRegCallback(SLPHandle slp_handle, SLPError errcode, void* cookie)
 {
     /* return the error code in the cookie */
@@ -132,12 +150,15 @@ void SLPRegCallback(SLPHandle slp_handle, SLPError errcode, void* cookie)
         reading slp packets from the wire.
     */
 }
-#endif /* PEGASUS_USE_OPENSLP */
+#endif /* PEGASUS_USE_EXTERNAL_SLP_TYPE */
 
 
 slp_service_agent::slp_service_agent()
    : _listen_thread(service_listener, this, false),
    _initialized(0)
+#ifdef PEGASUS_SLP_REG_TIMEOUT
+   ,_update_reg_semaphore(0)
+#endif
 {
     try
     {
@@ -154,7 +175,11 @@ slp_service_agent::slp_service_agent()
             427,
             "DSA",
             "DEFAULT",
+#ifdef PEGASUS_SLP_REG_TIMEOUT
+            FALSE,
+#else
             TRUE,
+#endif
             FALSE,
             "service:wbem");
     }
@@ -169,6 +194,10 @@ slp_service_agent::slp_service_agent(
     const char* srv_type)
     : _listen_thread(service_listener, this, false),
     _initialized(0)
+#ifdef PEGASUS_SLP_REG_TIMEOUT
+   ,_update_reg_semaphore(0)
+#endif
+
 {
 
     try
@@ -209,6 +238,7 @@ void slp_service_agent::_init()
 {
     _initialized = 0;
 
+
     String libraryFileName;
 
 #if defined(PEGASUS_OS_ZOS)
@@ -331,11 +361,11 @@ Boolean slp_service_agent::srv_register(
 
     _internal_regs.insert(url, rp);
 
-#ifdef PEGASUS_USE_OPENSLP
+#if defined(PEGASUS_USE_EXTERNAL_SLP_TYPE) && !defined(PEGASUS_SLP_REG_TIMEOUT)
     SLPHandle slp_handle = 0;
     SLPError  slpErr = SLP_OK;
     SLPError  callbackErr = SLP_OK;
-    if ((slpErr = SLPOpen(NULL, SLP_FALSE, &slp_handle)) == SLP_OK)
+    if ((slpErr = SLPOpen(slp_lang, SLP_FALSE, &slp_handle)) == SLP_OK)
     {
         slpErr = SLPReg(
             slp_handle,
@@ -357,11 +387,23 @@ Boolean slp_service_agent::srv_register(
     {
         return false;
     }
-#endif /* PEGASUS_USE_OPENSLP */
+#endif /* PEGASUS_USE_EXTERNAL_SLP_TYPE */
 
     return true;
 }
 
+#ifdef PEGASUS_SLP_REG_TIMEOUT
+Semaphore& slp_service_agent::get_update_reg_semaphore()
+{
+    return _update_reg_semaphore;
+}
+#else
+void slp_service_agent::update_reg_count()
+{
+    _update_reg_count++;
+}
+#endif
+
 void slp_service_agent::unregister()
 {
     if (_initialized.get() == 0 )
@@ -369,19 +411,23 @@ void slp_service_agent::unregister()
         throw UninitializedObjectException();
     }
 
-#ifndef PEGASUS_USE_OPENSLP
+#ifndef PEGASUS_USE_EXTERNAL_SLP_TYPE
     _should_listen = 0;
+#ifdef PEGASUS_SLP_REG_TIMEOUT
+    _update_reg_semaphore.signal();
+#endif
     _listen_thread.join();
-#endif  /* PEGASUS_USE_OPENSLP */
+#endif  /* PEGASUS_USE_EXTERNAL_SLP_TYPE */
 
     while (slp_reg_table::Iterator i = _internal_regs.start())
     {
         sa_reg_params *rp = i.value();
-#ifdef PEGASUS_USE_OPENSLP
+#ifdef PEGASUS_USE_EXTERNAL_SLP_TYPE
         SLPHandle slp_handle = 0;
         SLPError slpErr = SLP_OK;
         SLPError callbackErr=SLP_OK;
-        if ((slpErr = SLPOpen(NULL, SLP_FALSE, &slp_handle)) == SLP_OK)
+
+        if ((slpErr = SLPOpen(slp_lang, SLP_FALSE, &slp_handle)) == SLP_OK)
         {
             slpErr = SLPDereg(
                 slp_handle,
@@ -405,7 +451,18 @@ void slp_service_agent::unregister()
             */
             continue;
         }
-#endif  /* PEGASUS_USE_OPENSLP */
+#elif PEGASUS_SLP_REG_TIMEOUT
+        // Unregister with external SLP SA.
+        sa_reg_params *p;
+
+        _internal_regs.lookup(rp->url, p);
+        _rep->srv_reg_local(_rep,
+                            (const char*)p->url,
+                            (const char*)p->attrs,
+                            (const char*)p->type,
+                            p->scopes,
+                            0);
+#endif
 
         _internal_regs.remove(rp->url);
         delete rp;
@@ -464,19 +521,26 @@ void slp_service_agent::start_listener()
     {
         throw UninitializedObjectException();
     }
-#ifndef PEGASUS_USE_OPENSLP
+#ifndef PEGASUS_USE_EXTERNAL_SLP_TYPE
     _using_das = _find_das(_rep, NULL, "DEFAULT");
 
     _should_listen = 1;
     _listen_thread.run();
-#endif /* PEGASUS_USE_OPENSLP */
+#endif /* PEGASUS_USE_EXTERNAL_SLP_TYPE */
 
 }
 
+
+void slp_service_agent::set_registration_callback(void (*ptr)())
+{
+    update_registrations = ptr;
+}
+
 ThreadReturnType
 PEGASUS_THREAD_CDECL slp_service_agent::service_listener(void *parm)
 {
-#ifndef PEGASUS_USE_OPENSLP
+#if !defined(PEGASUS_USE_EXTERNAL_SLP_TYPE) ||  \
+    (defined(PEGASUS_USE_EXTERNAL_SLP_TYPE) && defined(PEGASUS_SLP_REG_TIMEOUT))
     Thread *myself = (Thread *)parm;
     if (myself == 0)
     {
@@ -486,16 +550,51 @@ PEGASUS_THREAD_CDECL slp_service_agent::service_listener(void *parm)
 
     lslpMsg msg_list;
 
+#ifdef PEGASUS_SLP_REG_TIMEOUT
+    Uint16 life = PEGASUS_SLP_REG_TIMEOUT * 60;
+#endif
     while (agent->_should_listen.get())
     {
         Uint32 now, msec;
         System::getCurrentTime(now, msec);
+
         // now register everything
         for (slp_reg_table::Iterator i = agent->_internal_regs.start();
             i ; i++)
         {
             sa_reg_params *rp = i.value();
 
+#ifdef PEGASUS_USE_EXTERNAL_SLP_TYPE
+            SLPHandle slp_handle = 0;
+            SLPError slpErr = SLP_OK;
+            SLPError callbackErr=SLP_OK;
+            if ((slpErr = SLPOpen(slp_lang, SLP_FALSE, &slp_handle))
+                == SLP_OK)
+            {
+                slpErr = SLPReg(
+                    slp_handle,
+                    rp->url,
+                    life,
+                    rp->type,
+                    rp->attrs,
+                    SLP_TRUE,
+                    SLPRegCallback,
+                    &callbackErr);
+                SLPClose(slp_handle);
+            }
+            else
+            {
+                // ATTN: Could not get SLP handle,
+                // we try again when lifetime expires.
+            }
+#elif PEGASUS_SLP_REG_TIMEOUT
+            agent->_rep->srv_reg_local(agent->_rep,
+                                       rp->url,
+                                       rp->attrs,
+                                       rp->type,
+                                       rp->scopes,
+                                       life);
+#else
             if(rp->expire == 0 || rp->expire < now - 1)
             {
                 rp->expire = now + rp->lifetime;
@@ -521,13 +620,39 @@ PEGASUS_THREAD_CDECL slp_service_agent::service_listener(void *parm)
                         rp->lifetime);
                 }
             }
+#endif
         }
+
+#ifdef PEGASUS_SLP_REG_TIMEOUT
+        Uint32 waitTime = life * 1000;
+        try
+        {
+            if (!agent->_update_reg_semaphore.time_wait(waitTime))
+            {
+                // PEGASUS_SLP_REG_TIMEOUT expired, re-register with
+                // external SLP SA.
+            }
+            // semaphore is signalled means we have to update registrations.
+            else if (agent->_should_listen.get())
+            {
+                agent->update_registrations();
+            }
+        }
+        catch(...)
+        {
+        }
+#else
         agent->_rep->service_listener(agent->_rep, 0, &msg_list);
         _LSLP_SLEEP(1);
+        if (agent->_update_reg_count.get() && agent->_should_listen.get())
+        {
+            agent->update_registrations();
+            agent->_update_reg_count--;
+        }
+#endif
     }
-    myself->exit_self((ThreadReturnType) 0);
-#endif /* PEGASUS_USE_OPENSLP */
-    return(0);
+#endif /* PEGASUS_USE_EXTERNAL_SLP_TYPE */
+    return ThreadReturnType(0);
 }
 
 PEGASUS_NAMESPACE_END
