@@ -1,33 +1,31 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
 //
-//=============================================================================
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 
 //NOCHKSRC
 
@@ -135,7 +133,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 67 "url.y"
+#line 63 "url.y"
 
 
 #include "slp_client.h"
@@ -143,9 +141,9 @@
 
 
 /* prototypes and globals go here */
-void urlerror(char *, ...);
+void urlerror(const char *, ...);
 int32 urlwrap(void);
-int32 urllex(void);   
+int32 urllex(void);
 int32 urlparse(void);
 void url_close_lexer(uint32 handle);
 size_t url_init_lexer(const char *s);
@@ -156,7 +154,7 @@ static lslpAtomList siteHead = {&siteHead, &siteHead, TRUE, NULL, 0};
 static lslpAtomList pathHead = {&pathHead, &pathHead, TRUE, NULL, 0};
 static lslpAtomList attrHead = {&attrHead, &attrHead, TRUE, NULL, 0};
 
-lslpAtomizedURL urlHead = 
+lslpAtomizedURL urlHead =
 {
     &urlHead,
     &urlHead,
@@ -191,14 +189,14 @@ lslpAtomizedURL urlHead =
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 105 "url.y"
+#line 101 "url.y"
 {
 	int32 _i;
 	char *_s;
 	lslpAtomList *_atl;
 	lslpAtomizedURL *_aturl;
 }
-/* Line 193 of yacc.c.  */
+/* Line 187 of yacc.c.  */
 #line 170 "y_url.c"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
@@ -507,10 +505,10 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   125,   125,   219,   227,   236,   254,   276,   283,   292,
-     305,   318,   332,   350,   353,   362,   373,   378,   383,   396,
-     402,   417,   420,   425,   428,   431,   436,   443,   453,   457,
-     475,   492,   510,   517,   526,   543
+       0,   121,   121,   215,   223,   232,   250,   272,   279,   288,
+     301,   314,   328,   346,   349,   358,   369,   374,   379,   392,
+     398,   413,   416,   421,   424,   427,   432,   439,   449,   453,
+     471,   488,   506,   513,   522,   539
 };
 #endif
 
@@ -1443,7 +1441,7 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 125 "url.y"
+#line 121 "url.y"
     {
 			if (NULL != ((yyval._aturl) = (lslpAtomizedURL *)calloc(1, sizeof(lslpAtomizedURL))))
 			{
@@ -1540,7 +1538,7 @@ yyreduce:
     break;
 
   case 3:
-#line 219 "url.y"
+#line 215 "url.y"
     {
 			(yyval._atl) = &srvcHead;
 			if ((yyvsp[(1) - (1)]._atl) != NULL)
@@ -1551,7 +1549,7 @@ yyreduce:
     break;
 
   case 4:
-#line 227 "url.y"
+#line 223 "url.y"
     {
 			(yyval._atl) = &srvcHead;
 			if ((yyvsp[(2) - (2)]._atl) != NULL)
@@ -1562,7 +1560,7 @@ yyreduce:
     break;
 
   case 5:
-#line 236 "url.y"
+#line 232 "url.y"
     {
 			if (NULL != ((yyval._atl) = (lslpAtomList *)calloc(1, sizeof(lslpAtomList))))
 			{
@@ -1584,7 +1582,7 @@ yyreduce:
     break;
 
   case 6:
-#line 254 "url.y"
+#line 250 "url.y"
     {
 			if (NULL != ((yyval._atl) = (lslpAtomList *)calloc(1, sizeof(lslpAtomList))))
 			{
@@ -1608,7 +1606,7 @@ yyreduce:
     break;
 
   case 7:
-#line 276 "url.y"
+#line 272 "url.y"
     {
 			(yyval._atl) = &siteHead;
 			if ((yyvsp[(1) - (1)]._atl) != NULL)
@@ -1619,7 +1617,7 @@ yyreduce:
     break;
 
   case 8:
-#line 283 "url.y"
+#line 279 "url.y"
     {
 			(yyval._atl) = &siteHead;
 			if ((yyvsp[(1) - (2)]._atl) != NULL)
@@ -1630,7 +1628,7 @@ yyreduce:
     break;
 
   case 9:
-#line 292 "url.y"
+#line 288 "url.y"
     {
 			if ((yyvsp[(1) - (1)]._s) != NULL)
 			{
@@ -1647,7 +1645,7 @@ yyreduce:
     break;
 
   case 10:
-#line 305 "url.y"
+#line 301 "url.y"
     {
 			if ((yyvsp[(1) - (1)]._s) != NULL)
 			{
@@ -1664,7 +1662,7 @@ yyreduce:
     break;
 
   case 11:
-#line 318 "url.y"
+#line 314 "url.y"
     {
 			if ((yyvsp[(1) - (1)]._s) != NULL)
 			{
@@ -1681,9 +1679,9 @@ yyreduce:
     break;
 
   case 12:
-#line 332 "url.y"
+#line 328 "url.y"
     {
-  
+
 			if ((yyvsp[(1) - (1)]._s) != NULL)
 			{
 				if(NULL != ((yyval._atl) = (lslpAtomList *)calloc(1, sizeof(lslpAtomList))))
@@ -1695,19 +1693,19 @@ yyreduce:
 			}
 			else
 				(yyval._atl) = NULL;
-  
+
 ;}
     break;
 
   case 13:
-#line 350 "url.y"
+#line 346 "url.y"
     {
 			(yyval._s) = strdup("//");
 		;}
     break;
 
   case 14:
-#line 353 "url.y"
+#line 349 "url.y"
     {
 			if(NULL != (yyvsp[(3) - (3)]._s) && (NULL !=((yyval._s) = (char *)calloc(3 + strlen((yyvsp[(3) - (3)]._s)), sizeof(char)))))
 			{
@@ -1720,7 +1718,7 @@ yyreduce:
     break;
 
   case 15:
-#line 362 "url.y"
+#line 358 "url.y"
     {
 			if(NULL != (yyvsp[(5) - (5)]._s) && (NULL !=((yyval._s) = (char *)calloc(4 + strlen((yyvsp[(3) - (5)]._s)) + strlen((yyvsp[(5) - (5)]._s)), sizeof(char)))))
 			{
@@ -1733,21 +1731,21 @@ yyreduce:
     break;
 
   case 16:
-#line 373 "url.y"
+#line 369 "url.y"
     {
 	  (yyval._s) = strdup((yyvsp[(1) - (1)]._s));
 	;}
     break;
 
   case 17:
-#line 378 "url.y"
+#line 374 "url.y"
     {
 			(yyval._s) = (yyvsp[(1) - (1)]._s);
 		;}
     break;
 
   case 18:
-#line 383 "url.y"
+#line 379 "url.y"
     {
 			if(NULL != ((yyval._s) = (char *)calloc(strlen((yyvsp[(1) - (6)]._s)) + strlen((yyvsp[(2) - (6)]._s)) + strlen((yyvsp[(4) - (6)]._s)) + strlen((yyvsp[(6) - (6)]._s)) + 3, sizeof(char))))
 			{
@@ -1762,7 +1760,7 @@ yyreduce:
     break;
 
   case 19:
-#line 396 "url.y"
+#line 392 "url.y"
     {
                         if (NULL != ((yyval._s) = (char *)calloc(strlen((yyvsp[(1) - (1)]._s)) + 2, sizeof(char))))
                         {
@@ -1772,7 +1770,7 @@ yyreduce:
     break;
 
   case 20:
-#line 402 "url.y"
+#line 398 "url.y"
     {
 			if ((yyvsp[(1) - (3)]._s) != NULL)
 			{
@@ -1789,42 +1787,42 @@ yyreduce:
     break;
 
   case 21:
-#line 417 "url.y"
+#line 413 "url.y"
     {
 			(yyval._s) = (yyvsp[(1) - (1)]._s);
 		;}
     break;
 
   case 22:
-#line 420 "url.y"
+#line 416 "url.y"
     {
 			(yyval._s) = (yyvsp[(1) - (1)]._s);
 		;}
     break;
 
   case 23:
-#line 425 "url.y"
+#line 421 "url.y"
     {
 			;	
 		;}
     break;
 
   case 24:
-#line 428 "url.y"
+#line 424 "url.y"
     {
 			;		
 		;}
     break;
 
   case 25:
-#line 431 "url.y"
+#line 427 "url.y"
     {
 			;
 		;}
     break;
 
   case 26:
-#line 436 "url.y"
+#line 432 "url.y"
     {
 			(yyval._atl) = &pathHead;
 			if ((yyvsp[(1) - (1)]._atl) != NULL)
@@ -1835,7 +1833,7 @@ yyreduce:
     break;
 
   case 27:
-#line 443 "url.y"
+#line 439 "url.y"
     {
 			(yyval._atl) = &pathHead;
 			if ((yyvsp[(2) - (2)]._atl) != NULL)
@@ -1846,7 +1844,7 @@ yyreduce:
     break;
 
   case 28:
-#line 453 "url.y"
+#line 449 "url.y"
     {
 			 /* dangling path slash - do nothing */
 			 (yyval._atl) = NULL;
@@ -1854,7 +1852,7 @@ yyreduce:
     break;
 
   case 29:
-#line 457 "url.y"
+#line 453 "url.y"
     {
 			if(NULL != ((yyval._atl) = (lslpAtomList *)calloc(1, sizeof(lslpAtomList))))
 			{
@@ -1876,7 +1874,7 @@ yyreduce:
     break;
 
   case 30:
-#line 475 "url.y"
+#line 471 "url.y"
     {
 			if(NULL != ((yyval._atl) = (lslpAtomList *)calloc(1, sizeof(lslpAtomList))))
 			{
@@ -1897,7 +1895,7 @@ yyreduce:
     break;
 
   case 31:
-#line 492 "url.y"
+#line 488 "url.y"
     {
 			if(NULL != ((yyval._atl) = (lslpAtomList *)calloc(1, sizeof(lslpAtomList))))
 			{
@@ -1917,7 +1915,7 @@ yyreduce:
     break;
 
   case 32:
-#line 510 "url.y"
+#line 506 "url.y"
     {
 			(yyval._atl) = &attrHead;
 			if ((yyvsp[(1) - (1)]._atl) != NULL)
@@ -1928,7 +1926,7 @@ yyreduce:
     break;
 
   case 33:
-#line 517 "url.y"
+#line 513 "url.y"
     {
 			(yyval._atl) = &attrHead;
 			if ((yyvsp[(2) - (2)]._atl) != NULL)
@@ -1939,7 +1937,7 @@ yyreduce:
     break;
 
   case 34:
-#line 526 "url.y"
+#line 522 "url.y"
     {
 			if(NULL != ((yyval._atl) = (lslpAtomList *)calloc(1, sizeof(lslpAtomList))))
 			{
@@ -1959,7 +1957,7 @@ yyreduce:
     break;
 
   case 35:
-#line 543 "url.y"
+#line 539 "url.y"
     {
 			if(NULL != ((yyval._atl) = (lslpAtomList *)calloc(1, sizeof(lslpAtomList))))
 			{
@@ -2196,8 +2194,8 @@ yyreturn:
 }
 
 
-#line 563 "url.y"
- 
+#line 559 "url.y"
+
 
 
 lslpAtomList *lslpAllocAtom(void)
@@ -2212,7 +2210,7 @@ lslpAtomList *lslpAllocAtom(void)
 
 lslpAtomList *lslpAllocAtomList(void)
 {
-	lslpAtomList *temp =lslpAllocAtom(); 
+	lslpAtomList *temp =lslpAllocAtom();
 	if (temp != NULL)
 		temp->isHead = TRUE;
 	return(temp);
@@ -2236,7 +2234,7 @@ void lslpFreeAtomList(lslpAtomList *l, int32 flag)
 	{
 		temp = l->next;
 		temp->prev->next = temp->next;
-		temp->next->prev = temp->prev; 
+		temp->next->prev = temp->prev;
 		lslpFreeAtom(temp);
 	}
 	if (flag)
@@ -2317,7 +2315,7 @@ void lslpInitURLList(void)
 
 void lslpCleanUpURLLists(void)
 {
-  
+
   lslpFreeAtomList(&srvcHead, 0);
   lslpFreeAtomList(&siteHead, 0);
   lslpFreeAtomList(&pathHead, 0);
@@ -2328,13 +2326,13 @@ void lslpCleanUpURLLists(void)
 lslpAtomizedURL *_lslpDecodeURLs(char *u[], int32 count)
 {
   int32 i;
-  
+
   uint32 lexer = 0;
   lslpAtomizedURL *temp = NULL;
   assert(u != NULL && u[count - 1] != NULL);
   lslpInitURLList();
   lslpInitAtomLists();
-  
+
   for (i = 0; i < count; i++) {
     if (NULL == u[i])
       break;
@@ -2349,8 +2347,8 @@ lslpAtomizedURL *_lslpDecodeURLs(char *u[], int32 count)
       _LSLP_LINK_HEAD(temp, &urlHead);
     }
   }
-  
+
   return(temp);	
-}	 
+}	
 
 
