@@ -1,37 +1,35 @@
-//%2006////////////////////////////////////////////////////////////////////////
+//%LICENSE////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
-// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
-// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation, The Open Group.
-// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
-// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; VERITAS Software Corporation; The Open Group.
-// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
-// EMC Corporation; Symantec Corporation; The Open Group.
+// Licensed to The Open Group (TOG) under one or more contributor license
+// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
+// this work for additional information regarding copyright ownership.
+// Each contributor licenses this file to you under the OpenPegasus Open
+// Source License; you may not use this file except in compliance with the
+// License.
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-// 
-// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
-// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
-// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
-// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the "Software"),
+// to deal in the Software without restriction, including without limitation
+// the rights to use, copy, modify, merge, publish, distribute, sublicense,
+// and/or sell copies of the Software, and to permit persons to whom the
+// Software is furnished to do so, subject to the following conditions:
 //
-//==============================================================================
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+//
+//////////////////////////////////////////////////////////////////////////
 //
 // Author:  Aruran, IBM (aruran.shanmug@in.ibm.com)
 //
-// Modified By: 
+// Modified By:
 //
 //%/////////////////////////////////////////////////////////////////////////////
 
@@ -44,7 +42,7 @@ Boolean verboseTest = false;
 
 Boolean quit = false;
 Boolean nextCheck = false;
-int status = CLIENT_UNKNOWN;
+int globalStatus = CLIENT_UNKNOWN;
 char clientName[] = "ModelWalkStressClient";
 
 String errorInfo;
@@ -67,7 +65,7 @@ class TestModelWalkStressClient:public TestStressTestClient
 /**
     GetNameSpaces
     If no nameSpace is supplied on the command line, this method looks into
-    the root and test nameSpaces for the _Namespace class. The names of the 
+    the root and test nameSpaces for the _Namespace class. The names of the
     instances of that class are retrued by this method.
 */
 Array<CIMNamespaceName> getNameSpaces(
@@ -107,7 +105,7 @@ Array<CIMNamespaceName> getNameSpaces(
         Uint32 end = topNamespaceNames.size();
 
         //
-        // for all new elements in the output array. 
+        // for all new elements in the output array.
         //
         for (Uint32 range = start; range < end; range ++)
         {
@@ -226,11 +224,11 @@ static void enumerateAllQualifiers(
 /**
     EnumerateReferenceNames
     This method enumerates the references to each instance in the array
-    "cimInstances" for the "nameSpace" 
+    "cimInstances" for the "nameSpace"
 */
 static void enumerateReferenceNames(
     TestModelWalkStressClient &tmsc,
-    CIMClient* client, 
+    CIMClient* client,
     Array<CIMInstance> cimNInstances,
     CIMNamespaceName nameSpace,
     CIMName referenceClass,
@@ -286,7 +284,7 @@ static void enumerateReferenceNames(
 /**
     EnumerateAssociatorNames
     This method enumerates the associators to each instance in the array
-    "cimInstances" for the "nameSpace" 
+    "cimInstances" for the "nameSpace"
 */
 static void enumerateAssociatorNames(
     TestModelWalkStressClient &tmsc,
@@ -347,13 +345,13 @@ static void enumerateAssociatorNames(
 }
 /**
     EnumerateInstanceRelatedInfo
-    This method enumerates instances, referances (by way of subrotine) and 
-    associators (by way of subrotine.Exceptions are caught, modified and 
+    This method enumerates instances, referances (by way of subrotine) and
+    associators (by way of subrotine.Exceptions are caught, modified and
     re-thrown so that generic exception handling can be used in Main
 */
 static void enumerateInstanceRelatedInfo(
     TestModelWalkStressClient &tmsc,
-    CIMClient *client, 
+    CIMClient *client,
     Array<CIMName> classNames,
     CIMNamespaceName nameSpace,
     pid_t clientPid,
@@ -432,7 +430,7 @@ static void enumerateInstanceRelatedInfo(
 }
 /**
     EnumerateClassRelatedInfo
-    This method enumerates classes and instances (by way of subrotine)  
+    This method enumerates classes and instances (by way of subrotine)
 */
 static void enumerateClassRelatedInfo(
     TestModelWalkStressClient &tmsc,
@@ -498,7 +496,7 @@ int main(int argc, char** argv)
     Uint32 cOptionCount =  0;
 
     //
-    // Variables need to connect to server. 
+    // Variables need to connect to server.
     //
     Boolean useSSL;
     String host;
@@ -519,7 +517,7 @@ int main(int argc, char** argv)
     char pid_str[15];
 
     //
-    // Number of times the command succeeded. 
+    // Number of times the command succeeded.
     //
     Uint32 successCount=0;
 
@@ -546,7 +544,7 @@ int main(int argc, char** argv)
         //
         // client specific options if any.
         //
-        struct OptionRow *cOptionTable = 0; 
+        struct OptionRow *cOptionTable = 0;
         newOptionsCount = cOptionCount;
 
         try
@@ -555,7 +553,7 @@ int main(int argc, char** argv)
             // Generate new option table for this client using
             // the OptionManager.
             //
-            
+
             newOptionsTable = tmsc.generateClientOptions(cOptionTable,
                 cOptionCount,newOptionsCount);
             validArg = tmsc.GetOptions(om, argc, argv, newOptionsTable,
@@ -591,7 +589,7 @@ int main(int argc, char** argv)
         {
             sscanf (portStr.getCString (), "%u", &portNumber);
         }
-        
+
         //
         // Setting default ports.
         //
@@ -666,7 +664,7 @@ int main(int argc, char** argv)
         //
         tmsc.startTime();
 
-        tmsc.logInfo(clientId, clientPid, status, pidFile);
+        tmsc.logInfo(clientId, clientPid, globalStatus, pidFile);
 
         //
         // connect the client.
@@ -691,7 +689,7 @@ int main(int argc, char** argv)
                 if (verboseTest)
                 {
                     String mes("Ending client. ");
-                    tmsc.errorLog(clientPid, clientLog, mes); 
+                    tmsc.errorLog(clientPid, clientLog, mes);
                 }
                 break;
             }
@@ -700,7 +698,7 @@ int main(int argc, char** argv)
                 {
 #ifdef PEGASUS_OS_TYPE_WINDOWS
                     freopen("nul","w",stdout);
-#else 
+#else
                     freopen("/dev/null","w",stdout);
 #endif
                 }
@@ -712,43 +710,43 @@ int main(int argc, char** argv)
                     tmsc.connectClient( client, host, portNumber, userName,
                         password, useSSL, timeout, verboseTest);
                     connectedToHost = true;
-                    
+
                    //
                    // Client has successfully connected to server.
                    // update status if previously not Success.
                    //
-                   if (status != CLIENT_PASS)
+                   if (globalStatus != CLIENT_PASS)
                    {
-                       status = CLIENT_PASS;
-                       tmsc.logInfo(clientId, clientPid, status, pidFile);
+                       globalStatus = CLIENT_PASS;
+                       tmsc.logInfo(clientId, clientPid, globalStatus, pidFile);
                    }
                 }
                 catch (CannotConnectException)
                 {
-                    status = CLIENT_UNKNOWN;
-                    tmsc.logInfo(clientId, clientPid, status, pidFile);
+                    globalStatus = CLIENT_UNKNOWN;
+                    tmsc.logInfo(clientId, clientPid, globalStatus, pidFile);
                     connectedToHost = false;
                 }
                 catch (CIMException &e)
                 {
-                    status = CLIENT_UNKNOWN;
-                    tmsc.logInfo(clientId, clientPid, status, pidFile);
+                    globalStatus = CLIENT_UNKNOWN;
+                    tmsc.logInfo(clientId, clientPid, globalStatus, pidFile);
                     connectedToHost = false;
                     String mes(e.getMessage());
                     tmsc.errorLog(clientPid, clientLog, mes);
                 }
                 catch (Exception &e)
                 {
-                    status = CLIENT_UNKNOWN;
-                    tmsc.logInfo(clientId, clientPid, status, pidFile);
+                    globalStatus = CLIENT_UNKNOWN;
+                    tmsc.logInfo(clientId, clientPid, globalStatus, pidFile);
                     connectedToHost = false;
                     String mes(e.getMessage());
                     tmsc.errorLog(clientPid, clientLog, mes);
                 }
                 catch (...)
                 {
-                    status = CLIENT_UNKNOWN;
-                    tmsc.logInfo(clientId, clientPid, status, pidFile);
+                    globalStatus = CLIENT_UNKNOWN;
+                    tmsc.logInfo(clientId, clientPid, globalStatus, pidFile);
                     connectedToHost = false;
                     String mes("Error connencting to server in ModleWalk");
                     mes.append(" client ");
@@ -773,7 +771,7 @@ int main(int argc, char** argv)
                                           clientPid,
                                           clientLog,
                                           clientId,
-                                          status,
+                                          globalStatus,
                                           pidFile);
 
                     //
@@ -781,12 +779,12 @@ int main(int argc, char** argv)
                     //
                     enumerateAllQualifiers(
                         tmsc,
-                        client, 
+                        client,
                         nameSpacesArray,
                         clientPid,
                         clientLog,
                         clientId,
-                        status,
+                        globalStatus,
                         pidFile);
 
                     //
@@ -800,7 +798,7 @@ int main(int argc, char** argv)
                         clientPid,
                         clientLog,
                         clientId,
-                        status,
+                        globalStatus,
                         pidFile);
 
                     successCount++;
@@ -810,31 +808,31 @@ int main(int argc, char** argv)
                 // the connenction was lost. We then connect on the next time
                 // through the loop.
                 //
-                
+
                 catch (CannotConnectException)
                 {
-                    status = CLIENT_UNKNOWN;
-                    tmsc.logInfo(clientId, clientPid, status, pidFile);
+                    globalStatus = CLIENT_UNKNOWN;
+                    tmsc.logInfo(clientId, clientPid, globalStatus, pidFile);
                     connectedToHost = false;
                 }
                 catch (CIMException &cimE)
                 {
-                    status = CLIENT_FAIL;
-                    tmsc.logInfo(clientId, clientPid, status, pidFile);
+                    globalStatus = CLIENT_FAIL;
+                    tmsc.logInfo(clientId, clientPid, globalStatus, pidFile);
                     String mes(cimE.getMessage());
                     tmsc.errorLog(clientPid, clientLog, mes);
                 }
                 catch (Exception &exp)
                 {
-                    status = CLIENT_FAIL;
-                    tmsc.logInfo(clientId, clientPid, status, pidFile);
+                    globalStatus = CLIENT_FAIL;
+                    tmsc.logInfo(clientId, clientPid, globalStatus, pidFile);
                     String mes(exp.getMessage());
                     tmsc.errorLog(clientPid, clientLog, mes);
                 }
                 catch (...)
                 {
-                    status = CLIENT_FAIL;
-                    tmsc.logInfo(clientId, clientPid, status, pidFile);
+                    globalStatus = CLIENT_FAIL;
+                    tmsc.logInfo(clientId, clientPid, globalStatus, pidFile);
                     String mes("Unknown Error during ModelWalk Execution");
                     tmsc.errorLog(clientPid, clientLog, mes);
                 }
@@ -842,7 +840,7 @@ int main(int argc, char** argv)
                 nextCheck = tmsc.checkTime();
                 if (nextCheck)
                 {
-                    tmsc.logInfo(clientId, clientPid, status, pidFile);
+                    tmsc.logInfo(clientId, clientPid, globalStatus, pidFile);
                     nextCheck = false;
                 }
 
@@ -856,8 +854,8 @@ int main(int argc, char** argv)
                     if (iteration == 100)
                     {
                         tmsc.logErrorPercentage(
-                            successCount, 
-                            totalCount, 
+                            successCount,
+                            totalCount,
                             clientPid,
                             clientLog,
                             clientName);
@@ -913,11 +911,11 @@ int main(int argc, char** argv)
     if (FileSystem::exists(stopClient))
     {
         //
-        // Remove STOP file here. 
+        // Remove STOP file here.
         //
         FileSystem::removeFile(stopClient);
     }
-   
+
     if (verboseTest)
     {
         errorInfo.clear();
